package com.ejie.ab60.comun;

import java.util.ArrayList;
import java.util.List;
import java.util.Vector;

import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;

import com.ejie.ab60.model.procedimientos.Procedimientos;

public abstract class SeguridadAplicacion {

	/**
	 * 
	 */
	public static String ROLE_ADMINISTRADOR = "ROLE_AB60-IN-0001";
	public static String ROLE_RESPONSABLE_TURISMO = "ROLE_AB60-IN-0002";
	public static String ROLE_TECNICO_TURISMO = "ROLE_AB60-IN-0003";
	public static String ROLE_RESPONSABLE_COMERCIO = "ROLE_AB60-IN-0004";
	public static String ROLE_TECNICO_COMERCIO = "ROLE_AB60-IN-0005";
	public static String ROLE_RESPONSABLE_CONSUMO = "ROLE_AB60-IN-0006";
	public static String ROLE_TECNICO_CONSUMO = "ROLE_AB60-IN-0007";

	/**
	 * 
	 */
	private static final long serialVersionUID = 7601398309596598460L;

	public SeguridadAplicacion() {

	}

	/**
	 * 
	 * @param authentication
	 *            org.springframework.security.core.Authentication
	 * @return Vector<String> con los roles del usuario
	 */
	public static Vector<String> getRolesUsuario(Authentication authentication) {
		List<GrantedAuthority> list = new ArrayList<GrantedAuthority>(authentication.getAuthorities());
		Vector<String> vecPermisos = new Vector<String>();

		for (GrantedAuthority grantedAuthority : list) {
			vecPermisos.add(grantedAuthority.getAuthority());
		}

		return vecPermisos;
	}

	/**
	 * 
	 * @param authentication
	 *            org.springframework.security.core.Authentication
	 * @param procedimientos
	 *            Procedimientos
	 * @return boolean para indicar si tiene acceso o no al procedimiento
	 */
	public static boolean validarAccesoProcedimiento(Procedimientos procedimientos) {

		boolean bolAcceso = false;

		Vector<String> vecPermisos = SeguridadAplicacion
				.getRolesUsuario(SecurityContextHolder.getContext().getAuthentication());

		if (procedimientos != null && procedimientos.getDirecciones() != null) {
			// Si el procedimiento tiene codigo de direccion 1 es visible
			// para perfil administrador y responsable / técnico de turismo
			if (procedimientos.getDirecciones().getIdDireccion() == Constantes.COD_DIRECCION_TURISMO
					&& (vecPermisos.contains(SeguridadAplicacion.ROLE_ADMINISTRADOR)
							|| vecPermisos.contains(SeguridadAplicacion.ROLE_RESPONSABLE_TURISMO)
							|| vecPermisos.contains(SeguridadAplicacion.ROLE_TECNICO_TURISMO)))
				bolAcceso = true;
			// Si el procedimiento tiene codigo de direccion 2 es visible
			// para perfil administrador y responsable / técnico de comercio
			else if (procedimientos.getDirecciones().getIdDireccion() == Constantes.COD_DIRECCION_COMERCIO
					&& (vecPermisos.contains(SeguridadAplicacion.ROLE_ADMINISTRADOR)
							|| vecPermisos.contains(SeguridadAplicacion.ROLE_RESPONSABLE_COMERCIO)
							|| vecPermisos.contains(SeguridadAplicacion.ROLE_TECNICO_COMERCIO)))
				bolAcceso = true;
			// Si el procedimiento tiene codigo de direccion 3 es visible
			// para perfil administrador y responsable / técnico de comercio
			else if (procedimientos.getDirecciones().getIdDireccion() == Constantes.COD_DIRECCION_CONSUMO
					&& (vecPermisos.contains(SeguridadAplicacion.ROLE_ADMINISTRADOR)
							|| vecPermisos.contains(SeguridadAplicacion.ROLE_RESPONSABLE_CONSUMO)
							|| vecPermisos.contains(SeguridadAplicacion.ROLE_TECNICO_CONSUMO)))
				bolAcceso = true;
		}

		return bolAcceso;
	}
}
