package com.ejie.ab60.dao.BEC;

import com.ejie.ab60.model.BEC.Caracteristicas;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * CaracteristicasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class CaracteristicasDaoImpl implements CaracteristicasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCARACTERISTICA", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Caracteristicas> rwMap = new RowMapper<Caracteristicas>() {
		public Caracteristicas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Caracteristicas(resultSet.getLong("IDCARACTERISTICA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<Caracteristicas> rwMapPK = new RowMapper<Caracteristicas>() {
		public Caracteristicas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Caracteristicas(resultSet.getLong("IDCARACTERISTICA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Caracteristicas>> rwMapJerarquia = new RowMapper<JerarquiaDto<Caracteristicas>>() {
		public JerarquiaDto<Caracteristicas> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Caracteristicas caracteristicas = new Caracteristicas(resultSet.getLong("IDCARACTERISTICA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<Caracteristicas> jerarquia = new JerarquiaDto<Caracteristicas>();
			jerarquia.setModel(caracteristicas);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @return Caracteristicas
	 */
	public Caracteristicas add(Caracteristicas caracteristicas) {
		String query = "INSERT INTO CARACTERISTICAS (ID_CARACTERISTICA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, caracteristicas.getIdCaracteristica(),
				caracteristicas.getDescripcionCastellano(), caracteristicas.getDescripcionEuskera(),
				caracteristicas.getFechaRegistro(), caracteristicas.getUsuarioRegistro());
		return caracteristicas;
	}

	/**
	 * Updates a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @return Caracteristicas
	 */
	public Caracteristicas update(Caracteristicas caracteristicas) {
		String query = "UPDATE CARACTERISTICAS SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_CARACTERISTICA=?";
		this.jdbcTemplate.update(query, caracteristicas.getDescripcionCastellano(),
				caracteristicas.getDescripcionEuskera(), caracteristicas.getFechaRegistro(),
				caracteristicas.getUsuarioRegistro(), caracteristicas.getIdCaracteristica());
		return caracteristicas;
	}

	/**
	 * Finds a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @return Caracteristicas
	 */
	@Transactional(readOnly = true)
	public Caracteristicas find(Caracteristicas caracteristicas) {
		String query = "SELECT t1.ID_CARACTERISTICA IDCARACTERISTICA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM CARACTERISTICAS t1  WHERE t1.ID_CARACTERISTICA = ?  ";

		List<Caracteristicas> caracteristicasList = this.jdbcTemplate.query(query, this.rwMap,
				caracteristicas.getIdCaracteristica());
		return (Caracteristicas) DataAccessUtils.uniqueResult(caracteristicasList);
	}

	/**
	 * Removes a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @return
	 */
	public void remove(Caracteristicas caracteristicas) {
		String query = "DELETE FROM CARACTERISTICAS WHERE ID_CARACTERISTICA=?";
		this.jdbcTemplate.update(query, caracteristicas.getIdCaracteristica());
	}

	/**
	 * Finds a list of rows in the Caracteristicas table.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Caracteristicas>
	 */
	@Transactional(readOnly = true)
	public List<Caracteristicas> findAll(Caracteristicas caracteristicas, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CARACTERISTICA IDCARACTERISTICA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM CARACTERISTICAS t1");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(caracteristicas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CaracteristicasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Caracteristicas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Caracteristicas table using like.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Caracteristicas>
	 */
	@Transactional(readOnly = true)
	public List<Caracteristicas> findAllLike(Caracteristicas caracteristicas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CARACTERISTICA IDCARACTERISTICA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM CARACTERISTICAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(caracteristicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CaracteristicasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Caracteristicas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Caracteristicas table.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Caracteristicas caracteristicas) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM CARACTERISTICAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(caracteristicas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Caracteristicas table using like.
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Caracteristicas caracteristicas, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM CARACTERISTICAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(caracteristicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Caracteristicas selected for rup_table
	 *
	 * @param caracteristicas
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Caracteristicas>>
	 */
	@Override
	public List<TableRowDto<Caracteristicas>> reorderSelection(Caracteristicas caracteristicas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CARACTERISTICA IDCARACTERISTICA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM CARACTERISTICAS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(caracteristicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				Caracteristicas.class, filterParamList, "ID_CARACTERISTICA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Caracteristicas>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Caracteristicas
	 * @param searchParams
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Caracteristicas>>
	 */
	@Override
	public List<TableRowDto<Caracteristicas>> search(Caracteristicas filterParams, Caracteristicas searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CARACTERISTICA IDCARACTERISTICA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM CARACTERISTICAS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				Caracteristicas.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_CARACTERISTICA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Caracteristicas>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtercaracteristicas
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Caracteristicas filtercaracteristicas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CARACTERISTICA IDCARACTERISTICA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM CARACTERISTICAS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtercaracteristicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				Caracteristicas.class, query, params, "ID_CARACTERISTICA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Caracteristicas table.
	 *
	 * @param filterCaracteristicas
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Caracteristicas>>
	 */
	@Override
	public List<JerarquiaDto<Caracteristicas>> findAllLikeJerarquia(Caracteristicas filterCaracteristicas,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CARACTERISTICA IDCARACTERISTICA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM CARACTERISTICAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CARACTERISTICAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCaracteristicas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CARACTERISTICA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					CaracteristicasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterCaracteristicas
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Caracteristicas filterCaracteristicas, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM CARACTERISTICAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CARACTERISTICAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCaracteristicas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CARACTERISTICA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterCaracteristicas
	 *            Caracteristicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Caracteristicas>>
	 */
	@Override
	public List<TableRowDto<Caracteristicas>> findAllChild(Caracteristicas filterCaracteristicas,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM CARACTERISTICAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CARACTERISTICAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCaracteristicas, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CARACTERISTICA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Caracteristicas>(this.rwMapPK, "ID_CARACTERISTICA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Caracteristicas entity
	 *
	 * @param caracteristicas
	 *            Caracteristicas Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Caracteristicas caracteristicas) {

		StringBuilder where = new StringBuilder(CaracteristicasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (caracteristicas != null && caracteristicas.getIdCaracteristica() != null) {
			where.append(" AND t1.ID_CARACTERISTICA = ?");
			params.add(caracteristicas.getIdCaracteristica());
		}
		if (caracteristicas != null && caracteristicas.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(caracteristicas.getDescripcionCastellano());
		}
		if (caracteristicas != null && caracteristicas.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(caracteristicas.getDescripcionEuskera());
		}
		if (caracteristicas != null && caracteristicas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(caracteristicas.getFechaRegistro());
		}
		if (caracteristicas != null && caracteristicas.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(caracteristicas.getUsuarioRegistro());
		}
		if (caracteristicas != null && caracteristicas.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(caracteristicas.getIdConvocatoria());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Caracteristicas entity
	 *
	 * @param caracteristicas
	 *            Caracteristicas Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Caracteristicas caracteristicas, Boolean startsWith) {

		StringBuilder where = new StringBuilder(CaracteristicasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (caracteristicas != null && caracteristicas.getIdCaracteristica() != null) {
			where.append(" AND t1.ID_CARACTERISTICA = ?");
			params.add(caracteristicas.getIdCaracteristica());
		}
		if (caracteristicas != null && caracteristicas.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(caracteristicas.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + caracteristicas.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (caracteristicas != null && caracteristicas.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(caracteristicas.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + caracteristicas.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (caracteristicas != null && caracteristicas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(caracteristicas.getFechaRegistro());
		}
		if (caracteristicas != null && caracteristicas.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(caracteristicas.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + caracteristicas.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
