package com.ejie.ab60.dao.BEC;

import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * CurriculumDao  
 * 
 *  
 */

public interface CurriculumDao {

	/**
	 * Inserts a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	Curriculum add(Curriculum curriculum);

	/**
	 * Updates a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	Curriculum update(Curriculum curriculum);

	/**
	 * Finds a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	Curriculum find(Curriculum curriculum);

	/**
	 * Removes a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 */
	void remove(Curriculum curriculum);

	/**
	 * Finds a List of rows in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<Curriculum> findAll(Curriculum curriculum, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Curriculum table using like.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Curriculum> findAllLike(Curriculum curriculum, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the Curriculum table using like.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(Curriculum curriculum, Boolean startsWith);

	/**
	 * Counts rows in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Long
	 */
	Long findAllCount(Curriculum curriculum);

	/**
	 * Reorder selection.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Curriculum>>
	 */
	List<TableRowDto<Curriculum>> reorderSelection(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param searchCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Curriculum>>
	 */
	List<TableRowDto<Curriculum>> search(Curriculum filterCurriculum, Curriculum searchCurriculum,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Curriculum>>
	 */
	List<JerarquiaDto<Curriculum>> findAllLikeJerarquia(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Curriculum>>
	 */
	List<TableRowDto<Curriculum>> findAllChild(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto);
}
