package com.ejie.ab60.dao.BEC;

import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.TiposCertificacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * CurriculumDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class CurriculumDaoImpl implements CurriculumDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCURRICULUM", "IDEXPEDIENTE", "TITULACION",
			"ANYOINICIO", "ANYOFIN", "MATRICULASHONOR", "SOBRESALIENTES", "NOTABLES", "SUFICIENTES", "EUSKERA",
			"FRANCES", "INGLES", "ITALIANO", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION", "TCIDTIPOCERT", "TCDESCCAST", "TCDESCEUSK", "TCFECHAREGISTRO",
			"TCUSUARIOREGISTRO", "TCIDTIPOCERT", "TCDESCCAST", "TCDESCEUSK", "TCFECHAREGISTRO", "TCUSUARIOREGISTRO",
			"TCIDTIPOCERT", "TCDESCCAST", "TCDESCEUSK", "TCFECHAREGISTRO", "TCUSUARIOREGISTRO", "TCIDTIPOCERT",
			"TCDESCCAST", "TCDESCEUSK", "TCFECHAREGISTRO", "TCUSUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Curriculum> rwMap = new RowMapper<Curriculum>() {
		public Curriculum mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Curriculum curriculum = new Curriculum();
			curriculum.setIdCurriculum(resultSet.getInt("IDCURRICULUM"));
			curriculum.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			curriculum.setTitulacion(resultSet.getString("TITULACION"));
			curriculum.setAnyoInicio(resultSet.getLong("ANYOINICIO"));
			curriculum.setAnyoFin(resultSet.getLong("ANYOFIN"));
			curriculum.setMatriculasHonor(resultSet.getLong("MATRICULASHONOR"));
			if (resultSet.wasNull()) {
				curriculum.setMatriculasHonor(null);
			}
			curriculum.setSobresalientes(resultSet.getLong("SOBRESALIENTES"));
			if (resultSet.wasNull()) {
				curriculum.setSobresalientes(null);
			}
			curriculum.setNotables(resultSet.getLong("NOTABLES"));
			if (resultSet.wasNull()) {
				curriculum.setNotables(null);
			}
			curriculum.setSuficientes(resultSet.getLong("SUFICIENTES"));
			if (resultSet.wasNull()) {
				curriculum.setSuficientes(null);
			}
			curriculum.setEuskera(resultSet.getInt("EUSKERA"));
			curriculum.setIngles(resultSet.getInt("INGLES"));
			curriculum.setFrances(resultSet.getInt("FRANCES"));
			curriculum.setItaliano(resultSet.getInt("ITALIANO"));
			TiposCertificacion euskera = new TiposCertificacion();
			Long idEuskera = resultSet.getLong("TCIDTIPOCERTEUSKERA");
			if (resultSet.wasNull()) {
				idEuskera = null;
			}
			euskera.setIdTipoCertificacion(idEuskera);
			euskera.setDescripcionCastellano(resultSet.getString("TCDESCCASTEUSKERA"));
			euskera.setDescripcionEuskera(resultSet.getString("TCDESCEUSKEUSKERA"));
			curriculum.setTiposCertificacionByIdCertificacionEuskera(euskera);
			TiposCertificacion ingles = new TiposCertificacion();
			Long idIngles = resultSet.getLong("TCIDTIPOCERTINGLES");
			if (resultSet.wasNull()) {
				idIngles = null;
			}
			ingles.setIdTipoCertificacion(idIngles);
			ingles.setDescripcionCastellano(resultSet.getString("TCDESCCASTINGLES"));
			ingles.setDescripcionEuskera(resultSet.getString("TCDESCEUSKINGLES"));
			curriculum.setTiposCertificacionByIdCertificacionIngles(ingles);
			TiposCertificacion frances = new TiposCertificacion();
			Long idFrances = resultSet.getLong("TCIDTIPOCERTFRANCES");
			if (resultSet.wasNull()) {
				idFrances = null;
			}
			frances.setIdTipoCertificacion(idFrances);
			frances.setDescripcionCastellano(resultSet.getString("TCDESCCASTFRANCES"));
			frances.setDescripcionEuskera(resultSet.getString("TCDESCEUSKFRANCES"));
			curriculum.setTiposCertificacionByIdCertificacionFrances(frances);
			TiposCertificacion italiano = new TiposCertificacion();
			Long idItaliano = resultSet.getLong("TCIDTIPOCERTITALIANO");
			if (resultSet.wasNull()) {
				idItaliano = null;
			}
			italiano.setIdTipoCertificacion(idItaliano);
			italiano.setDescripcionCastellano(resultSet.getString("TCDESCCASTITALIANO"));
			italiano.setDescripcionEuskera(resultSet.getString("TCDESCEUSKITALIANO"));
			curriculum.setTiposCertificacionByIdCertificacionItaliano(italiano);

			return curriculum;

		}
	};

	private RowMapper<Curriculum> rwMapPK = new RowMapper<Curriculum>() {
		public Curriculum mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Curriculum(resultSet.getInt("IDCURRICULUM"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Curriculum>> rwMapJerarquia = new RowMapper<JerarquiaDto<Curriculum>>() {
		public JerarquiaDto<Curriculum> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Curriculum curriculum = new Curriculum(resultSet.getInt("IDCURRICULUM"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getString("TITULACION"), resultSet.getLong("ANYOINICIO"), resultSet.getLong("ANYOFIN"),
					resultSet.getLong("MATRICULASHONOR"), resultSet.getLong("SOBRESALIENTES"),
					resultSet.getLong("NOTABLES"), resultSet.getLong("SUFICIENTES"), resultSet.getInt("EUSKERA"),
					resultSet.getInt("FRANCES"), resultSet.getInt("INGLES"), resultSet.getInt("ITALIANO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new TiposCertificacion(resultSet.getLong("TCIDTIPOCERT"), resultSet.getString("TCDESCCAST"),
							resultSet.getString("TCDESCEUSK"), resultSet.getDate("TCFECHAREGISTRO"),
							resultSet.getString("TCUSUARIOREGISTRO")),
					new TiposCertificacion(resultSet.getLong("TCIDTIPOCERT"), resultSet.getString("TCDESCCAST"),
							resultSet.getString("TCDESCEUSK"), resultSet.getDate("TCFECHAREGISTRO"),
							resultSet.getString("TCUSUARIOREGISTRO")),
					new TiposCertificacion(resultSet.getLong("TCIDTIPOCERT"), resultSet.getString("TCDESCCAST"),
							resultSet.getString("TCDESCEUSK"), resultSet.getDate("TCFECHAREGISTRO"),
							resultSet.getString("TCUSUARIOREGISTRO")),
					new TiposCertificacion(resultSet.getLong("TCIDTIPOCERT"), resultSet.getString("TCDESCCAST"),
							resultSet.getString("TCDESCEUSK"), resultSet.getDate("TCFECHAREGISTRO"),
							resultSet.getString("TCUSUARIOREGISTRO")));

			JerarquiaDto<Curriculum> jerarquia = new JerarquiaDto<Curriculum>();
			jerarquia.setModel(curriculum);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	public Curriculum add(Curriculum curriculum) {
		String query = "INSERT INTO CURRICULUM (ID_CURRICULUM, ID_CERTIFICACION_INGLES, ID_CERTIFICACION_FRANCES, ID_CERTIFICACION_ITALIANO, ID_CERTIFICACION_EUSKERA, ID_EXPEDIENTE, TITULACION, ANYO_INICIO, ANYO_FIN, MATRICULAS_HONOR, SOBRESALIENTES, NOTABLES, SUFICIENTES, EUSKERA, FRANCES, INGLES, ITALIANO, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		Object getTiposCertificacionByIdCertificacionInglesIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionInglesIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion();
		}
		Object getTiposCertificacionByIdCertificacionFrancesIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionFrancesIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion();
		}
		Object getTiposCertificacionByIdCertificacionItalianoIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionItalianoIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion();
		}
		Object getTiposCertificacionByIdCertificacionEuskeraIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionEuskeraIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion();
		}
		this.jdbcTemplate.update(query, curriculum.getIdCurriculum(),
				getTiposCertificacionByIdCertificacionInglesIdTipoCertificacionAux,
				getTiposCertificacionByIdCertificacionFrancesIdTipoCertificacionAux,
				getTiposCertificacionByIdCertificacionItalianoIdTipoCertificacionAux,
				getTiposCertificacionByIdCertificacionEuskeraIdTipoCertificacionAux, curriculum.getIdExpediente(),
				curriculum.getTitulacion(), curriculum.getAnyoInicio(), curriculum.getAnyoFin(),
				curriculum.getMatriculasHonor(), curriculum.getSobresalientes(), curriculum.getNotables(),
				curriculum.getSuficientes(), curriculum.getEuskera(), curriculum.getFrances(), curriculum.getIngles(),
				curriculum.getItaliano(), curriculum.getFechaRegistro(), curriculum.getUsuarioRegistro(),
				curriculum.getFechaUltmodificacion(), curriculum.getUsuarioUltmodificacion());
		return curriculum;
	}

	/**
	 * Updates a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	public Curriculum update(Curriculum curriculum) {
		String query = "UPDATE CURRICULUM SET ID_CERTIFICACION_INGLES=?, ID_CERTIFICACION_FRANCES=?, ID_CERTIFICACION_ITALIANO=?, ID_CERTIFICACION_EUSKERA=?, ID_EXPEDIENTE=?, TITULACION=?, MATRICULAS_HONOR=?, SOBRESALIENTES=?, NOTABLES=?, SUFICIENTES=?, EUSKERA=?, FRANCES=?, INGLES=?, ITALIANO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_CURRICULUM=?";
		Object getTiposCertificacionByIdCertificacionInglesIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionInglesIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion();
		}
		Object getTiposCertificacionByIdCertificacionFrancesIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionFrancesIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion();
		}
		Object getTiposCertificacionByIdCertificacionItalianoIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionItalianoIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion();
		}
		Object getTiposCertificacionByIdCertificacionEuskeraIdTipoCertificacionAux = null;
		if (curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion() != null) {
			getTiposCertificacionByIdCertificacionEuskeraIdTipoCertificacionAux = curriculum
					.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion();
		}
		this.jdbcTemplate.update(query, getTiposCertificacionByIdCertificacionInglesIdTipoCertificacionAux,
				getTiposCertificacionByIdCertificacionFrancesIdTipoCertificacionAux,
				getTiposCertificacionByIdCertificacionItalianoIdTipoCertificacionAux,
				getTiposCertificacionByIdCertificacionEuskeraIdTipoCertificacionAux, curriculum.getIdExpediente(),
				curriculum.getTitulacion(), curriculum.getMatriculasHonor(), curriculum.getSobresalientes(),
				curriculum.getNotables(), curriculum.getSuficientes(), curriculum.getEuskera(), curriculum.getFrances(),
				curriculum.getIngles(), curriculum.getItaliano(), curriculum.getFechaRegistro(),
				curriculum.getUsuarioRegistro(), curriculum.getFechaUltmodificacion(),
				curriculum.getUsuarioUltmodificacion(), curriculum.getIdCurriculum());
		return curriculum;
	}

	/**
	 * Finds a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	@Transactional(readOnly = true)
	public Curriculum find(Curriculum curriculum) {
		String query = "SELECT t1.ID_CURRICULUM IDCURRICULUM, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.TITULACION TITULACION, t1.ANYO_INICIO ANYOINICIO, t1.ANYO_FIN ANYOFIN, t1.MATRICULAS_HONOR MATRICULASHONOR, t1.SOBRESALIENTES SOBRESALIENTES, t1.NOTABLES NOTABLES, t1.SUFICIENTES SUFICIENTES, t1.EUSKERA EUSKERA, t1.FRANCES FRANCES, t1.INGLES INGLES, t1.ITALIANO ITALIANO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_TIPO_CERTIFICACION TCIDTIPOCERT, t2.DESCRIPCION_CASTELLANO TCDESCCAST, t2.DESCRIPCION_EUSKERA TCDESCEUSK, t2.FECHA_REGISTRO TCFECHAREGISTRO, t2.USUARIO_REGISTRO TCUSUARIOREGISTRO, t3.ID_TIPO_CERTIFICACION TCIDTIPOCERT, t3.DESCRIPCION_CASTELLANO TCDESCCAST, t3.DESCRIPCION_EUSKERA TCDESCEUSK, t3.FECHA_REGISTRO TCFECHAREGISTRO, t3.USUARIO_REGISTRO TCUSUARIOREGISTRO, t4.ID_TIPO_CERTIFICACION TCIDTIPOCERT, t4.DESCRIPCION_CASTELLANO TCDESCCAST, t4.DESCRIPCION_EUSKERA TCDESCEUSK, t4.FECHA_REGISTRO TCFECHAREGISTRO, t4.USUARIO_REGISTRO TCUSUARIOREGISTRO, t5.ID_TIPO_CERTIFICACION TCIDTIPOCERT, t5.DESCRIPCION_CASTELLANO TCDESCCAST, t5.DESCRIPCION_EUSKERA TCDESCEUSK, t5.FECHA_REGISTRO TCFECHAREGISTRO, t5.USUARIO_REGISTRO TCUSUARIOREGISTRO FROM CURRICULUM t1 , TIPOS_CERTIFICACION t2 , TIPOS_CERTIFICACION t3 , TIPOS_CERTIFICACION t4 , TIPOS_CERTIFICACION t5  WHERE t1.ID_CURRICULUM = ?   AND t1.ID_CERTIFICACION_INGLES= t2.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_FRANCES= t3.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_ITALIANO= t4.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_EUSKERA= t5.ID_TIPO_CERTIFICACION(+)";

		List<Curriculum> curriculumList = this.jdbcTemplate.query(query, this.rwMap, curriculum.getIdCurriculum());
		return (Curriculum) DataAccessUtils.uniqueResult(curriculumList);
	}

	/**
	 * Removes a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return
	 */
	public void remove(Curriculum curriculum) {
		String query = "DELETE FROM CURRICULUM WHERE ID_CURRICULUM=?";
		this.jdbcTemplate.update(query, curriculum.getIdCurriculum());
	}

	/**
	 * Finds a list of rows in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Curriculum>
	 */
	@Transactional(readOnly = true)
	public List<Curriculum> findAll(Curriculum curriculum, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CURRICULUM IDCURRICULUM,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TITULACION TITULACION,t1.ANYO_INICIO ANYOINICIO,t1.ANYO_FIN ANYOFIN,t1.MATRICULAS_HONOR MATRICULASHONOR,t1.SOBRESALIENTES SOBRESALIENTES,t1.NOTABLES NOTABLES,t1.SUFICIENTES SUFICIENTES,t1.EUSKERA EUSKERA,t1.FRANCES FRANCES,t1.INGLES INGLES,t1.ITALIANO ITALIANO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,INGLES.ID_TIPO_CERTIFICACION TCIDTIPOCERTINGLES,INGLES.DESCRIPCION_CASTELLANO TCDESCCASTINGLES,INGLES.DESCRIPCION_EUSKERA TCDESCEUSKINGLES,INGLES.FECHA_REGISTRO TCFECHAREGISTRO,INGLES.USUARIO_REGISTRO TCUSUARIOREGISTRO,FRANCES.ID_TIPO_CERTIFICACION TCIDTIPOCERTFRANCES,FRANCES.DESCRIPCION_CASTELLANO TCDESCCASTFRANCES,FRANCES.DESCRIPCION_EUSKERA TCDESCEUSKFRANCES,FRANCES.FECHA_REGISTRO TCFECHAREGISTRO,FRANCES.USUARIO_REGISTRO TCUSUARIOREGISTRO,ITALIANO.ID_TIPO_CERTIFICACION TCIDTIPOCERTITALIANO,ITALIANO.DESCRIPCION_CASTELLANO TCDESCCASTITALIANO,ITALIANO.DESCRIPCION_EUSKERA TCDESCEUSKITALIANO,ITALIANO.FECHA_REGISTRO TCFECHAREGISTRO,ITALIANO.USUARIO_REGISTRO TCUSUARIOREGISTRO,EUSKERA.ID_TIPO_CERTIFICACION TCIDTIPOCERTEUSKERA,EUSKERA.DESCRIPCION_CASTELLANO TCDESCCASTEUSKERA,EUSKERA.DESCRIPCION_EUSKERA TCDESCEUSKEUSKERA,EUSKERA.FECHA_REGISTRO TCFECHAREGISTRO,EUSKERA.USUARIO_REGISTRO TCUSUARIOREGISTRO ");
		query.append(
				"FROM CURRICULUM t1 ,TIPOS_CERTIFICACION INGLES ,TIPOS_CERTIFICACION FRANCES ,TIPOS_CERTIFICACION ITALIANO ,TIPOS_CERTIFICACION EUSKERA ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(curriculum);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CERTIFICACION_INGLES= INGLES.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_FRANCES= FRANCES.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_ITALIANO= ITALIANO.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_EUSKERA= EUSKERA.ID_TIPO_CERTIFICACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, CurriculumDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Curriculum>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Curriculum table using like.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Curriculum>
	 */
	@Transactional(readOnly = true)
	public List<Curriculum> findAllLike(Curriculum curriculum, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CURRICULUM IDCURRICULUM,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TITULACION TITULACION,t1.ANYO_INICIO ANYOINICIO,t1.ANYO_FIN ANYOFIN,t1.MATRICULAS_HONOR MATRICULASHONOR,t1.SOBRESALIENTES SOBRESALIENTES,t1.NOTABLES NOTABLES,t1.SUFICIENTES SUFICIENTES,t1.EUSKERA EUSKERA,t1.FRANCES FRANCES,t1.INGLES INGLES,t1.ITALIANO ITALIANO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t2.DESCRIPCION_CASTELLANO TCDESCCAST,t2.DESCRIPCION_EUSKERA TCDESCEUSK,t2.FECHA_REGISTRO TCFECHAREGISTRO,t2.USUARIO_REGISTRO TCUSUARIOREGISTRO,t3.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t3.DESCRIPCION_CASTELLANO TCDESCCAST,t3.DESCRIPCION_EUSKERA TCDESCEUSK,t3.FECHA_REGISTRO TCFECHAREGISTRO,t3.USUARIO_REGISTRO TCUSUARIOREGISTRO,t4.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t4.DESCRIPCION_CASTELLANO TCDESCCAST,t4.DESCRIPCION_EUSKERA TCDESCEUSK,t4.FECHA_REGISTRO TCFECHAREGISTRO,t4.USUARIO_REGISTRO TCUSUARIOREGISTRO,t5.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t5.DESCRIPCION_CASTELLANO TCDESCCAST,t5.DESCRIPCION_EUSKERA TCDESCEUSK,t5.FECHA_REGISTRO TCFECHAREGISTRO,t5.USUARIO_REGISTRO TCUSUARIOREGISTRO ");
		query.append(
				"FROM CURRICULUM t1 ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION t4 ,TIPOS_CERTIFICACION t5 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(curriculum, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CERTIFICACION_INGLES= t2.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_FRANCES= t3.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_ITALIANO= t4.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_EUSKERA= t5.ID_TIPO_CERTIFICACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, CurriculumDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Curriculum>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Curriculum curriculum) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM CURRICULUM t1 , TIPOS_CERTIFICACION t2 , TIPOS_CERTIFICACION t3 , TIPOS_CERTIFICACION t4 , TIPOS_CERTIFICACION t5 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(curriculum);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CERTIFICACION_INGLES= t2.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_FRANCES= t3.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_ITALIANO= t4.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_EUSKERA= t5.ID_TIPO_CERTIFICACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Curriculum table using like.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Curriculum curriculum, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM CURRICULUM t1 ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION t4 ,TIPOS_CERTIFICACION t5 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(curriculum, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CERTIFICACION_INGLES= t2.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_FRANCES= t3.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_ITALIANO= t4.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_EUSKERA= t5.ID_TIPO_CERTIFICACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Curriculum selected for rup_table
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Curriculum>>
	 */
	@Override
	public List<TableRowDto<Curriculum>> reorderSelection(Curriculum curriculum, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CURRICULUM IDCURRICULUM,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TITULACION TITULACION,t1.ANYO_INICIO ANYOINICIO,t1.ANYO_FIN ANYOFIN,t1.MATRICULAS_HONOR MATRICULASHONOR,t1.SOBRESALIENTES SOBRESALIENTES,t1.NOTABLES NOTABLES,t1.SUFICIENTES SUFICIENTES,t1.EUSKERA EUSKERA,t1.FRANCES FRANCES,t1.INGLES INGLES,t1.ITALIANO ITALIANO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t2.DESCRIPCION_CASTELLANO TCDESCCAST,t2.DESCRIPCION_EUSKERA TCDESCEUSK,t2.FECHA_REGISTRO TCFECHAREGISTRO,t2.USUARIO_REGISTRO TCUSUARIOREGISTRO,t3.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t3.DESCRIPCION_CASTELLANO TCDESCCAST,t3.DESCRIPCION_EUSKERA TCDESCEUSK,t3.FECHA_REGISTRO TCFECHAREGISTRO,t3.USUARIO_REGISTRO TCUSUARIOREGISTRO,t4.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t4.DESCRIPCION_CASTELLANO TCDESCCAST,t4.DESCRIPCION_EUSKERA TCDESCEUSK,t4.FECHA_REGISTRO TCFECHAREGISTRO,t4.USUARIO_REGISTRO TCUSUARIOREGISTRO,t5.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t5.DESCRIPCION_CASTELLANO TCDESCCAST,t5.DESCRIPCION_EUSKERA TCDESCEUSK,t5.FECHA_REGISTRO TCFECHAREGISTRO,t5.USUARIO_REGISTRO TCUSUARIOREGISTRO ");
		// FROM
		query.append(
				"FROM CURRICULUM t1 ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION t4 ,TIPOS_CERTIFICACION t5 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(curriculum, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CERTIFICACION_INGLES= t2.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_FRANCES= t3.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_ITALIANO= t4.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_EUSKERA= t5.ID_TIPO_CERTIFICACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Curriculum.class,
				filterParamList, "ID_CURRICULUM");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Curriculum>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Curriculum
	 * @param searchParams
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Curriculum>>
	 */
	@Override
	public List<TableRowDto<Curriculum>> search(Curriculum filterParams, Curriculum searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CURRICULUM IDCURRICULUM,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TITULACION TITULACION,t1.ANYO_INICIO ANYOINICIO,t1.ANYO_FIN ANYOFIN,t1.MATRICULAS_HONOR MATRICULASHONOR,t1.SOBRESALIENTES SOBRESALIENTES,t1.NOTABLES NOTABLES,t1.SUFICIENTES SUFICIENTES,t1.EUSKERA EUSKERA,t1.FRANCES FRANCES,t1.INGLES INGLES,t1.ITALIANO ITALIANO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t2.DESCRIPCION_CASTELLANO TCDESCCAST,t2.DESCRIPCION_EUSKERA TCDESCEUSK,t2.FECHA_REGISTRO TCFECHAREGISTRO,t2.USUARIO_REGISTRO TCUSUARIOREGISTRO,t3.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t3.DESCRIPCION_CASTELLANO TCDESCCAST,t3.DESCRIPCION_EUSKERA TCDESCEUSK,t3.FECHA_REGISTRO TCFECHAREGISTRO,t3.USUARIO_REGISTRO TCUSUARIOREGISTRO,t4.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t4.DESCRIPCION_CASTELLANO TCDESCCAST,t4.DESCRIPCION_EUSKERA TCDESCEUSK,t4.FECHA_REGISTRO TCFECHAREGISTRO,t4.USUARIO_REGISTRO TCUSUARIOREGISTRO,t5.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t5.DESCRIPCION_CASTELLANO TCDESCCAST,t5.DESCRIPCION_EUSKERA TCDESCEUSK,t5.FECHA_REGISTRO TCFECHAREGISTRO,t5.USUARIO_REGISTRO TCUSUARIOREGISTRO ");
		// FROM
		query.append(
				"FROM CURRICULUM t1 ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION t4 ,TIPOS_CERTIFICACION t5 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");
		from_alias.add(" t5 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CERTIFICACION_INGLES= t2.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_FRANCES= t3.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_ITALIANO= t4.ID_TIPO_CERTIFICACION(+) AND t1.ID_CERTIFICACION_EUSKERA= t5.ID_TIPO_CERTIFICACION(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Curriculum.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_CURRICULUM");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Curriculum>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtercurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Curriculum filtercurriculum, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CURRICULUM IDCURRICULUM,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TITULACION TITULACION,t1.ANYO_INICIO ANYOINICIO,t1.ANYO_FIN ANYOFIN,t1.MATRICULAS_HONOR MATRICULASHONOR,t1.SOBRESALIENTES SOBRESALIENTES,t1.NOTABLES NOTABLES,t1.SUFICIENTES SUFICIENTES,t1.EUSKERA EUSKERA,t1.FRANCES FRANCES,t1.INGLES INGLES,t1.ITALIANO ITALIANO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t2.DESCRIPCION_CASTELLANO TCDESCCAST,t2.DESCRIPCION_EUSKERA TCDESCEUSK,t2.FECHA_REGISTRO TCFECHAREGISTRO,t2.USUARIO_REGISTRO TCUSUARIOREGISTRO,t3.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t3.DESCRIPCION_CASTELLANO TCDESCCAST,t3.DESCRIPCION_EUSKERA TCDESCEUSK,t3.FECHA_REGISTRO TCFECHAREGISTRO,t3.USUARIO_REGISTRO TCUSUARIOREGISTRO,t4.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t4.DESCRIPCION_CASTELLANO TCDESCCAST,t4.DESCRIPCION_EUSKERA TCDESCEUSK,t4.FECHA_REGISTRO TCFECHAREGISTRO,t4.USUARIO_REGISTRO TCUSUARIOREGISTRO,t5.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t5.DESCRIPCION_CASTELLANO TCDESCCAST,t5.DESCRIPCION_EUSKERA TCDESCEUSK,t5.FECHA_REGISTRO TCFECHAREGISTRO,t5.USUARIO_REGISTRO TCUSUARIOREGISTRO ");
		// FROM
		query.append(
				"FROM CURRICULUM t1 ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION t4 ,TIPOS_CERTIFICACION t5 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtercurriculum, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Curriculum.class,
				query, params, "ID_CURRICULUM");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Curriculum>>
	 */
	@Override
	public List<JerarquiaDto<Curriculum>> findAllLikeJerarquia(Curriculum filterCurriculum,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CURRICULUM IDCURRICULUM,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TITULACION TITULACION,t1.ANYO_INICIO ANYOINICIO,t1.ANYO_FIN ANYOFIN,t1.MATRICULAS_HONOR MATRICULASHONOR,t1.SOBRESALIENTES SOBRESALIENTES,t1.NOTABLES NOTABLES,t1.SUFICIENTES SUFICIENTES,t1.EUSKERA EUSKERA,t1.FRANCES FRANCES,t1.INGLES INGLES,t1.ITALIANO ITALIANO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t2.DESCRIPCION_CASTELLANO TCDESCCAST,t2.DESCRIPCION_EUSKERA TCDESCEUSK,t2.FECHA_REGISTRO TCFECHAREGISTRO,t2.USUARIO_REGISTRO TCUSUARIOREGISTRO,t3.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t3.DESCRIPCION_CASTELLANO TCDESCCAST,t3.DESCRIPCION_EUSKERA TCDESCEUSK,t3.FECHA_REGISTRO TCFECHAREGISTRO,t3.USUARIO_REGISTRO TCUSUARIOREGISTRO,t4.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t4.DESCRIPCION_CASTELLANO TCDESCCAST,t4.DESCRIPCION_EUSKERA TCDESCEUSK,t4.FECHA_REGISTRO TCFECHAREGISTRO,t4.USUARIO_REGISTRO TCUSUARIOREGISTRO,t5.ID_TIPO_CERTIFICACION TCIDTIPOCERT,t5.DESCRIPCION_CASTELLANO TCDESCCAST,t5.DESCRIPCION_EUSKERA TCDESCEUSK,t5.FECHA_REGISTRO TCFECHAREGISTRO,t5.USUARIO_REGISTRO TCUSUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM CURRICULUM t1
		// ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION
		// t4 ,TIPOS_CERTIFICACION t5 ");
		List<String> from = new ArrayList<String>();
		from.add("CURRICULUM");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");
		from_alias.add(" t5 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCurriculum, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CURRICULUM", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					CurriculumDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM CURRICULUM t1
		// ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION
		// t4 ,TIPOS_CERTIFICACION t5 ");
		List<String> from = new ArrayList<String>();
		from.add("CURRICULUM");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");
		from_alias.add(" t5 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCurriculum, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CURRICULUM",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Curriculum>>
	 */
	@Override
	public List<TableRowDto<Curriculum>> findAllChild(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM CURRICULUM t1
		// ,TIPOS_CERTIFICACION t2 ,TIPOS_CERTIFICACION t3 ,TIPOS_CERTIFICACION
		// t4 ,TIPOS_CERTIFICACION t5 ");
		List<String> from = new ArrayList<String>();
		from.add("CURRICULUM");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");
		from.add("TIPOS_CERTIFICACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");
		from_alias.add(" t5 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCurriculum, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CURRICULUM",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Curriculum>(this.rwMapPK, "ID_CURRICULUM"), params.toArray());
	}
	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Curriculum entity
	 *
	 * @param curriculum
	 *            Curriculum Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Curriculum curriculum) {

		StringBuilder where = new StringBuilder(CurriculumDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (curriculum != null && curriculum.getIdCurriculum() != null) {
			where.append(" AND t1.ID_CURRICULUM = ?");
			params.add(curriculum.getIdCurriculum());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion() != null) {
			where.append(" AND t2.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionCastellano());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionEuskera());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getUsuarioRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion() != null) {
			where.append(" AND t3.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionCastellano() != null) {
			where.append(" AND t3.DESCRIPCION_CASTELLANO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionCastellano());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionEuskera() != null) {
			where.append(" AND t3.DESCRIPCION_EUSKERA = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionEuskera());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getUsuarioRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion() != null) {
			where.append(" AND t4.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionCastellano() != null) {
			where.append(" AND t4.DESCRIPCION_CASTELLANO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionCastellano());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionEuskera() != null) {
			where.append(" AND t4.DESCRIPCION_EUSKERA = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionEuskera());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getFechaRegistro() != null) {
			where.append(" AND t4.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getUsuarioRegistro() != null) {
			where.append(" AND t4.USUARIO_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getUsuarioRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion() != null) {
			where.append(" AND t5.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionCastellano() != null) {
			where.append(" AND t5.DESCRIPCION_CASTELLANO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionCastellano());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionEuskera() != null) {
			where.append(" AND t5.DESCRIPCION_EUSKERA = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionEuskera());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getFechaRegistro() != null) {
			where.append(" AND t5.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getUsuarioRegistro() != null) {
			where.append(" AND t5.USUARIO_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getUsuarioRegistro());
		}
		if (curriculum != null && curriculum.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(curriculum.getIdExpediente());
		}
		if (curriculum != null && curriculum.getTitulacion() != null) {
			where.append(" AND t1.TITULACION = ?");
			params.add(curriculum.getTitulacion());
		}
		if (curriculum != null && curriculum.getAnyoInicio() != null) {
			where.append(" AND t1.ANYO_INICIO = ?");
			params.add(curriculum.getAnyoInicio());
		}
		if (curriculum != null && curriculum.getAnyoFin() != null) {
			where.append(" AND t1.ANYO_FIN = ?");
			params.add(curriculum.getAnyoFin());
		}
		if (curriculum != null && curriculum.getMatriculasHonor() != null) {
			where.append(" AND t1.MATRICULAS_HONOR = ?");
			params.add(curriculum.getMatriculasHonor());
		}
		if (curriculum != null && curriculum.getSobresalientes() != null) {
			where.append(" AND t1.SOBRESALIENTES = ?");
			params.add(curriculum.getSobresalientes());
		}
		if (curriculum != null && curriculum.getNotables() != null) {
			where.append(" AND t1.NOTABLES = ?");
			params.add(curriculum.getNotables());
		}
		if (curriculum != null && curriculum.getSuficientes() != null) {
			where.append(" AND t1.SUFICIENTES = ?");
			params.add(curriculum.getSuficientes());
		}
		if (curriculum != null && curriculum.getEuskera() != null) {
			where.append(" AND t1.EUSKERA = ?");
			params.add(curriculum.getEuskera());
		}
		if (curriculum != null && curriculum.getFrances() != null) {
			where.append(" AND t1.FRANCES = ?");
			params.add(curriculum.getFrances());
		}
		if (curriculum != null && curriculum.getIngles() != null) {
			where.append(" AND t1.INGLES = ?");
			params.add(curriculum.getIngles());
		}
		if (curriculum != null && curriculum.getItaliano() != null) {
			where.append(" AND t1.ITALIANO = ?");
			params.add(curriculum.getItaliano());
		}
		if (curriculum != null && curriculum.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(curriculum.getFechaRegistro());
		}
		if (curriculum != null && curriculum.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(curriculum.getUsuarioRegistro());
		}
		if (curriculum != null && curriculum.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(curriculum.getFechaUltmodificacion());
		}
		if (curriculum != null && curriculum.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(curriculum.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Curriculum entity
	 *
	 * @param curriculum
	 *            Curriculum Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Curriculum curriculum, Boolean startsWith) {

		StringBuilder where = new StringBuilder(CurriculumDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (curriculum != null && curriculum.getIdCurriculum() != null) {
			where.append(" AND t1.ID_CURRICULUM = ?");
			params.add(curriculum.getIdCurriculum());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion() != null) {
			where.append(" AND t2.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionCastellano()
						.toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionCastellano()
						.toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(
						curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionEuskera().toUpperCase()
								+ "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionIngles().getDescripcionEuskera()
						.toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionIngles().getUsuarioRegistro().toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ curriculum.getTiposCertificacionByIdCertificacionIngles().getUsuarioRegistro().toUpperCase()
						+ "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion() != null) {
			where.append(" AND t3.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionCastellano()
						.toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionCastellano()
						.toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(
						curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionEuskera().toUpperCase()
								+ "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionFrances().getDescripcionEuskera()
						.toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionFrances().getUsuarioRegistro().toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ curriculum.getTiposCertificacionByIdCertificacionFrances().getUsuarioRegistro().toUpperCase()
						+ "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion() != null) {
			where.append(" AND t4.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t4.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionCastellano()
						.toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionCastellano()
						.toUpperCase() + "%");
			}
			where.append(" AND t4.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t4.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionEuskera()
						.toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionItaliano().getDescripcionEuskera()
						.toUpperCase() + "%");
			}
			where.append(" AND t4.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getFechaRegistro() != null) {
			where.append(" AND t4.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionItaliano().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t4.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(
						curriculum.getTiposCertificacionByIdCertificacionItaliano().getUsuarioRegistro().toUpperCase()
								+ "%");
			} else {
				params.add("%"
						+ curriculum.getTiposCertificacionByIdCertificacionItaliano().getUsuarioRegistro().toUpperCase()
						+ "%");
			}
			where.append(" AND t4.USUARIO_REGISTRO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion() != null) {
			where.append(" AND t5.ID_TIPO_CERTIFICACION = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t5.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionCastellano()
						.toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionCastellano()
						.toUpperCase() + "%");
			}
			where.append(" AND t5.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t5.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(
						curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionEuskera().toUpperCase()
								+ "%");
			} else {
				params.add("%" + curriculum.getTiposCertificacionByIdCertificacionEuskera().getDescripcionEuskera()
						.toUpperCase() + "%");
			}
			where.append(" AND t5.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getFechaRegistro() != null) {
			where.append(" AND t5.FECHA_REGISTRO = ?");
			params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getFechaRegistro());
		}
		if (curriculum != null && curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t5.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTiposCertificacionByIdCertificacionEuskera().getUsuarioRegistro().toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ curriculum.getTiposCertificacionByIdCertificacionEuskera().getUsuarioRegistro().toUpperCase()
						+ "%");
			}
			where.append(" AND t5.USUARIO_REGISTRO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(curriculum.getIdExpediente());
		}
		if (curriculum != null && curriculum.getTitulacion() != null) {
			where.append(" AND UPPER(t1.TITULACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getTitulacion().toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getTitulacion().toUpperCase() + "%");
			}
			where.append(" AND t1.TITULACION IS NOT NULL");
		}
		if (curriculum != null && curriculum.getAnyoInicio() != null) {
			where.append(" AND t1.ANYO_INICIO = ?");
			params.add(curriculum.getAnyoInicio());
		}
		if (curriculum != null && curriculum.getAnyoFin() != null) {
			where.append(" AND t1.ANYO_FIN = ?");
			params.add(curriculum.getAnyoFin());
		}
		if (curriculum != null && curriculum.getMatriculasHonor() != null) {
			where.append(" AND t1.MATRICULAS_HONOR = ?");
			params.add(curriculum.getMatriculasHonor());
		}
		if (curriculum != null && curriculum.getSobresalientes() != null) {
			where.append(" AND t1.SOBRESALIENTES = ?");
			params.add(curriculum.getSobresalientes());
		}
		if (curriculum != null && curriculum.getNotables() != null) {
			where.append(" AND t1.NOTABLES = ?");
			params.add(curriculum.getNotables());
		}
		if (curriculum != null && curriculum.getSuficientes() != null) {
			where.append(" AND t1.SUFICIENTES = ?");
			params.add(curriculum.getSuficientes());
		}
		if (curriculum != null && curriculum.getEuskera() != null) {
			where.append(" AND t1.EUSKERA = ?");
			params.add(curriculum.getEuskera());
		}
		if (curriculum != null && curriculum.getFrances() != null) {
			where.append(" AND t1.FRANCES = ?");
			params.add(curriculum.getFrances());
		}
		if (curriculum != null && curriculum.getIngles() != null) {
			where.append(" AND t1.INGLES = ?");
			params.add(curriculum.getIngles());
		}
		if (curriculum != null && curriculum.getItaliano() != null) {
			where.append(" AND t1.ITALIANO = ?");
			params.add(curriculum.getItaliano());
		}
		if (curriculum != null && curriculum.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(curriculum.getFechaRegistro());
		}
		if (curriculum != null && curriculum.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (curriculum != null && curriculum.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(curriculum.getFechaUltmodificacion());
		}
		if (curriculum != null && curriculum.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(curriculum.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + curriculum.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
