package com.ejie.ab60.dao.BEC;

import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.ExperienciaLaboral;
import com.ejie.ab60.model.BEC.TiposCertificacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * ExperienciaLaboralDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ExperienciaLaboralDaoImpl implements ExperienciaLaboralDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDEXPERIENCIALABORAL", "EMPRESA", "PUESTO",
			"NUMERODIAS", "VALORAR", "COMERCIO", "IDCURRICULUM" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ExperienciaLaboral> rwMap = new RowMapper<ExperienciaLaboral>() {
		public ExperienciaLaboral mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			ExperienciaLaboral experienciaLaboral = new ExperienciaLaboral();
			experienciaLaboral.setIdExperienciaLaboral(resultSet.getInt("IDEXPERIENCIALABORAL"));
			experienciaLaboral.setEmpresa(resultSet.getString("EMPRESA"));
			experienciaLaboral.setPuesto(resultSet.getString("PUESTO"));
			experienciaLaboral.setNumeroDias(resultSet.getLong("NUMERODIAS"));
			if (resultSet.wasNull()) {
				experienciaLaboral.setNumeroDias(null);
			}
			experienciaLaboral.setValorar(resultSet.getInt("VALORAR"));
			experienciaLaboral.setComercio(resultSet.getInt("COMERCIO"));
			experienciaLaboral.setIdCurriculum(resultSet.getInt("IDCURRICULUM"));
			return experienciaLaboral;
		}
	};

	private RowMapper<ExperienciaLaboral> rwMapPK = new RowMapper<ExperienciaLaboral>() {
		public ExperienciaLaboral mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ExperienciaLaboral(resultSet.getInt("IDEXPERIENCIALABORAL"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ExperienciaLaboral>> rwMapJerarquia = new RowMapper<JerarquiaDto<ExperienciaLaboral>>() {
		public JerarquiaDto<ExperienciaLaboral> mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			ExperienciaLaboral experienciaLaboral = new ExperienciaLaboral();
			experienciaLaboral.setIdExperienciaLaboral(resultSet.getInt("IDEXPERIENCIALABORAL"));
			experienciaLaboral.setEmpresa(resultSet.getString("EMPRESA"));
			experienciaLaboral.setPuesto(resultSet.getString("PUESTO"));
			experienciaLaboral.setNumeroDias(resultSet.getLong("NUMERODIAS"));
			if (resultSet.wasNull()) {
				experienciaLaboral.setNumeroDias(null);
			}
			experienciaLaboral.setValorar(resultSet.getInt("VALORAR"));
			experienciaLaboral.setComercio(resultSet.getInt("COMERCIO"));
			experienciaLaboral.setIdCurriculum(resultSet.getInt("IDCURRICULUM"));

			JerarquiaDto<ExperienciaLaboral> jerarquia = new JerarquiaDto<ExperienciaLaboral>();
			jerarquia.setModel(experienciaLaboral);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ExperienciaLaboral table.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @return ExperienciaLaboral
	 */
	public ExperienciaLaboral add(ExperienciaLaboral experiencialaboral) {
		int idExperiencia = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6017T00"));
		experiencialaboral.setIdExperienciaLaboral(idExperiencia);
		String query = "INSERT INTO EXPERIENCIA_LABORAL (ID_EXPERIENCIA_LABORAL, ID_CURRICULUM, EMPRESA, PUESTO, NUMERO_DIAS, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION, VALORAR, COMERCIO) VALUES (?,?,?,?,?,?,?,?,?,?,?)";
		Object getCurriculumIdCurriculumAux = null;
		if (experiencialaboral != null && experiencialaboral.getIdCurriculum() != null) {
			getCurriculumIdCurriculumAux = experiencialaboral.getIdCurriculum();
		}
		this.jdbcTemplate.update(query, experiencialaboral.getIdExperienciaLaboral(), getCurriculumIdCurriculumAux,
				experiencialaboral.getEmpresa(), experiencialaboral.getPuesto(), experiencialaboral.getNumeroDias(),
				experiencialaboral.getFechaRegistro(), experiencialaboral.getUsuarioRegistro(),
				experiencialaboral.getFechaUltmodificacion(), experiencialaboral.getUsuarioUltmodificacion(),
				experiencialaboral.getValorar(), experiencialaboral.getComercio());
		return experiencialaboral;
	}

	/**
	 * Updates a single row in the ExperienciaLaboral table.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @return ExperienciaLaboral
	 */
	public ExperienciaLaboral update(ExperienciaLaboral experiencialaboral) {
		String query = "UPDATE EXPERIENCIA_LABORAL SET ID_CURRICULUM=?, EMPRESA=?, PUESTO=?, NUMERO_DIAS=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, VALORAR=?, COMERCIO=? WHERE ID_EXPERIENCIA_LABORAL=?";
		Object getCurriculumIdCurriculumAux = null;
		if (experiencialaboral != null && experiencialaboral.getIdCurriculum() != null) {
			getCurriculumIdCurriculumAux = experiencialaboral.getIdCurriculum();
		}
		this.jdbcTemplate.update(query, getCurriculumIdCurriculumAux, experiencialaboral.getEmpresa(),
				experiencialaboral.getPuesto(), experiencialaboral.getNumeroDias(),
				experiencialaboral.getFechaUltmodificacion(), experiencialaboral.getUsuarioUltmodificacion(),
				experiencialaboral.getValorar(), experiencialaboral.getComercio(),
				experiencialaboral.getIdExperienciaLaboral());
		return experiencialaboral;
	}

	/**
	 * Finds a single row in the ExperienciaLaboral table.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @return ExperienciaLaboral
	 */
	@Transactional(readOnly = true)
	public ExperienciaLaboral find(ExperienciaLaboral experiencialaboral) {
		String query = "SELECT t1.ID_EXPERIENCIA_LABORAL IDEXPERIENCIALABORAL, t1.EMPRESA EMPRESA, t1.PUESTO PUESTO, t1.NUMERO_DIAS NUMERODIAS, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.VALORAR VALORAR, t1.COMERCIO COMERCIO, t2.ID_CURRICULUM IDCURRICULUM FROM EXPERIENCIA_LABORAL t1 , CURRICULUM t2  WHERE t1.ID_EXPERIENCIA_LABORAL = ?   AND t1.ID_CURRICULUM= t2.ID_CURRICULUM(+)";

		List<ExperienciaLaboral> experiencialaboralList = this.jdbcTemplate.query(query, this.rwMap,
				experiencialaboral.getIdExperienciaLaboral());
		return (ExperienciaLaboral) DataAccessUtils.uniqueResult(experiencialaboralList);
	}

	/**
	 * Removes a single row in the ExperienciaLaboral table.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @return
	 */
	public void remove(ExperienciaLaboral experiencialaboral) {
		String query = "DELETE FROM EXPERIENCIA_LABORAL WHERE ID_EXPERIENCIA_LABORAL=?";
		this.jdbcTemplate.update(query, experiencialaboral.getIdExperienciaLaboral());
	}

	/**
	 * Finds a list of rows in the ExperienciaLaboral table.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ExperienciaLaboral>
	 */
	@Transactional(readOnly = true)
	public List<ExperienciaLaboral> findAll(ExperienciaLaboral experiencialaboral, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_EXPERIENCIA_LABORAL IDEXPERIENCIALABORAL,t1.EMPRESA EMPRESA,t1.PUESTO PUESTO,t1.NUMERO_DIAS NUMERODIAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t1.COMERCIO COMERCIO,t2.ID_CURRICULUM IDCURRICULUM ");
		query.append("FROM EXPERIENCIA_LABORAL t1 ,CURRICULUM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(experiencialaboral);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CURRICULUM= t2.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ExperienciaLaboralDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ExperienciaLaboral>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the ExperienciaLaboral table using like.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ExperienciaLaboral>
	 */
	@Transactional(readOnly = true)
	public List<ExperienciaLaboral> findAllLike(ExperienciaLaboral experiencialaboral,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_EXPERIENCIA_LABORAL IDEXPERIENCIALABORAL,t1.EMPRESA EMPRESA,t1.PUESTO PUESTO,t1.NUMERO_DIAS NUMERODIAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t1.COMERCIO COMERCIO,t2.ID_CURRICULUM IDCURRICULUM ");
		query.append("FROM EXPERIENCIA_LABORAL t1 ,CURRICULUM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(experiencialaboral, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CURRICULUM= t2.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ExperienciaLaboralDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ExperienciaLaboral>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ExperienciaLaboral table.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ExperienciaLaboral experiencialaboral) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM EXPERIENCIA_LABORAL t1 , CURRICULUM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(experiencialaboral);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CURRICULUM= t2.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ExperienciaLaboral table using like.
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ExperienciaLaboral experiencialaboral, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM EXPERIENCIA_LABORAL t1 ,CURRICULUM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(experiencialaboral, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CURRICULUM= t2.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ExperienciaLaboral selected for rup_table
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ExperienciaLaboral>>
	 */
	@Override
	public List<TableRowDto<ExperienciaLaboral>> reorderSelection(ExperienciaLaboral experiencialaboral,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPERIENCIA_LABORAL IDEXPERIENCIALABORAL,t1.EMPRESA EMPRESA,t1.PUESTO PUESTO,t1.NUMERO_DIAS NUMERODIAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t1.COMERCIO COMERCIO,t2.ID_CURRICULUM IDCURRICULUM ");
		// FROM
		query.append("FROM EXPERIENCIA_LABORAL t1 ,CURRICULUM t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(experiencialaboral, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CURRICULUM= t2.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ExperienciaLaboral.class, filterParamList, "ID_EXPERIENCIA_LABORAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ExperienciaLaboral>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ExperienciaLaboral
	 * @param searchParams
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ExperienciaLaboral>>
	 */
	@Override
	public List<TableRowDto<ExperienciaLaboral>> search(ExperienciaLaboral filterParams,
			ExperienciaLaboral searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPERIENCIA_LABORAL IDEXPERIENCIALABORAL,t1.EMPRESA EMPRESA,t1.PUESTO PUESTO,t1.NUMERO_DIAS NUMERODIAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t1.COMERCIO COMERCIO,t2.ID_CURRICULUM IDCURRICULUM ");
		// FROM
		query.append("FROM EXPERIENCIA_LABORAL t1 ,CURRICULUM t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CURRICULUM= t2.ID_CURRICULUM(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ExperienciaLaboral.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_EXPERIENCIA_LABORAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ExperienciaLaboral>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterexperiencialaboral
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ExperienciaLaboral filterexperiencialaboral, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPERIENCIA_LABORAL IDEXPERIENCIALABORAL,t1.EMPRESA EMPRESA,t1.PUESTO PUESTO,t1.NUMERO_DIAS NUMERODIAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t1.COMERCIO COMERCIO,t2.ID_CURRICULUM IDCURRICULUM ");
		// FROM
		query.append("FROM EXPERIENCIA_LABORAL t1 ,CURRICULUM t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterexperiencialaboral, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				ExperienciaLaboral.class, query, params, "ID_EXPERIENCIA_LABORAL");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ExperienciaLaboral table.
	 *
	 * @param filterExperienciaLaboral
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ExperienciaLaboral>>
	 */
	@Override
	public List<JerarquiaDto<ExperienciaLaboral>> findAllLikeJerarquia(ExperienciaLaboral filterExperienciaLaboral,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPERIENCIA_LABORAL IDEXPERIENCIALABORAL,t1.EMPRESA EMPRESA,t1.PUESTO PUESTO,t1.NUMERO_DIAS NUMERODIAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t1.COMERCIO COMERCIO,t2.ID_CURRICULUM IDCURRICULUM ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM EXPERIENCIA_LABORAL t1
		// ,CURRICULUM t2 ");
		List<String> from = new ArrayList<String>();
		from.add("EXPERIENCIA_LABORAL");
		from.add("CURRICULUM");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterExperienciaLaboral, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_EXPERIENCIA_LABORAL",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ExperienciaLaboralDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterExperienciaLaboral
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ExperienciaLaboral filterExperienciaLaboral,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM EXPERIENCIA_LABORAL t1
		// ,CURRICULUM t2 ");
		List<String> from = new ArrayList<String>();
		from.add("EXPERIENCIA_LABORAL");
		from.add("CURRICULUM");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterExperienciaLaboral, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_EXPERIENCIA_LABORAL", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterExperienciaLaboral
	 *            ExperienciaLaboral
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ExperienciaLaboral>>
	 */
	@Override
	public List<TableRowDto<ExperienciaLaboral>> findAllChild(ExperienciaLaboral filterExperienciaLaboral,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM EXPERIENCIA_LABORAL t1
		// ,CURRICULUM t2 ");
		List<String> from = new ArrayList<String>();
		from.add("EXPERIENCIA_LABORAL");
		from.add("CURRICULUM");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterExperienciaLaboral, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_EXPERIENCIA_LABORAL", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ExperienciaLaboral>(this.rwMapPK, "ID_EXPERIENCIA_LABORAL"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ExperienciaLaboral entity
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ExperienciaLaboral experiencialaboral) {

		StringBuilder where = new StringBuilder(ExperienciaLaboralDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (experiencialaboral != null && experiencialaboral.getIdExperienciaLaboral() != null) {
			where.append(" AND t1.ID_EXPERIENCIA_LABORAL = ?");
			params.add(experiencialaboral.getIdExperienciaLaboral());
		}
		if (experiencialaboral != null && experiencialaboral.getIdCurriculum() != null) {
			where.append(" AND t2.ID_CURRICULUM = ?");
			params.add(experiencialaboral.getIdCurriculum());
		}

		if (experiencialaboral != null && experiencialaboral.getEmpresa() != null) {
			where.append(" AND t1.EMPRESA = ?");
			params.add(experiencialaboral.getEmpresa());
		}
		if (experiencialaboral != null && experiencialaboral.getPuesto() != null) {
			where.append(" AND t1.PUESTO = ?");
			params.add(experiencialaboral.getPuesto());
		}
		if (experiencialaboral != null && experiencialaboral.getNumeroDias() != null) {
			where.append(" AND t1.NUMERO_DIAS = ?");
			params.add(experiencialaboral.getNumeroDias());
		}
		if (experiencialaboral != null && experiencialaboral.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(experiencialaboral.getFechaRegistro());
		}
		if (experiencialaboral != null && experiencialaboral.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(experiencialaboral.getUsuarioRegistro());
		}
		if (experiencialaboral != null && experiencialaboral.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(experiencialaboral.getFechaUltmodificacion());
		}
		if (experiencialaboral != null && experiencialaboral.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(experiencialaboral.getUsuarioUltmodificacion());
		}
		if (experiencialaboral != null && experiencialaboral.getValorar() != null) {
			where.append(" AND t1.VALORAR = ?");
			params.add(experiencialaboral.getValorar());
		}
		if (experiencialaboral != null && experiencialaboral.getComercio() != null) {
			where.append(" AND t1.COMERCIO = ?");
			params.add(experiencialaboral.getComercio());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ExperienciaLaboral entity
	 *
	 * @param experiencialaboral
	 *            ExperienciaLaboral Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ExperienciaLaboral experiencialaboral, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ExperienciaLaboralDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (experiencialaboral != null && experiencialaboral.getIdExperienciaLaboral() != null) {
			where.append(" AND t1.ID_EXPERIENCIA_LABORAL = ?");
			params.add(experiencialaboral.getIdExperienciaLaboral());
		}
		if (experiencialaboral != null && experiencialaboral.getCurriculum() != null
				&& experiencialaboral.getCurriculum().getIdCurriculum() != null) {
			where.append(" AND t2.ID_CURRICULUM = ?");
			params.add(experiencialaboral.getCurriculum().getIdCurriculum());
		}

		if (experiencialaboral != null && experiencialaboral.getEmpresa() != null) {
			where.append(" AND UPPER(t1.EMPRESA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(experiencialaboral.getEmpresa().toUpperCase() + "%");
			} else {
				params.add("%" + experiencialaboral.getEmpresa().toUpperCase() + "%");
			}
			where.append(" AND t1.EMPRESA IS NOT NULL");
		}
		if (experiencialaboral != null && experiencialaboral.getPuesto() != null) {
			where.append(" AND UPPER(t1.PUESTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(experiencialaboral.getPuesto().toUpperCase() + "%");
			} else {
				params.add("%" + experiencialaboral.getPuesto().toUpperCase() + "%");
			}
			where.append(" AND t1.PUESTO IS NOT NULL");
		}
		if (experiencialaboral != null && experiencialaboral.getNumeroDias() != null) {
			where.append(" AND t1.NUMERO_DIAS = ?");
			params.add(experiencialaboral.getNumeroDias());
		}
		if (experiencialaboral != null && experiencialaboral.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(experiencialaboral.getFechaRegistro());
		}
		if (experiencialaboral != null && experiencialaboral.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(experiencialaboral.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + experiencialaboral.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (experiencialaboral != null && experiencialaboral.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(experiencialaboral.getFechaUltmodificacion());
		}
		if (experiencialaboral != null && experiencialaboral.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(experiencialaboral.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + experiencialaboral.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (experiencialaboral != null && experiencialaboral.getValorar() != null) {
			where.append(" AND t1.VALORAR = ?");
			params.add(experiencialaboral.getValorar());
		}
		if (experiencialaboral != null && experiencialaboral.getComercio() != null) {
			where.append(" AND t1.COMERCIO = ?");
			params.add(experiencialaboral.getComercio());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
