package com.ejie.ab60.dao.BEC;

import com.ejie.ab60.model.BEC.Fases;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * FasesDao  
 * 
 *  
 */

public interface FasesDao {

	/**
	 * Inserts a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @return Fases
	 */
	Fases add(Fases fases);

	/**
	 * Updates a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @return Fases
	 */
	Fases update(Fases fases);

	/**
	 * Finds a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @return Fases
	 */
	Fases find(Fases fases);

	/**
	 * Finds a list of rows in the Fases table.
	 *
	 * 
	 * @return List<Fases>
	 */
	List<Fases> findFases();

	/**
	 * Removes a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 */
	void remove(Fases fases);

	/**
	 * Finds a List of rows in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<Fases> findAll(Fases fases, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Fases table using like.
	 *
	 * @param fases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Fases> findAllLike(Fases fases, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Fases filterFases, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the Fases table using like.
	 *
	 * @param fases
	 *            Fases
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(Fases fases, Boolean startsWith);

	/**
	 * Counts rows in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @return Long
	 */
	Long findAllCount(Fases fases);

	/**
	 * Reorder selection.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Fases>>
	 */
	List<TableRowDto<Fases>> reorderSelection(Fases filterFases, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param searchFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Fases>>
	 */
	List<TableRowDto<Fases>> search(Fases filterFases, Fases searchFases, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Fases>>
	 */
	List<JerarquiaDto<Fases>> findAllLikeJerarquia(Fases filterFases, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(Fases filterFases, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Fases>>
	 */
	List<TableRowDto<Fases>> findAllChild(Fases filterFases, JQGridRequestDto jqGridRequestDto);

}
