package com.ejie.ab60.dao.BEC;

import com.bea.core.repackaged.springframework.context.i18n.LocaleContextHolder;
import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.model.BEC.Caracteristicas;
import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.OtrosTitulos;
import com.ejie.ab60.model.BEC.TiposCertificacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * OtrosTitulosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class OtrosTitulosDaoImpl implements OtrosTitulosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] {
			"IDTITULOCURSO, TITULOCURSO, ENTIDAD, HORAS, FECHAREGISTRO, USUARIOREGISTRO, FECHAULTMODIFICACION, USUARIOULTMODIFICACION, VALORAR, IDCARACTERISTICA, CDESCRIPCIONCASTELLANO, CDESCRIPCIONEUSKERA, CFECHAREGISTRO, CUSUARIOREGISTRO, IDCURRICULUM " };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<OtrosTitulos> rwMap = new RowMapper<OtrosTitulos>() {
		public OtrosTitulos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			OtrosTitulos otrosTitulos = new OtrosTitulos();
			otrosTitulos.setIdTituloCurso(resultSet.getInt("IDTITULOCURSO"));
			otrosTitulos.setTituloCurso(resultSet.getString("TITULOCURSO"));
			otrosTitulos.setEntidad(resultSet.getString("ENTIDAD"));
			otrosTitulos.setHoras(resultSet.getLong("HORAS"));
			if (resultSet.wasNull()) {
				otrosTitulos.setHoras(null);
			}
			otrosTitulos.setValorar(resultSet.getInt("VALORAR"));
			Caracteristicas caracteristicas = new Caracteristicas();
			caracteristicas.setIdCaracteristica(resultSet.getLong("IDCARACTERISTICA"));
			caracteristicas.setDescripcionCastellano(resultSet.getString("CDESCRIPCIONCASTELLANO"));
			caracteristicas.setDescripcionEuskera(resultSet.getString("CDESCRIPCIONEUSKERA"));
			if (LocaleContextHolder.getLocale().toString().equals("es")) {
				caracteristicas.setDescripcion(resultSet.getString("CDESCRIPCIONCASTELLANO"));
			} else {
				caracteristicas.setDescripcion(resultSet.getString("CDESCRIPCIONEUSKERA"));
			}
			otrosTitulos.setCaracteristicas(caracteristicas);
			otrosTitulos.setIdCurriculum(resultSet.getInt("IDCURRICULUM"));

			return otrosTitulos;

		}
	};

	private RowMapper<OtrosTitulos> rwMapPK = new RowMapper<OtrosTitulos>() {
		public OtrosTitulos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new OtrosTitulos(resultSet.getInt("IDTITULOCURSO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<OtrosTitulos>> rwMapJerarquia = new RowMapper<JerarquiaDto<OtrosTitulos>>() {
		public JerarquiaDto<OtrosTitulos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			OtrosTitulos otrosTitulos = new OtrosTitulos();
			otrosTitulos.setIdTituloCurso(resultSet.getInt("IDTITULOCURSO"));
			otrosTitulos.setTituloCurso(resultSet.getString("TITULOCURSO"));
			otrosTitulos.setEntidad(resultSet.getString("ENTIDAD"));
			otrosTitulos.setHoras(resultSet.getLong("HORAS"));
			otrosTitulos.setValorar(resultSet.getInt("VALORAR"));
			Caracteristicas caracteristicas = new Caracteristicas();
			caracteristicas.setIdCaracteristica(resultSet.getLong("IDCARACTERISTICA"));
			caracteristicas.setDescripcionCastellano(resultSet.getString("CDESCRIPCIONCASTELLANO"));
			caracteristicas.setDescripcionEuskera(resultSet.getString("CDESCRIPCIONEUSKERA"));
			otrosTitulos.setCaracteristicas(caracteristicas);
			otrosTitulos.setIdCurriculum(resultSet.getInt("IDCURRICULUM"));

			JerarquiaDto<OtrosTitulos> jerarquia = new JerarquiaDto<OtrosTitulos>();
			jerarquia.setModel(otrosTitulos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the OtrosTitulos table.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @return OtrosTitulos
	 */
	public OtrosTitulos add(OtrosTitulos otrostitulos) {
		int idTitulo = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6016T00"));
		otrostitulos.setIdTituloCurso(idTitulo);
		String query = "INSERT INTO OTROS_TITULOS (ID_TITULO_CURSO, ID_CARACTERISTICA, ID_CURRICULUM, TITULO_CURSO, ENTIDAD, HORAS, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION, VALORAR) VALUES (?,?,?,?,?,?,?,?,?,?,?)";
		Object getIDCARACTERISTICAAux = null;
		if (otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getIdCaracteristica() != null) {
			getIDCARACTERISTICAAux = otrostitulos.getCaracteristicas().getIdCaracteristica();
		}
		Object getIDCURRICULUMAux = null;
		if (otrostitulos != null && otrostitulos.getIdCurriculum() != null) {
			getIDCURRICULUMAux = otrostitulos.getIdCurriculum();
		}
		this.jdbcTemplate.update(query, otrostitulos.getIdTituloCurso(), getIDCARACTERISTICAAux, getIDCURRICULUMAux,
				otrostitulos.getTituloCurso(), otrostitulos.getEntidad(), otrostitulos.getHoras(),
				otrostitulos.getFechaRegistro(), otrostitulos.getUsuarioRegistro(),
				otrostitulos.getFechaUltmodificacion(), otrostitulos.getUsuarioUltmodificacion(),
				otrostitulos.getValorar());
		return otrostitulos;
	}

	/**
	 * Updates a single row in the OtrosTitulos table.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @return OtrosTitulos
	 */
	public OtrosTitulos update(OtrosTitulos otrostitulos) {
		String query = "UPDATE OTROS_TITULOS SET ID_CARACTERISTICA=?, ID_CURRICULUM=?, TITULO_CURSO=?, ENTIDAD=?, HORAS=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, VALORAR=? WHERE ID_TITULO_CURSO=?";
		Object getIDCARACTERISTICAAux = null;
		if (otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getIdCaracteristica() != null) {
			getIDCARACTERISTICAAux = otrostitulos.getCaracteristicas().getIdCaracteristica();
		}
		Object getIDCURRICULUMAux = null;
		if (otrostitulos != null && otrostitulos.getIdCurriculum() != null) {
			getIDCURRICULUMAux = otrostitulos.getIdCurriculum();
		}
		this.jdbcTemplate.update(query, getIDCARACTERISTICAAux, getIDCURRICULUMAux, otrostitulos.getTituloCurso(),
				otrostitulos.getEntidad(), otrostitulos.getHoras(), otrostitulos.getFechaUltmodificacion(),
				otrostitulos.getUsuarioUltmodificacion(), otrostitulos.getValorar(), otrostitulos.getIdTituloCurso());
		return otrostitulos;
	}

	/**
	 * Finds a single row in the OtrosTitulos table.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @return OtrosTitulos
	 */
	@Transactional(readOnly = true)
	public OtrosTitulos find(OtrosTitulos otrostitulos) {
		String query = "SELECT t1.ID_TITULO_CURSO IDTITULOCURSO, t1.TITULO_CURSO TITULOCURSO, t1.ENTIDAD ENTIDAD, t1.HORAS HORAS, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.VALORAR VALORAR, t2.ID_CARACTERISTICA IDCARACTERISTICA, t2.DESCRIPCION_CASTELLANO CDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA CDESCRIPCIONEUSKERA, t2.FECHA_REGISTRO CFECHAREGISTRO, t2.USUARIO_REGISTRO CUSUARIOREGISTRO, t3.ID_CURRICULUM IDCURRICULUM, t3.ID_EXPEDIENTE CURRICULUMIDEXPEDIENTE, t3.TITULACION CURRICULUMTITULACION, t3.ANYO_INICIO CURRICULUMANYOINICIO, t3.ANYO_FIN CURRICULUMANYOFIN, t3.MATRICULAS_HONOR CURRICULUMMATRICULASHONOR, t3.SOBRESALIENTES CURRICULUMSOBRESALIENTES, t3.NOTABLES CURRICULUMNOTABLES, t3.SUFICIENTES CURRICULUMSUFICIENTES, t3.EUSKERA CURRICULUMEUSKERA, t3.FRANCES CURRICULUMFRANCES, t3.INGLES CURRICULUMINGLES, t3.ITALIANO CURRICULUMITALIANO, t3.FECHA_REGISTRO CURRICULUMFECHAREGISTRO, t3.USUARIO_REGISTRO CURRICULUMUSUARIOREGISTRO, t3.FECHA_ULTMODIFICACION CUFECHAULTMODIFICACION, t3.USUARIO_ULTMODIFICACION CUUSUARIOULTMODIFICACION, t3.ID_CERTIFICACION_INGLES IDCERTIFICACIONINGLES, t3.ID_CERTIFICACION_FRANCES IDCERTIFICACIONFRANCES, t3.ID_CERTIFICACION_ITALIANO IDCERTIFICACIONITALIANO, t3.ID_CERTIFICACION_EUSKERA IDCERTIFICACIONEUSKERA FROM OTROS_TITULOS t1 , CARACTERISTICAS t2 , CURRICULUM t3  WHERE t1.ID_TITULO_CURSO = ?   AND t1.ID_CARACTERISTICA= t2.ID_CARACTERISTICA(+) AND t1.ID_CURRICULUM= t3.ID_CURRICULUM(+)";

		List<OtrosTitulos> otrostitulosList = this.jdbcTemplate.query(query, this.rwMap,
				otrostitulos.getIdTituloCurso());
		return (OtrosTitulos) DataAccessUtils.uniqueResult(otrostitulosList);
	}

	/**
	 * Removes a single row in the OtrosTitulos table.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @return
	 */
	public void remove(OtrosTitulos otrostitulos) {
		String query = "DELETE FROM OTROS_TITULOS WHERE ID_TITULO_CURSO=?";
		this.jdbcTemplate.update(query, otrostitulos.getIdTituloCurso());
	}

	/**
	 * Finds a list of rows in the OtrosTitulos table.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<OtrosTitulos>
	 */
	@Transactional(readOnly = true)
	public List<OtrosTitulos> findAll(OtrosTitulos otrostitulos, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TITULO_CURSO IDTITULOCURSO,t1.TITULO_CURSO TITULOCURSO,t1.ENTIDAD ENTIDAD,t1.HORAS HORAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t2.ID_CARACTERISTICA IDCARACTERISTICA,t2.DESCRIPCION_CASTELLANO CDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA CDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO CFECHAREGISTRO,t2.USUARIO_REGISTRO CUSUARIOREGISTRO,t3.ID_CURRICULUM IDCURRICULUM ");
		query.append("FROM OTROS_TITULOS t1 ,CARACTERISTICAS t2 ,CURRICULUM t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(otrostitulos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CARACTERISTICA= t2.ID_CARACTERISTICA(+) AND t1.ID_CURRICULUM= t3.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, OtrosTitulosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<OtrosTitulos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the OtrosTitulos table using like.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<OtrosTitulos>
	 */
	@Transactional(readOnly = true)
	public List<OtrosTitulos> findAllLike(OtrosTitulos otrostitulos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TITULO_CURSO IDTITULOCURSO,t1.TITULO_CURSO TITULOCURSO,t1.ENTIDAD ENTIDAD,t1.HORAS HORAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t2.ID_CARACTERISTICA IDCARACTERISTICA,t2.DESCRIPCION_CASTELLANO CDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA CDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO CFECHAREGISTRO,t2.USUARIO_REGISTRO CUSUARIOREGISTRO,t3.ID_CURRICULUM IDCURRICULUM,t3.ID_EXPEDIENTE CURRICULUMIDEXPEDIENTE,t3.TITULACION CURRICULUMTITULACION,t3.ANYO_INICIO CURRICULUMANYOINICIO,t3.ANYO_FIN CURRICULUMANYOFIN,t3.MATRICULAS_HONOR CURRICULUMMATRICULASHONOR,t3.SOBRESALIENTES CURRICULUMSOBRESALIENTES,t3.NOTABLES CURRICULUMNOTABLES,t3.SUFICIENTES CURRICULUMSUFICIENTES,t3.EUSKERA CURRICULUMEUSKERA,t3.FRANCES CURRICULUMFRANCES,t3.INGLES CURRICULUMINGLES,t3.ITALIANO CURRICULUMITALIANO,t3.FECHA_REGISTRO CURRICULUMFECHAREGISTRO,t3.USUARIO_REGISTRO CURRICULUMUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CUFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CUUSUARIOULTMODIFICACION,t3.ID_CERTIFICACION_INGLES IDCERTIFICACIONINGLES,t3.ID_CERTIFICACION_FRANCES IDCERTIFICACIONFRANCES,t3.ID_CERTIFICACION_ITALIANO IDCERTIFICACIONITALIANO,t3.ID_CERTIFICACION_EUSKERA IDCERTIFICACIONEUSKERA ");
		query.append("FROM OTROS_TITULOS t1 ,CARACTERISTICAS t2 ,CURRICULUM t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(otrostitulos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CARACTERISTICA= t2.ID_CARACTERISTICA(+) AND t1.ID_CURRICULUM= t3.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, OtrosTitulosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<OtrosTitulos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the OtrosTitulos table.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(OtrosTitulos otrostitulos) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM OTROS_TITULOS t1 , CARACTERISTICAS t2 , CURRICULUM t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(otrostitulos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CARACTERISTICA= t2.ID_CARACTERISTICA(+) AND t1.ID_CURRICULUM= t3.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the OtrosTitulos table using like.
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(OtrosTitulos otrostitulos, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM OTROS_TITULOS t1 ,CARACTERISTICAS t2 ,CURRICULUM t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(otrostitulos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CARACTERISTICA= t2.ID_CARACTERISTICA(+) AND t1.ID_CURRICULUM= t3.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of OtrosTitulos selected for rup_table
	 *
	 * @param otrostitulos
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<OtrosTitulos>>
	 */
	@Override
	public List<TableRowDto<OtrosTitulos>> reorderSelection(OtrosTitulos otrostitulos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TITULO_CURSO IDTITULOCURSO,t1.TITULO_CURSO TITULOCURSO,t1.ENTIDAD ENTIDAD,t1.HORAS HORAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t2.ID_CARACTERISTICA IDCARACTERISTICA,t2.DESCRIPCION_CASTELLANO CDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA CDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO CFECHAREGISTRO,t2.USUARIO_REGISTRO CUSUARIOREGISTRO,t3.ID_CURRICULUM IDCURRICULUM,t3.ID_EXPEDIENTE CURRICULUMIDEXPEDIENTE,t3.TITULACION CURRICULUMTITULACION,t3.ANYO_INICIO CURRICULUMANYOINICIO,t3.ANYO_FIN CURRICULUMANYOFIN,t3.MATRICULAS_HONOR CURRICULUMMATRICULASHONOR,t3.SOBRESALIENTES CURRICULUMSOBRESALIENTES,t3.NOTABLES CURRICULUMNOTABLES,t3.SUFICIENTES CURRICULUMSUFICIENTES,t3.EUSKERA CURRICULUMEUSKERA,t3.FRANCES CURRICULUMFRANCES,t3.INGLES CURRICULUMINGLES,t3.ITALIANO CURRICULUMITALIANO,t3.FECHA_REGISTRO CURRICULUMFECHAREGISTRO,t3.USUARIO_REGISTRO CURRICULUMUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CUFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CUUSUARIOULTMODIFICACION,t3.ID_CERTIFICACION_INGLES IDCERTIFICACIONINGLES,t3.ID_CERTIFICACION_FRANCES IDCERTIFICACIONFRANCES,t3.ID_CERTIFICACION_ITALIANO IDCERTIFICACIONITALIANO,t3.ID_CERTIFICACION_EUSKERA IDCERTIFICACIONEUSKERA ");
		// FROM
		query.append("FROM OTROS_TITULOS t1 ,CARACTERISTICAS t2 ,CURRICULUM t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(otrostitulos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CARACTERISTICA= t2.ID_CARACTERISTICA(+) AND t1.ID_CURRICULUM= t3.ID_CURRICULUM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, OtrosTitulos.class,
				filterParamList, "ID_TITULO_CURSO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<OtrosTitulos>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            OtrosTitulos
	 * @param searchParams
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<OtrosTitulos>>
	 */
	@Override
	public List<TableRowDto<OtrosTitulos>> search(OtrosTitulos filterParams, OtrosTitulos searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TITULO_CURSO IDTITULOCURSO,t1.TITULO_CURSO TITULOCURSO,t1.ENTIDAD ENTIDAD,t1.HORAS HORAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t2.ID_CARACTERISTICA IDCARACTERISTICA,t2.DESCRIPCION_CASTELLANO CDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA CDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO CFECHAREGISTRO,t2.USUARIO_REGISTRO CUSUARIOREGISTRO,t3.ID_CURRICULUM IDCURRICULUM,t3.ID_EXPEDIENTE CURRICULUMIDEXPEDIENTE,t3.TITULACION CURRICULUMTITULACION,t3.ANYO_INICIO CURRICULUMANYOINICIO,t3.ANYO_FIN CURRICULUMANYOFIN,t3.MATRICULAS_HONOR CURRICULUMMATRICULASHONOR,t3.SOBRESALIENTES CURRICULUMSOBRESALIENTES,t3.NOTABLES CURRICULUMNOTABLES,t3.SUFICIENTES CURRICULUMSUFICIENTES,t3.EUSKERA CURRICULUMEUSKERA,t3.FRANCES CURRICULUMFRANCES,t3.INGLES CURRICULUMINGLES,t3.ITALIANO CURRICULUMITALIANO,t3.FECHA_REGISTRO CURRICULUMFECHAREGISTRO,t3.USUARIO_REGISTRO CURRICULUMUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CUFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CUUSUARIOULTMODIFICACION,t3.ID_CERTIFICACION_INGLES IDCERTIFICACIONINGLES,t3.ID_CERTIFICACION_FRANCES IDCERTIFICACIONFRANCES,t3.ID_CERTIFICACION_ITALIANO IDCERTIFICACIONITALIANO,t3.ID_CERTIFICACION_EUSKERA IDCERTIFICACIONEUSKERA ");
		// FROM
		query.append("FROM OTROS_TITULOS t1 ,CARACTERISTICAS t2 ,CURRICULUM t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_CARACTERISTICA= t2.ID_CARACTERISTICA(+) AND t1.ID_CURRICULUM= t3.ID_CURRICULUM(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, OtrosTitulos.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_TITULO_CURSO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<OtrosTitulos>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterotrostitulos
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(OtrosTitulos filterotrostitulos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TITULO_CURSO IDTITULOCURSO,t1.TITULO_CURSO TITULOCURSO,t1.ENTIDAD ENTIDAD,t1.HORAS HORAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t2.ID_CARACTERISTICA IDCARACTERISTICA,t2.DESCRIPCION_CASTELLANO CDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA CDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO CFECHAREGISTRO,t2.USUARIO_REGISTRO CUSUARIOREGISTRO,t3.ID_CURRICULUM IDCURRICULUM,t3.ID_EXPEDIENTE CURRICULUMIDEXPEDIENTE,t3.TITULACION CURRICULUMTITULACION,t3.ANYO_INICIO CURRICULUMANYOINICIO,t3.ANYO_FIN CURRICULUMANYOFIN,t3.MATRICULAS_HONOR CURRICULUMMATRICULASHONOR,t3.SOBRESALIENTES CURRICULUMSOBRESALIENTES,t3.NOTABLES CURRICULUMNOTABLES,t3.SUFICIENTES CURRICULUMSUFICIENTES,t3.EUSKERA CURRICULUMEUSKERA,t3.FRANCES CURRICULUMFRANCES,t3.INGLES CURRICULUMINGLES,t3.ITALIANO CURRICULUMITALIANO,t3.FECHA_REGISTRO CURRICULUMFECHAREGISTRO,t3.USUARIO_REGISTRO CURRICULUMUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CUFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CUUSUARIOULTMODIFICACION,t3.ID_CERTIFICACION_INGLES IDCERTIFICACIONINGLES,t3.ID_CERTIFICACION_FRANCES IDCERTIFICACIONFRANCES,t3.ID_CERTIFICACION_ITALIANO IDCERTIFICACIONITALIANO,t3.ID_CERTIFICACION_EUSKERA IDCERTIFICACIONEUSKERA ");
		// FROM
		query.append("FROM OTROS_TITULOS t1 ,CARACTERISTICAS t2 ,CURRICULUM t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterotrostitulos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, OtrosTitulos.class,
				query, params, "ID_TITULO_CURSO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical OtrosTitulos table.
	 *
	 * @param filterOtrosTitulos
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<OtrosTitulos>>
	 */
	@Override
	public List<JerarquiaDto<OtrosTitulos>> findAllLikeJerarquia(OtrosTitulos filterOtrosTitulos,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TITULO_CURSO IDTITULOCURSO,t1.TITULO_CURSO TITULOCURSO,t1.ENTIDAD ENTIDAD,t1.HORAS HORAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.VALORAR VALORAR,t2.ID_CARACTERISTICA IDCARACTERISTICA,t2.DESCRIPCION_CASTELLANO CDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA CDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO CFECHAREGISTRO,t2.USUARIO_REGISTRO CUSUARIOREGISTRO,t3.ID_CURRICULUM IDCURRICULUM,t3.ID_EXPEDIENTE CURRICULUMIDEXPEDIENTE,t3.TITULACION CURRICULUMTITULACION,t3.ANYO_INICIO CURRICULUMANYOINICIO,t3.ANYO_FIN CURRICULUMANYOFIN,t3.MATRICULAS_HONOR CURRICULUMMATRICULASHONOR,t3.SOBRESALIENTES CURRICULUMSOBRESALIENTES,t3.NOTABLES CURRICULUMNOTABLES,t3.SUFICIENTES CURRICULUMSUFICIENTES,t3.EUSKERA CURRICULUMEUSKERA,t3.FRANCES CURRICULUMFRANCES,t3.INGLES CURRICULUMINGLES,t3.ITALIANO CURRICULUMITALIANO,t3.FECHA_REGISTRO CURRICULUMFECHAREGISTRO,t3.USUARIO_REGISTRO CURRICULUMUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CUFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CUUSUARIOULTMODIFICACION,t3.ID_CERTIFICACION_INGLES IDCERTIFICACIONINGLES,t3.ID_CERTIFICACION_FRANCES IDCERTIFICACIONFRANCES,t3.ID_CERTIFICACION_ITALIANO IDCERTIFICACIONITALIANO,t3.ID_CERTIFICACION_EUSKERA IDCERTIFICACIONEUSKERA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM OTROS_TITULOS t1
		// ,CARACTERISTICAS t2 ,CURRICULUM t3 ");
		List<String> from = new ArrayList<String>();
		from.add("OTROS_TITULOS");
		from.add("CARACTERISTICAS");
		from.add("CURRICULUM");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOtrosTitulos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TITULO_CURSO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					OtrosTitulosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterOtrosTitulos
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(OtrosTitulos filterOtrosTitulos, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM OTROS_TITULOS t1
		// ,CARACTERISTICAS t2 ,CURRICULUM t3 ");
		List<String> from = new ArrayList<String>();
		from.add("OTROS_TITULOS");
		from.add("CARACTERISTICAS");
		from.add("CURRICULUM");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOtrosTitulos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TITULO_CURSO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterOtrosTitulos
	 *            OtrosTitulos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<OtrosTitulos>>
	 */
	@Override
	public List<TableRowDto<OtrosTitulos>> findAllChild(OtrosTitulos filterOtrosTitulos,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM OTROS_TITULOS t1
		// ,CARACTERISTICAS t2 ,CURRICULUM t3 ");
		List<String> from = new ArrayList<String>();
		from.add("OTROS_TITULOS");
		from.add("CARACTERISTICAS");
		from.add("CURRICULUM");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOtrosTitulos, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_TITULO_CURSO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<OtrosTitulos>(this.rwMapPK, "ID_TITULO_CURSO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the OtrosTitulos entity
	 *
	 * @param otrostitulos
	 *            OtrosTitulos Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(OtrosTitulos otrostitulos) {

		StringBuilder where = new StringBuilder(OtrosTitulosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (otrostitulos != null && otrostitulos.getIdTituloCurso() != null) {
			where.append(" AND t1.ID_TITULO_CURSO = ?");
			params.add(otrostitulos.getIdTituloCurso());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getIdCaracteristica() != null) {
			where.append(" AND t2.ID_CARACTERISTICA = ?");
			params.add(otrostitulos.getCaracteristicas().getIdCaracteristica());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(otrostitulos.getCaracteristicas().getDescripcionCastellano());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(otrostitulos.getCaracteristicas().getDescripcionEuskera());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(otrostitulos.getCaracteristicas().getFechaRegistro());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(otrostitulos.getCaracteristicas().getUsuarioRegistro());
		}
		if (otrostitulos != null && otrostitulos.getIdCurriculum() != null && otrostitulos.getIdCurriculum() != null) {
			where.append(" AND t3.ID_CURRICULUM = ?");
			params.add(otrostitulos.getIdCurriculum());
		}

		if (otrostitulos != null && otrostitulos.getTituloCurso() != null) {
			where.append(" AND t1.TITULO_CURSO = ?");
			params.add(otrostitulos.getTituloCurso());
		}
		if (otrostitulos != null && otrostitulos.getEntidad() != null) {
			where.append(" AND t1.ENTIDAD = ?");
			params.add(otrostitulos.getEntidad());
		}
		if (otrostitulos != null && otrostitulos.getHoras() != null) {
			where.append(" AND t1.HORAS = ?");
			params.add(otrostitulos.getHoras());
		}
		if (otrostitulos != null && otrostitulos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(otrostitulos.getFechaRegistro());
		}
		if (otrostitulos != null && otrostitulos.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(otrostitulos.getUsuarioRegistro());
		}
		if (otrostitulos != null && otrostitulos.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(otrostitulos.getFechaUltmodificacion());
		}
		if (otrostitulos != null && otrostitulos.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(otrostitulos.getUsuarioUltmodificacion());
		}
		if (otrostitulos != null && otrostitulos.getValorar() != null) {
			where.append(" AND t1.VALORAR = ?");
			params.add(otrostitulos.getValorar());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the OtrosTitulos entity
	 *
	 * @param otrostitulos
	 *            OtrosTitulos Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(OtrosTitulos otrostitulos, Boolean startsWith) {

		StringBuilder where = new StringBuilder(OtrosTitulosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (otrostitulos != null && otrostitulos.getIdTituloCurso() != null) {
			where.append(" AND t1.ID_TITULO_CURSO = ?");
			params.add(otrostitulos.getIdTituloCurso());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getIdCaracteristica() != null) {
			where.append(" AND t2.ID_CARACTERISTICA = ?");
			params.add(otrostitulos.getCaracteristicas().getIdCaracteristica());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrostitulos.getCaracteristicas().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + otrostitulos.getCaracteristicas().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrostitulos.getCaracteristicas().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + otrostitulos.getCaracteristicas().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(otrostitulos.getCaracteristicas().getFechaRegistro());
		}
		if (otrostitulos != null && otrostitulos.getCaracteristicas() != null
				&& otrostitulos.getCaracteristicas().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrostitulos.getCaracteristicas().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + otrostitulos.getCaracteristicas().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (otrostitulos != null && otrostitulos.getCurriculum() != null
				&& otrostitulos.getCurriculum().getIdCurriculum() != null) {
			where.append(" AND t3.ID_CURRICULUM = ?");
			params.add(otrostitulos.getCurriculum().getIdCurriculum());
		}

		if (otrostitulos != null && otrostitulos.getTituloCurso() != null) {
			where.append(" AND UPPER(t1.TITULO_CURSO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrostitulos.getTituloCurso().toUpperCase() + "%");
			} else {
				params.add("%" + otrostitulos.getTituloCurso().toUpperCase() + "%");
			}
			where.append(" AND t1.TITULO_CURSO IS NOT NULL");
		}
		if (otrostitulos != null && otrostitulos.getEntidad() != null) {
			where.append(" AND UPPER(t1.ENTIDAD) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrostitulos.getEntidad().toUpperCase() + "%");
			} else {
				params.add("%" + otrostitulos.getEntidad().toUpperCase() + "%");
			}
			where.append(" AND t1.ENTIDAD IS NOT NULL");
		}
		if (otrostitulos != null && otrostitulos.getHoras() != null) {
			where.append(" AND t1.HORAS = ?");
			params.add(otrostitulos.getHoras());
		}
		if (otrostitulos != null && otrostitulos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(otrostitulos.getFechaRegistro());
		}
		if (otrostitulos != null && otrostitulos.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrostitulos.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + otrostitulos.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (otrostitulos != null && otrostitulos.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(otrostitulos.getFechaUltmodificacion());
		}
		if (otrostitulos != null && otrostitulos.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrostitulos.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + otrostitulos.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (otrostitulos != null && otrostitulos.getValorar() != null) {
			where.append(" AND t1.VALORAR = ?");
			params.add(otrostitulos.getValorar());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
