package com.ejie.ab60.dao.BEC;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.dao.MEC.ParticipantesDaoImpl;
import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.Fases;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.estudioTecnico.MotivosDesestimacion;
import com.ejie.ab60.model.estudioTecnico.TiposResultado;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.terceros.DatosTerceros;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * PuntuacionesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PuntuacionesDaoImpl implements PuntuacionesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPUNTUACION", "IDEXPEDIENTE",
			"PUNTUACIONEXPACA", "PUNTUACIONIDIOMAS", "PUNTUACIONFORCOM", "PUNTUACIONEXPLAB", "PUNTUACIONTOTCV",
			"OBSERVACIONESCV", "NOTACONOCIMIENTOS", "PUNTUACIONTOTCON", "OBSERVACIONESCON", "NOTACURSO",
			"PUNTUACIONTOTCURSO", "OBSERVACIONESCURSO", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Puntuaciones> rwMap = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Puntuaciones(resultSet.getInt("IDPUNTUACION"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getBigDecimal("PUNTUACIONEXPACA"), resultSet.getBigDecimal("PUNTUACIONIDIOMAS"),
					resultSet.getBigDecimal("PUNTUACIONFORCOM"), resultSet.getBigDecimal("PUNTUACIONEXPLAB"),
					resultSet.getBigDecimal("PUNTUACIONTOTCV"), resultSet.getString("OBSERVACIONESCV"),
					resultSet.getBigDecimal("NOTACONOCIMIENTOS"), resultSet.getBigDecimal("PUNTUACIONTOTCON"),
					resultSet.getString("OBSERVACIONESCON"), resultSet.getBigDecimal("NOTACURSO"),
					resultSet.getBigDecimal("PUNTUACIONTOTCURSO"), resultSet.getString("OBSERVACIONESCURSO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<Puntuaciones> rwMapRequisitosPuntuaciones = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Puntuaciones(resultSet.getInt("IDPUNTUACION"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getInt("REQUISITOTITULACION"), resultSet.getInt("REQUISITOEUSKERA"),
					resultSet.getInt("REQUISITOEDAD"));
		}
	};

	private RowMapper<Puntuaciones> rwMapConocimientos = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();
			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			puntuaciones.setNotaConocimientos(resultSet.getBigDecimal("NOTACONOCIMIENTOS"));
			puntuaciones.setPuntuacionTotCon(resultSet.getBigDecimal("PUNTUACIONTOTCON"));
			puntuaciones.setObservacionesCon(resultSet.getString("OBSERVACIONESCON"));
			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapCurso = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();
			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			puntuaciones.setNotaCurso(resultSet.getBigDecimal("NOTACURSO"));
			puntuaciones.setPuntuacionTotCurso(resultSet.getBigDecimal("PUNTUACIONTOTCURSO"));
			puntuaciones.setObservacionesCurso(resultSet.getString("OBSERVACIONESCURSO"));
			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapResolucion = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();
			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			puntuaciones.setPuntuacionTotCurso(resultSet.getBigDecimal("PUNTUACIONTOTCURSO"));
			puntuaciones.setEmpresa(resultSet.getString("EMPRESA"));
			puntuaciones.setDotacion(resultSet.getString("DOTACION"));
			puntuaciones.setObservacionesResolucion(resultSet.getString("OBSERVACIONESRESOLUCION"));
			Fases fases = new Fases();
			fases.setIdFase(resultSet.getLong("IDFASES"));
			fases.setDescripcionCastellano(resultSet.getString("FASESDESCASTELLANO"));
			fases.setDescripcionEuskera(resultSet.getString("FASESDESEUSKERA"));
			puntuaciones.setFases(fases);
			TiposResultado tiposResultado = new TiposResultado();
			tiposResultado.setIdResultado(resultSet.getLong("IDTIPOSRESULTADO"));
			tiposResultado.setDescripcionCastellano(resultSet.getString("TIPOSRESULTADODESCASTELLANO"));
			tiposResultado.setDescripcionEuskera(resultSet.getString("TIPOSRESULTADODESEUSKERA"));
			puntuaciones.setTiposResultado(tiposResultado);
			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVOSDESESTIMACION"));
			motivosDesestimacion.setDescripcionCastellano(resultSet.getString("DESMOTIVOCASTELLANO"));
			motivosDesestimacion.setDescripcionEuskera(resultSet.getString("DESMOTIVOEUSKERA"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);
			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapFaseCurriculum = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();

			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expedientes.setFolderNumber(resultSet.getString("FOLDERNUMBER"));

			DatosTerceros datosTerceros = new DatosTerceros();
			datosTerceros.setDocumento(resultSet.getString("DNI"));
			datosTerceros.setNombre(resultSet.getString("NOMBRE"));
			datosTerceros.setApellido1(resultSet.getString("APELLIDO1"));
			datosTerceros.setApellido2(resultSet.getString("APELLIDO2"));
			expedientes.setDatosTerceros(datosTerceros);

			puntuaciones.setExpedientes(expedientes);

			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setRequisitos(resultSet.getString("REQUISITOS"));
			puntuaciones.setPuntuacionTotCv(resultSet.getBigDecimal("PUNTUACIONTOTCV"));
			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapFaseConocimientos = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();

			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expedientes.setFolderNumber(resultSet.getString("FOLDERNUMBER"));

			DatosTerceros datosTerceros = new DatosTerceros();
			datosTerceros.setDocumento(resultSet.getString("DNI"));
			datosTerceros.setNombre(resultSet.getString("NOMBRE"));
			datosTerceros.setApellido1(resultSet.getString("APELLIDO1"));
			datosTerceros.setApellido2(resultSet.getString("APELLIDO2"));
			expedientes.setDatosTerceros(datosTerceros);

			puntuaciones.setExpedientes(expedientes);

			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setPuntuacionTotCv(resultSet.getBigDecimal("PUNTUACIONTOTCV"));

			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			puntuaciones.setNotaConocimientos(resultSet.getBigDecimal("NOTACONOCIMIENTOS"));
			puntuaciones.setPuntuacionTotCon(resultSet.getBigDecimal("PUNTUACIONTOTCON"));

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapFaseCurso = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();

			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expedientes.setFolderNumber(resultSet.getString("FOLDERNUMBER"));

			DatosTerceros datosTerceros = new DatosTerceros();
			datosTerceros.setDocumento(resultSet.getString("DNI"));
			datosTerceros.setNombre(resultSet.getString("NOMBRE"));
			datosTerceros.setApellido1(resultSet.getString("APELLIDO1"));
			datosTerceros.setApellido2(resultSet.getString("APELLIDO2"));
			expedientes.setDatosTerceros(datosTerceros);

			puntuaciones.setExpedientes(expedientes);

			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setPuntuacionTotCv(resultSet.getBigDecimal("PUNTUACIONTOTCV"));

			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			puntuaciones.setNotaConocimientos(resultSet.getBigDecimal("NOTACONOCIMIENTOS"));
			puntuaciones.setPuntuacionTotCon(resultSet.getBigDecimal("PUNTUACIONTOTCON"));
			puntuaciones.setNotaCurso(resultSet.getBigDecimal("NOTACURSO"));
			puntuaciones.setPuntuacionTotCurso(resultSet.getBigDecimal("PUNTUACIONTOTCURSO"));

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapFaseBecasBecarios = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();

			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expedientes.setFolderNumber(resultSet.getString("FOLDERNUMBER"));

			DatosTerceros datosTerceros = new DatosTerceros();
			datosTerceros.setDocumento(resultSet.getString("DNI"));
			datosTerceros.setNombre(resultSet.getString("NOMBRE"));
			datosTerceros.setApellido1(resultSet.getString("APELLIDO1"));
			datosTerceros.setApellido2(resultSet.getString("APELLIDO2"));
			expedientes.setDatosTerceros(datosTerceros);

			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setPuntuacionTotCurso(resultSet.getBigDecimal("PUNTUACIONTOTCURSO"));
			puntuaciones.setEmpresa(resultSet.getString("EMPRESA"));
			puntuaciones.setDotacion(resultSet.getString("DOTACION"));

			Curriculum curriculum = new Curriculum();
			curriculum.setIdCurriculum(resultSet.getInt("IDCURRICULUM"));
			curriculum.setIngles(resultSet.getInt("INGLES"));
			curriculum.setFrances(resultSet.getInt("FRANCES"));
			curriculum.setItaliano(resultSet.getInt("ITALIANO"));
			expedientes.setCurriculum(curriculum);

			puntuaciones.setExpedientes(expedientes);

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapFaseBecasSuplentes = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Puntuaciones puntuaciones = new Puntuaciones();

			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expedientes.setFolderNumber(resultSet.getString("FOLDERNUMBER"));

			DatosTerceros datosTerceros = new DatosTerceros();
			datosTerceros.setDocumento(resultSet.getString("DNI"));
			datosTerceros.setNombre(resultSet.getString("NOMBRE"));
			datosTerceros.setApellido1(resultSet.getString("APELLIDO1"));
			datosTerceros.setApellido2(resultSet.getString("APELLIDO2"));
			expedientes.setDatosTerceros(datosTerceros);

			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			puntuaciones.setIdPuntuacion(resultSet.getInt("IDPUNTUACION"));
			puntuaciones.setPuntuacionTotCurso(resultSet.getBigDecimal("PUNTUACIONTOTCURSO"));

			Curriculum curriculum = new Curriculum();
			curriculum.setIdCurriculum(resultSet.getInt("IDCURRICULUM"));
			curriculum.setIngles(resultSet.getInt("INGLES"));
			curriculum.setFrances(resultSet.getInt("FRANCES"));
			curriculum.setItaliano(resultSet.getInt("ITALIANO"));
			expedientes.setCurriculum(curriculum);

			puntuaciones.setExpedientes(expedientes);

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapFaseBecasPuntMaxSuplentes = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Puntuaciones puntuaciones = new Puntuaciones();
			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			puntuaciones.setExpedientes(expedientes);
			puntuaciones.setPuntuacionTotCurso(resultSet.getBigDecimal("PUNTUACIONTOTCURSO"));

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapExpedientesParaConocimientos = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Puntuaciones puntuaciones = new Puntuaciones();
			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			puntuaciones.setExpedientes(expedientes);

			puntuaciones.setRequisitos(resultSet.getString("REQUISITOS"));
			puntuaciones.setPuntuacionTotCv(resultSet.getBigDecimal("PUNTUACIONTOTCV"));
			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapExpedientesParaCurso = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Puntuaciones puntuaciones = new Puntuaciones();
			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			puntuaciones.setExpedientes(expedientes);

			puntuaciones.setPuntuacionTotCon(resultSet.getBigDecimal("PUNTUACIONTOTCON"));
			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapExpedientesParaBecariosSuplentes = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Puntuaciones puntuaciones = new Puntuaciones();
			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			puntuaciones.setExpedientes(expedientes);

			puntuaciones.setPuntuacionTotCurso(resultSet.getBigDecimal("PUNTUACIONTOTCURSO"));
			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
			puntuaciones.setMotivosDesestimacion(motivosDesestimacion);

			return puntuaciones;

		}
	};

	private RowMapper<Puntuaciones> rwMapPK = new RowMapper<Puntuaciones>() {
		public Puntuaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Puntuaciones(resultSet.getInt("IDPUNTUACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Puntuaciones>> rwMapJerarquia = new RowMapper<JerarquiaDto<Puntuaciones>>() {
		public JerarquiaDto<Puntuaciones> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Puntuaciones puntuaciones = new Puntuaciones(resultSet.getInt("IDPUNTUACION"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getBigDecimal("PUNTUACIONEXPACA"),
					resultSet.getBigDecimal("PUNTUACIONIDIOMAS"), resultSet.getBigDecimal("PUNTUACIONFORCOM"),
					resultSet.getBigDecimal("PUNTUACIONEXPLAB"), resultSet.getBigDecimal("PUNTUACIONTOTCV"),
					resultSet.getString("OBSERVACIONESCV"), resultSet.getBigDecimal("NOTACONOCIMIENTOS"),
					resultSet.getBigDecimal("PUNTUACIONTOTCON"), resultSet.getString("OBSERVACIONESCON"),
					resultSet.getBigDecimal("NOTACURSO"), resultSet.getBigDecimal("PUNTUACIONTOTCURSO"),
					resultSet.getString("OBSERVACIONESCURSO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<Puntuaciones> jerarquia = new JerarquiaDto<Puntuaciones>();
			jerarquia.setModel(puntuaciones);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	public Puntuaciones add(Puntuaciones puntuaciones) {
		int idPuntuacion = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6057T00"));
		puntuaciones.setIdPuntuacion(idPuntuacion);
		String query = "INSERT INTO PUNTUACIONES (ID_PUNTUACION, ID_EXPEDIENTE, PUNTUACION_EXP_ACA, PUNTUACION_IDIOMAS, PUNTUACION_FOR_COM, PUNTUACION_EXP_LAB, PUNTUACION_TOT_CV, OBSERVACIONES_CV, NOTA_CONOCIMIENTOS, PUNTUACION_TOT_CON, OBSERVACIONES_CON, NOTA_CURSO, PUNTUACION_TOT_CURSO, OBSERVACIONES_CURSO, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, puntuaciones.getIdPuntuacion(), puntuaciones.getIdExpediente(),
				puntuaciones.getPuntuacionExpAca(), puntuaciones.getPuntuacionIdiomas(),
				puntuaciones.getPuntuacionForCom(), puntuaciones.getPuntuacionExpLab(),
				puntuaciones.getPuntuacionTotCv(), puntuaciones.getObservacionesCv(),
				puntuaciones.getNotaConocimientos(), puntuaciones.getPuntuacionTotCon(),
				puntuaciones.getObservacionesCon(), puntuaciones.getNotaCurso(), puntuaciones.getPuntuacionTotCurso(),
				puntuaciones.getObservacionesCurso(), new Date(), puntuaciones.getUsuarioRegistro(),
				puntuaciones.getFechaUltmodificacion(), puntuaciones.getUsuarioUltmodificacion());
		return puntuaciones;
	}

	/**
	 * Inserts a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones addRequisitos(Puntuaciones puntuacion) {
		String query = "INSERT INTO PUNTUACIONES (ID_PUNTUACION, ID_EXPEDIENTE, REQUISITO_TITULACION, REQUISITO_EUSKERA, REQUISITO_EDAD, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6057T00.NEXTVAL,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, puntuacion.getIdExpediente(), puntuacion.getRequisitoTitulacion(),
				puntuacion.getRequisitoEuskera(), puntuacion.getRequisitoEdad(), puntuacion.getFechaRegistro(),
				puntuacion.getUsuarioRegistro());
		return puntuacion;
	}

	/**
	 * Inserts a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	public Puntuaciones addConocimientos(Puntuaciones puntuaciones) {
		int idPuntuacion = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6057T00"));
		puntuaciones.setIdPuntuacion(idPuntuacion);
		String query = "INSERT INTO PUNTUACIONES (ID_PUNTUACION, ID_EXPEDIENTE, NOTA_CONOCIMIENTOS, PUNTUACION_TOT_CON, OBSERVACIONES_CON, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, puntuaciones.getIdPuntuacion(), puntuaciones.getIdExpediente(),
				puntuaciones.getNotaConocimientos(), puntuaciones.getPuntuacionTotCon(),
				puntuaciones.getObservacionesCon(), puntuaciones.getFechaRegistro(), puntuaciones.getUsuarioRegistro());
		return puntuaciones;
	}

	/**
	 * Inserts a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	public Puntuaciones addCurso(Puntuaciones puntuaciones) {
		int idPuntuacion = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6057T00"));
		puntuaciones.setIdPuntuacion(idPuntuacion);
		String query = "INSERT INTO PUNTUACIONES (ID_PUNTUACION, ID_EXPEDIENTE, NOTA_CURSO, PUNTUACION_TOT_CURSO, OBSERVACIONES_CURSO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, puntuaciones.getIdPuntuacion(), puntuaciones.getIdExpediente(),
				puntuaciones.getNotaCurso(), puntuaciones.getPuntuacionTotCurso(), puntuaciones.getObservacionesCurso(),
				puntuaciones.getFechaRegistro(), puntuaciones.getUsuarioRegistro());
		return puntuaciones;
	}

	/**
	 * Inserts a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	public Puntuaciones addResolucion(Puntuaciones puntuaciones) {
		int idPuntuacion = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6057T00"));
		puntuaciones.setIdPuntuacion(idPuntuacion);
		String query = "INSERT INTO PUNTUACIONES (ID_PUNTUACION, ID_EXPEDIENTE, OBSERVACIONES_RESOLUCION, EMPRESA, DOTACION, ID_FASE, ID_RESULTADO, ID_MOTIVO_DESESTIMACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?,?)";

		Object getFasesAux = null;
		if (puntuaciones.getFases() != null && puntuaciones.getFases().getIdFase() != null) {
			getFasesAux = puntuaciones.getFases().getIdFase();
		}

		Object getTiposResultadoAux = null;
		if (puntuaciones.getTiposResultado() != null && puntuaciones.getTiposResultado().getIdResultado() != null) {
			getTiposResultadoAux = puntuaciones.getTiposResultado().getIdResultado();
		}

		Object getMotivosDesestimacionAux = null;
		if (puntuaciones.getMotivosDesestimacion() != null
				&& puntuaciones.getMotivosDesestimacion().getIdMotivoDesestimacion() != null) {
			getMotivosDesestimacionAux = puntuaciones.getMotivosDesestimacion().getIdMotivoDesestimacion();
		}

		this.jdbcTemplate.update(query, puntuaciones.getIdPuntuacion(), puntuaciones.getIdExpediente(),
				puntuaciones.getObservacionesResolucion(), puntuaciones.getEmpresa(), puntuaciones.getDotacion(),
				getFasesAux, getTiposResultadoAux, getMotivosDesestimacionAux, puntuaciones.getFechaRegistro(),
				puntuaciones.getUsuarioRegistro());
		return puntuaciones;
	}

	/**
	 * Updates a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones updateCurriculum(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET  PUNTUACION_EXP_ACA=?, PUNTUACION_IDIOMAS=?, PUNTUACION_FOR_COM=?, PUNTUACION_EXP_LAB=?, PUNTUACION_TOT_CV=?, OBSERVACIONES_CV=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PUNTUACION=?";
		this.jdbcTemplate.update(query, puntuaciones.getPuntuacionExpAca(), puntuaciones.getPuntuacionIdiomas(),
				puntuaciones.getPuntuacionForCom(), puntuaciones.getPuntuacionExpLab(),
				puntuaciones.getPuntuacionTotCv(), puntuaciones.getObservacionesCv(),
				puntuaciones.getFechaUltmodificacion(), puntuaciones.getUsuarioUltmodificacion(),
				puntuaciones.getIdPuntuacion());
		return puntuaciones;
	}

	/**
	 * Updates a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones updateConocimientos(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET NOTA_CONOCIMIENTOS=?, PUNTUACION_TOT_CON=?, OBSERVACIONES_CON=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PUNTUACION=?";
		this.jdbcTemplate.update(query, puntuaciones.getNotaConocimientos(), puntuaciones.getPuntuacionTotCon(),
				puntuaciones.getObservacionesCon(), puntuaciones.getFechaUltmodificacion(),
				puntuaciones.getUsuarioUltmodificacion(), puntuaciones.getIdPuntuacion());
		return puntuaciones;
	}

	/**
	 * Updates a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones updateCurso(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET  NOTA_CURSO=?, PUNTUACION_TOT_CURSO=?, OBSERVACIONES_CURSO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PUNTUACION=?";
		this.jdbcTemplate.update(query, puntuaciones.getNotaCurso(), puntuaciones.getPuntuacionTotCurso(),
				puntuaciones.getObservacionesCurso(), puntuaciones.getFechaUltmodificacion(),
				puntuaciones.getUsuarioUltmodificacion(), puntuaciones.getIdPuntuacion());
		return puntuaciones;
	}

	@Override
	public Puntuaciones updateRequisitos(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET REQUISITO_TITULACION=?, REQUISITO_EUSKERA=?, REQUISITO_EDAD=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PUNTUACION=?";
		this.jdbcTemplate.update(query, puntuaciones.getRequisitoTitulacion(), puntuaciones.getRequisitoEuskera(),
				puntuaciones.getRequisitoEdad(), puntuaciones.getFechaUltmodificacion(),
				puntuaciones.getUsuarioUltmodificacion(), puntuaciones.getIdPuntuacion());
		return puntuaciones;
	}

	/**
	 * Updates a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones updateResolucion(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET  OBSERVACIONES_RESOLUCION=?, EMPRESA=?, DOTACION=?, ID_FASE=?, ID_RESULTADO=?, ID_MOTIVO_DESESTIMACION=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PUNTUACION=?";

		Object getFasesAux = null;
		if (puntuaciones.getFases() != null && puntuaciones.getFases().getIdFase() != null) {
			getFasesAux = puntuaciones.getFases().getIdFase();
		}

		Object getTiposResultadoAux = null;
		if (puntuaciones.getTiposResultado() != null && puntuaciones.getTiposResultado().getIdResultado() != null) {
			getTiposResultadoAux = puntuaciones.getTiposResultado().getIdResultado();
		}

		Object getMotivosDesestimacionAux = null;
		if (puntuaciones.getMotivosDesestimacion() != null
				&& puntuaciones.getMotivosDesestimacion().getIdMotivoDesestimacion() != null) {
			getMotivosDesestimacionAux = puntuaciones.getMotivosDesestimacion().getIdMotivoDesestimacion();
		}

		this.jdbcTemplate.update(query, puntuaciones.getObservacionesResolucion(), puntuaciones.getEmpresa(),
				puntuaciones.getDotacion(), getFasesAux, getTiposResultadoAux, getMotivosDesestimacionAux,
				puntuaciones.getFechaUltmodificacion(), puntuaciones.getUsuarioUltmodificacion(),
				puntuaciones.getIdPuntuacion());
		return puntuaciones;
	}

	/**
	 * Updates a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones updateBecarios(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET  ID_FASE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_EXPEDIENTE=?";

		if (puntuaciones.getFases() == null || puntuaciones.getFases().getIdFase() == null) {
			Fases fases = new Fases();
			fases.setIdFase(Long.valueOf(Constantes.ID_FASE4));
			puntuaciones.setFases(fases);
		}

		this.jdbcTemplate.update(query, puntuaciones.getFases().getIdFase(), puntuaciones.getFechaUltmodificacion(),
				puntuaciones.getUsuarioUltmodificacion(), puntuaciones.getExpedientes().getIdExpediente());
		return puntuaciones;
	}

	/**
	 * Updates a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones updateSuplentes(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET  ID_FASE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_EXPEDIENTE=?";

		if (puntuaciones.getFases() == null || puntuaciones.getFases().getIdFase() == null) {
			Fases fases = new Fases();
			fases.setIdFase(Long.valueOf(Constantes.ID_FASE3));
			puntuaciones.setFases(fases);
		}

		this.jdbcTemplate.update(query, puntuaciones.getFases().getIdFase(), puntuaciones.getFechaUltmodificacion(),
				puntuaciones.getUsuarioUltmodificacion(), puntuaciones.getExpedientes().getIdExpediente());
		return puntuaciones;
	}

	/**
	 * Updates a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Override
	public Puntuaciones updateFasePuntuacion(Puntuaciones puntuaciones) {
		String query = "UPDATE PUNTUACIONES SET  ID_FASE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_EXPEDIENTE=?";

		this.jdbcTemplate.update(query, puntuaciones.getFases().getIdFase(), puntuaciones.getFechaUltmodificacion(),
				puntuaciones.getUsuarioUltmodificacion(), puntuaciones.getExpedientes().getIdExpediente());
		return puntuaciones;
	}

	/**
	 * Finds a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Transactional(readOnly = true)
	public Puntuaciones find(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_PUNTUACION IDPUNTUACION, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.PUNTUACION_EXP_ACA PUNTUACIONEXPACA, t1.PUNTUACION_IDIOMAS PUNTUACIONIDIOMAS, t1.PUNTUACION_FOR_COM PUNTUACIONFORCOM, t1.PUNTUACION_EXP_LAB PUNTUACIONEXPLAB, t1.PUNTUACION_TOT_CV PUNTUACIONTOTCV, t1.OBSERVACIONES_CV OBSERVACIONESCV, t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS, t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON, t1.OBSERVACIONES_CON OBSERVACIONESCON, t1.NOTA_CURSO NOTACURSO, t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO, t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM PUNTUACIONES t1  WHERE t1.ID_PUNTUACION = ?  ";

		List<Puntuaciones> puntuacionesList = this.jdbcTemplate.query(query, this.rwMap,
				puntuaciones.getIdPuntuacion());
		return (Puntuaciones) DataAccessUtils.uniqueResult(puntuacionesList);
	}

	/**
	 * Finds a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Transactional(readOnly = true)
	public Puntuaciones findRequisitos(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_PUNTUACION IDPUNTUACION, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.REQUISITO_TITULACION REQUISITOTITULACION, t1.REQUISITO_EUSKERA REQUISITOEUSKERA, t1.REQUISITO_EDAD REQUISITOEDAD FROM PUNTUACIONES t1 WHERE t1.ID_EXPEDIENTE = ?";

		List<Puntuaciones> puntuacionesList = this.jdbcTemplate.query(query, this.rwMapRequisitosPuntuaciones,
				puntuaciones.getIdExpediente());
		return (Puntuaciones) DataAccessUtils.uniqueResult(puntuacionesList);
	}

	/**
	 * Finds a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Transactional(readOnly = true)
	public Puntuaciones findConocimientos(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_PUNTUACION IDPUNTUACION, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS, t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON, t1.OBSERVACIONES_CON OBSERVACIONESCON FROM PUNTUACIONES t1  WHERE t1.ID_EXPEDIENTE = ?";

		List<Puntuaciones> puntuacionesList = this.jdbcTemplate.query(query, this.rwMapConocimientos,
				puntuaciones.getIdExpediente());
		return (Puntuaciones) DataAccessUtils.uniqueResult(puntuacionesList);
	}

	/**
	 * Finds a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Transactional(readOnly = true)
	public Puntuaciones findCurso(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_PUNTUACION IDPUNTUACION, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.NOTA_CURSO NOTACURSO, t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO, t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO FROM PUNTUACIONES t1  WHERE t1.ID_EXPEDIENTE = ?";

		List<Puntuaciones> puntuacionesList = this.jdbcTemplate.query(query, this.rwMapCurso,
				puntuaciones.getIdExpediente());
		return (Puntuaciones) DataAccessUtils.uniqueResult(puntuacionesList);
	}

	/**
	 * Finds a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Transactional(readOnly = true)
	public Puntuaciones findResolucion(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_PUNTUACION IDPUNTUACION,  t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO, t1.EMPRESA EMPRESA, t1.DOTACION DOTACION, t1.OBSERVACIONES_RESOLUCION OBSERVACIONESRESOLUCION, t2.ID_FASE IDFASES, t2.DESCRIPCION_CASTELLANO FASESDESCASTELLANO, t2.DESCRIPCION_EUSKERA FASESDESEUSKERA, t3.ID_RESULTADO IDTIPOSRESULTADO, t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA FROM PUNTUACIONES t1, FASES t2, TIPOS_RESULTADO t3,  MOTIVOS_DESESTIMACION t4 WHERE 1=1 AND t1.ID_FASE = t2.ID_FASE(+) AND t1.ID_RESULTADO = t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION = t4.ID_MOTIVO_DESESTIMACION(+) AND t1.ID_EXPEDIENTE = ?";

		List<Puntuaciones> puntuacionesList = this.jdbcTemplate.query(query, this.rwMapResolucion,
				puntuaciones.getIdExpediente());
		return (Puntuaciones) DataAccessUtils.uniqueResult(puntuacionesList);
	}

	/**
	 * Finds a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Puntuaciones
	 */
	@Transactional(readOnly = true)
	public Puntuaciones findPuntuacionMaxSuplentes(Integer idProcedimiento) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t4.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO FROM AB61.EXPEDIENTES t1, AB61.REL_EXP_TER t2, AB61.DATOS_TERCEROS t3, PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO  = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE = ? AND t2.ID_TIPO_TERCERO = ? AND t3.TIPO_PARTICIPANTE = ? AND t4.PUNTUACION_TOT_CURSO IS NOT NULL AND t4.PUNTUACION_TOT_CURSO IN (SELECT MAX(t4.PUNTUACION_TOT_CURSO) AS PUNTUACIONTOTCURSO FROM AB61.EXPEDIENTES t1,  AB61.REL_EXP_TER t2,  AB61.DATOS_TERCEROS t3,PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO= ? AND t1.ID_EXPEDIENTE= t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE  = ? AND t2.ID_TIPO_TERCERO = ?  AND t3.TIPO_PARTICIPANTE = ? AND t4.PUNTUACION_TOT_CURSO IS NOT NULL) AND ROWNUM = 1";
		List<Puntuaciones> puntuacionesList = this.jdbcTemplate.query(query, this.rwMapFaseBecasPuntMaxSuplentes,
				idProcedimiento, Constantes.ID_FASE4, Constantes.ID_TIPO_TERCERO_SOLICITANTE,
				Constantes.PARTICIPANTE_TITULAR, idProcedimiento, Constantes.ID_FASE4,
				Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR);
		return (Puntuaciones) DataAccessUtils.uniqueResult(puntuacionesList);
	}

	/**
	 * Removes a single row in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return
	 */
	public void remove(Puntuaciones puntuaciones) {
		String query = "DELETE FROM PUNTUACIONES WHERE ID_PUNTUACION=?";
		this.jdbcTemplate.update(query, puntuaciones.getIdPuntuacion());
	}

	/**
	 * Finds a list of rows in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findAll(Puntuaciones puntuaciones, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PUNTUACION IDPUNTUACION,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_EXP_ACA PUNTUACIONEXPACA,t1.PUNTUACION_IDIOMAS PUNTUACIONIDIOMAS,t1.PUNTUACION_FOR_COM PUNTUACIONFORCOM,t1.PUNTUACION_EXP_LAB PUNTUACIONEXPLAB,t1.PUNTUACION_TOT_CV PUNTUACIONTOTCV,t1.OBSERVACIONES_CV OBSERVACIONESCV,t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS,t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON,t1.OBSERVACIONES_CON OBSERVACIONESCON,t1.NOTA_CURSO NOTACURSO,t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM PUNTUACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(puntuaciones);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, PuntuacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findAllLike(Puntuaciones puntuaciones, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PUNTUACION IDPUNTUACION,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_EXP_ACA PUNTUACIONEXPACA,t1.PUNTUACION_IDIOMAS PUNTUACIONIDIOMAS,t1.PUNTUACION_FOR_COM PUNTUACIONFORCOM,t1.PUNTUACION_EXP_LAB PUNTUACIONEXPLAB,t1.PUNTUACION_TOT_CV PUNTUACIONTOTCV,t1.OBSERVACIONES_CV OBSERVACIONESCV,t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS,t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON,t1.OBSERVACIONES_CON OBSERVACIONESCON,t1.NOTA_CURSO NOTACURSO,t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM PUNTUACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(puntuaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, PuntuacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findFaseCurriculum(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t3.DOCUMENTO DNI, t3.NOMBRE NOMBRE, t3.APELLIDO1 APELLIDO1, t3.APELLIDO2 APELLIDO2, t4.ID_PUNTUACION IDPUNTUACION, DECODE(t4.REQUISITO_TITULACION || t4.REQUISITO_EUSKERA ||t4.REQUISITO_EDAD,'111','S','N')  AS REQUISITOS, t4.PUNTUACION_TOT_CV PUNTUACIONTOTCV, t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION, t1.FOLDER_NUMBER FOLDERNUMBER FROM AB61.EXPEDIENTES t1, AB61.REL_EXP_TER t2, AB61.DATOS_TERCEROS t3, PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t2.ID_TIPO_TERCERO = ?  AND t3.TIPO_PARTICIPANTE = ? ORDER BY IDMOTIVODESESTIMACION DESC, REQUISITOS DESC, t4.PUNTUACION_TOT_CV DESC";

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapFaseCurriculum,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(),
				Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findFaseConocimientos(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t3.DOCUMENTO DNI, t3.NOMBRE NOMBRE, t3.APELLIDO1 APELLIDO1, t3.APELLIDO2 APELLIDO2, t4.ID_PUNTUACION IDPUNTUACION, t4.PUNTUACION_TOT_CV PUNTUACIONTOTCV, t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION, t4.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS, t4.PUNTUACION_TOT_CON PUNTUACIONTOTCON, t1.FOLDER_NUMBER FOLDERNUMBER FROM AB61.EXPEDIENTES t1, AB61.REL_EXP_TER t2, AB61.DATOS_TERCEROS t3, PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE = ? AND t2.ID_TIPO_TERCERO = ? AND t3.TIPO_PARTICIPANTE = ? ORDER BY t4.PUNTUACION_TOT_CON DESC, t1.ID_EXPEDIENTE ASC";

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapFaseConocimientos,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(), Constantes.ID_FASE1,
				Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findFaseCurso(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t3.DOCUMENTO DNI, t3.NOMBRE NOMBRE, t3.APELLIDO1 APELLIDO1, t3.APELLIDO2 APELLIDO2, t4.ID_PUNTUACION IDPUNTUACION, t4.PUNTUACION_TOT_CV PUNTUACIONTOTCV, t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION, t4.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS, t4.PUNTUACION_TOT_CON PUNTUACIONTOTCON,  t4.NOTA_CURSO NOTACURSO, t4.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO, t1.FOLDER_NUMBER FOLDERNUMBER FROM AB61.EXPEDIENTES t1, AB61.REL_EXP_TER t2,  AB61.DATOS_TERCEROS t3, PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE = ? AND t2.ID_TIPO_TERCERO = ? AND t3.TIPO_PARTICIPANTE = ? ORDER BY t4.PUNTUACION_TOT_CURSO DESC, t1.ID_EXPEDIENTE ASC";

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapFaseCurso,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(), Constantes.ID_FASE2,
				Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findFaseBecasBecarios(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t3.DOCUMENTO DNI, t3.NOMBRE NOMBRE,  t3.APELLIDO1 APELLIDO1, t3.APELLIDO2 APELLIDO2,  t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION, t4.ID_PUNTUACION IDPUNTUACION,  t4.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,  t4.EMPRESA EMPRESA, t4.DOTACION DOTACION,  t5.ID_CURRICULUM IDCURRICULUM,  t5.INGLES INGLES,  t5.FRANCES FRANCES,  t5.ITALIANO ITALIANO, t1.FOLDER_NUMBER FOLDERNUMBER FROM AB61.EXPEDIENTES t1,  AB61.REL_EXP_TER t2,  AB61.DATOS_TERCEROS t3,  PUNTUACIONES t4,  CURRICULUM t5 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t5.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE = ? AND t2.ID_TIPO_TERCERO = ? AND t3.TIPO_PARTICIPANTE = ? ORDER BY t4.PUNTUACION_TOT_CURSO DESC, t1.ID_EXPEDIENTE ASC";

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapFaseBecasBecarios,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(), Constantes.ID_FASE3,
				Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findFaseBecasSuplentes(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,  t3.DOCUMENTO DNI,  t3.NOMBRE NOMBRE,  t3.APELLIDO1 APELLIDO1,  t3.APELLIDO2 APELLIDO2,  t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION, t4.ID_PUNTUACION IDPUNTUACION, t4.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,  t5.ID_CURRICULUM IDCURRICULUM,  t5.INGLES INGLES,  t5.FRANCES FRANCES,  t5.ITALIANO ITALIANO, t1.FOLDER_NUMBER FOLDERNUMBER FROM AB61.EXPEDIENTES t1,  AB61.REL_EXP_TER t2,  AB61.DATOS_TERCEROS t3, PUNTUACIONES t4,  CURRICULUM t5 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t5.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE = ? AND t2.ID_TIPO_TERCERO = ? AND t3.TIPO_PARTICIPANTE  = ? ORDER BY t4.PUNTUACION_TOT_CURSO DESC, t1.ID_EXPEDIENTE ASC";

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapFaseBecasSuplentes,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(), Constantes.ID_FASE4,
				Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findFaseBecasBecariosSuplentes(Puntuaciones puntuaciones) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,  t3.DOCUMENTO DNI,  t3.NOMBRE NOMBRE, t3.APELLIDO1 APELLIDO1, t3.APELLIDO2 APELLIDO2, t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION, t4.ID_PUNTUACION IDPUNTUACION, t4.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO, t4.EMPRESA EMPRESA, t4.DOTACION DOTACION, t5.ID_CURRICULUM IDCURRICULUM, t5.INGLES INGLES, t5.FRANCES FRANCES, t5.ITALIANO ITALIANO, t1.FOLDER_NUMBER FOLDERNUMBER FROM AB61.EXPEDIENTES t1, AB61.REL_EXP_TER t2, AB61.DATOS_TERCEROS t3, PUNTUACIONES t4,  CURRICULUM t5 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t5.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE IN (?,?) AND t2.ID_TIPO_TERCERO = ? AND t3.TIPO_PARTICIPANTE = ? ORDER BY t4.PUNTUACION_TOT_CURSO DESC,  t1.ID_EXPEDIENTE ASC";

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapFaseBecasBecarios,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(), Constantes.ID_FASE3,
				Constantes.ID_FASE4, Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param idConvocatoria
	 *            Integer
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findExpedientesParaConocimientos(Puntuaciones puntuaciones, Integer idConvocatoria) {
		String query = "SELECT * FROM (SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,  DECODE(t4.REQUISITO_TITULACION  || t4.REQUISITO_EUSKERA  ||t4.REQUISITO_EDAD,'111','S','N') AS REQUISITOS,  t4.PUNTUACION_TOT_CV PUNTUACIONTOTCV,  t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION FROM AB61.EXPEDIENTES t1,   AB61.REL_EXP_TER t2,   AB61.DATOS_TERCEROS t3,   PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t2.ID_TIPO_TERCERO = ?   AND t3.TIPO_PARTICIPANTE =? AND t4.PUNTUACION_TOT_CV IS NOT NULL AND t4.ID_MOTIVO_DESESTIMACION IS NULL ORDER BY REQUISITOS DESC,   t4.PUNTUACION_TOT_CV DESC) WHERE 1=1 AND ROWNUM <=  (SELECT NUM_PER_CON FROM CONVOCATORIAS WHERE ID_CONVOCATORIA = ?)";

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapExpedientesParaConocimientos,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(),
				Constantes.ID_TIPO_TERCERO_SOLICITANTE, Constantes.PARTICIPANTE_TITULAR, idConvocatoria);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param idConvocatoria
	 *            Integer
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findExpedientesParaCurso(Puntuaciones puntuaciones, Integer idConvocatoria) {
		String query = "SELECT * FROM (SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t4.PUNTUACION_TOT_CON PUNTUACIONTOTCON, t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION FROM AB61.EXPEDIENTES t1, AB61.REL_EXP_TER t2, AB61.DATOS_TERCEROS t3, PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE = ? AND t2.ID_TIPO_TERCERO = ?   AND t3.TIPO_PARTICIPANTE = ? AND t4.PUNTUACION_TOT_CV IS NOT NULL AND t4.ID_MOTIVO_DESESTIMACION IS NULL ORDER BY t4.PUNTUACION_TOT_CON DESC) WHERE 1=1 AND ROWNUM <= (SELECT NUM_PER_CUR FROM CONVOCATORIAS WHERE ID_CONVOCATORIA = ?)";

		if (puntuaciones.getFases() == null || puntuaciones.getFases().getIdFase() == null) {
			Fases fases = new Fases();
			fases.setIdFase(Long.valueOf(Constantes.ID_FASE1));
			puntuaciones.setFases(fases);
		}

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(), this.rwMapExpedientesParaCurso,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(),
				puntuaciones.getFases().getIdFase(), Constantes.ID_TIPO_TERCERO_SOLICITANTE,
				Constantes.PARTICIPANTE_TITULAR, idConvocatoria);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param idConvocatoria
	 *            Integer
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findExpedientesParaBecarios(Puntuaciones puntuaciones, Integer idConvocatoria) {
		String query = "SELECT * FROM (SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,  t4.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO, t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION FROM AB61.EXPEDIENTES t1,  AB61.REL_EXP_TER t2,  AB61.DATOS_TERCEROS t3,   PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE  = ? AND t2.ID_TIPO_TERCERO = ?   AND t3.TIPO_PARTICIPANTE =? AND t4.PUNTUACION_TOT_CV IS NOT NULL AND t4.ID_MOTIVO_DESESTIMACION IS NULL ORDER BY t4.PUNTUACION_TOT_CURSO DESC) WHERE 1=1 AND ROWNUM  <=  (SELECT NUM_BECAS FROM CONVOCATORIAS WHERE ID_CONVOCATORIA = ?)";

		if (puntuaciones.getFases() == null || puntuaciones.getFases().getIdFase() == null) {
			Fases fases = new Fases();
			fases.setIdFase(Long.valueOf(Constantes.ID_FASE2));
			puntuaciones.setFases(fases);
		}

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(),
				this.rwMapExpedientesParaBecariosSuplentes,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(),
				puntuaciones.getFases().getIdFase(), Constantes.ID_TIPO_TERCERO_SOLICITANTE,
				Constantes.PARTICIPANTE_TITULAR, idConvocatoria);
	}

	/**
	 * Finds rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param idConvocatoria
	 *            Integer
	 * @return List<Puntuaciones>
	 */
	@Transactional(readOnly = true)
	public List<Puntuaciones> findExpedientesParaSuplentes(Puntuaciones puntuaciones, Integer idConvocatoria) {
		String query = "SELECT * FROM (SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t4.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,  t4.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION FROM AB61.EXPEDIENTES t1,  AB61.REL_EXP_TER t2,   AB61.DATOS_TERCEROS t3,  PUNTUACIONES t4 WHERE t1.ID_PROCEDIMIENTO = ? AND t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t4.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t4.ID_FASE = ? AND t2.ID_TIPO_TERCERO = ?   AND t3.TIPO_PARTICIPANTE =? AND t4.PUNTUACION_TOT_CV IS NOT NULL AND t4.ID_MOTIVO_DESESTIMACION IS NULL AND t4.ID_FASE NOT IN (3) ORDER BY t4.PUNTUACION_TOT_CURSO DESC) WHERE 1=1 AND ROWNUM <= (SELECT NUM_SUPLENTES FROM CONVOCATORIAS WHERE ID_CONVOCATORIA = ?)";

		if (puntuaciones.getFases() == null || puntuaciones.getFases().getIdFase() == null) {
			Fases fases = new Fases();
			fases.setIdFase(Long.valueOf(Constantes.ID_FASE2));
			puntuaciones.setFases(fases);
		}

		return (List<Puntuaciones>) this.jdbcTemplate.query(query.toString(),
				this.rwMapExpedientesParaBecariosSuplentes,
				puntuaciones.getExpedientes().getProcedimientos().getIdProcedimiento(),
				puntuaciones.getFases().getIdFase(), Constantes.ID_TIPO_TERCERO_SOLICITANTE,
				Constantes.PARTICIPANTE_TITULAR, idConvocatoria);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Puntuaciones table.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Puntuaciones puntuaciones) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PUNTUACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(puntuaciones);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Puntuaciones table using like.
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Puntuaciones puntuaciones, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PUNTUACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(puntuaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Puntuaciones selected for rup_table
	 *
	 * @param puntuaciones
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Puntuaciones>>
	 */
	@Override
	public List<TableRowDto<Puntuaciones>> reorderSelection(Puntuaciones puntuaciones,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PUNTUACION IDPUNTUACION,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_EXP_ACA PUNTUACIONEXPACA,t1.PUNTUACION_IDIOMAS PUNTUACIONIDIOMAS,t1.PUNTUACION_FOR_COM PUNTUACIONFORCOM,t1.PUNTUACION_EXP_LAB PUNTUACIONEXPLAB,t1.PUNTUACION_TOT_CV PUNTUACIONTOTCV,t1.OBSERVACIONES_CV OBSERVACIONESCV,t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS,t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON,t1.OBSERVACIONES_CON OBSERVACIONESCON,t1.NOTA_CURSO NOTACURSO,t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM PUNTUACIONES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(puntuaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Puntuaciones.class,
				filterParamList, "ID_PUNTUACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Puntuaciones>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Puntuaciones
	 * @param searchParams
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Puntuaciones>>
	 */
	@Override
	public List<TableRowDto<Puntuaciones>> search(Puntuaciones filterParams, Puntuaciones searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PUNTUACION IDPUNTUACION,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_EXP_ACA PUNTUACIONEXPACA,t1.PUNTUACION_IDIOMAS PUNTUACIONIDIOMAS,t1.PUNTUACION_FOR_COM PUNTUACIONFORCOM,t1.PUNTUACION_EXP_LAB PUNTUACIONEXPLAB,t1.PUNTUACION_TOT_CV PUNTUACIONTOTCV,t1.OBSERVACIONES_CV OBSERVACIONESCV,t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS,t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON,t1.OBSERVACIONES_CON OBSERVACIONESCON,t1.NOTA_CURSO NOTACURSO,t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM PUNTUACIONES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Puntuaciones.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_PUNTUACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Puntuaciones>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterpuntuaciones
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Puntuaciones filterpuntuaciones, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PUNTUACION IDPUNTUACION,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_EXP_ACA PUNTUACIONEXPACA,t1.PUNTUACION_IDIOMAS PUNTUACIONIDIOMAS,t1.PUNTUACION_FOR_COM PUNTUACIONFORCOM,t1.PUNTUACION_EXP_LAB PUNTUACIONEXPLAB,t1.PUNTUACION_TOT_CV PUNTUACIONTOTCV,t1.OBSERVACIONES_CV OBSERVACIONESCV,t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS,t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON,t1.OBSERVACIONES_CON OBSERVACIONESCON,t1.NOTA_CURSO NOTACURSO,t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM PUNTUACIONES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterpuntuaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Puntuaciones.class,
				query, params, "ID_PUNTUACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Puntuaciones table.
	 *
	 * @param filterPuntuaciones
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Puntuaciones>>
	 */
	@Override
	public List<JerarquiaDto<Puntuaciones>> findAllLikeJerarquia(Puntuaciones filterPuntuaciones,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PUNTUACION IDPUNTUACION,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_EXP_ACA PUNTUACIONEXPACA,t1.PUNTUACION_IDIOMAS PUNTUACIONIDIOMAS,t1.PUNTUACION_FOR_COM PUNTUACIONFORCOM,t1.PUNTUACION_EXP_LAB PUNTUACIONEXPLAB,t1.PUNTUACION_TOT_CV PUNTUACIONTOTCV,t1.OBSERVACIONES_CV OBSERVACIONESCV,t1.NOTA_CONOCIMIENTOS NOTACONOCIMIENTOS,t1.PUNTUACION_TOT_CON PUNTUACIONTOTCON,t1.OBSERVACIONES_CON OBSERVACIONESCON,t1.NOTA_CURSO NOTACURSO,t1.PUNTUACION_TOT_CURSO PUNTUACIONTOTCURSO,t1.OBSERVACIONES_CURSO OBSERVACIONESCURSO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PUNTUACIONES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("PUNTUACIONES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPuntuaciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PUNTUACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					PuntuacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPuntuaciones
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Puntuaciones filterPuntuaciones, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PUNTUACIONES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("PUNTUACIONES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPuntuaciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PUNTUACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPuntuaciones
	 *            Puntuaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Puntuaciones>>
	 */
	@Override
	public List<TableRowDto<Puntuaciones>> findAllChild(Puntuaciones filterPuntuaciones,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PUNTUACIONES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("PUNTUACIONES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPuntuaciones, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_PUNTUACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Puntuaciones>(this.rwMapPK, "ID_PUNTUACION"), params.toArray());
	}
	/*
	 * MÉTODOS PRIVADOS
	 */

	private Map<String, ?> getWhereMapExpediente(Expedientes expediente) {

		StringBuilder where = new StringBuilder(ParticipantesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (expediente.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(expediente.getIdExpediente());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Puntuaciones entity
	 *
	 * @param puntuaciones
	 *            Puntuaciones Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Puntuaciones puntuaciones) {

		StringBuilder where = new StringBuilder(PuntuacionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (puntuaciones != null && puntuaciones.getIdPuntuacion() != null) {
			where.append(" AND t1.ID_PUNTUACION = ?");
			params.add(puntuaciones.getIdPuntuacion());
		}
		if (puntuaciones != null && puntuaciones.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(puntuaciones.getIdExpediente());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionExpAca() != null) {
			where.append(" AND t1.PUNTUACION_EXP_ACA = ?");
			params.add(puntuaciones.getPuntuacionExpAca());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionIdiomas() != null) {
			where.append(" AND t1.PUNTUACION_IDIOMAS = ?");
			params.add(puntuaciones.getPuntuacionIdiomas());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionForCom() != null) {
			where.append(" AND t1.PUNTUACION_FOR_COM = ?");
			params.add(puntuaciones.getPuntuacionForCom());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionExpLab() != null) {
			where.append(" AND t1.PUNTUACION_EXP_LAB = ?");
			params.add(puntuaciones.getPuntuacionExpLab());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionTotCv() != null) {
			where.append(" AND t1.PUNTUACION_TOT_CV = ?");
			params.add(puntuaciones.getPuntuacionTotCv());
		}
		if (puntuaciones != null && puntuaciones.getObservacionesCv() != null) {
			where.append(" AND t1.OBSERVACIONES_CV = ?");
			params.add(puntuaciones.getObservacionesCv());
		}
		if (puntuaciones != null && puntuaciones.getNotaConocimientos() != null) {
			where.append(" AND t1.NOTA_CONOCIMIENTOS = ?");
			params.add(puntuaciones.getNotaConocimientos());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionTotCon() != null) {
			where.append(" AND t1.PUNTUACION_TOT_CON = ?");
			params.add(puntuaciones.getPuntuacionTotCon());
		}
		if (puntuaciones != null && puntuaciones.getObservacionesCon() != null) {
			where.append(" AND t1.OBSERVACIONES_CON = ?");
			params.add(puntuaciones.getObservacionesCon());
		}
		if (puntuaciones != null && puntuaciones.getNotaCurso() != null) {
			where.append(" AND t1.NOTA_CURSO = ?");
			params.add(puntuaciones.getNotaCurso());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionTotCurso() != null) {
			where.append(" AND t1.PUNTUACION_TOT_CURSO = ?");
			params.add(puntuaciones.getPuntuacionTotCurso());
		}
		if (puntuaciones != null && puntuaciones.getObservacionesCurso() != null) {
			where.append(" AND t1.OBSERVACIONES_CURSO = ?");
			params.add(puntuaciones.getObservacionesCurso());
		}
		if (puntuaciones != null && puntuaciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(puntuaciones.getFechaRegistro());
		}
		if (puntuaciones != null && puntuaciones.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(puntuaciones.getUsuarioRegistro());
		}
		if (puntuaciones != null && puntuaciones.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(puntuaciones.getFechaUltmodificacion());
		}
		if (puntuaciones != null && puntuaciones.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(puntuaciones.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Puntuaciones entity
	 *
	 * @param puntuaciones
	 *            Puntuaciones Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Puntuaciones puntuaciones, Boolean startsWith) {

		StringBuilder where = new StringBuilder(PuntuacionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (puntuaciones != null && puntuaciones.getIdPuntuacion() != null) {
			where.append(" AND t1.ID_PUNTUACION = ?");
			params.add(puntuaciones.getIdPuntuacion());
		}
		if (puntuaciones != null && puntuaciones.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(puntuaciones.getIdExpediente());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionExpAca() != null) {
			where.append(" AND t1.PUNTUACION_EXP_ACA = ?");
			params.add(puntuaciones.getPuntuacionExpAca());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionIdiomas() != null) {
			where.append(" AND t1.PUNTUACION_IDIOMAS = ?");
			params.add(puntuaciones.getPuntuacionIdiomas());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionForCom() != null) {
			where.append(" AND t1.PUNTUACION_FOR_COM = ?");
			params.add(puntuaciones.getPuntuacionForCom());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionExpLab() != null) {
			where.append(" AND t1.PUNTUACION_EXP_LAB = ?");
			params.add(puntuaciones.getPuntuacionExpLab());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionTotCv() != null) {
			where.append(" AND t1.PUNTUACION_TOT_CV = ?");
			params.add(puntuaciones.getPuntuacionTotCv());
		}
		if (puntuaciones != null && puntuaciones.getObservacionesCv() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES_CV) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(puntuaciones.getObservacionesCv().toUpperCase() + "%");
			} else {
				params.add("%" + puntuaciones.getObservacionesCv().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES_CV IS NOT NULL");
		}
		if (puntuaciones != null && puntuaciones.getNotaConocimientos() != null) {
			where.append(" AND t1.NOTA_CONOCIMIENTOS = ?");
			params.add(puntuaciones.getNotaConocimientos());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionTotCon() != null) {
			where.append(" AND t1.PUNTUACION_TOT_CON = ?");
			params.add(puntuaciones.getPuntuacionTotCon());
		}
		if (puntuaciones != null && puntuaciones.getObservacionesCon() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES_CON) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(puntuaciones.getObservacionesCon().toUpperCase() + "%");
			} else {
				params.add("%" + puntuaciones.getObservacionesCon().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES_CON IS NOT NULL");
		}
		if (puntuaciones != null && puntuaciones.getNotaCurso() != null) {
			where.append(" AND t1.NOTA_CURSO = ?");
			params.add(puntuaciones.getNotaCurso());
		}
		if (puntuaciones != null && puntuaciones.getPuntuacionTotCurso() != null) {
			where.append(" AND t1.PUNTUACION_TOT_CURSO = ?");
			params.add(puntuaciones.getPuntuacionTotCurso());
		}
		if (puntuaciones != null && puntuaciones.getObservacionesCurso() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES_CURSO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(puntuaciones.getObservacionesCurso().toUpperCase() + "%");
			} else {
				params.add("%" + puntuaciones.getObservacionesCurso().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES_CURSO IS NOT NULL");
		}
		if (puntuaciones != null && puntuaciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(puntuaciones.getFechaRegistro());
		}
		if (puntuaciones != null && puntuaciones.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(puntuaciones.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + puntuaciones.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (puntuaciones != null && puntuaciones.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(puntuaciones.getFechaUltmodificacion());
		}
		if (puntuaciones != null && puntuaciones.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(puntuaciones.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + puntuaciones.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
