package com.ejie.ab60.dao.BEC;

import com.ejie.ab60.model.BEC.TiposCertificacion;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * TiposCertificacionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposCertificacionDaoImpl implements TiposCertificacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOCERTIFICACION", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposCertificacion> rwMap = new RowMapper<TiposCertificacion>() {
		public TiposCertificacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposCertificacion(resultSet.getLong("IDTIPOCERTIFICACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<TiposCertificacion> rwMapPK = new RowMapper<TiposCertificacion>() {
		public TiposCertificacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposCertificacion(resultSet.getLong("IDTIPOCERTIFICACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposCertificacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposCertificacion>>() {
		public JerarquiaDto<TiposCertificacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposCertificacion tiposcertificacion = new TiposCertificacion(resultSet.getLong("IDTIPOCERTIFICACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<TiposCertificacion> jerarquia = new JerarquiaDto<TiposCertificacion>();
			jerarquia.setModel(tiposcertificacion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposCertificacion table.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @return TiposCertificacion
	 */
	public TiposCertificacion add(TiposCertificacion tiposcertificacion) {
		String query = "INSERT INTO TIPOS_CERTIFICACION (ID_TIPO_CERTIFICACION, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, tiposcertificacion.getIdTipoCertificacion(),
				tiposcertificacion.getDescripcionCastellano(), tiposcertificacion.getDescripcionEuskera(),
				tiposcertificacion.getFechaRegistro(), tiposcertificacion.getUsuarioRegistro());
		return tiposcertificacion;
	}

	/**
	 * Updates a single row in the TiposCertificacion table.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @return TiposCertificacion
	 */
	public TiposCertificacion update(TiposCertificacion tiposcertificacion) {
		String query = "UPDATE TIPOS_CERTIFICACION SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_TIPO_CERTIFICACION=?";
		this.jdbcTemplate.update(query, tiposcertificacion.getDescripcionCastellano(),
				tiposcertificacion.getDescripcionEuskera(), tiposcertificacion.getFechaRegistro(),
				tiposcertificacion.getUsuarioRegistro(), tiposcertificacion.getIdTipoCertificacion());
		return tiposcertificacion;
	}

	/**
	 * Finds a single row in the TiposCertificacion table.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @return TiposCertificacion
	 */
	@Transactional(readOnly = true)
	public TiposCertificacion find(TiposCertificacion tiposcertificacion) {
		String query = "SELECT t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_CERTIFICACION t1  WHERE t1.ID_TIPO_CERTIFICACION = ?  ";

		List<TiposCertificacion> tiposcertificacionList = this.jdbcTemplate.query(query, this.rwMap,
				tiposcertificacion.getIdTipoCertificacion());
		return (TiposCertificacion) DataAccessUtils.uniqueResult(tiposcertificacionList);
	}

	@Override
	public List<TiposCertificacion> findCertificaciones(TiposCertificacion tiposCertificacion) {
		String query = "SELECT t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_CERTIFICACION t1  WHERE ID_CONVOCATORIA = ?";

		return (List<TiposCertificacion>) this.jdbcTemplate.query(query, this.rwMap,
				tiposCertificacion.getIdConvocatoria());

	}

	/**
	 * Removes a single row in the TiposCertificacion table.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @return
	 */
	public void remove(TiposCertificacion tiposcertificacion) {
		String query = "DELETE FROM TIPOS_CERTIFICACION WHERE ID_TIPO_CERTIFICACION=?";
		this.jdbcTemplate.update(query, tiposcertificacion.getIdTipoCertificacion());
	}

	/**
	 * Finds a list of rows in the TiposCertificacion table.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposCertificacion>
	 */
	@Transactional(readOnly = true)
	public List<TiposCertificacion> findAll(TiposCertificacion tiposcertificacion, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_CERTIFICACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposcertificacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposCertificacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposCertificacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposCertificacion table using like.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposCertificacion>
	 */
	@Transactional(readOnly = true)
	public List<TiposCertificacion> findAllLike(TiposCertificacion tiposcertificacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_CERTIFICACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposcertificacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposCertificacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposCertificacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposCertificacion table.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposCertificacion tiposcertificacion) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_CERTIFICACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposcertificacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposCertificacion table using like.
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposCertificacion tiposcertificacion, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_CERTIFICACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposcertificacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposCertificacion selected for rup_table
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposCertificacion>>
	 */
	@Override
	public List<TableRowDto<TiposCertificacion>> reorderSelection(TiposCertificacion tiposcertificacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_CERTIFICACION t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposcertificacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				TiposCertificacion.class, filterParamList, "ID_TIPO_CERTIFICACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposCertificacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposCertificacion
	 * @param searchParams
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposCertificacion>>
	 */
	@Override
	public List<TableRowDto<TiposCertificacion>> search(TiposCertificacion filterParams,
			TiposCertificacion searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_CERTIFICACION t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				TiposCertificacion.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_TIPO_CERTIFICACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposCertificacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertiposcertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposCertificacion filtertiposcertificacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_CERTIFICACION t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertiposcertificacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				TiposCertificacion.class, query, params, "ID_TIPO_CERTIFICACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposCertificacion table.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposCertificacion>>
	 */
	@Override
	public List<JerarquiaDto<TiposCertificacion>> findAllLikeJerarquia(TiposCertificacion filterTiposCertificacion,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CERTIFICACION IDTIPOCERTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_CERTIFICACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_CERTIFICACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposCertificacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_CERTIFICACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposCertificacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposCertificacion filterTiposCertificacion,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_CERTIFICACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_CERTIFICACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposCertificacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_CERTIFICACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposCertificacion>>
	 */
	@Override
	public List<TableRowDto<TiposCertificacion>> findAllChild(TiposCertificacion filterTiposCertificacion,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_CERTIFICACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_CERTIFICACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposCertificacion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_TIPO_CERTIFICACION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposCertificacion>(this.rwMapPK, "ID_TIPO_CERTIFICACION"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposCertificacion entity
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposCertificacion tiposcertificacion) {

		StringBuilder where = new StringBuilder(TiposCertificacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposcertificacion != null && tiposcertificacion.getIdTipoCertificacion() != null) {
			where.append(" AND t1.ID_TIPO_CERTIFICACION = ?");
			params.add(tiposcertificacion.getIdTipoCertificacion());
		}
		if (tiposcertificacion != null && tiposcertificacion.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposcertificacion.getDescripcionCastellano());
		}
		if (tiposcertificacion != null && tiposcertificacion.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposcertificacion.getDescripcionEuskera());
		}
		if (tiposcertificacion != null && tiposcertificacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposcertificacion.getFechaRegistro());
		}
		if (tiposcertificacion != null && tiposcertificacion.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposcertificacion.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposCertificacion entity
	 *
	 * @param tiposcertificacion
	 *            TiposCertificacion Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposCertificacion tiposcertificacion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposCertificacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposcertificacion != null && tiposcertificacion.getIdTipoCertificacion() != null) {
			where.append(" AND t1.ID_TIPO_CERTIFICACION = ?");
			params.add(tiposcertificacion.getIdTipoCertificacion());
		}
		if (tiposcertificacion != null && tiposcertificacion.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposcertificacion.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tiposcertificacion.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tiposcertificacion != null && tiposcertificacion.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposcertificacion.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tiposcertificacion.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tiposcertificacion != null && tiposcertificacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposcertificacion.getFechaRegistro());
		}
		if (tiposcertificacion != null && tiposcertificacion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposcertificacion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tiposcertificacion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
