package com.ejie.ab60.dao.CTP;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.CTP.AsociacionesSectoriales;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AsociacionesSectorialesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class AsociacionesSectorialesDaoImpl implements AsociacionesSectorialesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDASOCIACION", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "LIMITEENTIDAD", "PORCENTAJE", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<AsociacionesSectoriales> rwMap = new RowMapper<AsociacionesSectoriales>() {
		public AsociacionesSectoriales mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AsociacionesSectoriales(resultSet.getLong("IDASOCIACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getBigDecimal("LIMITEENTIDAD"), resultSet.getBigDecimal("PORCENTAJE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<AsociacionesSectoriales> rwMapAsociaciones = new RowMapper<AsociacionesSectoriales>() {
		public AsociacionesSectoriales mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AsociacionesSectoriales(resultSet.getLong("IDASOCIACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"));
		}
	};

	private RowMapper<AsociacionesSectoriales> rwMapPK = new RowMapper<AsociacionesSectoriales>() {
		public AsociacionesSectoriales mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AsociacionesSectoriales(resultSet.getLong("IDASOCIACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<AsociacionesSectoriales>> rwMapJerarquia = new RowMapper<JerarquiaDto<AsociacionesSectoriales>>() {
		public JerarquiaDto<AsociacionesSectoriales> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			AsociacionesSectoriales asociacionessectoriales = new AsociacionesSectoriales(
					resultSet.getLong("IDASOCIACION"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getBigDecimal("LIMITEENTIDAD"),
					resultSet.getBigDecimal("PORCENTAJE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<AsociacionesSectoriales> jerarquia = new JerarquiaDto<AsociacionesSectoriales>();
			jerarquia.setModel(asociacionessectoriales);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * Lista de asociones sectoriales para cargar el combo del select
	 */

	@Override
	public List<AsociacionesSectoriales> findAsociacionesSectoriales() {
		String query = "SELECT t1.ID_ASOCIACION AS IDASOCIACION, t1.DESCRIPCION_CASTELLANO AS DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA AS DESCRIPCIONEUSKERA FROM ASOCIACIONES_SECTORIALES t1";
		return (List<AsociacionesSectoriales>) this.jdbcTemplate.query(query, this.rwMapAsociaciones);

	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @return AsociacionesSectoriales
	 */
	public AsociacionesSectoriales add(AsociacionesSectoriales asociacionessectoriales) {
		String query = "INSERT INTO ASOCIACIONES_SECTORIALES (ID_ASOCIACION, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, LIMITE_ENTIDAD, PORCENTAJE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, asociacionessectoriales.getIdAsociacion(),
				asociacionessectoriales.getDescripcionCastellano(), asociacionessectoriales.getDescripcionEuskera(),
				asociacionessectoriales.getLimiteEntidad(), asociacionessectoriales.getPorcentaje(),
				asociacionessectoriales.getFechaRegistro(), asociacionessectoriales.getUsuarioRegistro());
		return asociacionessectoriales;
	}

	/**
	 * Updates a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @return AsociacionesSectoriales
	 */
	public AsociacionesSectoriales update(AsociacionesSectoriales asociacionessectoriales) {
		String query = "UPDATE ASOCIACIONES_SECTORIALES SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, LIMITE_ENTIDAD=?, PORCENTAJE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_ASOCIACION=?";
		this.jdbcTemplate.update(query, asociacionessectoriales.getDescripcionCastellano(),
				asociacionessectoriales.getDescripcionEuskera(), asociacionessectoriales.getLimiteEntidad(),
				asociacionessectoriales.getPorcentaje(), asociacionessectoriales.getFechaRegistro(),
				asociacionessectoriales.getUsuarioRegistro(), asociacionessectoriales.getIdAsociacion());
		return asociacionessectoriales;
	}

	/**
	 * Finds a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @return AsociacionesSectoriales
	 */
	@Transactional(readOnly = true)
	public AsociacionesSectoriales find(AsociacionesSectoriales asociacionessectoriales) {
		String query = "SELECT t1.ID_ASOCIACION IDASOCIACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.LIMITE_ENTIDAD LIMITEENTIDAD, t1.PORCENTAJE PORCENTAJE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM ASOCIACIONES_SECTORIALES t1  WHERE t1.ID_ASOCIACION = ?  ";

		List<AsociacionesSectoriales> asociacionessectorialesList = this.jdbcTemplate.query(query, this.rwMap,
				asociacionessectoriales.getIdAsociacion());
		return (AsociacionesSectoriales) DataAccessUtils.uniqueResult(asociacionessectorialesList);
	}

	/**
	 * Removes a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @return
	 */
	public void remove(AsociacionesSectoriales asociacionessectoriales) {
		String query = "DELETE FROM ASOCIACIONES_SECTORIALES WHERE ID_ASOCIACION=?";
		this.jdbcTemplate.update(query, asociacionessectoriales.getIdAsociacion());
	}

	/**
	 * Finds a list of rows in the AsociacionesSectoriales table.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<AsociacionesSectoriales>
	 */
	@Transactional(readOnly = true)
	public List<AsociacionesSectoriales> findAll(AsociacionesSectoriales asociacionessectoriales,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ASOCIACION IDASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM ASOCIACIONES_SECTORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(asociacionessectoriales);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AsociacionesSectorialesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AsociacionesSectoriales>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the AsociacionesSectoriales table using like.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<AsociacionesSectoriales>
	 */
	@Transactional(readOnly = true)
	public List<AsociacionesSectoriales> findAllLike(AsociacionesSectoriales asociacionessectoriales,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ASOCIACION IDASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM ASOCIACIONES_SECTORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(asociacionessectoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AsociacionesSectorialesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AsociacionesSectoriales>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the AsociacionesSectoriales table.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(AsociacionesSectoriales asociacionessectoriales) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ASOCIACIONES_SECTORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(asociacionessectoriales);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the AsociacionesSectoriales table using like.
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(AsociacionesSectoriales asociacionessectoriales, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ASOCIACIONES_SECTORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(asociacionessectoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of AsociacionesSectoriales selected for rup_table
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AsociacionesSectoriales>>
	 */
	@Override
	public List<TableRowDto<AsociacionesSectoriales>> reorderSelection(AsociacionesSectoriales asociacionessectoriales,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION IDASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM ASOCIACIONES_SECTORIALES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(asociacionessectoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				AsociacionesSectoriales.class, filterParamList, "ID_ASOCIACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AsociacionesSectoriales>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            AsociacionesSectoriales
	 * @param searchParams
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AsociacionesSectoriales>>
	 */
	@Override
	public List<TableRowDto<AsociacionesSectoriales>> search(AsociacionesSectoriales filterParams,
			AsociacionesSectoriales searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION IDASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM ASOCIACIONES_SECTORIALES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				AsociacionesSectoriales.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_ASOCIACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AsociacionesSectoriales>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterasociacionessectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(AsociacionesSectoriales filterasociacionessectoriales, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION IDASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM ASOCIACIONES_SECTORIALES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterasociacionessectoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				AsociacionesSectoriales.class, query, params, "ID_ASOCIACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical AsociacionesSectoriales table.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<AsociacionesSectoriales>>
	 */
	@Override
	public List<JerarquiaDto<AsociacionesSectoriales>> findAllLikeJerarquia(
			AsociacionesSectoriales filterAsociacionesSectoriales, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION IDASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ASOCIACIONES_SECTORIALES
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("ASOCIACIONES_SECTORIALES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAsociacionesSectoriales, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ASOCIACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					AsociacionesSectorialesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(AsociacionesSectoriales filterAsociacionesSectoriales,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ASOCIACIONES_SECTORIALES
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("ASOCIACIONES_SECTORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAsociacionesSectoriales, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ASOCIACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<AsociacionesSectoriales>>
	 */
	@Override
	public List<TableRowDto<AsociacionesSectoriales>> findAllChild(
			AsociacionesSectoriales filterAsociacionesSectoriales, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ASOCIACIONES_SECTORIALES
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("ASOCIACIONES_SECTORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAsociacionesSectoriales, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_ASOCIACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<AsociacionesSectoriales>(this.rwMapPK, "ID_ASOCIACION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AsociacionesSectoriales entity
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales Bean with the criteria values to
	 *            filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(AsociacionesSectoriales asociacionessectoriales) {

		StringBuilder where = new StringBuilder(AsociacionesSectorialesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (asociacionessectoriales != null && asociacionessectoriales.getIdAsociacion() != null) {
			where.append(" AND t1.ID_ASOCIACION = ?");
			params.add(asociacionessectoriales.getIdAsociacion());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(asociacionessectoriales.getDescripcionCastellano());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(asociacionessectoriales.getDescripcionEuskera());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getLimiteEntidad() != null) {
			where.append(" AND t1.LIMITE_ENTIDAD = ?");
			params.add(asociacionessectoriales.getLimiteEntidad());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getPorcentaje() != null) {
			where.append(" AND t1.PORCENTAJE = ?");
			params.add(asociacionessectoriales.getPorcentaje());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(asociacionessectoriales.getFechaRegistro());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(asociacionessectoriales.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AsociacionesSectoriales entity
	 *
	 * @param asociacionessectoriales
	 *            AsociacionesSectoriales Bean with the criteria values to
	 *            filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(AsociacionesSectoriales asociacionessectoriales, Boolean startsWith) {

		StringBuilder where = new StringBuilder(AsociacionesSectorialesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (asociacionessectoriales != null && asociacionessectoriales.getIdAsociacion() != null) {
			where.append(" AND t1.ID_ASOCIACION = ?");
			params.add(asociacionessectoriales.getIdAsociacion());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionessectoriales.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionessectoriales.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionessectoriales.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionessectoriales.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getLimiteEntidad() != null) {
			where.append(" AND t1.LIMITE_ENTIDAD = ?");
			params.add(asociacionessectoriales.getLimiteEntidad());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getPorcentaje() != null) {
			where.append(" AND t1.PORCENTAJE = ?");
			params.add(asociacionessectoriales.getPorcentaje());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(asociacionessectoriales.getFechaRegistro());
		}
		if (asociacionessectoriales != null && asociacionessectoriales.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionessectoriales.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionessectoriales.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
