package com.ejie.ab60.dao.CTP;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.CTP.AsociacionesSectoriales;
import com.ejie.ab60.model.CTP.Proyectos;
import com.ejie.ab60.model.CTP.Solicitantes;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ProyectosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ProyectosDaoImpl implements ProyectosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPROYECTO", "IDEXPEDIENTE", "DENOMINACION",
			"FECHAREGISTRO", "USUARIOREGISTRO", "SOLICITANTESIDSOLICITANTE", "SOLICITANTESDESCRIPCIONCASTELLANO",
			"SOLICITANTESDESCRIPCIONEUSKERA", "SOLICITANTESLIMITEENTIDAD", "SOLICITANTESPORCENTAJE",
			"SOLICITANTESFECHAREGISTRO", "SOLICITANTESUSUARIOREGISTRO", "ASOCIACIONESSECTORIALESIDASOCIACION",
			"ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO", "ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA",
			"ASOCIACIONESSECTORIALESLIMITEENTIDAD", "ASOCIACIONESSECTORIALESPORCENTAJE",
			"ASOCIACIONESSECTORIALESFECHAREGISTRO", "ASOCIACIONESSECTORIALESUSUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Proyectos> rwMap = new RowMapper<Proyectos>() {
		public Proyectos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Proyectos(resultSet.getString("IDPROYECTO"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getString("DENOMINACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new Solicitantes(resultSet.getLong("SolicitantesIDSOLICITANTE"),
							resultSet.getString("SolicitantesDESCRIPCIONCASTELLANO"),
							resultSet.getString("SolicitantesDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("SolicitantesLIMITEENTIDAD"),
							resultSet.getBigDecimal("SolicitantesPORCENTAJE"),
							resultSet.getDate("SolicitantesFECHAREGISTRO"),
							resultSet.getString("SolicitantesUSUARIOREGISTRO")),
					new AsociacionesSectoriales(resultSet.getLong("AsociacionesSectorialesIDASOCIACION"),
							resultSet.getString("AsociacionesSectorialesDESCRIPCIONCASTELLANO"),
							resultSet.getString("AsociacionesSectorialesDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("AsociacionesSectorialesLIMITEENTIDAD"),
							resultSet.getBigDecimal("AsociacionesSectorialesPORCENTAJE"),
							resultSet.getDate("AsociacionesSectorialesFECHAREGISTRO"),
							resultSet.getString("AsociacionesSectorialesUSUARIOREGISTRO")));
		}
	};

	private RowMapper<Proyectos> rwMapPK = new RowMapper<Proyectos>() {
		public Proyectos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Proyectos(resultSet.getString("IDPROYECTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Proyectos>> rwMapJerarquia = new RowMapper<JerarquiaDto<Proyectos>>() {
		public JerarquiaDto<Proyectos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Proyectos proyectos = new Proyectos(resultSet.getString("IDPROYECTO"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getString("DENOMINACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new Solicitantes(resultSet.getLong("SolicitantesIDSOLICITANTE"),
							resultSet.getString("SolicitantesDESCRIPCIONCASTELLANO"),
							resultSet.getString("SolicitantesDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("SolicitantesLIMITEENTIDAD"),
							resultSet.getBigDecimal("SolicitantesPORCENTAJE"),
							resultSet.getDate("SolicitantesFECHAREGISTRO"),
							resultSet.getString("SolicitantesUSUARIOREGISTRO")),
					new AsociacionesSectoriales(resultSet.getLong("AsociacionesSectorialesIDASOCIACION"),
							resultSet.getString("AsociacionesSectorialesDESCRIPCIONCASTELLANO"),
							resultSet.getString("AsociacionesSectorialesDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("AsociacionesSectorialesLIMITEENTIDAD"),
							resultSet.getBigDecimal("AsociacionesSectorialesPORCENTAJE"),
							resultSet.getDate("AsociacionesSectorialesFECHAREGISTRO"),
							resultSet.getString("AsociacionesSectorialesUSUARIOREGISTRO")));

			JerarquiaDto<Proyectos> jerarquia = new JerarquiaDto<Proyectos>();
			jerarquia.setModel(proyectos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	public Proyectos add(Proyectos proyectos) {
		String query = "INSERT INTO PROYECTOS (ID_PROYECTO, ID_SOLICITANTE, ID_ASOCIACION, ID_EXPEDIENTE, DENOMINACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		Object getSolicitantesIdSolicitanteAux = null;
		if (proyectos.getSolicitantes() != null && proyectos.getSolicitantes().getIdSolicitante() != null) {
			getSolicitantesIdSolicitanteAux = proyectos.getSolicitantes().getIdSolicitante();
		}
		Object getAsociacionesSectorialesIdAsociacionAux = null;
		if (proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getIdAsociacion() != null) {
			getAsociacionesSectorialesIdAsociacionAux = proyectos.getAsociacionesSectoriales().getIdAsociacion();
		}
		this.jdbcTemplate.update(query, proyectos.getIdProyecto(), getSolicitantesIdSolicitanteAux,
				getAsociacionesSectorialesIdAsociacionAux, proyectos.getIdExpediente(), proyectos.getDenominacion(),
				proyectos.getFechaRegistro(), proyectos.getUsuarioRegistro());
		return proyectos;
	}

	/**
	 * Updates a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	public Proyectos update(Proyectos proyectos) {
		String query = "UPDATE PROYECTOS SET ID_SOLICITANTE=?, ID_ASOCIACION=?, ID_EXPEDIENTE=?, DENOMINACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_PROYECTO=?";
		Object getSolicitantesIdSolicitanteAux = null;
		if (proyectos.getSolicitantes() != null && proyectos.getSolicitantes().getIdSolicitante() != null) {
			getSolicitantesIdSolicitanteAux = proyectos.getSolicitantes().getIdSolicitante();
		}
		Object getAsociacionesSectorialesIdAsociacionAux = null;
		if (proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getIdAsociacion() != null) {
			getAsociacionesSectorialesIdAsociacionAux = proyectos.getAsociacionesSectoriales().getIdAsociacion();
		}
		this.jdbcTemplate.update(query, getSolicitantesIdSolicitanteAux, getAsociacionesSectorialesIdAsociacionAux,
				proyectos.getIdExpediente(), proyectos.getDenominacion(), proyectos.getFechaRegistro(),
				proyectos.getUsuarioRegistro(), proyectos.getIdProyecto());
		return proyectos;
	}

	/**
	 * Updates idAsociacion en la tabla in the Proyectos
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	public Proyectos updateIdAsociacion(Proyectos proyectos) {
		String query = "UPDATE PROYECTOS SET  ID_ASOCIACION=?,  FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_EXPEDIENTE=?";

		Object getAsociacionesSectorialesIdAsociacionAux = null;
		if (proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getIdAsociacion() != null) {
			getAsociacionesSectorialesIdAsociacionAux = proyectos.getAsociacionesSectoriales().getIdAsociacion();
		}
		this.jdbcTemplate.update(query, getAsociacionesSectorialesIdAsociacionAux, proyectos.getFechaUltmodificacion(),
				proyectos.getUsuarioUltmodificacion(), proyectos.getIdExpediente());
		return proyectos;
	}

	/**
	 * Finds a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	@Transactional(readOnly = true)
	public Proyectos find(Proyectos proyectos) {
		String query = "SELECT t1.ID_PROYECTO IDPROYECTO, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.DENOMINACION DENOMINACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_SOLICITANTE SOLICITANTESIDSOLICITANTE, t2.DESCRIPCION_CASTELLANO SOLICITANTESDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA SOLICITANTESDESCRIPCIONEUSKERA, t2.LIMITE_ENTIDAD SOLICITANTESLIMITEENTIDAD, t2.PORCENTAJE SOLICITANTESPORCENTAJE, t2.FECHA_REGISTRO SOLICITANTESFECHAREGISTRO, t2.USUARIO_REGISTRO SOLICITANTESUSUARIOREGISTRO, t3.ID_ASOCIACION ASOCIACIONESSECTORIALESIDASOCIACION, t3.DESCRIPCION_CASTELLANO ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA, t3.LIMITE_ENTIDAD ASOCIACIONESSECTORIALESLIMITEENTIDAD, t3.PORCENTAJE ASOCIACIONESSECTORIALESPORCENTAJE, t3.FECHA_REGISTRO ASOCIACIONESSECTORIALESFECHAREGISTRO, t3.USUARIO_REGISTRO ASOCIACIONESSECTORIALESUSUARIOREGISTRO FROM PROYECTOS t1 , SOLICITANTES t2 , ASOCIACIONES_SECTORIALES t3  WHERE t1.ID_PROYECTO = ?   AND t1.ID_SOLICITANTE= t2.ID_SOLICITANTE(+) AND t1.ID_ASOCIACION= t3.ID_ASOCIACION(+)";

		List<Proyectos> proyectosList = this.jdbcTemplate.query(query, this.rwMap, proyectos.getIdProyecto());
		return (Proyectos) DataAccessUtils.uniqueResult(proyectosList);
	}

	/**
	 * Removes a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return
	 */
	public void remove(Proyectos proyectos) {
		String query = "DELETE FROM PROYECTOS WHERE ID_PROYECTO=?";
		this.jdbcTemplate.update(query, proyectos.getIdProyecto());
	}

	/**
	 * Finds a list of rows in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Proyectos>
	 */
	@Transactional(readOnly = true)
	public List<Proyectos> findAll(Proyectos proyectos, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PROYECTO IDPROYECTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_SOLICITANTE SOLICITANTESIDSOLICITANTE,t2.DESCRIPCION_CASTELLANO SOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA SOLICITANTESDESCRIPCIONEUSKERA,t2.LIMITE_ENTIDAD SOLICITANTESLIMITEENTIDAD,t2.PORCENTAJE SOLICITANTESPORCENTAJE,t2.FECHA_REGISTRO SOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO SOLICITANTESUSUARIOREGISTRO,t3.ID_ASOCIACION ASOCIACIONESSECTORIALESIDASOCIACION,t3.DESCRIPCION_CASTELLANO ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA,t3.LIMITE_ENTIDAD ASOCIACIONESSECTORIALESLIMITEENTIDAD,t3.PORCENTAJE ASOCIACIONESSECTORIALESPORCENTAJE,t3.FECHA_REGISTRO ASOCIACIONESSECTORIALESFECHAREGISTRO,t3.USUARIO_REGISTRO ASOCIACIONESSECTORIALESUSUARIOREGISTRO ");
		query.append("FROM PROYECTOS t1 ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(proyectos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_SOLICITANTE= t2.ID_SOLICITANTE(+) AND t1.ID_ASOCIACION= t3.ID_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ProyectosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Proyectos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Proyectos table using like.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Proyectos>
	 */
	@Transactional(readOnly = true)
	public List<Proyectos> findAllLike(Proyectos proyectos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PROYECTO IDPROYECTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_SOLICITANTE SOLICITANTESIDSOLICITANTE,t2.DESCRIPCION_CASTELLANO SOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA SOLICITANTESDESCRIPCIONEUSKERA,t2.LIMITE_ENTIDAD SOLICITANTESLIMITEENTIDAD,t2.PORCENTAJE SOLICITANTESPORCENTAJE,t2.FECHA_REGISTRO SOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO SOLICITANTESUSUARIOREGISTRO,t3.ID_ASOCIACION ASOCIACIONESSECTORIALESIDASOCIACION,t3.DESCRIPCION_CASTELLANO ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA,t3.LIMITE_ENTIDAD ASOCIACIONESSECTORIALESLIMITEENTIDAD,t3.PORCENTAJE ASOCIACIONESSECTORIALESPORCENTAJE,t3.FECHA_REGISTRO ASOCIACIONESSECTORIALESFECHAREGISTRO,t3.USUARIO_REGISTRO ASOCIACIONESSECTORIALESUSUARIOREGISTRO ");
		query.append("FROM PROYECTOS t1 ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(proyectos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_SOLICITANTE= t2.ID_SOLICITANTE(+) AND t1.ID_ASOCIACION= t3.ID_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ProyectosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Proyectos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Proyectos proyectos) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM PROYECTOS t1 , SOLICITANTES t2 , ASOCIACIONES_SECTORIALES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(proyectos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_SOLICITANTE= t2.ID_SOLICITANTE(+) AND t1.ID_ASOCIACION= t3.ID_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Proyectos table using like.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Proyectos proyectos, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM PROYECTOS t1 ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(proyectos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_SOLICITANTE= t2.ID_SOLICITANTE(+) AND t1.ID_ASOCIACION= t3.ID_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Proyectos selected for rup_table
	 *
	 * @param proyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Proyectos>>
	 */
	@Override
	public List<TableRowDto<Proyectos>> reorderSelection(Proyectos proyectos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROYECTO IDPROYECTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_SOLICITANTE SOLICITANTESIDSOLICITANTE,t2.DESCRIPCION_CASTELLANO SOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA SOLICITANTESDESCRIPCIONEUSKERA,t2.LIMITE_ENTIDAD SOLICITANTESLIMITEENTIDAD,t2.PORCENTAJE SOLICITANTESPORCENTAJE,t2.FECHA_REGISTRO SOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO SOLICITANTESUSUARIOREGISTRO,t3.ID_ASOCIACION ASOCIACIONESSECTORIALESIDASOCIACION,t3.DESCRIPCION_CASTELLANO ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA,t3.LIMITE_ENTIDAD ASOCIACIONESSECTORIALESLIMITEENTIDAD,t3.PORCENTAJE ASOCIACIONESSECTORIALESPORCENTAJE,t3.FECHA_REGISTRO ASOCIACIONESSECTORIALESFECHAREGISTRO,t3.USUARIO_REGISTRO ASOCIACIONESSECTORIALESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM PROYECTOS t1 ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(proyectos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_SOLICITANTE= t2.ID_SOLICITANTE(+) AND t1.ID_ASOCIACION= t3.ID_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Proyectos.class,
				filterParamList, "ID_PROYECTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Proyectos>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Proyectos
	 * @param searchParams
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Proyectos>>
	 */
	@Override
	public List<TableRowDto<Proyectos>> search(Proyectos filterParams, Proyectos searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROYECTO IDPROYECTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_SOLICITANTE SOLICITANTESIDSOLICITANTE,t2.DESCRIPCION_CASTELLANO SOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA SOLICITANTESDESCRIPCIONEUSKERA,t2.LIMITE_ENTIDAD SOLICITANTESLIMITEENTIDAD,t2.PORCENTAJE SOLICITANTESPORCENTAJE,t2.FECHA_REGISTRO SOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO SOLICITANTESUSUARIOREGISTRO,t3.ID_ASOCIACION ASOCIACIONESSECTORIALESIDASOCIACION,t3.DESCRIPCION_CASTELLANO ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA,t3.LIMITE_ENTIDAD ASOCIACIONESSECTORIALESLIMITEENTIDAD,t3.PORCENTAJE ASOCIACIONESSECTORIALESPORCENTAJE,t3.FECHA_REGISTRO ASOCIACIONESSECTORIALESFECHAREGISTRO,t3.USUARIO_REGISTRO ASOCIACIONESSECTORIALESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM PROYECTOS t1 ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_SOLICITANTE= t2.ID_SOLICITANTE(+) AND t1.ID_ASOCIACION= t3.ID_ASOCIACION(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Proyectos.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_PROYECTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Proyectos>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterproyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Proyectos filterproyectos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROYECTO IDPROYECTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_SOLICITANTE SOLICITANTESIDSOLICITANTE,t2.DESCRIPCION_CASTELLANO SOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA SOLICITANTESDESCRIPCIONEUSKERA,t2.LIMITE_ENTIDAD SOLICITANTESLIMITEENTIDAD,t2.PORCENTAJE SOLICITANTESPORCENTAJE,t2.FECHA_REGISTRO SOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO SOLICITANTESUSUARIOREGISTRO,t3.ID_ASOCIACION ASOCIACIONESSECTORIALESIDASOCIACION,t3.DESCRIPCION_CASTELLANO ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA,t3.LIMITE_ENTIDAD ASOCIACIONESSECTORIALESLIMITEENTIDAD,t3.PORCENTAJE ASOCIACIONESSECTORIALESPORCENTAJE,t3.FECHA_REGISTRO ASOCIACIONESSECTORIALESFECHAREGISTRO,t3.USUARIO_REGISTRO ASOCIACIONESSECTORIALESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM PROYECTOS t1 ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterproyectos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Proyectos.class,
				query, params, "ID_PROYECTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Proyectos table.
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Proyectos>>
	 */
	@Override
	public List<JerarquiaDto<Proyectos>> findAllLikeJerarquia(Proyectos filterProyectos,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROYECTO IDPROYECTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_SOLICITANTE SOLICITANTESIDSOLICITANTE,t2.DESCRIPCION_CASTELLANO SOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA SOLICITANTESDESCRIPCIONEUSKERA,t2.LIMITE_ENTIDAD SOLICITANTESLIMITEENTIDAD,t2.PORCENTAJE SOLICITANTESPORCENTAJE,t2.FECHA_REGISTRO SOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO SOLICITANTESUSUARIOREGISTRO,t3.ID_ASOCIACION ASOCIACIONESSECTORIALESIDASOCIACION,t3.DESCRIPCION_CASTELLANO ASOCIACIONESSECTORIALESDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA ASOCIACIONESSECTORIALESDESCRIPCIONEUSKERA,t3.LIMITE_ENTIDAD ASOCIACIONESSECTORIALESLIMITEENTIDAD,t3.PORCENTAJE ASOCIACIONESSECTORIALESPORCENTAJE,t3.FECHA_REGISTRO ASOCIACIONESSECTORIALESFECHAREGISTRO,t3.USUARIO_REGISTRO ASOCIACIONESSECTORIALESUSUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PROYECTOS t1
		// ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");
		List<String> from = new ArrayList<String>();
		from.add("PROYECTOS");
		from.add("SOLICITANTES");
		from.add("ASOCIACIONES_SECTORIALES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProyectos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PROYECTO", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ProyectosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Proyectos filterProyectos, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PROYECTOS t1
		// ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");
		List<String> from = new ArrayList<String>();
		from.add("PROYECTOS");
		from.add("SOLICITANTES");
		from.add("ASOCIACIONES_SECTORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProyectos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PROYECTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Proyectos>>
	 */
	@Override
	public List<TableRowDto<Proyectos>> findAllChild(Proyectos filterProyectos, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PROYECTOS t1
		// ,SOLICITANTES t2 ,ASOCIACIONES_SECTORIALES t3 ");
		List<String> from = new ArrayList<String>();
		from.add("PROYECTOS");
		from.add("SOLICITANTES");
		from.add("ASOCIACIONES_SECTORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProyectos, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_PROYECTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Proyectos>(this.rwMapPK, "ID_PROYECTO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Proyectos entity
	 *
	 * @param proyectos
	 *            Proyectos Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Proyectos proyectos) {

		StringBuilder where = new StringBuilder(ProyectosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (proyectos != null && proyectos.getIdProyecto() != null) {
			where.append(" AND t1.ID_PROYECTO = ?");
			params.add(proyectos.getIdProyecto());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getIdSolicitante() != null) {
			where.append(" AND t2.ID_SOLICITANTE = ?");
			params.add(proyectos.getSolicitantes().getIdSolicitante());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(proyectos.getSolicitantes().getDescripcionCastellano());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(proyectos.getSolicitantes().getDescripcionEuskera());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getLimiteEntidad() != null) {
			where.append(" AND t2.LIMITE_ENTIDAD = ?");
			params.add(proyectos.getSolicitantes().getLimiteEntidad());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getPorcentaje() != null) {
			where.append(" AND t2.PORCENTAJE = ?");
			params.add(proyectos.getSolicitantes().getPorcentaje());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(proyectos.getSolicitantes().getFechaRegistro());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(proyectos.getSolicitantes().getUsuarioRegistro());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getIdAsociacion() != null) {
			where.append(" AND t3.ID_ASOCIACION = ?");
			params.add(proyectos.getAsociacionesSectoriales().getIdAsociacion());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getDescripcionCastellano() != null) {
			where.append(" AND t3.DESCRIPCION_CASTELLANO = ?");
			params.add(proyectos.getAsociacionesSectoriales().getDescripcionCastellano());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getDescripcionEuskera() != null) {
			where.append(" AND t3.DESCRIPCION_EUSKERA = ?");
			params.add(proyectos.getAsociacionesSectoriales().getDescripcionEuskera());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getLimiteEntidad() != null) {
			where.append(" AND t3.LIMITE_ENTIDAD = ?");
			params.add(proyectos.getAsociacionesSectoriales().getLimiteEntidad());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getPorcentaje() != null) {
			where.append(" AND t3.PORCENTAJE = ?");
			params.add(proyectos.getAsociacionesSectoriales().getPorcentaje());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(proyectos.getAsociacionesSectoriales().getFechaRegistro());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(proyectos.getAsociacionesSectoriales().getUsuarioRegistro());
		}
		if (proyectos != null && proyectos.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(proyectos.getIdExpediente());
		}
		if (proyectos != null && proyectos.getDenominacion() != null) {
			where.append(" AND t1.DENOMINACION = ?");
			params.add(proyectos.getDenominacion());
		}
		if (proyectos != null && proyectos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(proyectos.getFechaRegistro());
		}
		if (proyectos != null && proyectos.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(proyectos.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Proyectos entity
	 *
	 * @param proyectos
	 *            Proyectos Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Proyectos proyectos, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ProyectosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (proyectos != null && proyectos.getIdProyecto() != null) {
			where.append(" AND UPPER(t1.ID_PROYECTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getIdProyecto().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getIdProyecto().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_PROYECTO IS NOT NULL");
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getIdSolicitante() != null) {
			where.append(" AND t2.ID_SOLICITANTE = ?");
			params.add(proyectos.getSolicitantes().getIdSolicitante());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getSolicitantes().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getSolicitantes().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getSolicitantes().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getSolicitantes().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getLimiteEntidad() != null) {
			where.append(" AND t2.LIMITE_ENTIDAD = ?");
			params.add(proyectos.getSolicitantes().getLimiteEntidad());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getPorcentaje() != null) {
			where.append(" AND t2.PORCENTAJE = ?");
			params.add(proyectos.getSolicitantes().getPorcentaje());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(proyectos.getSolicitantes().getFechaRegistro());
		}
		if (proyectos != null && proyectos.getSolicitantes() != null
				&& proyectos.getSolicitantes().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getSolicitantes().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getSolicitantes().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getIdAsociacion() != null) {
			where.append(" AND t3.ID_ASOCIACION = ?");
			params.add(proyectos.getAsociacionesSectoriales().getIdAsociacion());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getAsociacionesSectoriales().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getAsociacionesSectoriales().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getAsociacionesSectoriales().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getAsociacionesSectoriales().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getLimiteEntidad() != null) {
			where.append(" AND t3.LIMITE_ENTIDAD = ?");
			params.add(proyectos.getAsociacionesSectoriales().getLimiteEntidad());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getPorcentaje() != null) {
			where.append(" AND t3.PORCENTAJE = ?");
			params.add(proyectos.getAsociacionesSectoriales().getPorcentaje());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(proyectos.getAsociacionesSectoriales().getFechaRegistro());
		}
		if (proyectos != null && proyectos.getAsociacionesSectoriales() != null
				&& proyectos.getAsociacionesSectoriales().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getAsociacionesSectoriales().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getAsociacionesSectoriales().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (proyectos != null && proyectos.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(proyectos.getIdExpediente());
		}
		if (proyectos != null && proyectos.getDenominacion() != null) {
			where.append(" AND UPPER(t1.DENOMINACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getDenominacion().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getDenominacion().toUpperCase() + "%");
			}
			where.append(" AND t1.DENOMINACION IS NOT NULL");
		}
		if (proyectos != null && proyectos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(proyectos.getFechaRegistro());
		}
		if (proyectos != null && proyectos.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(proyectos.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + proyectos.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
