package com.ejie.ab60.dao.CTP;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.CTP.Solicitantes;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * SolicitantesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class SolicitantesDaoImpl implements SolicitantesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDSOLICITANTE", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "LIMITEENTIDAD", "PORCENTAJE", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Solicitantes> rwMap = new RowMapper<Solicitantes>() {
		public Solicitantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Solicitantes(resultSet.getLong("IDSOLICITANTE"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getBigDecimal("LIMITEENTIDAD"),
					resultSet.getBigDecimal("PORCENTAJE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<Solicitantes> rwMapPK = new RowMapper<Solicitantes>() {
		public Solicitantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Solicitantes(resultSet.getLong("IDSOLICITANTE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Solicitantes>> rwMapJerarquia = new RowMapper<JerarquiaDto<Solicitantes>>() {
		public JerarquiaDto<Solicitantes> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Solicitantes solicitantes = new Solicitantes(resultSet.getLong("IDSOLICITANTE"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getBigDecimal("LIMITEENTIDAD"), resultSet.getBigDecimal("PORCENTAJE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<Solicitantes> jerarquia = new JerarquiaDto<Solicitantes>();
			jerarquia.setModel(solicitantes);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return Solicitantes
	 */
	public Solicitantes add(Solicitantes solicitantes) {
		String query = "INSERT INTO SOLICITANTES (ID_SOLICITANTE, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, LIMITE_ENTIDAD, PORCENTAJE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, solicitantes.getIdSolicitante(), solicitantes.getDescripcionCastellano(),
				solicitantes.getDescripcionEuskera(), solicitantes.getLimiteEntidad(), solicitantes.getPorcentaje(),
				solicitantes.getFechaRegistro(), solicitantes.getUsuarioRegistro());
		return solicitantes;
	}

	/**
	 * Updates a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return Solicitantes
	 */
	public Solicitantes update(Solicitantes solicitantes) {
		String query = "UPDATE SOLICITANTES SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, LIMITE_ENTIDAD=?, PORCENTAJE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_SOLICITANTE=?";
		this.jdbcTemplate.update(query, solicitantes.getDescripcionCastellano(), solicitantes.getDescripcionEuskera(),
				solicitantes.getLimiteEntidad(), solicitantes.getPorcentaje(), solicitantes.getFechaRegistro(),
				solicitantes.getUsuarioRegistro(), solicitantes.getIdSolicitante());
		return solicitantes;
	}

	/**
	 * Finds a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return Solicitantes
	 */
	@Transactional(readOnly = true)
	public Solicitantes find(Solicitantes solicitantes) {
		String query = "SELECT t1.ID_SOLICITANTE IDSOLICITANTE, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.LIMITE_ENTIDAD LIMITEENTIDAD, t1.PORCENTAJE PORCENTAJE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM SOLICITANTES t1  WHERE t1.ID_SOLICITANTE = ?  ";

		List<Solicitantes> solicitantesList = this.jdbcTemplate.query(query, this.rwMap,
				solicitantes.getIdSolicitante());
		return (Solicitantes) DataAccessUtils.uniqueResult(solicitantesList);
	}

	/**
	 * Removes a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return
	 */
	public void remove(Solicitantes solicitantes) {
		String query = "DELETE FROM SOLICITANTES WHERE ID_SOLICITANTE=?";
		this.jdbcTemplate.update(query, solicitantes.getIdSolicitante());
	}

	/**
	 * Finds a list of rows in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Solicitantes>
	 */
	@Transactional(readOnly = true)
	public List<Solicitantes> findAll(Solicitantes solicitantes, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_SOLICITANTE IDSOLICITANTE,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM SOLICITANTES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(solicitantes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, SolicitantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Solicitantes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Solicitantes table using like.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Solicitantes>
	 */
	@Transactional(readOnly = true)
	public List<Solicitantes> findAllLike(Solicitantes solicitantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_SOLICITANTE IDSOLICITANTE,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM SOLICITANTES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(solicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, SolicitantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Solicitantes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Solicitantes solicitantes) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM SOLICITANTES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(solicitantes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Solicitantes table using like.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Solicitantes solicitantes, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM SOLICITANTES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(solicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Solicitantes selected for rup_table
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Solicitantes>>
	 */
	@Override
	public List<TableRowDto<Solicitantes>> reorderSelection(Solicitantes solicitantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_SOLICITANTE IDSOLICITANTE,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM SOLICITANTES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(solicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Solicitantes.class,
				filterParamList, "ID_SOLICITANTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Solicitantes>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Solicitantes
	 * @param searchParams
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Solicitantes>>
	 */
	@Override
	public List<TableRowDto<Solicitantes>> search(Solicitantes filterParams, Solicitantes searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_SOLICITANTE IDSOLICITANTE,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM SOLICITANTES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Solicitantes.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_SOLICITANTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Solicitantes>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtersolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Solicitantes filtersolicitantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_SOLICITANTE IDSOLICITANTE,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM SOLICITANTES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtersolicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Solicitantes.class,
				query, params, "ID_SOLICITANTE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Solicitantes table.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Solicitantes>>
	 */
	@Override
	public List<JerarquiaDto<Solicitantes>> findAllLikeJerarquia(Solicitantes filterSolicitantes,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_SOLICITANTE IDSOLICITANTE,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ENTIDAD LIMITEENTIDAD,t1.PORCENTAJE PORCENTAJE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM SOLICITANTES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("SOLICITANTES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterSolicitantes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_SOLICITANTE", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					SolicitantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Solicitantes filterSolicitantes, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM SOLICITANTES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterSolicitantes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_SOLICITANTE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Solicitantes>>
	 */
	@Override
	public List<TableRowDto<Solicitantes>> findAllChild(Solicitantes filterSolicitantes,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM SOLICITANTES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterSolicitantes, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_SOLICITANTE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Solicitantes>(this.rwMapPK, "ID_SOLICITANTE"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Solicitantes entity
	 *
	 * @param solicitantes
	 *            Solicitantes Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Solicitantes solicitantes) {

		StringBuilder where = new StringBuilder(SolicitantesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (solicitantes != null && solicitantes.getIdSolicitante() != null) {
			where.append(" AND t1.ID_SOLICITANTE = ?");
			params.add(solicitantes.getIdSolicitante());
		}
		if (solicitantes != null && solicitantes.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(solicitantes.getDescripcionCastellano());
		}
		if (solicitantes != null && solicitantes.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(solicitantes.getDescripcionEuskera());
		}
		if (solicitantes != null && solicitantes.getLimiteEntidad() != null) {
			where.append(" AND t1.LIMITE_ENTIDAD = ?");
			params.add(solicitantes.getLimiteEntidad());
		}
		if (solicitantes != null && solicitantes.getPorcentaje() != null) {
			where.append(" AND t1.PORCENTAJE = ?");
			params.add(solicitantes.getPorcentaje());
		}
		if (solicitantes != null && solicitantes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(solicitantes.getFechaRegistro());
		}
		if (solicitantes != null && solicitantes.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(solicitantes.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Solicitantes entity
	 *
	 * @param solicitantes
	 *            Solicitantes Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Solicitantes solicitantes, Boolean startsWith) {

		StringBuilder where = new StringBuilder(SolicitantesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (solicitantes != null && solicitantes.getIdSolicitante() != null) {
			where.append(" AND t1.ID_SOLICITANTE = ?");
			params.add(solicitantes.getIdSolicitante());
		}
		if (solicitantes != null && solicitantes.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(solicitantes.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + solicitantes.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (solicitantes != null && solicitantes.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(solicitantes.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + solicitantes.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (solicitantes != null && solicitantes.getLimiteEntidad() != null) {
			where.append(" AND t1.LIMITE_ENTIDAD = ?");
			params.add(solicitantes.getLimiteEntidad());
		}
		if (solicitantes != null && solicitantes.getPorcentaje() != null) {
			where.append(" AND t1.PORCENTAJE = ?");
			params.add(solicitantes.getPorcentaje());
		}
		if (solicitantes != null && solicitantes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(solicitantes.getFechaRegistro());
		}
		if (solicitantes != null && solicitantes.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(solicitantes.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + solicitantes.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
