package com.ejie.ab60.dao.DEC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DEC.ActAsociacion;
import com.ejie.ab60.model.DEC.AsociacionesComerciantes;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ActAsociacionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ActAsociacionDaoImpl implements ActAsociacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDACTASOCIACION", "TITULO", "FECHAINICIO",
			"FECHAFIN", "DECRIPCION", "FECHAREGISTRO", "USUARIOREGISTRO", "RELEXPACTSUBIDRELEXPACTSUB",
			"RELEXPACTSUBIDEXPEDIENTE", "RELEXPACTSUBFECHAREGISTRO", "RELEXPACTSUBUSUARIOREGISTRO",
			"RELEXPACTSUBIDACTSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ActAsociacion> rwMap = new RowMapper<ActAsociacion>() {
		public ActAsociacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAsociacion(resultSet.getInt("IDACTASOCIACION"), resultSet.getString("TITULO"),
					resultSet.getDate("FECHAINICIO"), resultSet.getDate("FECHAFIN"), resultSet.getString("DECRIPCION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));
		}
	};

	private RowMapper<ActAsociacion> rwMapPK = new RowMapper<ActAsociacion>() {
		public ActAsociacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAsociacion(resultSet.getInt("IDACTASOCIACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ActAsociacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<ActAsociacion>>() {
		public JerarquiaDto<ActAsociacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ActAsociacion actasociacion = new ActAsociacion(resultSet.getInt("IDACTASOCIACION"),
					resultSet.getString("TITULO"), resultSet.getDate("FECHAINICIO"), resultSet.getDate("FECHAFIN"),
					resultSet.getString("DECRIPCION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));

			JerarquiaDto<ActAsociacion> jerarquia = new JerarquiaDto<ActAsociacion>();
			jerarquia.setModel(actasociacion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ActAsociacion table.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @return ActAsociacion
	 */
	public ActAsociacion add(ActAsociacion actasociacion) {
		String query = "INSERT INTO ACT_ASOCIACION (ID_ACT_ASOCIACION, ID_REL_EXP_ACT_SUB, TITULO, FECHA_INICIO, FECHA_FIN, DESCRIPCION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6024T00.NEXTVAL,?,?,TO_DATE (?,'DD/MM/YYYY'),TO_DATE (?,'DD/MM/YYYY'),?,?,?)";
		this.jdbcTemplate.update(query, actasociacion.getRelExpActSub().getIdRelExpActSub(), actasociacion.getTitulo(),
				actasociacion.getFechaInicioStr(), actasociacion.getFechaFinStr(), actasociacion.getDescripcion(),
				actasociacion.getFechaRegistro(), actasociacion.getUsuarioRegistro());
		return actasociacion;
	}

	/**
	 * Updates a single row in the ActAsociacion table.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @return ActAsociacion
	 */
	public RelExpActSub update(RelExpActSub relExpActSub) {
		String query = "UPDATE ACT_ASOCIACION SET TITULO=?, FECHA_INICIO=TO_DATE (?,'DD/MM/YYYY'), FECHA_FIN=TO_DATE (?,'DD/MM/YYYY'), DESCRIPCION=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_EXP_ACT_SUB=?";

		this.jdbcTemplate.update(query, relExpActSub.getActAsociacion().getTitulo(),
				relExpActSub.getActAsociacion().getFechaInicioStr(), relExpActSub.getActAsociacion().getFechaFinStr(),
				relExpActSub.getActAsociacion().getDescripcion(), new Date(),
				relExpActSub.getActAsociacion().getUsuarioUltmodificacion(), relExpActSub.getIdRelExpActSub());
		return relExpActSub;
	}

	/**
	 * Finds a single row in the ActAsociacion table.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @return ActAsociacion
	 */
	@Transactional(readOnly = true)
	public ActAsociacion find(ActAsociacion actasociacion) {
		String query = "SELECT t1.ID_ACT_ASOCIACION IDACTASOCIACION, t1.TITULO TITULO, t1.FECHA_INICIO FECHAINICIO, t1.FECHA_FIN FECHAFIN, t1.DECRIPCION DECRIPCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE, t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO, t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB FROM ACT_ASOCIACION t1 , REL_EXP_ACT_SUB t2  WHERE t1.ID_ACT_ASOCIACION = ?   AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+)";

		List<ActAsociacion> actasociacionList = this.jdbcTemplate.query(query, this.rwMap,
				actasociacion.getIdActAsociacion());
		return (ActAsociacion) DataAccessUtils.uniqueResult(actasociacionList);
	}

	/**
	 * Removes a single row in the ActAsociacion table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return
	 */
	public void remove(Integer idRelExpActSub) {
		String query = "DELETE FROM ACT_ASOCIACION WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, idRelExpActSub);
	}

	/**
	 * Removes a single row in the ActAsociacion table.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @return
	 */
	public void remove(ActAsociacion actasociacion) {
		String query = "DELETE FROM ACT_ASOCIACION WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, actasociacion.getRelExpActSub().getIdRelExpActSub());
	}

	/**
	 * Finds a list of rows in the ActAsociacion table.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ActAsociacion>
	 */
	@Transactional(readOnly = true)
	public List<ActAsociacion> findAll(ActAsociacion actasociacion, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACT_ASOCIACION IDACTASOCIACION,t1.TITULO TITULO,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DECRIPCION DECRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM ACT_ASOCIACION t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(actasociacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ActAsociacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ActAsociacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the ActAsociacion table using like.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ActAsociacion>
	 */
	@Transactional(readOnly = true)
	public List<ActAsociacion> findAllLike(ActAsociacion actasociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACT_ASOCIACION IDACTASOCIACION,t1.TITULO TITULO,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DECRIPCION DECRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM ACT_ASOCIACION t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ActAsociacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ActAsociacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ActAsociacion table.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ActAsociacion actasociacion) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ACT_ASOCIACION t1 , REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(actasociacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ActAsociacion table using like.
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ActAsociacion actasociacion, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ACT_ASOCIACION t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ActAsociacion selected for rup_table
	 *
	 * @param actasociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ActAsociacion>>
	 */
	@Override
	public List<TableRowDto<ActAsociacion>> reorderSelection(ActAsociacion actasociacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_ASOCIACION IDACTASOCIACION,t1.TITULO TITULO,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DECRIPCION DECRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM ACT_ASOCIACION t1 ,REL_EXP_ACT_SUB t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ActAsociacion.class, filterParamList, "ID_ACT_ASOCIACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ActAsociacion>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ActAsociacion
	 * @param searchParams
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ActAsociacion>>
	 */
	@Override
	public List<TableRowDto<ActAsociacion>> search(ActAsociacion filterParams, ActAsociacion searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_ASOCIACION IDACTASOCIACION,t1.TITULO TITULO,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DECRIPCION DECRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM ACT_ASOCIACION t1 ,REL_EXP_ACT_SUB t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, ActAsociacion.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_ACT_ASOCIACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ActAsociacion>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filteractasociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ActAsociacion filteractasociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_ASOCIACION IDACTASOCIACION,t1.TITULO TITULO,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DECRIPCION DECRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM ACT_ASOCIACION t1 ,REL_EXP_ACT_SUB t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filteractasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, ActAsociacion.class,
				query, params, "ID_ACT_ASOCIACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ActAsociacion table.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ActAsociacion>>
	 */
	@Override
	public List<JerarquiaDto<ActAsociacion>> findAllLikeJerarquia(ActAsociacion filterActAsociacion,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_ASOCIACION IDACTASOCIACION,t1.TITULO TITULO,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DECRIPCION DECRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_ASOCIACION t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_ASOCIACION");
		from.add("REL_EXP_ACT_SUB");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActAsociacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ACT_ASOCIACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ActAsociacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ActAsociacion filterActAsociacion, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_ASOCIACION t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_ASOCIACION");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActAsociacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ACT_ASOCIACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ActAsociacion>>
	 */
	@Override
	public List<TableRowDto<ActAsociacion>> findAllChild(ActAsociacion filterActAsociacion,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_ASOCIACION t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_ASOCIACION");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActAsociacion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_ACT_ASOCIACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ActAsociacion>(this.rwMapPK, "ID_ACT_ASOCIACION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ActAsociacion entity
	 *
	 * @param actasociacion
	 *            ActAsociacion Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ActAsociacion actasociacion) {

		StringBuilder where = new StringBuilder(ActAsociacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (actasociacion != null && actasociacion.getIdActAsociacion() != null) {
			where.append(" AND t1.ID_ACT_ASOCIACION = ?");
			params.add(actasociacion.getIdActAsociacion());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(actasociacion.getRelExpActSub().getIdRelExpActSub());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getActSubvencionable() != null
				&& actasociacion.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(actasociacion.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(actasociacion.getRelExpActSub().getIdExpediente());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(actasociacion.getRelExpActSub().getFechaRegistro());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(actasociacion.getRelExpActSub().getUsuarioRegistro());
		}
		if (actasociacion != null && actasociacion.getTitulo() != null) {
			where.append(" AND t1.TITULO = ?");
			params.add(actasociacion.getTitulo());
		}
		if (actasociacion != null && actasociacion.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(actasociacion.getFechaInicio());
		}
		if (actasociacion != null && actasociacion.getFechaFin() != null) {
			where.append(" AND t1.FECHA_FIN = ?");
			params.add(actasociacion.getFechaFin());
		}
		if (actasociacion != null && actasociacion.getDescripcion() != null) {
			where.append(" AND t1.DECRIPCION = ?");
			params.add(actasociacion.getDescripcion());
		}
		if (actasociacion != null && actasociacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(actasociacion.getFechaRegistro());
		}
		if (actasociacion != null && actasociacion.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(actasociacion.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ActAsociacion entity
	 *
	 * @param actasociacion
	 *            ActAsociacion Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ActAsociacion actasociacion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ActAsociacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (actasociacion != null && actasociacion.getIdActAsociacion() != null) {
			where.append(" AND t1.ID_ACT_ASOCIACION = ?");
			params.add(actasociacion.getIdActAsociacion());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(actasociacion.getRelExpActSub().getIdRelExpActSub());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getActSubvencionable() != null
				&& actasociacion.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(actasociacion.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(actasociacion.getRelExpActSub().getIdExpediente());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(actasociacion.getRelExpActSub().getFechaRegistro());
		}
		if (actasociacion != null && actasociacion.getRelExpActSub() != null
				&& actasociacion.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actasociacion.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + actasociacion.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (actasociacion != null && actasociacion.getTitulo() != null) {
			where.append(" AND UPPER(t1.TITULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actasociacion.getTitulo().toUpperCase() + "%");
			} else {
				params.add("%" + actasociacion.getTitulo().toUpperCase() + "%");
			}
			where.append(" AND t1.TITULO IS NOT NULL");
		}
		if (actasociacion != null && actasociacion.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(actasociacion.getFechaInicio());
		}
		if (actasociacion != null && actasociacion.getFechaFin() != null) {
			where.append(" AND t1.FECHA_FIN = ?");
			params.add(actasociacion.getFechaFin());
		}
		if (actasociacion != null && actasociacion.getDescripcion() != null) {
			where.append(" AND UPPER(t1.DECRIPCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actasociacion.getDescripcion().toUpperCase() + "%");
			} else {
				params.add("%" + actasociacion.getDescripcion().toUpperCase() + "%");
			}
			where.append(" AND t1.DECRIPCION IS NOT NULL");
		}
		if (actasociacion != null && actasociacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(actasociacion.getFechaRegistro());
		}
		if (actasociacion != null && actasociacion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actasociacion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + actasociacion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
