package com.ejie.ab60.dao.DEC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DEC.ActAyuntamiento;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ActAyuntamientoDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ActAyuntamientoDaoImpl implements ActAyuntamientoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDACTAYUNTAMIENTO", "TITULO",
			"PRESUPUESTOMATERIAL", "IMPORTEIVA", "IMPORTETOTAL", "FECHAADJUDICACION", "FECHAINICIO", "FECHAFIN",
			"IMPORTEADMITIDO", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION",
			"RELEXPACTSUBIDRELEXPACTSUB", "RELEXPACTSUBIDEXPEDIENTE", "RELEXPACTSUBFECHAREGISTRO",
			"RELEXPACTSUBUSUARIOREGISTRO", "SUBTIPOSACTSUVIDSUBTIPOACTSUB", "SUBTIPOSACTSUVDESCRIPCIONCASTELLANO",
			"SUBTIPOSACTSUVDESCRIPCIONEUSKERA", "SUBTIPOSACTSUVLIMITEACTIVIDAD", "SUBTIPOSACTSUVFECHAREGISTRO",
			"SUBTIPOSACTSUVUSUARIOREGISTRO", "RELEXPACTSUBIDACTSUB", "SUBTIPOSACTSUVIDTIPOACTSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ActAyuntamiento> rwMap = new RowMapper<ActAyuntamiento>() {
		public ActAyuntamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"), resultSet.getString("TITULO"),
					resultSet.getBigDecimal("PRESUPUESTOMATERIAL"), resultSet.getBigDecimal("IMPORTEIVA"),
					resultSet.getBigDecimal("IMPORTETOTAL"), resultSet.getDate("FECHAADJUDICACION"),
					resultSet.getDate("FECHAINICIO"), resultSet.getDate("FECHAFIN"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"), resultSet
									.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));
		}
	};

	private RowMapper<ActAyuntamiento> rwMapfindAyuntamiento = new RowMapper<ActAyuntamiento>() {
		public ActAyuntamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"), resultSet.getString("TITULO"),
					resultSet.getBigDecimal("PRESUPUESTOMATERIAL"), resultSet.getBigDecimal("IMPORTEIVA"),
					resultSet.getDate("FECHAADJUDICACION"), resultSet.getDate("FECHAINICIO"),
					resultSet.getDate("FECHAFIN"),
					new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getBigDecimal("IMPORTEPRESENTADO"),
							resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getString("NOTAS"),
							resultSet.getString("OBSERVACIONESCASTELLANO"),
							resultSet.getString("OBSERVACIONESEUSKERA")));

		}
	};

	private RowMapper<ActAyuntamiento> rwMapfindAyuntamientoEMCO = new RowMapper<ActAyuntamiento>() {
		public ActAyuntamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"), resultSet.getString("TITULO"), null, null,
					null, resultSet.getDate("FECHAINICIO"), resultSet.getDate("FECHAFIN"),
					new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getBigDecimal("IMPORTEPRESENTADO"),
							resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getString("NOTAS"),
							resultSet.getString("OBSERVACIONESCASTELLANO"),
							resultSet.getString("OBSERVACIONESEUSKERA")));

		}
	};

	private RowMapper<ActAyuntamiento> rwMapTotales = new RowMapper<ActAyuntamiento>() {
		public ActAyuntamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAyuntamiento(resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"));

		}
	};

	private RowMapper<ActAyuntamiento> rwMapPK = new RowMapper<ActAyuntamiento>() {
		public ActAyuntamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"));
		}
	};

	private RowMapper<ActAyuntamiento> rwMapRelacion = new RowMapper<ActAyuntamiento>() {
		public ActAyuntamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActAyuntamiento(new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB")));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ActAyuntamiento>> rwMapJerarquia = new RowMapper<JerarquiaDto<ActAyuntamiento>>() {
		public JerarquiaDto<ActAyuntamiento> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ActAyuntamiento actayuntamiento = new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"),
					resultSet.getString("TITULO"), resultSet.getBigDecimal("PRESUPUESTOMATERIAL"),
					resultSet.getBigDecimal("IMPORTEIVA"), resultSet.getBigDecimal("IMPORTETOTAL"),
					resultSet.getDate("FECHAADJUDICACION"), resultSet.getDate("FECHAINICIO"),
					resultSet.getDate("FECHAFIN"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));

			JerarquiaDto<ActAyuntamiento> jerarquia = new JerarquiaDto<ActAyuntamiento>();
			jerarquia.setModel(actayuntamiento);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return ActAyuntamiento
	 */
	public ActAyuntamiento add(ActAyuntamiento actayuntamiento) {
		String query = "INSERT INTO ACT_AYUNTAMIENTO (ID_ACT_AYUNTAMIENTO, ID_REL_EXP_ACT_SUB, TITULO, PRESUPUESTO_MATERIAL, IMPORTE_IVA, IMPORTE_TOTAL, FECHA_ADJUDICACION, FECHA_INICIO, FECHA_FIN, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6022T00.NEXTVAL,?,?,?,?,?,TO_DATE (?,'DD/MM/YYYY'),TO_DATE (?,'DD/MM/YYYY'),TO_DATE (?,'DD/MM/YYYY'),?,?)";

		this.jdbcTemplate.update(query, actayuntamiento.getRelExpActSub().getIdRelExpActSub(),
				actayuntamiento.getTitulo(), actayuntamiento.getPresupuestoMaterial(), actayuntamiento.getImporteIva(),
				actayuntamiento.getImporteTotal(), actayuntamiento.getFechaAdjudicacionStr(),
				actayuntamiento.getFechaInicioStr(), actayuntamiento.getFechaFinStr(),
				actayuntamiento.getFechaRegistro(), actayuntamiento.getUsuarioRegistro());
		return actayuntamiento;
	}

	/**
	 * Inserts a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return ActAyuntamiento
	 */
	public ActAyuntamiento addEMCO(ActAyuntamiento actayuntamiento) {
		String query = "INSERT INTO REL_ACT_AYUNTAMIENTO (ID_ACT_AYUNTAMIENTO, ID_REL_EXP_ACT_SUB, TITULO, DESCRIPCION, FECHA_INICIO, FECHA_FIN, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB601ET00.NEXTVAL,?,?,?,TO_DATE (?,'DD/MM/YYYY'),TO_DATE (?,'DD/MM/YYYY'),SYSDATE,?)";

		this.jdbcTemplate.update(query, actayuntamiento.getRelExpActSub().getIdRelExpActSub(),
				actayuntamiento.getTitulo(), actayuntamiento.getDescripcion(), actayuntamiento.getFechaInicioStr(),
				actayuntamiento.getFechaFinStr(), actayuntamiento.getUsuarioRegistro());
		return actayuntamiento;
	}

	/**
	 * Updates a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return ActAyuntamiento
	 */
	public RelExpActSub update(RelExpActSub relExpActSub) {
		String query = "UPDATE ACT_AYUNTAMIENTO SET TITULO=?, PRESUPUESTO_MATERIAL=?, IMPORTE_IVA=?, IMPORTE_TOTAL=?, FECHA_ADJUDICACION=TO_DATE (?,'DD/MM/YYYY'), FECHA_INICIO=TO_DATE (?,'DD/MM/YYYY'), FECHA_FIN=TO_DATE (?,'DD/MM/YYYY'), FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_EXP_ACT_SUB=?";

		this.jdbcTemplate.update(query, relExpActSub.getActAyuntamiento().getTitulo(),
				relExpActSub.getActAyuntamiento().getPresupuestoMaterial(),
				relExpActSub.getActAyuntamiento().getImporteIva(), relExpActSub.getActAyuntamiento().getImporteTotal(),
				relExpActSub.getActAyuntamiento().getFechaAdjudicacionStr(),
				relExpActSub.getActAyuntamiento().getFechaInicioStr(),
				relExpActSub.getActAyuntamiento().getFechaFinStr(), new Date(),
				relExpActSub.getActAyuntamiento().getUsuarioUltactualizacion(), relExpActSub.getIdRelExpActSub());
		return relExpActSub;
	}

	/**
	 * Finds a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return ActAyuntamiento
	 */
	@Transactional(readOnly = true)
	public ActAyuntamiento find(RelExpActSub relExpActSub) {
		String query = "SELECT T1.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO, T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, T1.TITULO TITULO, T1.PRESUPUESTO_MATERIAL PRESUPUESTOMATERIAL, T1.IMPORTE_IVA IMPORTEIVA, T1.FECHA_ADJUDICACION FECHAADJUDICACION, T1.FECHA_INICIO FECHAINICIO, T1.FECHA_FIN FECHAFIN, T2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, T2.IMPORTE_ADMITIDO IMPORTEADMITIDO, T2.NOTAS NOTAS, T2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, T2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA FROM ACT_AYUNTAMIENTO T1 INNER JOIN AB6023T00 T2 ON T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB WHERE T2.ID_REL_EXP_ACT_SUB = ?";

		List<ActAyuntamiento> actayuntamientoList = this.jdbcTemplate.query(query, this.rwMapfindAyuntamiento,
				relExpActSub.getIdRelExpActSub());
		return (ActAyuntamiento) DataAccessUtils.uniqueResult(actayuntamientoList);
	}

	@Transactional(readOnly = true)
	public ActAyuntamiento findEMCO(RelExpActSub relExpActSub) {
		String query = "SELECT T1.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO, T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, T1.TITULO TITULO, T1.FECHA_INICIO FECHAINICIO, T1.FECHA_FIN FECHAFIN, T2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, T2.IMPORTE_ADMITIDO IMPORTEADMITIDO, T2.NOTAS NOTAS, T2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, T2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA FROM REL_ACT_AYUNTAMIENTO T1 INNER JOIN AB6023T00 T2 ON T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB WHERE T2.ID_REL_EXP_ACT_SUB = ?";

		List<ActAyuntamiento> actayuntamientoList = this.jdbcTemplate.query(query, this.rwMapfindAyuntamientoEMCO,
				relExpActSub.getIdRelExpActSub());
		return (ActAyuntamiento) DataAccessUtils.uniqueResult(actayuntamientoList);
	}

	/**
	 * Finds a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return ActAyuntamiento
	 */
	@Transactional(readOnly = true)
	public ActAyuntamiento findidRelacion(ActAyuntamiento actayuntamiento) {
		String query = "SELECT ID_REL_EXP_ACT_SUB IDRELEXPACTSUB FROM ACT_AYUNTAMIENTO WHERE ID_ACT_AYUNTAMIENTO = ?";

		List<ActAyuntamiento> actayuntamientoList = this.jdbcTemplate.query(query, this.rwMapRelacion,
				actayuntamiento.getIdActAyuntamiento());
		return (ActAyuntamiento) DataAccessUtils.uniqueResult(actayuntamientoList);
	}

	/**
	 * Removes a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return
	 */
	public void remove(ActAyuntamiento actayuntamiento) {
		String query = "DELETE FROM ACT_AYUNTAMIENTO WHERE ID_ACT_AYUNTAMIENTO=?";
		this.jdbcTemplate.update(query, actayuntamiento.getIdActAyuntamiento());
	}

	/**
	 * Removes a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return
	 */
	public void removeEMCO(ActAyuntamiento actayuntamiento) {
		String query = "DELETE FROM REL_ACT_AYUNTAMIENTO WHERE ID_ACT_AYUNTAMIENTO=?";
		this.jdbcTemplate.update(query, actayuntamiento.getIdActAyuntamiento());
	}

	/**
	 * Updates a single row in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return ActAyuntamiento
	 */
	public ActAyuntamiento updateTotal(ActAyuntamiento actayuntamiento) {
		String query = "SELECT SUM(T2.IMPORTE_TOTAL) IMPORTEPRESENTADO, SUM(T2.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB T1, ACT_AYUNTAMIENTO T2 WHERE T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T1.ID_REL_EXP_ACT_SUB = ?";

		List<ActAyuntamiento> actAyuntamientoList = this.jdbcTemplate.query(query, this.rwMapTotales,
				actayuntamiento.getRelExpActSub().getIdRelExpActSub());

		return (ActAyuntamiento) DataAccessUtils.uniqueResult(actAyuntamientoList);
	}

	/**
	 * Finds a list of rows in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ActAyuntamiento>
	 */
	@Transactional(readOnly = true)
	public List<ActAyuntamiento> findAll(ActAyuntamiento actayuntamiento, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO,t1.TITULO TITULO,t1.PRESUPUESTO_MATERIAL PRESUPUESTOMATERIAL,t1.IMPORTE_IVA IMPORTEIVA,t1.IMPORTE_TOTAL IMPORTETOTAL,t1.FECHA_ADJUDICACION FECHAADJUDICACION,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_SUBTIPO_ACT_SUB SUBTIPOSACTSUVIDSUBTIPOACTSUB,t3.DESCRIPCION_CASTELLANO SUBTIPOSACTSUVDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA SUBTIPOSACTSUVDESCRIPCIONEUSKERA,t3.LIMITE_ACTIVIDAD SUBTIPOSACTSUVLIMITEACTIVIDAD,t3.FECHA_REGISTRO SUBTIPOSACTSUVFECHAREGISTRO,t3.USUARIO_REGISTRO SUBTIPOSACTSUVUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB,t3.ID_TIPO_ACT_SUB SUBTIPOSACTSUVIDTIPOACTSUB ");
		query.append("FROM ACT_AYUNTAMIENTO t1 ,REL_EXP_ACT_SUB t2 ,SUBTIPOS_ACT_SUV t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(actayuntamiento);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_SUBTIPO_ACT_SUB= t3.ID_SUBTIPO_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ActAyuntamientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ActAyuntamiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ActAyuntamiento table.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ActAyuntamiento actayuntamiento) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ACT_AYUNTAMIENTO t1 , REL_EXP_ACT_SUB t2 , SUBTIPOS_ACT_SUV t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(actayuntamiento);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_SUBTIPO_ACT_SUB= t3.ID_SUBTIPO_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ActAyuntamiento table using like.
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ActAyuntamiento actayuntamiento, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ACT_AYUNTAMIENTO t1");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actayuntamiento, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ActAyuntamiento selected for rup_table
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ActAyuntamiento>>
	 */
	@Override
	public List<TableRowDto<ActAyuntamiento>> reorderSelection(ActAyuntamiento actayuntamiento,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO,t1.TITULO TITULO,t1.PRESUPUESTO_MATERIAL PRESUPUESTOMATERIAL,t1.IMPORTE_IVA IMPORTEIVA,t1.IMPORTE_TOTAL IMPORTETOTAL,t1.FECHA_ADJUDICACION FECHAADJUDICACION,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_SUBTIPO_ACT_SUB SUBTIPOSACTSUVIDSUBTIPOACTSUB,t3.DESCRIPCION_CASTELLANO SUBTIPOSACTSUVDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA SUBTIPOSACTSUVDESCRIPCIONEUSKERA,t3.LIMITE_ACTIVIDAD SUBTIPOSACTSUVLIMITEACTIVIDAD,t3.FECHA_REGISTRO SUBTIPOSACTSUVFECHAREGISTRO,t3.USUARIO_REGISTRO SUBTIPOSACTSUVUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB,t3.ID_TIPO_ACT_SUB SUBTIPOSACTSUVIDTIPOACTSUB ");
		// FROM
		query.append("FROM ACT_AYUNTAMIENTO t1 ,REL_EXP_ACT_SUB t2 ,SUBTIPOS_ACT_SUV t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actayuntamiento, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_SUBTIPO_ACT_SUB= t3.ID_SUBTIPO_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ActAyuntamiento.class, filterParamList, "ID_ACT_AYUNTAMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ActAyuntamiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ActAyuntamiento
	 * @param searchParams
	 *            ActAyuntamiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ActAyuntamiento>>
	 */
	@Override
	public List<TableRowDto<ActAyuntamiento>> search(ActAyuntamiento filterParams, ActAyuntamiento searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO,t1.TITULO TITULO,t1.PRESUPUESTO_MATERIAL PRESUPUESTOMATERIAL,t1.IMPORTE_IVA IMPORTEIVA,t1.IMPORTE_TOTAL IMPORTETOTAL,t1.FECHA_ADJUDICACION FECHAADJUDICACION,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_SUBTIPO_ACT_SUB SUBTIPOSACTSUVIDSUBTIPOACTSUB,t3.DESCRIPCION_CASTELLANO SUBTIPOSACTSUVDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA SUBTIPOSACTSUVDESCRIPCIONEUSKERA,t3.LIMITE_ACTIVIDAD SUBTIPOSACTSUVLIMITEACTIVIDAD,t3.FECHA_REGISTRO SUBTIPOSACTSUVFECHAREGISTRO,t3.USUARIO_REGISTRO SUBTIPOSACTSUVUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB,t3.ID_TIPO_ACT_SUB SUBTIPOSACTSUVIDTIPOACTSUB ");
		// FROM
		query.append("FROM ACT_AYUNTAMIENTO t1 ,REL_EXP_ACT_SUB t2 ,SUBTIPOS_ACT_SUV t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_SUBTIPO_ACT_SUB= t3.ID_SUBTIPO_ACT_SUB(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ActAyuntamiento.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_ACT_AYUNTAMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ActAyuntamiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filteractayuntamiento
	 *            ActAyuntamiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ActAyuntamiento filteractayuntamiento, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO,t1.TITULO TITULO,t1.PRESUPUESTO_MATERIAL PRESUPUESTOMATERIAL,t1.IMPORTE_IVA IMPORTEIVA,t1.IMPORTE_TOTAL IMPORTETOTAL,t1.FECHA_ADJUDICACION FECHAADJUDICACION,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_SUBTIPO_ACT_SUB SUBTIPOSACTSUVIDSUBTIPOACTSUB,t3.DESCRIPCION_CASTELLANO SUBTIPOSACTSUVDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA SUBTIPOSACTSUVDESCRIPCIONEUSKERA,t3.LIMITE_ACTIVIDAD SUBTIPOSACTSUVLIMITEACTIVIDAD,t3.FECHA_REGISTRO SUBTIPOSACTSUVFECHAREGISTRO,t3.USUARIO_REGISTRO SUBTIPOSACTSUVUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB,t3.ID_TIPO_ACT_SUB SUBTIPOSACTSUVIDTIPOACTSUB ");
		// FROM
		query.append("FROM ACT_AYUNTAMIENTO t1 ,REL_EXP_ACT_SUB t2 ,SUBTIPOS_ACT_SUV t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filteractayuntamiento, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				ActAyuntamiento.class, query, params, "ID_ACT_AYUNTAMIENTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ActAyuntamiento table.
	 *
	 * @param filterActAyuntamiento
	 *            ActAyuntamiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ActAyuntamiento>>
	 */
	@Override
	public List<JerarquiaDto<ActAyuntamiento>> findAllLikeJerarquia(ActAyuntamiento filterActAyuntamiento,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO,t1.TITULO TITULO,t1.PRESUPUESTO_MATERIAL PRESUPUESTOMATERIAL,t1.IMPORTE_IVA IMPORTEIVA,t1.IMPORTE_TOTAL IMPORTETOTAL,t1.FECHA_ADJUDICACION FECHAADJUDICACION,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_SUBTIPO_ACT_SUB SUBTIPOSACTSUVIDSUBTIPOACTSUB,t3.DESCRIPCION_CASTELLANO SUBTIPOSACTSUVDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA SUBTIPOSACTSUVDESCRIPCIONEUSKERA,t3.LIMITE_ACTIVIDAD SUBTIPOSACTSUVLIMITEACTIVIDAD,t3.FECHA_REGISTRO SUBTIPOSACTSUVFECHAREGISTRO,t3.USUARIO_REGISTRO SUBTIPOSACTSUVUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB,t3.ID_TIPO_ACT_SUB SUBTIPOSACTSUVIDTIPOACTSUB ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_AYUNTAMIENTO t1
		// ,REL_EXP_ACT_SUB t2 ,SUBTIPOS_ACT_SUV t3 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_AYUNTAMIENTO");
		from.add("REL_EXP_ACT_SUB");
		from.add("SUBTIPOS_ACT_SUV");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActAyuntamiento, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ACT_AYUNTAMIENTO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ActAyuntamientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterActAyuntamiento
	 *            ActAyuntamiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ActAyuntamiento filterActAyuntamiento, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_AYUNTAMIENTO t1
		// ,REL_EXP_ACT_SUB t2 ,SUBTIPOS_ACT_SUV t3 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_AYUNTAMIENTO");
		from.add("REL_EXP_ACT_SUB");
		from.add("SUBTIPOS_ACT_SUV");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActAyuntamiento, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ACT_AYUNTAMIENTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterActAyuntamiento
	 *            ActAyuntamiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ActAyuntamiento>>
	 */
	@Override
	public List<TableRowDto<ActAyuntamiento>> findAllChild(ActAyuntamiento filterActAyuntamiento,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_AYUNTAMIENTO t1
		// ,REL_EXP_ACT_SUB t2 ,SUBTIPOS_ACT_SUV t3 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_AYUNTAMIENTO");
		from.add("REL_EXP_ACT_SUB");
		from.add("SUBTIPOS_ACT_SUV");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActAyuntamiento, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_ACT_AYUNTAMIENTO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ActAyuntamiento>(this.rwMapPK, "ID_ACT_AYUNTAMIENTO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ActAyuntamiento entity
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ActAyuntamiento actayuntamiento) {

		StringBuilder where = new StringBuilder(ActAyuntamientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (actayuntamiento != null && actayuntamiento.getIdActAyuntamiento() != null) {
			where.append(" AND t1.ID_ACT_AYUNTAMIENTO = ?");
			params.add(actayuntamiento.getIdActAyuntamiento());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(actayuntamiento.getRelExpActSub().getIdRelExpActSub());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getActSubvencionable() != null
				&& actayuntamiento.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(actayuntamiento.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(actayuntamiento.getRelExpActSub().getIdExpediente());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(actayuntamiento.getRelExpActSub().getFechaRegistro());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(actayuntamiento.getRelExpActSub().getUsuarioRegistro());
		}
		if (actayuntamiento != null && actayuntamiento.getTitulo() != null) {
			where.append(" AND t1.TITULO = ?");
			params.add(actayuntamiento.getTitulo());
		}
		if (actayuntamiento != null && actayuntamiento.getPresupuestoMaterial() != null) {
			where.append(" AND t1.PRESUPUESTO_MATERIAL = ?");
			params.add(actayuntamiento.getPresupuestoMaterial());
		}
		if (actayuntamiento != null && actayuntamiento.getImporteIva() != null) {
			where.append(" AND t1.IMPORTE_IVA = ?");
			params.add(actayuntamiento.getImporteIva());
		}
		if (actayuntamiento != null && actayuntamiento.getImporteTotal() != null) {
			where.append(" AND t1.IMPORTE_TOTAL = ?");
			params.add(actayuntamiento.getImporteTotal());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaAdjudicacion() != null) {
			where.append(" AND t1.FECHA_ADJUDICACION = ?");
			params.add(actayuntamiento.getFechaAdjudicacion());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(actayuntamiento.getFechaInicio());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaFin() != null) {
			where.append(" AND t1.FECHA_FIN = ?");
			params.add(actayuntamiento.getFechaFin());
		}
		if (actayuntamiento != null && actayuntamiento.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(actayuntamiento.getImporteAdmitido());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(actayuntamiento.getFechaRegistro());
		}
		if (actayuntamiento != null && actayuntamiento.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(actayuntamiento.getUsuarioRegistro());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaUltactualizacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(actayuntamiento.getFechaUltactualizacion());
		}
		if (actayuntamiento != null && actayuntamiento.getUsuarioUltactualizacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(actayuntamiento.getUsuarioUltactualizacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ActAyuntamiento entity
	 *
	 * @param actayuntamiento
	 *            ActAyuntamiento Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ActAyuntamiento actayuntamiento, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ActAyuntamientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (actayuntamiento != null && actayuntamiento.getIdActAyuntamiento() != null) {
			where.append(" AND t1.ID_ACT_AYUNTAMIENTO = ?");
			params.add(actayuntamiento.getIdActAyuntamiento());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(actayuntamiento.getRelExpActSub().getIdRelExpActSub());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getActSubvencionable() != null
				&& actayuntamiento.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(actayuntamiento.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(actayuntamiento.getRelExpActSub().getIdExpediente());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(actayuntamiento.getRelExpActSub().getFechaRegistro());
		}
		if (actayuntamiento != null && actayuntamiento.getRelExpActSub() != null
				&& actayuntamiento.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actayuntamiento.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + actayuntamiento.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (actayuntamiento != null && actayuntamiento.getTitulo() != null) {
			where.append(" AND UPPER(t1.TITULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actayuntamiento.getTitulo().toUpperCase() + "%");
			} else {
				params.add("%" + actayuntamiento.getTitulo().toUpperCase() + "%");
			}
			where.append(" AND t1.TITULO IS NOT NULL");
		}
		if (actayuntamiento != null && actayuntamiento.getPresupuestoMaterial() != null) {
			where.append(" AND t1.PRESUPUESTO_MATERIAL = ?");
			params.add(actayuntamiento.getPresupuestoMaterial());
		}
		if (actayuntamiento != null && actayuntamiento.getImporteIva() != null) {
			where.append(" AND t1.IMPORTE_IVA = ?");
			params.add(actayuntamiento.getImporteIva());
		}
		if (actayuntamiento != null && actayuntamiento.getImporteTotal() != null) {
			where.append(" AND t1.IMPORTE_TOTAL = ?");
			params.add(actayuntamiento.getImporteTotal());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaAdjudicacion() != null) {
			where.append(" AND t1.FECHA_ADJUDICACION = ?");
			params.add(actayuntamiento.getFechaAdjudicacion());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(actayuntamiento.getFechaInicio());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaFin() != null) {
			where.append(" AND t1.FECHA_FIN = ?");
			params.add(actayuntamiento.getFechaFin());
		}
		if (actayuntamiento != null && actayuntamiento.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(actayuntamiento.getImporteAdmitido());
		}
		if (actayuntamiento != null && actayuntamiento.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(actayuntamiento.getFechaRegistro());
		}
		if (actayuntamiento != null && actayuntamiento.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actayuntamiento.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + actayuntamiento.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (actayuntamiento != null && actayuntamiento.getFechaUltactualizacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(actayuntamiento.getFechaUltactualizacion());
		}
		if (actayuntamiento != null && actayuntamiento.getUsuarioUltactualizacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actayuntamiento.getUsuarioUltactualizacion().toUpperCase() + "%");
			} else {
				params.add("%" + actayuntamiento.getUsuarioUltactualizacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public RelExpActSub updateEMCO(RelExpActSub relExpActSub) {
		String query = "UPDATE REL_ACT_AYUNTAMIENTO SET TITULO=?, DESCRIPCION=?, FECHA_INICIO=TO_DATE (?,'DD/MM/YYYY'), FECHA_FIN=TO_DATE (?,'DD/MM/YYYY'), FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_EXP_ACT_SUB=?";

		this.jdbcTemplate.update(query, relExpActSub.getActAyuntamiento().getTitulo(),
				relExpActSub.getActAyuntamiento().getDescripcion(),
				relExpActSub.getActAyuntamiento().getFechaInicioStr(),
				relExpActSub.getActAyuntamiento().getFechaFinStr(), new Date(),
				relExpActSub.getActAyuntamiento().getUsuarioUltactualizacion(), relExpActSub.getIdRelExpActSub());

		return relExpActSub;
	}
}
