package com.ejie.ab60.dao.DEC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DEC.AsociacionesComerciantes;
import com.ejie.ab60.model.DEC.RelMunAsoCom;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AsociacionesComerciantesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class AsociacionesComerciantesDaoImpl implements AsociacionesComerciantesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDASOCIACIONCOMERCIANTE", "CIF", "NOMBRE",
			"REPRESENTANTE", "FECHAREGISTRO", "USUARIOREGISTRO", "RELMUNASOCOMIDMUNICIPIOASOCOM",
			"RELMUNASOCOMIDMUNICIPIO", "RELMUNASOCOMNUMEROASOCIACIONES", "RELMUNASOCOMORGANOSEGUIMIENTO",
			"RELMUNASOCOMFECHAREGISTRO", "RELMUNASOCOMUSUARIOREGISTRO", "RELMUNASOCOMIDTIPOSOLICITANTE" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<AsociacionesComerciantes> rwMap = new RowMapper<AsociacionesComerciantes>() {
		public AsociacionesComerciantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AsociacionesComerciantes(resultSet.getInt("IDASOCIACIONCOMERCIANTE"), resultSet.getString("CIF"),
					resultSet.getString("NOMBRE"), resultSet.getString("REPRESENTANTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new RelMunAsoCom(resultSet.getInt("RelMunAsoComIDMUNICIPIOASOCOM"),
							resultSet.getLong("RelMunAsoComIDMUNICIPIO"),
							resultSet.getLong("RelMunAsoComNUMEROASOCIACIONES"),
							resultSet.getInt("RelMunAsoComORGANOSEGUIMIENTO"),
							resultSet.getDate("RelMunAsoComFECHAREGISTRO"),
							resultSet.getString("RelMunAsoComUSUARIOREGISTRO")));
		}
	};

	private RowMapper<AsociacionesComerciantes> rwMapPK = new RowMapper<AsociacionesComerciantes>() {
		public AsociacionesComerciantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AsociacionesComerciantes(resultSet.getInt("IDASOCIACIONCOMERCIANTE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<AsociacionesComerciantes>> rwMapJerarquia = new RowMapper<JerarquiaDto<AsociacionesComerciantes>>() {
		public JerarquiaDto<AsociacionesComerciantes> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			AsociacionesComerciantes asociacionescomerciantes = new AsociacionesComerciantes(
					resultSet.getInt("IDASOCIACIONCOMERCIANTE"), resultSet.getString("CIF"),
					resultSet.getString("NOMBRE"), resultSet.getString("REPRESENTANTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new RelMunAsoCom(resultSet.getInt("RelMunAsoComIDMUNICIPIOASOCOM"),
							resultSet.getLong("RelMunAsoComIDMUNICIPIO"),
							resultSet.getLong("RelMunAsoComNUMEROASOCIACIONES"),
							resultSet.getInt("RelMunAsoComORGANOSEGUIMIENTO"),
							resultSet.getDate("RelMunAsoComFECHAREGISTRO"),
							resultSet.getString("RelMunAsoComUSUARIOREGISTRO")));

			JerarquiaDto<AsociacionesComerciantes> jerarquia = new JerarquiaDto<AsociacionesComerciantes>();
			jerarquia.setModel(asociacionescomerciantes);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @return AsociacionesComerciantes
	 */
	public AsociacionesComerciantes add(AsociacionesComerciantes asociacionescomerciantes) {
		String query = "INSERT INTO ASOCIACIONES_COMERCIANTES (ID_ASOCIACION_COMERCIANTE, ID_MUNICIPIO_ASO_COM, CIF, NOMBRE, REPRESENTANTE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		Object getRelMunAsoComIdMunicipioAsoComAux = null;
		if (asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom() != null) {
			getRelMunAsoComIdMunicipioAsoComAux = asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom();
		}
		this.jdbcTemplate.update(query, asociacionescomerciantes.getIdAsociacionComerciante(),
				getRelMunAsoComIdMunicipioAsoComAux, asociacionescomerciantes.getCif(),
				asociacionescomerciantes.getNombre(), asociacionescomerciantes.getRepresentante(),
				asociacionescomerciantes.getFechaRegistro(), asociacionescomerciantes.getUsuarioRegistro());
		return asociacionescomerciantes;
	}

	/**
	 * Updates a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @return AsociacionesComerciantes
	 */
	public AsociacionesComerciantes update(AsociacionesComerciantes asociacionescomerciantes) {
		String query = "UPDATE ASOCIACIONES_COMERCIANTES SET ID_MUNICIPIO_ASO_COM=?, CIF=?, NOMBRE=?, REPRESENTANTE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_ASOCIACION_COMERCIANTE=?";
		Object getRelMunAsoComIdMunicipioAsoComAux = null;
		if (asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom() != null) {
			getRelMunAsoComIdMunicipioAsoComAux = asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom();
		}
		this.jdbcTemplate.update(query, getRelMunAsoComIdMunicipioAsoComAux, asociacionescomerciantes.getCif(),
				asociacionescomerciantes.getNombre(), asociacionescomerciantes.getRepresentante(),
				asociacionescomerciantes.getFechaRegistro(), asociacionescomerciantes.getUsuarioRegistro(),
				asociacionescomerciantes.getIdAsociacionComerciante());
		return asociacionescomerciantes;
	}

	/**
	 * Finds a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @return AsociacionesComerciantes
	 */
	@Transactional(readOnly = true)
	public AsociacionesComerciantes find(AsociacionesComerciantes asociacionescomerciantes) {
		String query = "SELECT t1.ID_ASOCIACION_COMERCIANTE IDASOCIACIONCOMERCIANTE, t1.CIF CIF, t1.NOMBRE NOMBRE, t1.REPRESENTANTE REPRESENTANTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_MUNICIPIO_ASO_COM RELMUNASOCOMIDMUNICIPIOASOCOM, t2.ID_MUNICIPIO RELMUNASOCOMIDMUNICIPIO, t2.NUMERO_ASOCIACIONES RELMUNASOCOMNUMEROASOCIACIONES, t2.ORGANO_SEGUIMIENTO RELMUNASOCOMORGANOSEGUIMIENTO, t2.FECHA_REGISTRO RELMUNASOCOMFECHAREGISTRO, t2.USUARIO_REGISTRO RELMUNASOCOMUSUARIOREGISTRO, t2.ID_TIPO_SOLICITANTE RELMUNASOCOMIDTIPOSOLICITANTE FROM ASOCIACIONES_COMERCIANTES t1 , REL_MUN_ASO_COM t2  WHERE t1.ID_ASOCIACION_COMERCIANTE = ?   AND t1.ID_MUNICIPIO_ASO_COM= t2.ID_MUNICIPIO_ASO_COM(+)";

		List<AsociacionesComerciantes> asociacionescomerciantesList = this.jdbcTemplate.query(query, this.rwMap,
				asociacionescomerciantes.getIdAsociacionComerciante());
		return (AsociacionesComerciantes) DataAccessUtils.uniqueResult(asociacionescomerciantesList);
	}

	/**
	 * Removes a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @return
	 */
	public void remove(AsociacionesComerciantes asociacionescomerciantes) {
		String query = "DELETE FROM ASOCIACIONES_COMERCIANTES WHERE ID_ASOCIACION_COMERCIANTE=?";
		this.jdbcTemplate.update(query, asociacionescomerciantes.getIdAsociacionComerciante());
	}

	/**
	 * Finds a list of rows in the AsociacionesComerciantes table.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<AsociacionesComerciantes>
	 */
	@Transactional(readOnly = true)
	public List<AsociacionesComerciantes> findAll(AsociacionesComerciantes asociacionescomerciantes,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ASOCIACION_COMERCIANTE IDASOCIACIONCOMERCIANTE,t1.CIF CIF,t1.NOMBRE NOMBRE,t1.REPRESENTANTE REPRESENTANTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_MUNICIPIO_ASO_COM RELMUNASOCOMIDMUNICIPIOASOCOM,t2.ID_MUNICIPIO RELMUNASOCOMIDMUNICIPIO,t2.NUMERO_ASOCIACIONES RELMUNASOCOMNUMEROASOCIACIONES,t2.ORGANO_SEGUIMIENTO RELMUNASOCOMORGANOSEGUIMIENTO,t2.FECHA_REGISTRO RELMUNASOCOMFECHAREGISTRO,t2.USUARIO_REGISTRO RELMUNASOCOMUSUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE RELMUNASOCOMIDTIPOSOLICITANTE ");
		query.append("FROM ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(asociacionescomerciantes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_MUNICIPIO_ASO_COM= t2.ID_MUNICIPIO_ASO_COM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AsociacionesComerciantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AsociacionesComerciantes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the AsociacionesComerciantes table using like.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<AsociacionesComerciantes>
	 */
	@Transactional(readOnly = true)
	public List<AsociacionesComerciantes> findAllLike(AsociacionesComerciantes asociacionescomerciantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ASOCIACION_COMERCIANTE IDASOCIACIONCOMERCIANTE,t1.CIF CIF,t1.NOMBRE NOMBRE,t1.REPRESENTANTE REPRESENTANTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_MUNICIPIO_ASO_COM RELMUNASOCOMIDMUNICIPIOASOCOM,t2.ID_MUNICIPIO RELMUNASOCOMIDMUNICIPIO,t2.NUMERO_ASOCIACIONES RELMUNASOCOMNUMEROASOCIACIONES,t2.ORGANO_SEGUIMIENTO RELMUNASOCOMORGANOSEGUIMIENTO,t2.FECHA_REGISTRO RELMUNASOCOMFECHAREGISTRO,t2.USUARIO_REGISTRO RELMUNASOCOMUSUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE RELMUNASOCOMIDTIPOSOLICITANTE ");
		query.append("FROM ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(asociacionescomerciantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_MUNICIPIO_ASO_COM= t2.ID_MUNICIPIO_ASO_COM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AsociacionesComerciantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AsociacionesComerciantes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the AsociacionesComerciantes table.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(AsociacionesComerciantes asociacionescomerciantes) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ASOCIACIONES_COMERCIANTES t1 , REL_MUN_ASO_COM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(asociacionescomerciantes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_MUNICIPIO_ASO_COM= t2.ID_MUNICIPIO_ASO_COM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the AsociacionesComerciantes table using like.
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(AsociacionesComerciantes asociacionescomerciantes, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(asociacionescomerciantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_MUNICIPIO_ASO_COM= t2.ID_MUNICIPIO_ASO_COM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of AsociacionesComerciantes selected for rup_table
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AsociacionesComerciantes>>
	 */
	@Override
	public List<TableRowDto<AsociacionesComerciantes>> reorderSelection(
			AsociacionesComerciantes asociacionescomerciantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION_COMERCIANTE IDASOCIACIONCOMERCIANTE,t1.CIF CIF,t1.NOMBRE NOMBRE,t1.REPRESENTANTE REPRESENTANTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_MUNICIPIO_ASO_COM RELMUNASOCOMIDMUNICIPIOASOCOM,t2.ID_MUNICIPIO RELMUNASOCOMIDMUNICIPIO,t2.NUMERO_ASOCIACIONES RELMUNASOCOMNUMEROASOCIACIONES,t2.ORGANO_SEGUIMIENTO RELMUNASOCOMORGANOSEGUIMIENTO,t2.FECHA_REGISTRO RELMUNASOCOMFECHAREGISTRO,t2.USUARIO_REGISTRO RELMUNASOCOMUSUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE RELMUNASOCOMIDTIPOSOLICITANTE ");
		// FROM
		query.append("FROM ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(asociacionescomerciantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_MUNICIPIO_ASO_COM= t2.ID_MUNICIPIO_ASO_COM(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				AsociacionesComerciantes.class, filterParamList, "ID_ASOCIACION_COMERCIANTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AsociacionesComerciantes>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            AsociacionesComerciantes
	 * @param searchParams
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AsociacionesComerciantes>>
	 */
	@Override
	public List<TableRowDto<AsociacionesComerciantes>> search(AsociacionesComerciantes filterParams,
			AsociacionesComerciantes searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION_COMERCIANTE IDASOCIACIONCOMERCIANTE,t1.CIF CIF,t1.NOMBRE NOMBRE,t1.REPRESENTANTE REPRESENTANTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_MUNICIPIO_ASO_COM RELMUNASOCOMIDMUNICIPIOASOCOM,t2.ID_MUNICIPIO RELMUNASOCOMIDMUNICIPIO,t2.NUMERO_ASOCIACIONES RELMUNASOCOMNUMEROASOCIACIONES,t2.ORGANO_SEGUIMIENTO RELMUNASOCOMORGANOSEGUIMIENTO,t2.FECHA_REGISTRO RELMUNASOCOMFECHAREGISTRO,t2.USUARIO_REGISTRO RELMUNASOCOMUSUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE RELMUNASOCOMIDTIPOSOLICITANTE ");
		// FROM
		query.append("FROM ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_MUNICIPIO_ASO_COM= t2.ID_MUNICIPIO_ASO_COM(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				AsociacionesComerciantes.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_ASOCIACION_COMERCIANTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AsociacionesComerciantes>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterasociacionescomerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(AsociacionesComerciantes filterasociacionescomerciantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION_COMERCIANTE IDASOCIACIONCOMERCIANTE,t1.CIF CIF,t1.NOMBRE NOMBRE,t1.REPRESENTANTE REPRESENTANTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_MUNICIPIO_ASO_COM RELMUNASOCOMIDMUNICIPIOASOCOM,t2.ID_MUNICIPIO RELMUNASOCOMIDMUNICIPIO,t2.NUMERO_ASOCIACIONES RELMUNASOCOMNUMEROASOCIACIONES,t2.ORGANO_SEGUIMIENTO RELMUNASOCOMORGANOSEGUIMIENTO,t2.FECHA_REGISTRO RELMUNASOCOMFECHAREGISTRO,t2.USUARIO_REGISTRO RELMUNASOCOMUSUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE RELMUNASOCOMIDTIPOSOLICITANTE ");
		// FROM
		query.append("FROM ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterasociacionescomerciantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				AsociacionesComerciantes.class, query, params, "ID_ASOCIACION_COMERCIANTE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical AsociacionesComerciantes table.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<AsociacionesComerciantes>>
	 */
	@Override
	public List<JerarquiaDto<AsociacionesComerciantes>> findAllLikeJerarquia(
			AsociacionesComerciantes filterAsociacionesComerciantes, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASOCIACION_COMERCIANTE IDASOCIACIONCOMERCIANTE,t1.CIF CIF,t1.NOMBRE NOMBRE,t1.REPRESENTANTE REPRESENTANTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_MUNICIPIO_ASO_COM RELMUNASOCOMIDMUNICIPIOASOCOM,t2.ID_MUNICIPIO RELMUNASOCOMIDMUNICIPIO,t2.NUMERO_ASOCIACIONES RELMUNASOCOMNUMEROASOCIACIONES,t2.ORGANO_SEGUIMIENTO RELMUNASOCOMORGANOSEGUIMIENTO,t2.FECHA_REGISTRO RELMUNASOCOMFECHAREGISTRO,t2.USUARIO_REGISTRO RELMUNASOCOMUSUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE RELMUNASOCOMIDTIPOSOLICITANTE ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM
		// ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ASOCIACIONES_COMERCIANTES");
		from.add("REL_MUN_ASO_COM");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAsociacionesComerciantes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ASOCIACION_COMERCIANTE",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					AsociacionesComerciantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(AsociacionesComerciantes filterAsociacionesComerciantes,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM
		// ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ASOCIACIONES_COMERCIANTES");
		from.add("REL_MUN_ASO_COM");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAsociacionesComerciantes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_ASOCIACION_COMERCIANTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<AsociacionesComerciantes>>
	 */
	@Override
	public List<TableRowDto<AsociacionesComerciantes>> findAllChild(
			AsociacionesComerciantes filterAsociacionesComerciantes, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM
		// ASOCIACIONES_COMERCIANTES t1 ,REL_MUN_ASO_COM t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ASOCIACIONES_COMERCIANTES");
		from.add("REL_MUN_ASO_COM");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAsociacionesComerciantes, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_ASOCIACION_COMERCIANTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<AsociacionesComerciantes>(this.rwMapPK, "ID_ASOCIACION_COMERCIANTE"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AsociacionesComerciantes entity
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes Bean with the criteria values to
	 *            filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(AsociacionesComerciantes asociacionescomerciantes) {

		StringBuilder where = new StringBuilder(AsociacionesComerciantesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (asociacionescomerciantes != null && asociacionescomerciantes.getIdAsociacionComerciante() != null) {
			where.append(" AND t1.ID_ASOCIACION_COMERCIANTE = ?");
			params.add(asociacionescomerciantes.getIdAsociacionComerciante());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom() != null) {
			where.append(" AND t2.ID_MUNICIPIO_ASO_COM = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getIdMunicipio() != null) {
			where.append(" AND t2.ID_MUNICIPIO = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getIdMunicipio());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getNumeroAsociaciones() != null) {
			where.append(" AND t2.NUMERO_ASOCIACIONES = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getNumeroAsociaciones());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getOrganoSeguimiento() != null) {
			where.append(" AND t2.ORGANO_SEGUIMIENTO = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getOrganoSeguimiento());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getFechaRegistro());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getUsuarioRegistro());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getCif() != null) {
			where.append(" AND t1.CIF = ?");
			params.add(asociacionescomerciantes.getCif());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getNombre() != null) {
			where.append(" AND t1.NOMBRE = ?");
			params.add(asociacionescomerciantes.getNombre());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRepresentante() != null) {
			where.append(" AND t1.REPRESENTANTE = ?");
			params.add(asociacionescomerciantes.getRepresentante());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(asociacionescomerciantes.getFechaRegistro());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(asociacionescomerciantes.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AsociacionesComerciantes entity
	 *
	 * @param asociacionescomerciantes
	 *            AsociacionesComerciantes Bean with the criteria values to
	 *            filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(AsociacionesComerciantes asociacionescomerciantes, Boolean startsWith) {

		StringBuilder where = new StringBuilder(AsociacionesComerciantesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (asociacionescomerciantes != null && asociacionescomerciantes.getIdAsociacionComerciante() != null) {
			where.append(" AND t1.ID_ASOCIACION_COMERCIANTE = ?");
			params.add(asociacionescomerciantes.getIdAsociacionComerciante());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom() != null) {
			where.append(" AND t2.ID_MUNICIPIO_ASO_COM = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getIdMunicipioAsoCom());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getIdMunicipio() != null) {
			where.append(" AND t2.ID_MUNICIPIO = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getIdMunicipio());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getNumeroAsociaciones() != null) {
			where.append(" AND t2.NUMERO_ASOCIACIONES = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getNumeroAsociaciones());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getOrganoSeguimiento() != null) {
			where.append(" AND t2.ORGANO_SEGUIMIENTO = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getOrganoSeguimiento());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(asociacionescomerciantes.getRelMunAsoCom().getFechaRegistro());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRelMunAsoCom() != null
				&& asociacionescomerciantes.getRelMunAsoCom().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionescomerciantes.getRelMunAsoCom().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionescomerciantes.getRelMunAsoCom().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getCif() != null) {
			where.append(" AND UPPER(t1.CIF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionescomerciantes.getCif().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionescomerciantes.getCif().toUpperCase() + "%");
			}
			where.append(" AND t1.CIF IS NOT NULL");
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getNombre() != null) {
			where.append(" AND UPPER(t1.NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionescomerciantes.getNombre().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionescomerciantes.getNombre().toUpperCase() + "%");
			}
			where.append(" AND t1.NOMBRE IS NOT NULL");
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getRepresentante() != null) {
			where.append(" AND UPPER(t1.REPRESENTANTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionescomerciantes.getRepresentante().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionescomerciantes.getRepresentante().toUpperCase() + "%");
			}
			where.append(" AND t1.REPRESENTANTE IS NOT NULL");
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(asociacionescomerciantes.getFechaRegistro());
		}
		if (asociacionescomerciantes != null && asociacionescomerciantes.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(asociacionescomerciantes.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + asociacionescomerciantes.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
