package com.ejie.ab60.dao.DEC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DEC.LimiteAsociaciones;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * LimiteAsociacionesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class LimiteAsociacionesDaoImpl implements LimiteAsociacionesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMUNICIPIOASO", "MUNICIPIO", "NUMEROCOMERCIOS",
			"POBLACION", "DENSIDAD", "COEFICIENTE", "SUBVTRAMOPOBLACION", "SUBVMAXPOBLACION", "FECHAREGISTRO",
			"USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<LimiteAsociaciones> rwMap = new RowMapper<LimiteAsociaciones>() {
		public LimiteAsociaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new LimiteAsociaciones(resultSet.getLong("IDMUNICIPIOASO"), resultSet.getString("MUNICIPIO"),
					resultSet.getLong("NUMEROCOMERCIOS"), resultSet.getLong("POBLACION"),
					resultSet.getBigDecimal("DENSIDAD"), resultSet.getBigDecimal("COEFICIENTE"),
					resultSet.getBigDecimal("SUBVTRAMOPOBLACION"), resultSet.getBigDecimal("SUBVMAXPOBLACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<LimiteAsociaciones> rwMapPK = new RowMapper<LimiteAsociaciones>() {
		public LimiteAsociaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new LimiteAsociaciones(resultSet.getLong("IDMUNICIPIOASO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<LimiteAsociaciones>> rwMapJerarquia = new RowMapper<JerarquiaDto<LimiteAsociaciones>>() {
		public JerarquiaDto<LimiteAsociaciones> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			LimiteAsociaciones limiteasociaciones = new LimiteAsociaciones(resultSet.getLong("IDMUNICIPIOASO"),
					resultSet.getString("MUNICIPIO"), resultSet.getLong("NUMEROCOMERCIOS"),
					resultSet.getLong("POBLACION"), resultSet.getBigDecimal("DENSIDAD"),
					resultSet.getBigDecimal("COEFICIENTE"), resultSet.getBigDecimal("SUBVTRAMOPOBLACION"),
					resultSet.getBigDecimal("SUBVMAXPOBLACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<LimiteAsociaciones> jerarquia = new JerarquiaDto<LimiteAsociaciones>();
			jerarquia.setModel(limiteasociaciones);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the LimiteAsociaciones table.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @return LimiteAsociaciones
	 */
	public LimiteAsociaciones add(LimiteAsociaciones limiteasociaciones) {
		String query = "INSERT INTO LIMITE_ASOCIACIONES (ID_MUNICIPIO_ASO, MUNICIPIO, NUMERO_COMERCIOS, POBLACION, DENSIDAD, COEFICIENTE, SUBV_TRAMO_POBLACION, SUBV_MAX_POBLACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, limiteasociaciones.getIdMunicipioAso(), limiteasociaciones.getMunicipio(),
				limiteasociaciones.getNumeroComercios(), limiteasociaciones.getPoblacion(),
				limiteasociaciones.getDensidad(), limiteasociaciones.getCoeficiente(),
				limiteasociaciones.getSubvTramoPoblacion(), limiteasociaciones.getSubvMaxPoblacion(),
				limiteasociaciones.getFechaRegistro(), limiteasociaciones.getUsuarioRegistro());
		return limiteasociaciones;
	}

	/**
	 * Updates a single row in the LimiteAsociaciones table.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @return LimiteAsociaciones
	 */
	public LimiteAsociaciones update(LimiteAsociaciones limiteasociaciones) {
		String query = "UPDATE LIMITE_ASOCIACIONES SET MUNICIPIO=?, NUMERO_COMERCIOS=?, POBLACION=?, DENSIDAD=?, COEFICIENTE=?, SUBV_TRAMO_POBLACION=?, SUBV_MAX_POBLACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_MUNICIPIO_ASO=?";
		this.jdbcTemplate.update(query, limiteasociaciones.getMunicipio(), limiteasociaciones.getNumeroComercios(),
				limiteasociaciones.getPoblacion(), limiteasociaciones.getDensidad(),
				limiteasociaciones.getCoeficiente(), limiteasociaciones.getSubvTramoPoblacion(),
				limiteasociaciones.getSubvMaxPoblacion(), limiteasociaciones.getFechaRegistro(),
				limiteasociaciones.getUsuarioRegistro(), limiteasociaciones.getIdMunicipioAso());
		return limiteasociaciones;
	}

	/**
	 * Finds a single row in the LimiteAsociaciones table.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @return LimiteAsociaciones
	 */
	@Transactional(readOnly = true)
	public LimiteAsociaciones find(LimiteAsociaciones limiteasociaciones) {
		String query = "SELECT t1.ID_MUNICIPIO_ASO IDMUNICIPIOASO, t1.MUNICIPIO MUNICIPIO, t1.NUMERO_COMERCIOS NUMEROCOMERCIOS, t1.POBLACION POBLACION, t1.DENSIDAD DENSIDAD, t1.COEFICIENTE COEFICIENTE, t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION, t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM LIMITE_ASOCIACIONES t1  WHERE t1.ID_MUNICIPIO_ASO = ?  ";

		List<LimiteAsociaciones> limiteasociacionesList = this.jdbcTemplate.query(query, this.rwMap,
				limiteasociaciones.getIdMunicipioAso());
		return (LimiteAsociaciones) DataAccessUtils.uniqueResult(limiteasociacionesList);
	}

	/**
	 * Removes a single row in the LimiteAsociaciones table.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @return
	 */
	public void remove(LimiteAsociaciones limiteasociaciones) {
		String query = "DELETE FROM LIMITE_ASOCIACIONES WHERE ID_MUNICIPIO_ASO=?";
		this.jdbcTemplate.update(query, limiteasociaciones.getIdMunicipioAso());
	}

	/**
	 * Finds a list of rows in the LimiteAsociaciones table.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<LimiteAsociaciones>
	 */
	@Transactional(readOnly = true)
	public List<LimiteAsociaciones> findAll(LimiteAsociaciones limiteasociaciones, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MUNICIPIO_ASO IDMUNICIPIOASO,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM LIMITE_ASOCIACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(limiteasociaciones);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					LimiteAsociacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<LimiteAsociaciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the LimiteAsociaciones table using like.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<LimiteAsociaciones>
	 */
	@Transactional(readOnly = true)
	public List<LimiteAsociaciones> findAllLike(LimiteAsociaciones limiteasociaciones,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MUNICIPIO_ASO IDMUNICIPIOASO,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM LIMITE_ASOCIACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(limiteasociaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					LimiteAsociacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<LimiteAsociaciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the LimiteAsociaciones table.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(LimiteAsociaciones limiteasociaciones) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM LIMITE_ASOCIACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(limiteasociaciones);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the LimiteAsociaciones table using like.
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(LimiteAsociaciones limiteasociaciones, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM LIMITE_ASOCIACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(limiteasociaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of LimiteAsociaciones selected for rup_table
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<LimiteAsociaciones>>
	 */
	@Override
	public List<TableRowDto<LimiteAsociaciones>> reorderSelection(LimiteAsociaciones limiteasociaciones,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO IDMUNICIPIOASO,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM LIMITE_ASOCIACIONES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(limiteasociaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				LimiteAsociaciones.class, filterParamList, "ID_MUNICIPIO_ASO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<LimiteAsociaciones>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            LimiteAsociaciones
	 * @param searchParams
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<LimiteAsociaciones>>
	 */
	@Override
	public List<TableRowDto<LimiteAsociaciones>> search(LimiteAsociaciones filterParams,
			LimiteAsociaciones searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO IDMUNICIPIOASO,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM LIMITE_ASOCIACIONES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				LimiteAsociaciones.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_MUNICIPIO_ASO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<LimiteAsociaciones>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterlimiteasociaciones
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(LimiteAsociaciones filterlimiteasociaciones, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO IDMUNICIPIOASO,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM LIMITE_ASOCIACIONES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterlimiteasociaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				LimiteAsociaciones.class, query, params, "ID_MUNICIPIO_ASO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical LimiteAsociaciones table.
	 *
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<LimiteAsociaciones>>
	 */
	@Override
	public List<JerarquiaDto<LimiteAsociaciones>> findAllLikeJerarquia(LimiteAsociaciones filterLimiteAsociaciones,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO IDMUNICIPIOASO,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM LIMITE_ASOCIACIONES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("LIMITE_ASOCIACIONES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterLimiteAsociaciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MUNICIPIO_ASO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					LimiteAsociacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(LimiteAsociaciones filterLimiteAsociaciones,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM LIMITE_ASOCIACIONES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("LIMITE_ASOCIACIONES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterLimiteAsociaciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_MUNICIPIO_ASO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<LimiteAsociaciones>>
	 */
	@Override
	public List<TableRowDto<LimiteAsociaciones>> findAllChild(LimiteAsociaciones filterLimiteAsociaciones,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM LIMITE_ASOCIACIONES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("LIMITE_ASOCIACIONES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterLimiteAsociaciones, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_MUNICIPIO_ASO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<LimiteAsociaciones>(this.rwMapPK, "ID_MUNICIPIO_ASO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the LimiteAsociaciones entity
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(LimiteAsociaciones limiteasociaciones) {

		StringBuilder where = new StringBuilder(LimiteAsociacionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (limiteasociaciones != null && limiteasociaciones.getIdMunicipioAso() != null) {
			where.append(" AND t1.ID_MUNICIPIO_ASO = ?");
			params.add(limiteasociaciones.getIdMunicipioAso());
		}
		if (limiteasociaciones != null && limiteasociaciones.getMunicipio() != null) {
			where.append(" AND t1.MUNICIPIO = ?");
			params.add(limiteasociaciones.getMunicipio());
		}
		if (limiteasociaciones != null && limiteasociaciones.getNumeroComercios() != null) {
			where.append(" AND t1.NUMERO_COMERCIOS = ?");
			params.add(limiteasociaciones.getNumeroComercios());
		}
		if (limiteasociaciones != null && limiteasociaciones.getPoblacion() != null) {
			where.append(" AND t1.POBLACION = ?");
			params.add(limiteasociaciones.getPoblacion());
		}
		if (limiteasociaciones != null && limiteasociaciones.getDensidad() != null) {
			where.append(" AND t1.DENSIDAD = ?");
			params.add(limiteasociaciones.getDensidad());
		}
		if (limiteasociaciones != null && limiteasociaciones.getCoeficiente() != null) {
			where.append(" AND t1.COEFICIENTE = ?");
			params.add(limiteasociaciones.getCoeficiente());
		}
		if (limiteasociaciones != null && limiteasociaciones.getSubvTramoPoblacion() != null) {
			where.append(" AND t1.SUBV_TRAMO_POBLACION = ?");
			params.add(limiteasociaciones.getSubvTramoPoblacion());
		}
		if (limiteasociaciones != null && limiteasociaciones.getSubvMaxPoblacion() != null) {
			where.append(" AND t1.SUBV_MAX_POBLACION = ?");
			params.add(limiteasociaciones.getSubvMaxPoblacion());
		}
		if (limiteasociaciones != null && limiteasociaciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(limiteasociaciones.getFechaRegistro());
		}
		if (limiteasociaciones != null && limiteasociaciones.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(limiteasociaciones.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the LimiteAsociaciones entity
	 *
	 * @param limiteasociaciones
	 *            LimiteAsociaciones Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(LimiteAsociaciones limiteasociaciones, Boolean startsWith) {

		StringBuilder where = new StringBuilder(LimiteAsociacionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (limiteasociaciones != null && limiteasociaciones.getIdMunicipioAso() != null) {
			where.append(" AND t1.ID_MUNICIPIO_ASO = ?");
			params.add(limiteasociaciones.getIdMunicipioAso());
		}
		if (limiteasociaciones != null && limiteasociaciones.getMunicipio() != null) {
			where.append(" AND UPPER(t1.MUNICIPIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(limiteasociaciones.getMunicipio().toUpperCase() + "%");
			} else {
				params.add("%" + limiteasociaciones.getMunicipio().toUpperCase() + "%");
			}
			where.append(" AND t1.MUNICIPIO IS NOT NULL");
		}
		if (limiteasociaciones != null && limiteasociaciones.getNumeroComercios() != null) {
			where.append(" AND t1.NUMERO_COMERCIOS = ?");
			params.add(limiteasociaciones.getNumeroComercios());
		}
		if (limiteasociaciones != null && limiteasociaciones.getPoblacion() != null) {
			where.append(" AND t1.POBLACION = ?");
			params.add(limiteasociaciones.getPoblacion());
		}
		if (limiteasociaciones != null && limiteasociaciones.getDensidad() != null) {
			where.append(" AND t1.DENSIDAD = ?");
			params.add(limiteasociaciones.getDensidad());
		}
		if (limiteasociaciones != null && limiteasociaciones.getCoeficiente() != null) {
			where.append(" AND t1.COEFICIENTE = ?");
			params.add(limiteasociaciones.getCoeficiente());
		}
		if (limiteasociaciones != null && limiteasociaciones.getSubvTramoPoblacion() != null) {
			where.append(" AND t1.SUBV_TRAMO_POBLACION = ?");
			params.add(limiteasociaciones.getSubvTramoPoblacion());
		}
		if (limiteasociaciones != null && limiteasociaciones.getSubvMaxPoblacion() != null) {
			where.append(" AND t1.SUBV_MAX_POBLACION = ?");
			params.add(limiteasociaciones.getSubvMaxPoblacion());
		}
		if (limiteasociaciones != null && limiteasociaciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(limiteasociaciones.getFechaRegistro());
		}
		if (limiteasociaciones != null && limiteasociaciones.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(limiteasociaciones.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + limiteasociaciones.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
