package com.ejie.ab60.dao.DEC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DEC.LimiteAyuntamientos;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * LimiteAyuntamientosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class LimiteAyuntamientosDaoImpl implements LimiteAyuntamientosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMUNICIPIOAYU", "MUNICIPIO", "NUMEROCOMERCIOS",
			"POBLACION", "DENSIDAD", "COEFICIENTE", "SUBVTRAMOPOBLACION", "SUBVMAXPOBLACION", "FECHAREGISTRO",
			"USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<LimiteAyuntamientos> rwMap = new RowMapper<LimiteAyuntamientos>() {
		public LimiteAyuntamientos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new LimiteAyuntamientos(resultSet.getLong("IDMUNICIPIOAYU"), resultSet.getString("MUNICIPIO"),
					resultSet.getLong("NUMEROCOMERCIOS"), resultSet.getLong("POBLACION"),
					resultSet.getBigDecimal("DENSIDAD"), resultSet.getBigDecimal("COEFICIENTE"),
					resultSet.getBigDecimal("SUBVTRAMOPOBLACION"), resultSet.getBigDecimal("SUBVMAXPOBLACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<LimiteAyuntamientos> rwMapPK = new RowMapper<LimiteAyuntamientos>() {
		public LimiteAyuntamientos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new LimiteAyuntamientos(resultSet.getLong("IDMUNICIPIOAYU"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<LimiteAyuntamientos>> rwMapJerarquia = new RowMapper<JerarquiaDto<LimiteAyuntamientos>>() {
		public JerarquiaDto<LimiteAyuntamientos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			LimiteAyuntamientos limiteayuntamientos = new LimiteAyuntamientos(resultSet.getLong("IDMUNICIPIOAYU"),
					resultSet.getString("MUNICIPIO"), resultSet.getLong("NUMEROCOMERCIOS"),
					resultSet.getLong("POBLACION"), resultSet.getBigDecimal("DENSIDAD"),
					resultSet.getBigDecimal("COEFICIENTE"), resultSet.getBigDecimal("SUBVTRAMOPOBLACION"),
					resultSet.getBigDecimal("SUBVMAXPOBLACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<LimiteAyuntamientos> jerarquia = new JerarquiaDto<LimiteAyuntamientos>();
			jerarquia.setModel(limiteayuntamientos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the LimiteAyuntamientos table.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @return LimiteAyuntamientos
	 */
	public LimiteAyuntamientos add(LimiteAyuntamientos limiteayuntamientos) {
		String query = "INSERT INTO LIMITE_AYUNTAMIENTOS (ID_MUNICIPIO_AYU, MUNICIPIO, NUMERO_COMERCIOS, POBLACION, DENSIDAD, COEFICIENTE, SUBV_TRAMO_POBLACION, SUBV_MAX_POBLACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, limiteayuntamientos.getIdMunicipioAyu(), limiteayuntamientos.getMunicipio(),
				limiteayuntamientos.getNumeroComercios(), limiteayuntamientos.getPoblacion(),
				limiteayuntamientos.getDensidad(), limiteayuntamientos.getCoeficiente(),
				limiteayuntamientos.getSubvTramoPoblacion(), limiteayuntamientos.getSubvMaxPoblacion(),
				limiteayuntamientos.getFechaRegistro(), limiteayuntamientos.getUsuarioRegistro());
		return limiteayuntamientos;
	}

	/**
	 * Updates a single row in the LimiteAyuntamientos table.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @return LimiteAyuntamientos
	 */
	public LimiteAyuntamientos update(LimiteAyuntamientos limiteayuntamientos) {
		String query = "UPDATE LIMITE_AYUNTAMIENTOS SET MUNICIPIO=?, NUMERO_COMERCIOS=?, POBLACION=?, DENSIDAD=?, COEFICIENTE=?, SUBV_TRAMO_POBLACION=?, SUBV_MAX_POBLACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_MUNICIPIO_AYU=?";
		this.jdbcTemplate.update(query, limiteayuntamientos.getMunicipio(), limiteayuntamientos.getNumeroComercios(),
				limiteayuntamientos.getPoblacion(), limiteayuntamientos.getDensidad(),
				limiteayuntamientos.getCoeficiente(), limiteayuntamientos.getSubvTramoPoblacion(),
				limiteayuntamientos.getSubvMaxPoblacion(), limiteayuntamientos.getFechaRegistro(),
				limiteayuntamientos.getUsuarioRegistro(), limiteayuntamientos.getIdMunicipioAyu());
		return limiteayuntamientos;
	}

	/**
	 * Finds a single row in the LimiteAyuntamientos table.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @return LimiteAyuntamientos
	 */
	@Transactional(readOnly = true)
	public LimiteAyuntamientos find(LimiteAyuntamientos limiteayuntamientos) {
		String query = "SELECT t1.ID_MUNICIPIO_AYU IDMUNICIPIOAYU, t1.MUNICIPIO MUNICIPIO, t1.NUMERO_COMERCIOS NUMEROCOMERCIOS, t1.POBLACION POBLACION, t1.DENSIDAD DENSIDAD, t1.COEFICIENTE COEFICIENTE, t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION, t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM LIMITE_AYUNTAMIENTOS t1  WHERE t1.ID_MUNICIPIO_AYU = ?  ";

		List<LimiteAyuntamientos> limiteayuntamientosList = this.jdbcTemplate.query(query, this.rwMap,
				limiteayuntamientos.getIdMunicipioAyu());
		return (LimiteAyuntamientos) DataAccessUtils.uniqueResult(limiteayuntamientosList);
	}

	/**
	 * Removes a single row in the LimiteAyuntamientos table.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @return
	 */
	public void remove(LimiteAyuntamientos limiteayuntamientos) {
		String query = "DELETE FROM LIMITE_AYUNTAMIENTOS WHERE ID_MUNICIPIO_AYU=?";
		this.jdbcTemplate.update(query, limiteayuntamientos.getIdMunicipioAyu());
	}

	/**
	 * Finds a list of rows in the LimiteAyuntamientos table.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<LimiteAyuntamientos>
	 */
	@Transactional(readOnly = true)
	public List<LimiteAyuntamientos> findAll(LimiteAyuntamientos limiteayuntamientos,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MUNICIPIO_AYU IDMUNICIPIOAYU,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM LIMITE_AYUNTAMIENTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(limiteayuntamientos);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					LimiteAyuntamientosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<LimiteAyuntamientos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the LimiteAyuntamientos table using like.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<LimiteAyuntamientos>
	 */
	@Transactional(readOnly = true)
	public List<LimiteAyuntamientos> findAllLike(LimiteAyuntamientos limiteayuntamientos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MUNICIPIO_AYU IDMUNICIPIOAYU,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM LIMITE_AYUNTAMIENTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(limiteayuntamientos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					LimiteAyuntamientosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<LimiteAyuntamientos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the LimiteAyuntamientos table.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(LimiteAyuntamientos limiteayuntamientos) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM LIMITE_AYUNTAMIENTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(limiteayuntamientos);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the LimiteAyuntamientos table using like.
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(LimiteAyuntamientos limiteayuntamientos, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM LIMITE_AYUNTAMIENTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(limiteayuntamientos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of LimiteAyuntamientos selected for rup_table
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<LimiteAyuntamientos>>
	 */
	@Override
	public List<TableRowDto<LimiteAyuntamientos>> reorderSelection(LimiteAyuntamientos limiteayuntamientos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_AYU IDMUNICIPIOAYU,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM LIMITE_AYUNTAMIENTOS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(limiteayuntamientos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				LimiteAyuntamientos.class, filterParamList, "ID_MUNICIPIO_AYU");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<LimiteAyuntamientos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            LimiteAyuntamientos
	 * @param searchParams
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<LimiteAyuntamientos>>
	 */
	@Override
	public List<TableRowDto<LimiteAyuntamientos>> search(LimiteAyuntamientos filterParams,
			LimiteAyuntamientos searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_AYU IDMUNICIPIOAYU,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM LIMITE_AYUNTAMIENTOS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				LimiteAyuntamientos.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_MUNICIPIO_AYU");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<LimiteAyuntamientos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterlimiteayuntamientos
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(LimiteAyuntamientos filterlimiteayuntamientos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_AYU IDMUNICIPIOAYU,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM LIMITE_AYUNTAMIENTOS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterlimiteayuntamientos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				LimiteAyuntamientos.class, query, params, "ID_MUNICIPIO_AYU");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical LimiteAyuntamientos table.
	 *
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<LimiteAyuntamientos>>
	 */
	@Override
	public List<JerarquiaDto<LimiteAyuntamientos>> findAllLikeJerarquia(LimiteAyuntamientos filterLimiteAyuntamientos,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_AYU IDMUNICIPIOAYU,t1.MUNICIPIO MUNICIPIO,t1.NUMERO_COMERCIOS NUMEROCOMERCIOS,t1.POBLACION POBLACION,t1.DENSIDAD DENSIDAD,t1.COEFICIENTE COEFICIENTE,t1.SUBV_TRAMO_POBLACION SUBVTRAMOPOBLACION,t1.SUBV_MAX_POBLACION SUBVMAXPOBLACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM LIMITE_AYUNTAMIENTOS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("LIMITE_AYUNTAMIENTOS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterLimiteAyuntamientos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MUNICIPIO_AYU", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					LimiteAyuntamientosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(LimiteAyuntamientos filterLimiteAyuntamientos,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM LIMITE_AYUNTAMIENTOS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("LIMITE_AYUNTAMIENTOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterLimiteAyuntamientos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_MUNICIPIO_AYU",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<LimiteAyuntamientos>>
	 */
	@Override
	public List<TableRowDto<LimiteAyuntamientos>> findAllChild(LimiteAyuntamientos filterLimiteAyuntamientos,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM LIMITE_AYUNTAMIENTOS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("LIMITE_AYUNTAMIENTOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterLimiteAyuntamientos, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_MUNICIPIO_AYU",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<LimiteAyuntamientos>(this.rwMapPK, "ID_MUNICIPIO_AYU"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the LimiteAyuntamientos entity
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(LimiteAyuntamientos limiteayuntamientos) {

		StringBuilder where = new StringBuilder(LimiteAyuntamientosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (limiteayuntamientos != null && limiteayuntamientos.getIdMunicipioAyu() != null) {
			where.append(" AND t1.ID_MUNICIPIO_AYU = ?");
			params.add(limiteayuntamientos.getIdMunicipioAyu());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getMunicipio() != null) {
			where.append(" AND t1.MUNICIPIO = ?");
			params.add(limiteayuntamientos.getMunicipio());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getNumeroComercios() != null) {
			where.append(" AND t1.NUMERO_COMERCIOS = ?");
			params.add(limiteayuntamientos.getNumeroComercios());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getPoblacion() != null) {
			where.append(" AND t1.POBLACION = ?");
			params.add(limiteayuntamientos.getPoblacion());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getDensidad() != null) {
			where.append(" AND t1.DENSIDAD = ?");
			params.add(limiteayuntamientos.getDensidad());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getCoeficiente() != null) {
			where.append(" AND t1.COEFICIENTE = ?");
			params.add(limiteayuntamientos.getCoeficiente());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getSubvTramoPoblacion() != null) {
			where.append(" AND t1.SUBV_TRAMO_POBLACION = ?");
			params.add(limiteayuntamientos.getSubvTramoPoblacion());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getSubvMaxPoblacion() != null) {
			where.append(" AND t1.SUBV_MAX_POBLACION = ?");
			params.add(limiteayuntamientos.getSubvMaxPoblacion());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(limiteayuntamientos.getFechaRegistro());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(limiteayuntamientos.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the LimiteAyuntamientos entity
	 *
	 * @param limiteayuntamientos
	 *            LimiteAyuntamientos Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(LimiteAyuntamientos limiteayuntamientos, Boolean startsWith) {

		StringBuilder where = new StringBuilder(LimiteAyuntamientosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (limiteayuntamientos != null && limiteayuntamientos.getIdMunicipioAyu() != null) {
			where.append(" AND t1.ID_MUNICIPIO_AYU = ?");
			params.add(limiteayuntamientos.getIdMunicipioAyu());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getMunicipio() != null) {
			where.append(" AND UPPER(t1.MUNICIPIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(limiteayuntamientos.getMunicipio().toUpperCase() + "%");
			} else {
				params.add("%" + limiteayuntamientos.getMunicipio().toUpperCase() + "%");
			}
			where.append(" AND t1.MUNICIPIO IS NOT NULL");
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getNumeroComercios() != null) {
			where.append(" AND t1.NUMERO_COMERCIOS = ?");
			params.add(limiteayuntamientos.getNumeroComercios());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getPoblacion() != null) {
			where.append(" AND t1.POBLACION = ?");
			params.add(limiteayuntamientos.getPoblacion());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getDensidad() != null) {
			where.append(" AND t1.DENSIDAD = ?");
			params.add(limiteayuntamientos.getDensidad());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getCoeficiente() != null) {
			where.append(" AND t1.COEFICIENTE = ?");
			params.add(limiteayuntamientos.getCoeficiente());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getSubvTramoPoblacion() != null) {
			where.append(" AND t1.SUBV_TRAMO_POBLACION = ?");
			params.add(limiteayuntamientos.getSubvTramoPoblacion());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getSubvMaxPoblacion() != null) {
			where.append(" AND t1.SUBV_MAX_POBLACION = ?");
			params.add(limiteayuntamientos.getSubvMaxPoblacion());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(limiteayuntamientos.getFechaRegistro());
		}
		if (limiteayuntamientos != null && limiteayuntamientos.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(limiteayuntamientos.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + limiteayuntamientos.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
