package com.ejie.ab60.dao.DEC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DEC.RelMunAsoCom;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelMunAsoComDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelMunAsoComDaoImpl implements RelMunAsoComDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMUNICIPIOASOCOM", "IDMUNICIPIO",
			"NUMEROASOCIACIONES", "ORGANOSEGUIMIENTO", "FECHAREGISTRO", "USUARIOREGISTRO",
			"TIPOSSOLICITANTESIDTIPOSOLICITANTE", "TIPOSSOLICITANTESDESCRIPCIONCASTELLANO",
			"TIPOSSOLICITANTESDESCRIPCIONEUSKERA", "TIPOSSOLICITANTESFECHAREGISTRO", "TIPOSSOLICITANTESUSUARIOREGISTRO",
			"IDEXPEDIENTE", "IDPROVINCIA", "NUMEROHOMBRES", "NUMEROMUJERES", "EXENTOIVA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelMunAsoCom> rwMap = new RowMapper<RelMunAsoCom>() {
		public RelMunAsoCom mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelMunAsoCom(resultSet.getInt("IDMUNICIPIOASOCOM"), resultSet.getLong("IDMUNICIPIO"),
					resultSet.getLong("NUMEROASOCIACIONES"), resultSet.getInt("ORGANOSEGUIMIENTO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<RelMunAsoCom> rwMapFindById = new RowMapper<RelMunAsoCom>() {
		public RelMunAsoCom mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelMunAsoCom relMunAsoCom = new RelMunAsoCom();

			relMunAsoCom.setIdMunicipioAsoCom(resultSet.getInt("IDMUNICIPIOASOCOM"));
			relMunAsoCom.setIdProvincia(resultSet.getLong("IDPROVINCIA"));
			relMunAsoCom.setIdMunicipio(resultSet.getLong("IDMUNICIPIO"));
			relMunAsoCom.setNumeroAsociaciones(resultSet.getLong("NUMEROASOCIACIONES"));
			relMunAsoCom.setOrganoSeguimiento(resultSet.getInt("ORGANOSEGUIMIENTO"));
			relMunAsoCom.setFechaRegistro(resultSet.getDate("FECHAREGISTRO"));
			relMunAsoCom.setUsuarioRegistro(resultSet.getString("USUARIOREGISTRO"));
			relMunAsoCom.setNumeroHombres(resultSet.getInt("NUMEROHOMBRES"));
			relMunAsoCom.setNumeroMujeres(resultSet.getInt("NUMEROMUJERES"));
			relMunAsoCom.setExentoIva(resultSet.getInt("EXENTOIVA"));

			return relMunAsoCom;
		}
	};

	private RowMapper<RelMunAsoCom> rwMapPK = new RowMapper<RelMunAsoCom>() {
		public RelMunAsoCom mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelMunAsoCom(resultSet.getInt("IDMUNICIPIOASOCOM"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelMunAsoCom>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelMunAsoCom>>() {
		public JerarquiaDto<RelMunAsoCom> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelMunAsoCom relmunasocom = new RelMunAsoCom(resultSet.getInt("IDMUNICIPIOASOCOM"),
					resultSet.getLong("IDMUNICIPIO"), resultSet.getLong("NUMEROASOCIACIONES"),
					resultSet.getInt("ORGANOSEGUIMIENTO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<RelMunAsoCom> jerarquia = new JerarquiaDto<RelMunAsoCom>();
			jerarquia.setModel(relmunasocom);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelMunAsoCom table.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @return RelMunAsoCom
	 */
	public RelMunAsoCom add(RelMunAsoCom relmunasocom) {
		String query = "INSERT INTO REL_MUN_ASO_COM (ID_MUNICIPIO_ASO_COM, ID_TIPO_SOLICITANTE, ID_MUNICIPIO, NUMERO_ASOCIACIONES, ORGANO_SEGUIMIENTO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		Object getTiposSolicitantesIdTipoSolicitanteAux = null;
		this.jdbcTemplate.update(query, relmunasocom.getIdMunicipioAsoCom(), getTiposSolicitantesIdTipoSolicitanteAux,
				relmunasocom.getIdMunicipio(), relmunasocom.getNumeroAsociaciones(),
				relmunasocom.getOrganoSeguimiento(), relmunasocom.getFechaRegistro(),
				relmunasocom.getUsuarioRegistro());
		return relmunasocom;
	}

	/**
	 * Updates a single row in the RelMunAsoCom table.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @return RelMunAsoCom
	 */
	public RelMunAsoCom update(RelMunAsoCom relmunasocom) {
		String query = "UPDATE REL_MUN_ASO_COM SET ID_TIPO_SOLICITANTE=?, ID_MUNICIPIO=?, NUMERO_ASOCIACIONES=?, ORGANO_SEGUIMIENTO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_MUNICIPIO_ASO_COM=?";
		Object getTiposSolicitantesIdTipoSolicitanteAux = null;
		this.jdbcTemplate.update(query, getTiposSolicitantesIdTipoSolicitanteAux, relmunasocom.getIdMunicipio(),
				relmunasocom.getNumeroAsociaciones(), relmunasocom.getOrganoSeguimiento(),
				relmunasocom.getFechaRegistro(), relmunasocom.getUsuarioRegistro(),
				relmunasocom.getIdMunicipioAsoCom());
		return relmunasocom;
	}

	/**
	 * Finds a single row in the RelMunAsoCom table.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @return RelMunAsoCom
	 */
	@Transactional(readOnly = true)
	public RelMunAsoCom find(RelMunAsoCom relmunasocom) {
		String query = "SELECT t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM, t1.ID_MUNICIPIO IDMUNICIPIO, t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES, t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_TIPO_SOLICITANTE TIPOSSOLICITANTESIDTIPOSOLICITANTE, t2.DESCRIPCION_CASTELLANO TIPOSSOLICITANTESDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA TIPOSSOLICITANTESDESCRIPCIONEUSKERA, t2.FECHA_REGISTRO TIPOSSOLICITANTESFECHAREGISTRO, t2.USUARIO_REGISTRO TIPOSSOLICITANTESUSUARIOREGISTRO FROM REL_MUN_ASO_COM t1 , TIPOS_SOLICITANTES t2  WHERE t1.ID_MUNICIPIO_ASO_COM = ?   AND t1.ID_TIPO_SOLICITANTE= t2.ID_TIPO_SOLICITANTE(+)";

		List<RelMunAsoCom> relmunasocomList = this.jdbcTemplate.query(query, this.rwMap,
				relmunasocom.getIdMunicipioAsoCom());
		return (RelMunAsoCom) DataAccessUtils.uniqueResult(relmunasocomList);
	}

	/**
	 * Removes a single row in the RelMunAsoCom table.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @return
	 */
	public void remove(RelMunAsoCom relmunasocom) {
		String query = "DELETE FROM REL_MUN_ASO_COM WHERE ID_MUNICIPIO_ASO_COM=?";
		this.jdbcTemplate.update(query, relmunasocom.getIdMunicipioAsoCom());
	}

	/**
	 * Finds a list of rows in the RelMunAsoCom table.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelMunAsoCom>
	 */
	@Transactional(readOnly = true)
	public List<RelMunAsoCom> findAll(RelMunAsoCom relmunasocom, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM,t1.ID_MUNICIPIO IDMUNICIPIO,t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES,t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE TIPOSSOLICITANTESIDTIPOSOLICITANTE,t2.DESCRIPCION_CASTELLANO TIPOSSOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSSOLICITANTESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSSOLICITANTESUSUARIOREGISTRO ");
		query.append("FROM REL_MUN_ASO_COM t1 ,TIPOS_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relmunasocom);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_SOLICITANTE= t2.ID_TIPO_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelMunAsoComDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelMunAsoCom>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelMunAsoCom table using like.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelMunAsoCom>
	 */
	@Transactional(readOnly = true)
	public List<RelMunAsoCom> findAllLike(RelMunAsoCom relmunasocom, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM,t1.ID_MUNICIPIO IDMUNICIPIO,t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES,t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE TIPOSSOLICITANTESIDTIPOSOLICITANTE,t2.DESCRIPCION_CASTELLANO TIPOSSOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSSOLICITANTESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSSOLICITANTESUSUARIOREGISTRO ");
		query.append("FROM REL_MUN_ASO_COM t1 ,TIPOS_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relmunasocom, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_SOLICITANTE= t2.ID_TIPO_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelMunAsoComDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelMunAsoCom>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelMunAsoCom table.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelMunAsoCom relmunasocom) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_MUN_ASO_COM t1 , TIPOS_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relmunasocom);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_SOLICITANTE= t2.ID_TIPO_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelMunAsoCom table using like.
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelMunAsoCom relmunasocom, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_MUN_ASO_COM t1 ,TIPOS_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relmunasocom, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_SOLICITANTE= t2.ID_TIPO_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelMunAsoCom selected for rup_table
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelMunAsoCom>>
	 */
	@Override
	public List<TableRowDto<RelMunAsoCom>> reorderSelection(RelMunAsoCom relmunasocom,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM,t1.ID_MUNICIPIO IDMUNICIPIO,t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES,t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE TIPOSSOLICITANTESIDTIPOSOLICITANTE,t2.DESCRIPCION_CASTELLANO TIPOSSOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSSOLICITANTESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSSOLICITANTESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_MUN_ASO_COM t1 ,TIPOS_SOLICITANTES t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relmunasocom, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_SOLICITANTE= t2.ID_TIPO_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelMunAsoCom.class,
				filterParamList, "ID_MUNICIPIO_ASO_COM");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelMunAsoCom>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelMunAsoCom
	 * @param searchParams
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelMunAsoCom>>
	 */
	@Override
	public List<TableRowDto<RelMunAsoCom>> search(RelMunAsoCom filterParams, RelMunAsoCom searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM,t1.ID_MUNICIPIO IDMUNICIPIO,t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES,t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE TIPOSSOLICITANTESIDTIPOSOLICITANTE,t2.DESCRIPCION_CASTELLANO TIPOSSOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSSOLICITANTESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSSOLICITANTESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_MUN_ASO_COM t1 ,TIPOS_SOLICITANTES t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_SOLICITANTE= t2.ID_TIPO_SOLICITANTE(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelMunAsoCom.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_MUNICIPIO_ASO_COM");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelMunAsoCom>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelmunasocom
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelMunAsoCom filterrelmunasocom, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM,t1.ID_MUNICIPIO IDMUNICIPIO,t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES,t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE TIPOSSOLICITANTESIDTIPOSOLICITANTE,t2.DESCRIPCION_CASTELLANO TIPOSSOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSSOLICITANTESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSSOLICITANTESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_MUN_ASO_COM t1 ,TIPOS_SOLICITANTES t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelmunasocom, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelMunAsoCom.class,
				query, params, "ID_MUNICIPIO_ASO_COM");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelMunAsoCom table.
	 *
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelMunAsoCom>>
	 */
	@Override
	public List<JerarquiaDto<RelMunAsoCom>> findAllLikeJerarquia(RelMunAsoCom filterRelMunAsoCom,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM,t1.ID_MUNICIPIO IDMUNICIPIO,t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES,t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_SOLICITANTE TIPOSSOLICITANTESIDTIPOSOLICITANTE,t2.DESCRIPCION_CASTELLANO TIPOSSOLICITANTESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSSOLICITANTESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSSOLICITANTESUSUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_MUN_ASO_COM t1
		// ,TIPOS_SOLICITANTES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_MUN_ASO_COM");
		from.add("TIPOS_SOLICITANTES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelMunAsoCom, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MUNICIPIO_ASO_COM", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelMunAsoComDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelMunAsoCom filterRelMunAsoCom, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_MUN_ASO_COM t1
		// ,TIPOS_SOLICITANTES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_MUN_ASO_COM");
		from.add("TIPOS_SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelMunAsoCom, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_MUNICIPIO_ASO_COM",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelMunAsoCom>>
	 */
	@Override
	public List<TableRowDto<RelMunAsoCom>> findAllChild(RelMunAsoCom filterRelMunAsoCom,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_MUN_ASO_COM t1
		// ,TIPOS_SOLICITANTES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_MUN_ASO_COM");
		from.add("TIPOS_SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelMunAsoCom, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_MUNICIPIO_ASO_COM", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelMunAsoCom>(this.rwMapPK, "ID_MUNICIPIO_ASO_COM"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelMunAsoCom entity
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelMunAsoCom relmunasocom) {

		StringBuilder where = new StringBuilder(RelMunAsoComDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relmunasocom != null && relmunasocom.getIdMunicipioAsoCom() != null) {
			where.append(" AND t1.ID_MUNICIPIO_ASO_COM = ?");
			params.add(relmunasocom.getIdMunicipioAsoCom());
		}
		if (relmunasocom != null && relmunasocom.getIdMunicipio() != null) {
			where.append(" AND t1.ID_MUNICIPIO = ?");
			params.add(relmunasocom.getIdMunicipio());
		}
		if (relmunasocom != null && relmunasocom.getNumeroAsociaciones() != null) {
			where.append(" AND t1.NUMERO_ASOCIACIONES = ?");
			params.add(relmunasocom.getNumeroAsociaciones());
		}
		if (relmunasocom != null && relmunasocom.getOrganoSeguimiento() != null) {
			where.append(" AND t1.ORGANO_SEGUIMIENTO = ?");
			params.add(relmunasocom.getOrganoSeguimiento());
		}
		if (relmunasocom != null && relmunasocom.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relmunasocom.getFechaRegistro());
		}
		if (relmunasocom != null && relmunasocom.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relmunasocom.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelMunAsoCom entity
	 *
	 * @param relmunasocom
	 *            RelMunAsoCom Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelMunAsoCom relmunasocom, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelMunAsoComDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relmunasocom != null && relmunasocom.getIdMunicipioAsoCom() != null) {
			where.append(" AND t1.ID_MUNICIPIO_ASO_COM = ?");
			params.add(relmunasocom.getIdMunicipioAsoCom());
		}
		if (relmunasocom != null && relmunasocom.getIdMunicipio() != null) {
			where.append(" AND t1.ID_MUNICIPIO = ?");
			params.add(relmunasocom.getIdMunicipio());
		}
		if (relmunasocom != null && relmunasocom.getNumeroAsociaciones() != null) {
			where.append(" AND t1.NUMERO_ASOCIACIONES = ?");
			params.add(relmunasocom.getNumeroAsociaciones());
		}
		if (relmunasocom != null && relmunasocom.getOrganoSeguimiento() != null) {
			where.append(" AND t1.ORGANO_SEGUIMIENTO = ?");
			params.add(relmunasocom.getOrganoSeguimiento());
		}
		if (relmunasocom != null && relmunasocom.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relmunasocom.getFechaRegistro());
		}
		if (relmunasocom != null && relmunasocom.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relmunasocom.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relmunasocom.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public RelMunAsoCom findById(Integer idExpediente) {
		String query = "SELECT t1.ID_MUNICIPIO_ASO_COM IDMUNICIPIOASOCOM, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_PROVINCIA IDPROVINCIA, t1.ID_MUNICIPIO IDMUNICIPIO, t1.NUMERO_ASOCIACIONES NUMEROASOCIACIONES, t1.ORGANO_SEGUIMIENTO ORGANOSEGUIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.NUMERO_HOMBRES NUMEROHOMBRES, t1.NUMERO_MUJERES NUMEROMUJERES, t1.EXENTOIVA EXENTOIVA FROM REL_MUN_ASO_COM t1 WHERE t1.ID_EXPEDIENTE = ?";

		List<RelMunAsoCom> relmunasocomList = this.jdbcTemplate.query(query, this.rwMapFindById, idExpediente);
		return (RelMunAsoCom) DataAccessUtils.uniqueResult(relmunasocomList);
	}
}
