package com.ejie.ab60.dao.DIV;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DIV.Acciones;
import com.ejie.ab60.model.DIV.EntidadesSolicitantes;
import com.ejie.ab60.model.DIV.TiposActividad;
import com.ejie.ab60.model.DIV.TiposAsociacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AccionesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class AccionesDaoImpl implements AccionesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDACCIONES", "TITULO", "PONENTES", "FECHAINICIO",
			"FECHAFIN", "DURACION", "NEMPRESASCOMERCIALES", "NEMPRESASASISTENTES", "CONTRATACION",
			"CONTRATACIONADMITIDA", "ACTPUBLICIDAD", "ACTPUBLICIDADADMITIDA", "ACTMAILING", "ACTMAILINGADMITIDO",
			"ACTIMPRESION", "ACTIMPRESIONADMITIDA", "ACTDIVULGACION", "ACTDIVULGACIONADMITIDA", "ACTDISTRIBUCION",
			"ACTDISTRIBUCIONADMITIDA", "ACTOTROS", "ACTOTROSADMITIDOS", "GASFOTOCOPIAS", "GASFOTOCOPIASADMITIDO",
			"GASMATERIAL", "GASMATERIALADMITIDA", "GASDOCUMENTACION", "GASDOCUMENTACIONADMITIDA", "GASALQUILER",
			"GASALQUILERADMITIDO", "GASOTROS", "GASOTROSADMITIDOS", "GASALOJAMIENTO", "GASALOJAMIENTOADMITIDO",
			"GASTRASLADO", "GASTRASLADOADMITIDO", "GASMANUTENCION", "GASMANUTENCIONADMITIDO", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "TIPOSACTIVIDADIDTIPOACTIVIDAD",
			"TIPOSACTIVIDADDESCRIPCIONCASTELLANO", "TIPOSACTIVIDADDESCRIPCIONEUSKERA", "TIPOSACTIVIDADLIMITEACTIVIDAD",
			"TIPOSACTIVIDADMAXIMOHORA", "TIPOSACTIVIDADLIMITECONTRATACION", "TIPOSACTIVIDADLIMITERESTO",
			"TIPOSACTIVIDADFECHAREGISTRO", "TIPOSACTIVIDADUSUARIOREGISTRO", "ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE",
			"ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES", "ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES",
			"ENTIDADESSOLICITANTESANTIGUEDADENTIDAD", "ENTIDADESSOLICITANTESNSOCIOSTOTAL",
			"ENTIDADESSOLICITANTESNSOCIOSMUJERES", "ENTIDADESSOLICITANTESNSOCIOSHOMBRES",
			"ENTIDADESSOLICITANTESFECHAREGISTRO", "ENTIDADESSOLICITANTESUSUARIOREGISTRO",
			"ENTIDADESSOLICITANTESIDTIPOASOCIACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Acciones> rwMap = new RowMapper<Acciones>() {
		public Acciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Acciones(resultSet.getInt("IDACCIONES"), resultSet.getString("TITULO"),
					resultSet.getString("PONENTES"), resultSet.getDate("FECHAINICIO"), resultSet.getDate("FECHAFIN"),
					resultSet.getLong("DURACION"), resultSet.getLong("NEMPRESASCOMERCIALES"),
					resultSet.getLong("NEMPRESASASISTENTES"), resultSet.getBigDecimal("CONTRATACION"),
					resultSet.getBigDecimal("CONTRATACIONADMITIDA"), resultSet.getBigDecimal("ACTPUBLICIDAD"),
					resultSet.getBigDecimal("ACTPUBLICIDADADMITIDA"), resultSet.getBigDecimal("ACTMAILING"),
					resultSet.getBigDecimal("ACTMAILINGADMITIDO"), resultSet.getBigDecimal("ACTIMPRESION"),
					resultSet.getBigDecimal("ACTIMPRESIONADMITIDA"), resultSet.getBigDecimal("ACTDIVULGACION"),
					resultSet.getBigDecimal("ACTDIVULGACIONADMITIDA"), resultSet.getBigDecimal("ACTDISTRIBUCION"),
					resultSet.getBigDecimal("ACTDISTRIBUCIONADMITIDA"), resultSet.getBigDecimal("ACTOTROS"),
					resultSet.getBigDecimal("ACTOTROSADMITIDOS"), resultSet.getBigDecimal("GASFOTOCOPIAS"),
					resultSet.getBigDecimal("GASFOTOCOPIASADMITIDO"), resultSet.getBigDecimal("GASMATERIAL"),
					resultSet.getBigDecimal("GASMATERIALADMITIDA"), resultSet.getBigDecimal("GASDOCUMENTACION"),
					resultSet.getBigDecimal("GASDOCUMENTACIONADMITIDA"), resultSet.getBigDecimal("GASALQUILER"),
					resultSet.getBigDecimal("GASALQUILERADMITIDO"), resultSet.getBigDecimal("GASOTROS"),
					resultSet.getBigDecimal("GASOTROSADMITIDOS"), resultSet.getBigDecimal("GASALOJAMIENTO"),
					resultSet.getBigDecimal("GASALOJAMIENTOADMITIDO"), resultSet.getBigDecimal("GASTRASLADO"),
					resultSet.getBigDecimal("GASTRASLADOADMITIDO"), resultSet.getBigDecimal("GASMANUTENCION"),
					resultSet.getBigDecimal("GASMANUTENCIONADMITIDO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new TiposActividad(resultSet.getLong("TiposActividadIDTIPOACTIVIDAD"),
							resultSet.getString("TiposActividadDESCRIPCIONCASTELLANO"),
							resultSet.getString("TiposActividadDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("TiposActividadLIMITEACTIVIDAD"),
							resultSet.getBigDecimal("TiposActividadMAXIMOHORA"),
							resultSet.getBigDecimal("TiposActividadLIMITECONTRATACION"),
							resultSet.getBigDecimal("TiposActividadLIMITERESTO"),
							resultSet.getDate("TiposActividadFECHAREGISTRO"),
							resultSet.getString("TiposActividadUSUARIOREGISTRO")),
					new EntidadesSolicitantes(resultSet.getInt("EntidadesSolicitantesIDENTIDADSOLICITANTE"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOMUJERES"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOHOMBRES"),
							resultSet.getLong("EntidadesSolicitantesANTIGUEDADENTIDAD"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSTOTAL"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSMUJERES"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSHOMBRES"),
							resultSet.getDate("EntidadesSolicitantesFECHAREGISTRO"),
							resultSet.getString("EntidadesSolicitantesUSUARIOREGISTRO"),
							new TiposAsociacion(resultSet.getLong("EntidadesSolicitantesIDTIPOASOCIACION"), null, null,
									null, null, null)));
		}
	};

	private RowMapper<Acciones> rwMapPK = new RowMapper<Acciones>() {
		public Acciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Acciones(resultSet.getInt("IDACCIONES"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Acciones>> rwMapJerarquia = new RowMapper<JerarquiaDto<Acciones>>() {
		public JerarquiaDto<Acciones> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Acciones acciones = new Acciones(resultSet.getInt("IDACCIONES"), resultSet.getString("TITULO"),
					resultSet.getString("PONENTES"), resultSet.getDate("FECHAINICIO"), resultSet.getDate("FECHAFIN"),
					resultSet.getLong("DURACION"), resultSet.getLong("NEMPRESASCOMERCIALES"),
					resultSet.getLong("NEMPRESASASISTENTES"), resultSet.getBigDecimal("CONTRATACION"),
					resultSet.getBigDecimal("CONTRATACIONADMITIDA"), resultSet.getBigDecimal("ACTPUBLICIDAD"),
					resultSet.getBigDecimal("ACTPUBLICIDADADMITIDA"), resultSet.getBigDecimal("ACTMAILING"),
					resultSet.getBigDecimal("ACTMAILINGADMITIDO"), resultSet.getBigDecimal("ACTIMPRESION"),
					resultSet.getBigDecimal("ACTIMPRESIONADMITIDA"), resultSet.getBigDecimal("ACTDIVULGACION"),
					resultSet.getBigDecimal("ACTDIVULGACIONADMITIDA"), resultSet.getBigDecimal("ACTDISTRIBUCION"),
					resultSet.getBigDecimal("ACTDISTRIBUCIONADMITIDA"), resultSet.getBigDecimal("ACTOTROS"),
					resultSet.getBigDecimal("ACTOTROSADMITIDOS"), resultSet.getBigDecimal("GASFOTOCOPIAS"),
					resultSet.getBigDecimal("GASFOTOCOPIASADMITIDO"), resultSet.getBigDecimal("GASMATERIAL"),
					resultSet.getBigDecimal("GASMATERIALADMITIDA"), resultSet.getBigDecimal("GASDOCUMENTACION"),
					resultSet.getBigDecimal("GASDOCUMENTACIONADMITIDA"), resultSet.getBigDecimal("GASALQUILER"),
					resultSet.getBigDecimal("GASALQUILERADMITIDO"), resultSet.getBigDecimal("GASOTROS"),
					resultSet.getBigDecimal("GASOTROSADMITIDOS"), resultSet.getBigDecimal("GASALOJAMIENTO"),
					resultSet.getBigDecimal("GASALOJAMIENTOADMITIDO"), resultSet.getBigDecimal("GASTRASLADO"),
					resultSet.getBigDecimal("GASTRASLADOADMITIDO"), resultSet.getBigDecimal("GASMANUTENCION"),
					resultSet.getBigDecimal("GASMANUTENCIONADMITIDO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new TiposActividad(resultSet.getLong("TiposActividadIDTIPOACTIVIDAD"),
							resultSet.getString("TiposActividadDESCRIPCIONCASTELLANO"),
							resultSet.getString("TiposActividadDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("TiposActividadLIMITEACTIVIDAD"),
							resultSet.getBigDecimal("TiposActividadMAXIMOHORA"),
							resultSet.getBigDecimal("TiposActividadLIMITECONTRATACION"),
							resultSet.getBigDecimal("TiposActividadLIMITERESTO"),
							resultSet.getDate("TiposActividadFECHAREGISTRO"),
							resultSet.getString("TiposActividadUSUARIOREGISTRO")),
					new EntidadesSolicitantes(resultSet.getInt("EntidadesSolicitantesIDENTIDADSOLICITANTE"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOMUJERES"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOHOMBRES"),
							resultSet.getLong("EntidadesSolicitantesANTIGUEDADENTIDAD"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSTOTAL"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSMUJERES"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSHOMBRES"),
							resultSet.getDate("EntidadesSolicitantesFECHAREGISTRO"),
							resultSet.getString("EntidadesSolicitantesUSUARIOREGISTRO"),
							new TiposAsociacion(resultSet.getLong("EntidadesSolicitantesIDTIPOASOCIACION"), null, null,
									null, null, null)));

			JerarquiaDto<Acciones> jerarquia = new JerarquiaDto<Acciones>();
			jerarquia.setModel(acciones);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return Acciones
	 */
	public Acciones add(Acciones acciones) {
		String query = "INSERT INTO ACCIONES (ID_ACCIONES, ID_TIPO_ACTIVIDAD, ID_ENTIDAD_SOLICITANTE, TITULO, PONENTES, FECHA_INICIO, FECHA_FIN, DURACION, N_EMPRESAS_COMERCIALES, N_EMPRESAS_ASISTENTES, CONTRATACION, CONTRATACION_ADMITIDA, ACT_PUBLICIDAD, ACT_PUBLICIDAD_ADMITIDA, ACT_MAILING, ACT_MAILING_ADMITIDO, ACT_IMPRESION, ACT_IMPRESION_ADMITIDA, ACT_DIVULGACION, ACT_DIVULGACION_ADMITIDA, ACT_DISTRIBUCION, ACT_DISTRIBUCION_ADMITIDA, ACT_OTROS, ACT_OTROS_ADMITIDOS, GAS_FOTOCOPIAS, GAS_FOTOCOPIAS_ADMITIDO, GAS_MATERIAL, GAS_MATERIAL_ADMITIDA, GAS_DOCUMENTACION, GAS_DOCUMENTACION_ADMITIDA, GAS_ALQUILER, GAS_ALQUILER_ADMITIDO, GAS_OTROS, GAS_OTROS_ADMITIDOS, GAS_ALOJAMIENTO, GAS_ALOJAMIENTO_ADMITIDO, GAS_TRASLADO, GAS_TRASLADO_ADMITIDO, GAS_MANUTENCION, GAS_MANUTENCION_ADMITIDO, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		Object getTiposActividadIdTipoActividadAux = null;
		if (acciones.getTiposActividad() != null && acciones.getTiposActividad().getIdTipoActividad() != null) {
			getTiposActividadIdTipoActividadAux = acciones.getTiposActividad().getIdTipoActividad();
		}
		Object getEntidadesSolicitantesIdEntidadSolicitanteAux = null;
		if (acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			getEntidadesSolicitantesIdEntidadSolicitanteAux = acciones.getEntidadesSolicitantes()
					.getIdEntidadSolicitante();
		}
		this.jdbcTemplate.update(query, acciones.getIdAcciones(), getTiposActividadIdTipoActividadAux,
				getEntidadesSolicitantesIdEntidadSolicitanteAux, acciones.getTitulo(), acciones.getPonentes(),
				acciones.getFechaInicio(), acciones.getFechaFin(), acciones.getDuracion(),
				acciones.getNEmpresasComerciales(), acciones.getNEmpresasAsistentes(), acciones.getContratacion(),
				acciones.getContratacionAdmitida(), acciones.getActPublicidad(), acciones.getActPublicidadAdmitida(),
				acciones.getActMailing(), acciones.getActMailingAdmitido(), acciones.getActImpresion(),
				acciones.getActImpresionAdmitida(), acciones.getActDivulgacion(), acciones.getActDivulgacionAdmitida(),
				acciones.getActDistribucion(), acciones.getActDistribucionAdmitida(), acciones.getActOtros(),
				acciones.getActOtrosAdmitidos(), acciones.getGasFotocopias(), acciones.getGasFotocopiasAdmitido(),
				acciones.getGasMaterial(), acciones.getGasMaterialAdmitida(), acciones.getGasDocumentacion(),
				acciones.getGasDocumentacionAdmitida(), acciones.getGasAlquiler(), acciones.getGasAlquilerAdmitido(),
				acciones.getGasOtros(), acciones.getGasOtrosAdmitidos(), acciones.getGasAlojamiento(),
				acciones.getGasAlojamientoAdmitido(), acciones.getGasTraslado(), acciones.getGasTrasladoAdmitido(),
				acciones.getGasManutencion(), acciones.getGasManutencionAdmitido(), acciones.getFechaRegistro(),
				acciones.getUsuarioRegistro(), acciones.getFechaUltmodificacion(),
				acciones.getUsuarioUltmodificacion());
		return acciones;
	}

	/**
	 * Updates a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return Acciones
	 */
	public Acciones update(Acciones acciones) {
		String query = "UPDATE ACCIONES SET ID_TIPO_ACTIVIDAD=?, ID_ENTIDAD_SOLICITANTE=?, TITULO=?, PONENTES=?, FECHA_INICIO=?, FECHA_FIN=?, DURACION=?, N_EMPRESAS_COMERCIALES=?, N_EMPRESAS_ASISTENTES=?, CONTRATACION=?, CONTRATACION_ADMITIDA=?, ACT_PUBLICIDAD=?, ACT_PUBLICIDAD_ADMITIDA=?, ACT_MAILING=?, ACT_MAILING_ADMITIDO=?, ACT_IMPRESION=?, ACT_IMPRESION_ADMITIDA=?, ACT_DIVULGACION=?, ACT_DIVULGACION_ADMITIDA=?, ACT_DISTRIBUCION=?, ACT_DISTRIBUCION_ADMITIDA=?, ACT_OTROS=?, ACT_OTROS_ADMITIDOS=?, GAS_FOTOCOPIAS=?, GAS_FOTOCOPIAS_ADMITIDO=?, GAS_MATERIAL=?, GAS_MATERIAL_ADMITIDA=?, GAS_DOCUMENTACION=?, GAS_DOCUMENTACION_ADMITIDA=?, GAS_ALQUILER=?, GAS_ALQUILER_ADMITIDO=?, GAS_OTROS=?, GAS_OTROS_ADMITIDOS=?, GAS_ALOJAMIENTO=?, GAS_ALOJAMIENTO_ADMITIDO=?, GAS_TRASLADO=?, GAS_TRASLADO_ADMITIDO=?, GAS_MANUTENCION=?, GAS_MANUTENCION_ADMITIDO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_ACCIONES=?";
		Object getTiposActividadIdTipoActividadAux = null;
		if (acciones.getTiposActividad() != null && acciones.getTiposActividad().getIdTipoActividad() != null) {
			getTiposActividadIdTipoActividadAux = acciones.getTiposActividad().getIdTipoActividad();
		}
		Object getEntidadesSolicitantesIdEntidadSolicitanteAux = null;
		if (acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			getEntidadesSolicitantesIdEntidadSolicitanteAux = acciones.getEntidadesSolicitantes()
					.getIdEntidadSolicitante();
		}
		this.jdbcTemplate.update(query, getTiposActividadIdTipoActividadAux,
				getEntidadesSolicitantesIdEntidadSolicitanteAux, acciones.getTitulo(), acciones.getPonentes(),
				acciones.getFechaInicio(), acciones.getFechaFin(), acciones.getDuracion(),
				acciones.getNEmpresasComerciales(), acciones.getNEmpresasAsistentes(), acciones.getContratacion(),
				acciones.getContratacionAdmitida(), acciones.getActPublicidad(), acciones.getActPublicidadAdmitida(),
				acciones.getActMailing(), acciones.getActMailingAdmitido(), acciones.getActImpresion(),
				acciones.getActImpresionAdmitida(), acciones.getActDivulgacion(), acciones.getActDivulgacionAdmitida(),
				acciones.getActDistribucion(), acciones.getActDistribucionAdmitida(), acciones.getActOtros(),
				acciones.getActOtrosAdmitidos(), acciones.getGasFotocopias(), acciones.getGasFotocopiasAdmitido(),
				acciones.getGasMaterial(), acciones.getGasMaterialAdmitida(), acciones.getGasDocumentacion(),
				acciones.getGasDocumentacionAdmitida(), acciones.getGasAlquiler(), acciones.getGasAlquilerAdmitido(),
				acciones.getGasOtros(), acciones.getGasOtrosAdmitidos(), acciones.getGasAlojamiento(),
				acciones.getGasAlojamientoAdmitido(), acciones.getGasTraslado(), acciones.getGasTrasladoAdmitido(),
				acciones.getGasManutencion(), acciones.getGasManutencionAdmitido(), acciones.getFechaRegistro(),
				acciones.getUsuarioRegistro(), acciones.getFechaUltmodificacion(), acciones.getUsuarioUltmodificacion(),
				acciones.getIdAcciones());
		return acciones;
	}

	/**
	 * Finds a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return Acciones
	 */
	@Transactional(readOnly = true)
	public Acciones find(Acciones acciones) {
		String query = "SELECT t1.ID_ACCIONES IDACCIONES, t1.TITULO TITULO, t1.PONENTES PONENTES, t1.FECHA_INICIO FECHAINICIO, t1.FECHA_FIN FECHAFIN, t1.DURACION DURACION, t1.N_EMPRESAS_COMERCIALES NEMPRESASCOMERCIALES, t1.N_EMPRESAS_ASISTENTES NEMPRESASASISTENTES, t1.CONTRATACION CONTRATACION, t1.CONTRATACION_ADMITIDA CONTRATACIONADMITIDA, t1.ACT_PUBLICIDAD ACTPUBLICIDAD, t1.ACT_PUBLICIDAD_ADMITIDA ACTPUBLICIDADADMITIDA, t1.ACT_MAILING ACTMAILING, t1.ACT_MAILING_ADMITIDO ACTMAILINGADMITIDO, t1.ACT_IMPRESION ACTIMPRESION, t1.ACT_IMPRESION_ADMITIDA ACTIMPRESIONADMITIDA, t1.ACT_DIVULGACION ACTDIVULGACION, t1.ACT_DIVULGACION_ADMITIDA ACTDIVULGACIONADMITIDA, t1.ACT_DISTRIBUCION ACTDISTRIBUCION, t1.ACT_DISTRIBUCION_ADMITIDA ACTDISTRIBUCIONADMITIDA, t1.ACT_OTROS ACTOTROS, t1.ACT_OTROS_ADMITIDOS ACTOTROSADMITIDOS, t1.GAS_FOTOCOPIAS GASFOTOCOPIAS, t1.GAS_FOTOCOPIAS_ADMITIDO GASFOTOCOPIASADMITIDO, t1.GAS_MATERIAL GASMATERIAL, t1.GAS_MATERIAL_ADMITIDA GASMATERIALADMITIDA, t1.GAS_DOCUMENTACION GASDOCUMENTACION, t1.GAS_DOCUMENTACION_ADMITIDA GASDOCUMENTACIONADMITIDA, t1.GAS_ALQUILER GASALQUILER, t1.GAS_ALQUILER_ADMITIDO GASALQUILERADMITIDO, t1.GAS_OTROS GASOTROS, t1.GAS_OTROS_ADMITIDOS GASOTROSADMITIDOS, t1.GAS_ALOJAMIENTO GASALOJAMIENTO, t1.GAS_ALOJAMIENTO_ADMITIDO GASALOJAMIENTOADMITIDO, t1.GAS_TRASLADO GASTRASLADO, t1.GAS_TRASLADO_ADMITIDO GASTRASLADOADMITIDO, t1.GAS_MANUTENCION GASMANUTENCION, t1.GAS_MANUTENCION_ADMITIDO GASMANUTENCIONADMITIDO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_TIPO_ACTIVIDAD TIPOSACTIVIDADIDTIPOACTIVIDAD, t2.DESCRIPCION_CASTELLANO TIPOSACTIVIDADDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA TIPOSACTIVIDADDESCRIPCIONEUSKERA, t2.LIMITE_ACTIVIDAD TIPOSACTIVIDADLIMITEACTIVIDAD, t2.MAXIMO_HORA TIPOSACTIVIDADMAXIMOHORA, t2.LIMITE_CONTRATACION TIPOSACTIVIDADLIMITECONTRATACION, t2.LIMITE_RESTO TIPOSACTIVIDADLIMITERESTO, t2.FECHA_REGISTRO TIPOSACTIVIDADFECHAREGISTRO, t2.USUARIO_REGISTRO TIPOSACTIVIDADUSUARIOREGISTRO, t3.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE, t3.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES, t3.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES, t3.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD, t3.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL, t3.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES, t3.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES, t3.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO, t3.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO, t3.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION FROM ACCIONES t1 , TIPOS_ACTIVIDAD t2 , ENTIDADES_SOLICITANTES t3  WHERE t1.ID_ACCIONES = ?   AND t1.ID_TIPO_ACTIVIDAD= t2.ID_TIPO_ACTIVIDAD(+) AND t1.ID_ENTIDAD_SOLICITANTE= t3.ID_ENTIDAD_SOLICITANTE(+)";

		List<Acciones> accionesList = this.jdbcTemplate.query(query, this.rwMap, acciones.getIdAcciones());
		return (Acciones) DataAccessUtils.uniqueResult(accionesList);
	}

	/**
	 * Removes a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return
	 */
	public void remove(Acciones acciones) {
		String query = "DELETE FROM ACCIONES WHERE ID_ACCIONES=?";
		this.jdbcTemplate.update(query, acciones.getIdAcciones());
	}

	/**
	 * Finds a list of rows in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Acciones>
	 */
	@Transactional(readOnly = true)
	public List<Acciones> findAll(Acciones acciones, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACCIONES IDACCIONES,t1.TITULO TITULO,t1.PONENTES PONENTES,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DURACION DURACION,t1.N_EMPRESAS_COMERCIALES NEMPRESASCOMERCIALES,t1.N_EMPRESAS_ASISTENTES NEMPRESASASISTENTES,t1.CONTRATACION CONTRATACION,t1.CONTRATACION_ADMITIDA CONTRATACIONADMITIDA,t1.ACT_PUBLICIDAD ACTPUBLICIDAD,t1.ACT_PUBLICIDAD_ADMITIDA ACTPUBLICIDADADMITIDA,t1.ACT_MAILING ACTMAILING,t1.ACT_MAILING_ADMITIDO ACTMAILINGADMITIDO,t1.ACT_IMPRESION ACTIMPRESION,t1.ACT_IMPRESION_ADMITIDA ACTIMPRESIONADMITIDA,t1.ACT_DIVULGACION ACTDIVULGACION,t1.ACT_DIVULGACION_ADMITIDA ACTDIVULGACIONADMITIDA,t1.ACT_DISTRIBUCION ACTDISTRIBUCION,t1.ACT_DISTRIBUCION_ADMITIDA ACTDISTRIBUCIONADMITIDA,t1.ACT_OTROS ACTOTROS,t1.ACT_OTROS_ADMITIDOS ACTOTROSADMITIDOS,t1.GAS_FOTOCOPIAS GASFOTOCOPIAS,t1.GAS_FOTOCOPIAS_ADMITIDO GASFOTOCOPIASADMITIDO,t1.GAS_MATERIAL GASMATERIAL,t1.GAS_MATERIAL_ADMITIDA GASMATERIALADMITIDA,t1.GAS_DOCUMENTACION GASDOCUMENTACION,t1.GAS_DOCUMENTACION_ADMITIDA GASDOCUMENTACIONADMITIDA,t1.GAS_ALQUILER GASALQUILER,t1.GAS_ALQUILER_ADMITIDO GASALQUILERADMITIDO,t1.GAS_OTROS GASOTROS,t1.GAS_OTROS_ADMITIDOS GASOTROSADMITIDOS,t1.GAS_ALOJAMIENTO GASALOJAMIENTO,t1.GAS_ALOJAMIENTO_ADMITIDO GASALOJAMIENTOADMITIDO,t1.GAS_TRASLADO GASTRASLADO,t1.GAS_TRASLADO_ADMITIDO GASTRASLADOADMITIDO,t1.GAS_MANUTENCION GASMANUTENCION,t1.GAS_MANUTENCION_ADMITIDO GASMANUTENCIONADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ACTIVIDAD TIPOSACTIVIDADIDTIPOACTIVIDAD,t2.DESCRIPCION_CASTELLANO TIPOSACTIVIDADDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSACTIVIDADDESCRIPCIONEUSKERA,t2.LIMITE_ACTIVIDAD TIPOSACTIVIDADLIMITEACTIVIDAD,t2.MAXIMO_HORA TIPOSACTIVIDADMAXIMOHORA,t2.LIMITE_CONTRATACION TIPOSACTIVIDADLIMITECONTRATACION,t2.LIMITE_RESTO TIPOSACTIVIDADLIMITERESTO,t2.FECHA_REGISTRO TIPOSACTIVIDADFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSACTIVIDADUSUARIOREGISTRO,t3.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t3.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t3.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t3.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t3.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t3.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t3.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t3.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t3.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t3.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		query.append("FROM ACCIONES t1 ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(acciones);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ACTIVIDAD= t2.ID_TIPO_ACTIVIDAD(+) AND t1.ID_ENTIDAD_SOLICITANTE= t3.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, AccionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Acciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Acciones table using like.
	 *
	 * @param acciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Acciones>
	 */
	@Transactional(readOnly = true)
	public List<Acciones> findAllLike(Acciones acciones, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACCIONES IDACCIONES,t1.TITULO TITULO,t1.PONENTES PONENTES,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DURACION DURACION,t1.N_EMPRESAS_COMERCIALES NEMPRESASCOMERCIALES,t1.N_EMPRESAS_ASISTENTES NEMPRESASASISTENTES,t1.CONTRATACION CONTRATACION,t1.CONTRATACION_ADMITIDA CONTRATACIONADMITIDA,t1.ACT_PUBLICIDAD ACTPUBLICIDAD,t1.ACT_PUBLICIDAD_ADMITIDA ACTPUBLICIDADADMITIDA,t1.ACT_MAILING ACTMAILING,t1.ACT_MAILING_ADMITIDO ACTMAILINGADMITIDO,t1.ACT_IMPRESION ACTIMPRESION,t1.ACT_IMPRESION_ADMITIDA ACTIMPRESIONADMITIDA,t1.ACT_DIVULGACION ACTDIVULGACION,t1.ACT_DIVULGACION_ADMITIDA ACTDIVULGACIONADMITIDA,t1.ACT_DISTRIBUCION ACTDISTRIBUCION,t1.ACT_DISTRIBUCION_ADMITIDA ACTDISTRIBUCIONADMITIDA,t1.ACT_OTROS ACTOTROS,t1.ACT_OTROS_ADMITIDOS ACTOTROSADMITIDOS,t1.GAS_FOTOCOPIAS GASFOTOCOPIAS,t1.GAS_FOTOCOPIAS_ADMITIDO GASFOTOCOPIASADMITIDO,t1.GAS_MATERIAL GASMATERIAL,t1.GAS_MATERIAL_ADMITIDA GASMATERIALADMITIDA,t1.GAS_DOCUMENTACION GASDOCUMENTACION,t1.GAS_DOCUMENTACION_ADMITIDA GASDOCUMENTACIONADMITIDA,t1.GAS_ALQUILER GASALQUILER,t1.GAS_ALQUILER_ADMITIDO GASALQUILERADMITIDO,t1.GAS_OTROS GASOTROS,t1.GAS_OTROS_ADMITIDOS GASOTROSADMITIDOS,t1.GAS_ALOJAMIENTO GASALOJAMIENTO,t1.GAS_ALOJAMIENTO_ADMITIDO GASALOJAMIENTOADMITIDO,t1.GAS_TRASLADO GASTRASLADO,t1.GAS_TRASLADO_ADMITIDO GASTRASLADOADMITIDO,t1.GAS_MANUTENCION GASMANUTENCION,t1.GAS_MANUTENCION_ADMITIDO GASMANUTENCIONADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ACTIVIDAD TIPOSACTIVIDADIDTIPOACTIVIDAD,t2.DESCRIPCION_CASTELLANO TIPOSACTIVIDADDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSACTIVIDADDESCRIPCIONEUSKERA,t2.LIMITE_ACTIVIDAD TIPOSACTIVIDADLIMITEACTIVIDAD,t2.MAXIMO_HORA TIPOSACTIVIDADMAXIMOHORA,t2.LIMITE_CONTRATACION TIPOSACTIVIDADLIMITECONTRATACION,t2.LIMITE_RESTO TIPOSACTIVIDADLIMITERESTO,t2.FECHA_REGISTRO TIPOSACTIVIDADFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSACTIVIDADUSUARIOREGISTRO,t3.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t3.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t3.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t3.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t3.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t3.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t3.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t3.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t3.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t3.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		query.append("FROM ACCIONES t1 ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(acciones, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ACTIVIDAD= t2.ID_TIPO_ACTIVIDAD(+) AND t1.ID_ENTIDAD_SOLICITANTE= t3.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, AccionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Acciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Acciones acciones) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ACCIONES t1 , TIPOS_ACTIVIDAD t2 , ENTIDADES_SOLICITANTES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(acciones);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ACTIVIDAD= t2.ID_TIPO_ACTIVIDAD(+) AND t1.ID_ENTIDAD_SOLICITANTE= t3.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Acciones table using like.
	 *
	 * @param acciones
	 *            Acciones
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Acciones acciones, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ACCIONES t1 ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(acciones, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ACTIVIDAD= t2.ID_TIPO_ACTIVIDAD(+) AND t1.ID_ENTIDAD_SOLICITANTE= t3.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Acciones selected for rup_table
	 *
	 * @param acciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Acciones>>
	 */
	@Override
	public List<TableRowDto<Acciones>> reorderSelection(Acciones acciones, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACCIONES IDACCIONES,t1.TITULO TITULO,t1.PONENTES PONENTES,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DURACION DURACION,t1.N_EMPRESAS_COMERCIALES NEMPRESASCOMERCIALES,t1.N_EMPRESAS_ASISTENTES NEMPRESASASISTENTES,t1.CONTRATACION CONTRATACION,t1.CONTRATACION_ADMITIDA CONTRATACIONADMITIDA,t1.ACT_PUBLICIDAD ACTPUBLICIDAD,t1.ACT_PUBLICIDAD_ADMITIDA ACTPUBLICIDADADMITIDA,t1.ACT_MAILING ACTMAILING,t1.ACT_MAILING_ADMITIDO ACTMAILINGADMITIDO,t1.ACT_IMPRESION ACTIMPRESION,t1.ACT_IMPRESION_ADMITIDA ACTIMPRESIONADMITIDA,t1.ACT_DIVULGACION ACTDIVULGACION,t1.ACT_DIVULGACION_ADMITIDA ACTDIVULGACIONADMITIDA,t1.ACT_DISTRIBUCION ACTDISTRIBUCION,t1.ACT_DISTRIBUCION_ADMITIDA ACTDISTRIBUCIONADMITIDA,t1.ACT_OTROS ACTOTROS,t1.ACT_OTROS_ADMITIDOS ACTOTROSADMITIDOS,t1.GAS_FOTOCOPIAS GASFOTOCOPIAS,t1.GAS_FOTOCOPIAS_ADMITIDO GASFOTOCOPIASADMITIDO,t1.GAS_MATERIAL GASMATERIAL,t1.GAS_MATERIAL_ADMITIDA GASMATERIALADMITIDA,t1.GAS_DOCUMENTACION GASDOCUMENTACION,t1.GAS_DOCUMENTACION_ADMITIDA GASDOCUMENTACIONADMITIDA,t1.GAS_ALQUILER GASALQUILER,t1.GAS_ALQUILER_ADMITIDO GASALQUILERADMITIDO,t1.GAS_OTROS GASOTROS,t1.GAS_OTROS_ADMITIDOS GASOTROSADMITIDOS,t1.GAS_ALOJAMIENTO GASALOJAMIENTO,t1.GAS_ALOJAMIENTO_ADMITIDO GASALOJAMIENTOADMITIDO,t1.GAS_TRASLADO GASTRASLADO,t1.GAS_TRASLADO_ADMITIDO GASTRASLADOADMITIDO,t1.GAS_MANUTENCION GASMANUTENCION,t1.GAS_MANUTENCION_ADMITIDO GASMANUTENCIONADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ACTIVIDAD TIPOSACTIVIDADIDTIPOACTIVIDAD,t2.DESCRIPCION_CASTELLANO TIPOSACTIVIDADDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSACTIVIDADDESCRIPCIONEUSKERA,t2.LIMITE_ACTIVIDAD TIPOSACTIVIDADLIMITEACTIVIDAD,t2.MAXIMO_HORA TIPOSACTIVIDADMAXIMOHORA,t2.LIMITE_CONTRATACION TIPOSACTIVIDADLIMITECONTRATACION,t2.LIMITE_RESTO TIPOSACTIVIDADLIMITERESTO,t2.FECHA_REGISTRO TIPOSACTIVIDADFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSACTIVIDADUSUARIOREGISTRO,t3.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t3.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t3.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t3.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t3.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t3.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t3.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t3.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t3.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t3.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		query.append("FROM ACCIONES t1 ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(acciones, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ACTIVIDAD= t2.ID_TIPO_ACTIVIDAD(+) AND t1.ID_ENTIDAD_SOLICITANTE= t3.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Acciones.class,
				filterParamList, "ID_ACCIONES");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Acciones>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Acciones
	 * @param searchParams
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Acciones>>
	 */
	@Override
	public List<TableRowDto<Acciones>> search(Acciones filterParams, Acciones searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACCIONES IDACCIONES,t1.TITULO TITULO,t1.PONENTES PONENTES,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DURACION DURACION,t1.N_EMPRESAS_COMERCIALES NEMPRESASCOMERCIALES,t1.N_EMPRESAS_ASISTENTES NEMPRESASASISTENTES,t1.CONTRATACION CONTRATACION,t1.CONTRATACION_ADMITIDA CONTRATACIONADMITIDA,t1.ACT_PUBLICIDAD ACTPUBLICIDAD,t1.ACT_PUBLICIDAD_ADMITIDA ACTPUBLICIDADADMITIDA,t1.ACT_MAILING ACTMAILING,t1.ACT_MAILING_ADMITIDO ACTMAILINGADMITIDO,t1.ACT_IMPRESION ACTIMPRESION,t1.ACT_IMPRESION_ADMITIDA ACTIMPRESIONADMITIDA,t1.ACT_DIVULGACION ACTDIVULGACION,t1.ACT_DIVULGACION_ADMITIDA ACTDIVULGACIONADMITIDA,t1.ACT_DISTRIBUCION ACTDISTRIBUCION,t1.ACT_DISTRIBUCION_ADMITIDA ACTDISTRIBUCIONADMITIDA,t1.ACT_OTROS ACTOTROS,t1.ACT_OTROS_ADMITIDOS ACTOTROSADMITIDOS,t1.GAS_FOTOCOPIAS GASFOTOCOPIAS,t1.GAS_FOTOCOPIAS_ADMITIDO GASFOTOCOPIASADMITIDO,t1.GAS_MATERIAL GASMATERIAL,t1.GAS_MATERIAL_ADMITIDA GASMATERIALADMITIDA,t1.GAS_DOCUMENTACION GASDOCUMENTACION,t1.GAS_DOCUMENTACION_ADMITIDA GASDOCUMENTACIONADMITIDA,t1.GAS_ALQUILER GASALQUILER,t1.GAS_ALQUILER_ADMITIDO GASALQUILERADMITIDO,t1.GAS_OTROS GASOTROS,t1.GAS_OTROS_ADMITIDOS GASOTROSADMITIDOS,t1.GAS_ALOJAMIENTO GASALOJAMIENTO,t1.GAS_ALOJAMIENTO_ADMITIDO GASALOJAMIENTOADMITIDO,t1.GAS_TRASLADO GASTRASLADO,t1.GAS_TRASLADO_ADMITIDO GASTRASLADOADMITIDO,t1.GAS_MANUTENCION GASMANUTENCION,t1.GAS_MANUTENCION_ADMITIDO GASMANUTENCIONADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ACTIVIDAD TIPOSACTIVIDADIDTIPOACTIVIDAD,t2.DESCRIPCION_CASTELLANO TIPOSACTIVIDADDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSACTIVIDADDESCRIPCIONEUSKERA,t2.LIMITE_ACTIVIDAD TIPOSACTIVIDADLIMITEACTIVIDAD,t2.MAXIMO_HORA TIPOSACTIVIDADMAXIMOHORA,t2.LIMITE_CONTRATACION TIPOSACTIVIDADLIMITECONTRATACION,t2.LIMITE_RESTO TIPOSACTIVIDADLIMITERESTO,t2.FECHA_REGISTRO TIPOSACTIVIDADFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSACTIVIDADUSUARIOREGISTRO,t3.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t3.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t3.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t3.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t3.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t3.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t3.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t3.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t3.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t3.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		query.append("FROM ACCIONES t1 ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ACTIVIDAD= t2.ID_TIPO_ACTIVIDAD(+) AND t1.ID_ENTIDAD_SOLICITANTE= t3.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Acciones.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_ACCIONES");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Acciones>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filteracciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Acciones filteracciones, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACCIONES IDACCIONES,t1.TITULO TITULO,t1.PONENTES PONENTES,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DURACION DURACION,t1.N_EMPRESAS_COMERCIALES NEMPRESASCOMERCIALES,t1.N_EMPRESAS_ASISTENTES NEMPRESASASISTENTES,t1.CONTRATACION CONTRATACION,t1.CONTRATACION_ADMITIDA CONTRATACIONADMITIDA,t1.ACT_PUBLICIDAD ACTPUBLICIDAD,t1.ACT_PUBLICIDAD_ADMITIDA ACTPUBLICIDADADMITIDA,t1.ACT_MAILING ACTMAILING,t1.ACT_MAILING_ADMITIDO ACTMAILINGADMITIDO,t1.ACT_IMPRESION ACTIMPRESION,t1.ACT_IMPRESION_ADMITIDA ACTIMPRESIONADMITIDA,t1.ACT_DIVULGACION ACTDIVULGACION,t1.ACT_DIVULGACION_ADMITIDA ACTDIVULGACIONADMITIDA,t1.ACT_DISTRIBUCION ACTDISTRIBUCION,t1.ACT_DISTRIBUCION_ADMITIDA ACTDISTRIBUCIONADMITIDA,t1.ACT_OTROS ACTOTROS,t1.ACT_OTROS_ADMITIDOS ACTOTROSADMITIDOS,t1.GAS_FOTOCOPIAS GASFOTOCOPIAS,t1.GAS_FOTOCOPIAS_ADMITIDO GASFOTOCOPIASADMITIDO,t1.GAS_MATERIAL GASMATERIAL,t1.GAS_MATERIAL_ADMITIDA GASMATERIALADMITIDA,t1.GAS_DOCUMENTACION GASDOCUMENTACION,t1.GAS_DOCUMENTACION_ADMITIDA GASDOCUMENTACIONADMITIDA,t1.GAS_ALQUILER GASALQUILER,t1.GAS_ALQUILER_ADMITIDO GASALQUILERADMITIDO,t1.GAS_OTROS GASOTROS,t1.GAS_OTROS_ADMITIDOS GASOTROSADMITIDOS,t1.GAS_ALOJAMIENTO GASALOJAMIENTO,t1.GAS_ALOJAMIENTO_ADMITIDO GASALOJAMIENTOADMITIDO,t1.GAS_TRASLADO GASTRASLADO,t1.GAS_TRASLADO_ADMITIDO GASTRASLADOADMITIDO,t1.GAS_MANUTENCION GASMANUTENCION,t1.GAS_MANUTENCION_ADMITIDO GASMANUTENCIONADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ACTIVIDAD TIPOSACTIVIDADIDTIPOACTIVIDAD,t2.DESCRIPCION_CASTELLANO TIPOSACTIVIDADDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSACTIVIDADDESCRIPCIONEUSKERA,t2.LIMITE_ACTIVIDAD TIPOSACTIVIDADLIMITEACTIVIDAD,t2.MAXIMO_HORA TIPOSACTIVIDADMAXIMOHORA,t2.LIMITE_CONTRATACION TIPOSACTIVIDADLIMITECONTRATACION,t2.LIMITE_RESTO TIPOSACTIVIDADLIMITERESTO,t2.FECHA_REGISTRO TIPOSACTIVIDADFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSACTIVIDADUSUARIOREGISTRO,t3.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t3.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t3.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t3.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t3.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t3.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t3.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t3.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t3.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t3.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		query.append("FROM ACCIONES t1 ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filteracciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Acciones.class,
				query, params, "ID_ACCIONES");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Acciones table.
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Acciones>>
	 */
	@Override
	public List<JerarquiaDto<Acciones>> findAllLikeJerarquia(Acciones filterAcciones,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACCIONES IDACCIONES,t1.TITULO TITULO,t1.PONENTES PONENTES,t1.FECHA_INICIO FECHAINICIO,t1.FECHA_FIN FECHAFIN,t1.DURACION DURACION,t1.N_EMPRESAS_COMERCIALES NEMPRESASCOMERCIALES,t1.N_EMPRESAS_ASISTENTES NEMPRESASASISTENTES,t1.CONTRATACION CONTRATACION,t1.CONTRATACION_ADMITIDA CONTRATACIONADMITIDA,t1.ACT_PUBLICIDAD ACTPUBLICIDAD,t1.ACT_PUBLICIDAD_ADMITIDA ACTPUBLICIDADADMITIDA,t1.ACT_MAILING ACTMAILING,t1.ACT_MAILING_ADMITIDO ACTMAILINGADMITIDO,t1.ACT_IMPRESION ACTIMPRESION,t1.ACT_IMPRESION_ADMITIDA ACTIMPRESIONADMITIDA,t1.ACT_DIVULGACION ACTDIVULGACION,t1.ACT_DIVULGACION_ADMITIDA ACTDIVULGACIONADMITIDA,t1.ACT_DISTRIBUCION ACTDISTRIBUCION,t1.ACT_DISTRIBUCION_ADMITIDA ACTDISTRIBUCIONADMITIDA,t1.ACT_OTROS ACTOTROS,t1.ACT_OTROS_ADMITIDOS ACTOTROSADMITIDOS,t1.GAS_FOTOCOPIAS GASFOTOCOPIAS,t1.GAS_FOTOCOPIAS_ADMITIDO GASFOTOCOPIASADMITIDO,t1.GAS_MATERIAL GASMATERIAL,t1.GAS_MATERIAL_ADMITIDA GASMATERIALADMITIDA,t1.GAS_DOCUMENTACION GASDOCUMENTACION,t1.GAS_DOCUMENTACION_ADMITIDA GASDOCUMENTACIONADMITIDA,t1.GAS_ALQUILER GASALQUILER,t1.GAS_ALQUILER_ADMITIDO GASALQUILERADMITIDO,t1.GAS_OTROS GASOTROS,t1.GAS_OTROS_ADMITIDOS GASOTROSADMITIDOS,t1.GAS_ALOJAMIENTO GASALOJAMIENTO,t1.GAS_ALOJAMIENTO_ADMITIDO GASALOJAMIENTOADMITIDO,t1.GAS_TRASLADO GASTRASLADO,t1.GAS_TRASLADO_ADMITIDO GASTRASLADOADMITIDO,t1.GAS_MANUTENCION GASMANUTENCION,t1.GAS_MANUTENCION_ADMITIDO GASMANUTENCIONADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ACTIVIDAD TIPOSACTIVIDADIDTIPOACTIVIDAD,t2.DESCRIPCION_CASTELLANO TIPOSACTIVIDADDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSACTIVIDADDESCRIPCIONEUSKERA,t2.LIMITE_ACTIVIDAD TIPOSACTIVIDADLIMITEACTIVIDAD,t2.MAXIMO_HORA TIPOSACTIVIDADMAXIMOHORA,t2.LIMITE_CONTRATACION TIPOSACTIVIDADLIMITECONTRATACION,t2.LIMITE_RESTO TIPOSACTIVIDADLIMITERESTO,t2.FECHA_REGISTRO TIPOSACTIVIDADFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSACTIVIDADUSUARIOREGISTRO,t3.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t3.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t3.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t3.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t3.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t3.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t3.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t3.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t3.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t3.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACCIONES t1
		// ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");
		List<String> from = new ArrayList<String>();
		from.add("ACCIONES");
		from.add("TIPOS_ACTIVIDAD");
		from.add("ENTIDADES_SOLICITANTES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAcciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ACCIONES", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					AccionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Acciones filterAcciones, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACCIONES t1
		// ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");
		List<String> from = new ArrayList<String>();
		from.add("ACCIONES");
		from.add("TIPOS_ACTIVIDAD");
		from.add("ENTIDADES_SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAcciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ACCIONES",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Acciones>>
	 */
	@Override
	public List<TableRowDto<Acciones>> findAllChild(Acciones filterAcciones, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ACCIONES t1
		// ,TIPOS_ACTIVIDAD t2 ,ENTIDADES_SOLICITANTES t3 ");
		List<String> from = new ArrayList<String>();
		from.add("ACCIONES");
		from.add("TIPOS_ACTIVIDAD");
		from.add("ENTIDADES_SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAcciones, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_ACCIONES",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Acciones>(this.rwMapPK, "ID_ACCIONES"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Acciones entity
	 *
	 * @param acciones
	 *            Acciones Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Acciones acciones) {

		StringBuilder where = new StringBuilder(AccionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (acciones != null && acciones.getIdAcciones() != null) {
			where.append(" AND t1.ID_ACCIONES = ?");
			params.add(acciones.getIdAcciones());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getIdTipoActividad() != null) {
			where.append(" AND t2.ID_TIPO_ACTIVIDAD = ?");
			params.add(acciones.getTiposActividad().getIdTipoActividad());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(acciones.getTiposActividad().getDescripcionCastellano());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(acciones.getTiposActividad().getDescripcionEuskera());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getLimiteActividad() != null) {
			where.append(" AND t2.LIMITE_ACTIVIDAD = ?");
			params.add(acciones.getTiposActividad().getLimiteActividad());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getMaximoHora() != null) {
			where.append(" AND t2.MAXIMO_HORA = ?");
			params.add(acciones.getTiposActividad().getMaximoHora());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getLimiteContratacion() != null) {
			where.append(" AND t2.LIMITE_CONTRATACION = ?");
			params.add(acciones.getTiposActividad().getLimiteContratacion());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getLimiteResto() != null) {
			where.append(" AND t2.LIMITE_RESTO = ?");
			params.add(acciones.getTiposActividad().getLimiteResto());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(acciones.getTiposActividad().getFechaRegistro());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(acciones.getTiposActividad().getUsuarioRegistro());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			where.append(" AND t3.ID_ENTIDAD_SOLICITANTE = ?");
			params.add(acciones.getEntidadesSolicitantes().getIdEntidadSolicitante());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getTiposAsociacion() != null
				&& acciones.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion() != null) {
			where.append(" AND t3.ID_TIPO_ASOCIACION = ?");
			params.add(acciones.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getOrganoDirectivoMujeres() != null) {
			where.append(" AND t3.ORGANO_DIRECTIVO_MUJERES = ?");
			params.add(acciones.getEntidadesSolicitantes().getOrganoDirectivoMujeres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getOrganoDirectivoHombres() != null) {
			where.append(" AND t3.ORGANO_DIRECTIVO_HOMBRES = ?");
			params.add(acciones.getEntidadesSolicitantes().getOrganoDirectivoHombres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getAntiguedadEntidad() != null) {
			where.append(" AND t3.ANTIGUEDAD_ENTIDAD = ?");
			params.add(acciones.getEntidadesSolicitantes().getAntiguedadEntidad());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getNSociosTotal() != null) {
			where.append(" AND t3.N_SOCIOS_TOTAL = ?");
			params.add(acciones.getEntidadesSolicitantes().getNSociosTotal());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getNSociosMujeres() != null) {
			where.append(" AND t3.N_SOCIOS_MUJERES = ?");
			params.add(acciones.getEntidadesSolicitantes().getNSociosMujeres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getNSociosHombres() != null) {
			where.append(" AND t3.N_SOCIOS_HOMBRES = ?");
			params.add(acciones.getEntidadesSolicitantes().getNSociosHombres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(acciones.getEntidadesSolicitantes().getFechaRegistro());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(acciones.getEntidadesSolicitantes().getUsuarioRegistro());
		}
		if (acciones != null && acciones.getTitulo() != null) {
			where.append(" AND t1.TITULO = ?");
			params.add(acciones.getTitulo());
		}
		if (acciones != null && acciones.getPonentes() != null) {
			where.append(" AND t1.PONENTES = ?");
			params.add(acciones.getPonentes());
		}
		if (acciones != null && acciones.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(acciones.getFechaInicio());
		}
		if (acciones != null && acciones.getFechaFin() != null) {
			where.append(" AND t1.FECHA_FIN = ?");
			params.add(acciones.getFechaFin());
		}
		if (acciones != null && acciones.getDuracion() != null) {
			where.append(" AND t1.DURACION = ?");
			params.add(acciones.getDuracion());
		}
		if (acciones != null && acciones.getNEmpresasComerciales() != null) {
			where.append(" AND t1.N_EMPRESAS_COMERCIALES = ?");
			params.add(acciones.getNEmpresasComerciales());
		}
		if (acciones != null && acciones.getNEmpresasAsistentes() != null) {
			where.append(" AND t1.N_EMPRESAS_ASISTENTES = ?");
			params.add(acciones.getNEmpresasAsistentes());
		}
		if (acciones != null && acciones.getContratacion() != null) {
			where.append(" AND t1.CONTRATACION = ?");
			params.add(acciones.getContratacion());
		}
		if (acciones != null && acciones.getContratacionAdmitida() != null) {
			where.append(" AND t1.CONTRATACION_ADMITIDA = ?");
			params.add(acciones.getContratacionAdmitida());
		}
		if (acciones != null && acciones.getActPublicidad() != null) {
			where.append(" AND t1.ACT_PUBLICIDAD = ?");
			params.add(acciones.getActPublicidad());
		}
		if (acciones != null && acciones.getActPublicidadAdmitida() != null) {
			where.append(" AND t1.ACT_PUBLICIDAD_ADMITIDA = ?");
			params.add(acciones.getActPublicidadAdmitida());
		}
		if (acciones != null && acciones.getActMailing() != null) {
			where.append(" AND t1.ACT_MAILING = ?");
			params.add(acciones.getActMailing());
		}
		if (acciones != null && acciones.getActMailingAdmitido() != null) {
			where.append(" AND t1.ACT_MAILING_ADMITIDO = ?");
			params.add(acciones.getActMailingAdmitido());
		}
		if (acciones != null && acciones.getActImpresion() != null) {
			where.append(" AND t1.ACT_IMPRESION = ?");
			params.add(acciones.getActImpresion());
		}
		if (acciones != null && acciones.getActImpresionAdmitida() != null) {
			where.append(" AND t1.ACT_IMPRESION_ADMITIDA = ?");
			params.add(acciones.getActImpresionAdmitida());
		}
		if (acciones != null && acciones.getActDivulgacion() != null) {
			where.append(" AND t1.ACT_DIVULGACION = ?");
			params.add(acciones.getActDivulgacion());
		}
		if (acciones != null && acciones.getActDivulgacionAdmitida() != null) {
			where.append(" AND t1.ACT_DIVULGACION_ADMITIDA = ?");
			params.add(acciones.getActDivulgacionAdmitida());
		}
		if (acciones != null && acciones.getActDistribucion() != null) {
			where.append(" AND t1.ACT_DISTRIBUCION = ?");
			params.add(acciones.getActDistribucion());
		}
		if (acciones != null && acciones.getActDistribucionAdmitida() != null) {
			where.append(" AND t1.ACT_DISTRIBUCION_ADMITIDA = ?");
			params.add(acciones.getActDistribucionAdmitida());
		}
		if (acciones != null && acciones.getActOtros() != null) {
			where.append(" AND t1.ACT_OTROS = ?");
			params.add(acciones.getActOtros());
		}
		if (acciones != null && acciones.getActOtrosAdmitidos() != null) {
			where.append(" AND t1.ACT_OTROS_ADMITIDOS = ?");
			params.add(acciones.getActOtrosAdmitidos());
		}
		if (acciones != null && acciones.getGasFotocopias() != null) {
			where.append(" AND t1.GAS_FOTOCOPIAS = ?");
			params.add(acciones.getGasFotocopias());
		}
		if (acciones != null && acciones.getGasFotocopiasAdmitido() != null) {
			where.append(" AND t1.GAS_FOTOCOPIAS_ADMITIDO = ?");
			params.add(acciones.getGasFotocopiasAdmitido());
		}
		if (acciones != null && acciones.getGasMaterial() != null) {
			where.append(" AND t1.GAS_MATERIAL = ?");
			params.add(acciones.getGasMaterial());
		}
		if (acciones != null && acciones.getGasMaterialAdmitida() != null) {
			where.append(" AND t1.GAS_MATERIAL_ADMITIDA = ?");
			params.add(acciones.getGasMaterialAdmitida());
		}
		if (acciones != null && acciones.getGasDocumentacion() != null) {
			where.append(" AND t1.GAS_DOCUMENTACION = ?");
			params.add(acciones.getGasDocumentacion());
		}
		if (acciones != null && acciones.getGasDocumentacionAdmitida() != null) {
			where.append(" AND t1.GAS_DOCUMENTACION_ADMITIDA = ?");
			params.add(acciones.getGasDocumentacionAdmitida());
		}
		if (acciones != null && acciones.getGasAlquiler() != null) {
			where.append(" AND t1.GAS_ALQUILER = ?");
			params.add(acciones.getGasAlquiler());
		}
		if (acciones != null && acciones.getGasAlquilerAdmitido() != null) {
			where.append(" AND t1.GAS_ALQUILER_ADMITIDO = ?");
			params.add(acciones.getGasAlquilerAdmitido());
		}
		if (acciones != null && acciones.getGasOtros() != null) {
			where.append(" AND t1.GAS_OTROS = ?");
			params.add(acciones.getGasOtros());
		}
		if (acciones != null && acciones.getGasOtrosAdmitidos() != null) {
			where.append(" AND t1.GAS_OTROS_ADMITIDOS = ?");
			params.add(acciones.getGasOtrosAdmitidos());
		}
		if (acciones != null && acciones.getGasAlojamiento() != null) {
			where.append(" AND t1.GAS_ALOJAMIENTO = ?");
			params.add(acciones.getGasAlojamiento());
		}
		if (acciones != null && acciones.getGasAlojamientoAdmitido() != null) {
			where.append(" AND t1.GAS_ALOJAMIENTO_ADMITIDO = ?");
			params.add(acciones.getGasAlojamientoAdmitido());
		}
		if (acciones != null && acciones.getGasTraslado() != null) {
			where.append(" AND t1.GAS_TRASLADO = ?");
			params.add(acciones.getGasTraslado());
		}
		if (acciones != null && acciones.getGasTrasladoAdmitido() != null) {
			where.append(" AND t1.GAS_TRASLADO_ADMITIDO = ?");
			params.add(acciones.getGasTrasladoAdmitido());
		}
		if (acciones != null && acciones.getGasManutencion() != null) {
			where.append(" AND t1.GAS_MANUTENCION = ?");
			params.add(acciones.getGasManutencion());
		}
		if (acciones != null && acciones.getGasManutencionAdmitido() != null) {
			where.append(" AND t1.GAS_MANUTENCION_ADMITIDO = ?");
			params.add(acciones.getGasManutencionAdmitido());
		}
		if (acciones != null && acciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(acciones.getFechaRegistro());
		}
		if (acciones != null && acciones.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(acciones.getUsuarioRegistro());
		}
		if (acciones != null && acciones.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(acciones.getFechaUltmodificacion());
		}
		if (acciones != null && acciones.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(acciones.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Acciones entity
	 *
	 * @param acciones
	 *            Acciones Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Acciones acciones, Boolean startsWith) {

		StringBuilder where = new StringBuilder(AccionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (acciones != null && acciones.getIdAcciones() != null) {
			where.append(" AND t1.ID_ACCIONES = ?");
			params.add(acciones.getIdAcciones());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getIdTipoActividad() != null) {
			where.append(" AND t2.ID_TIPO_ACTIVIDAD = ?");
			params.add(acciones.getTiposActividad().getIdTipoActividad());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getTiposActividad().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getTiposActividad().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getTiposActividad().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getTiposActividad().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getLimiteActividad() != null) {
			where.append(" AND t2.LIMITE_ACTIVIDAD = ?");
			params.add(acciones.getTiposActividad().getLimiteActividad());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getMaximoHora() != null) {
			where.append(" AND t2.MAXIMO_HORA = ?");
			params.add(acciones.getTiposActividad().getMaximoHora());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getLimiteContratacion() != null) {
			where.append(" AND t2.LIMITE_CONTRATACION = ?");
			params.add(acciones.getTiposActividad().getLimiteContratacion());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getLimiteResto() != null) {
			where.append(" AND t2.LIMITE_RESTO = ?");
			params.add(acciones.getTiposActividad().getLimiteResto());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(acciones.getTiposActividad().getFechaRegistro());
		}
		if (acciones != null && acciones.getTiposActividad() != null
				&& acciones.getTiposActividad().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getTiposActividad().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getTiposActividad().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			where.append(" AND t3.ID_ENTIDAD_SOLICITANTE = ?");
			params.add(acciones.getEntidadesSolicitantes().getIdEntidadSolicitante());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getTiposAsociacion() != null
				&& acciones.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion() != null) {
			where.append(" AND t3.ID_TIPO_ASOCIACION = ?");
			params.add(acciones.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getOrganoDirectivoMujeres() != null) {
			where.append(" AND t3.ORGANO_DIRECTIVO_MUJERES = ?");
			params.add(acciones.getEntidadesSolicitantes().getOrganoDirectivoMujeres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getOrganoDirectivoHombres() != null) {
			where.append(" AND t3.ORGANO_DIRECTIVO_HOMBRES = ?");
			params.add(acciones.getEntidadesSolicitantes().getOrganoDirectivoHombres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getAntiguedadEntidad() != null) {
			where.append(" AND t3.ANTIGUEDAD_ENTIDAD = ?");
			params.add(acciones.getEntidadesSolicitantes().getAntiguedadEntidad());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getNSociosTotal() != null) {
			where.append(" AND t3.N_SOCIOS_TOTAL = ?");
			params.add(acciones.getEntidadesSolicitantes().getNSociosTotal());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getNSociosMujeres() != null) {
			where.append(" AND t3.N_SOCIOS_MUJERES = ?");
			params.add(acciones.getEntidadesSolicitantes().getNSociosMujeres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getNSociosHombres() != null) {
			where.append(" AND t3.N_SOCIOS_HOMBRES = ?");
			params.add(acciones.getEntidadesSolicitantes().getNSociosHombres());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(acciones.getEntidadesSolicitantes().getFechaRegistro());
		}
		if (acciones != null && acciones.getEntidadesSolicitantes() != null
				&& acciones.getEntidadesSolicitantes().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getEntidadesSolicitantes().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getEntidadesSolicitantes().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (acciones != null && acciones.getTitulo() != null) {
			where.append(" AND UPPER(t1.TITULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getTitulo().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getTitulo().toUpperCase() + "%");
			}
			where.append(" AND t1.TITULO IS NOT NULL");
		}
		if (acciones != null && acciones.getPonentes() != null) {
			where.append(" AND UPPER(t1.PONENTES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getPonentes().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getPonentes().toUpperCase() + "%");
			}
			where.append(" AND t1.PONENTES IS NOT NULL");
		}
		if (acciones != null && acciones.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(acciones.getFechaInicio());
		}
		if (acciones != null && acciones.getFechaFin() != null) {
			where.append(" AND t1.FECHA_FIN = ?");
			params.add(acciones.getFechaFin());
		}
		if (acciones != null && acciones.getDuracion() != null) {
			where.append(" AND t1.DURACION = ?");
			params.add(acciones.getDuracion());
		}
		if (acciones != null && acciones.getNEmpresasComerciales() != null) {
			where.append(" AND t1.N_EMPRESAS_COMERCIALES = ?");
			params.add(acciones.getNEmpresasComerciales());
		}
		if (acciones != null && acciones.getNEmpresasAsistentes() != null) {
			where.append(" AND t1.N_EMPRESAS_ASISTENTES = ?");
			params.add(acciones.getNEmpresasAsistentes());
		}
		if (acciones != null && acciones.getContratacion() != null) {
			where.append(" AND t1.CONTRATACION = ?");
			params.add(acciones.getContratacion());
		}
		if (acciones != null && acciones.getContratacionAdmitida() != null) {
			where.append(" AND t1.CONTRATACION_ADMITIDA = ?");
			params.add(acciones.getContratacionAdmitida());
		}
		if (acciones != null && acciones.getActPublicidad() != null) {
			where.append(" AND t1.ACT_PUBLICIDAD = ?");
			params.add(acciones.getActPublicidad());
		}
		if (acciones != null && acciones.getActPublicidadAdmitida() != null) {
			where.append(" AND t1.ACT_PUBLICIDAD_ADMITIDA = ?");
			params.add(acciones.getActPublicidadAdmitida());
		}
		if (acciones != null && acciones.getActMailing() != null) {
			where.append(" AND t1.ACT_MAILING = ?");
			params.add(acciones.getActMailing());
		}
		if (acciones != null && acciones.getActMailingAdmitido() != null) {
			where.append(" AND t1.ACT_MAILING_ADMITIDO = ?");
			params.add(acciones.getActMailingAdmitido());
		}
		if (acciones != null && acciones.getActImpresion() != null) {
			where.append(" AND t1.ACT_IMPRESION = ?");
			params.add(acciones.getActImpresion());
		}
		if (acciones != null && acciones.getActImpresionAdmitida() != null) {
			where.append(" AND t1.ACT_IMPRESION_ADMITIDA = ?");
			params.add(acciones.getActImpresionAdmitida());
		}
		if (acciones != null && acciones.getActDivulgacion() != null) {
			where.append(" AND t1.ACT_DIVULGACION = ?");
			params.add(acciones.getActDivulgacion());
		}
		if (acciones != null && acciones.getActDivulgacionAdmitida() != null) {
			where.append(" AND t1.ACT_DIVULGACION_ADMITIDA = ?");
			params.add(acciones.getActDivulgacionAdmitida());
		}
		if (acciones != null && acciones.getActDistribucion() != null) {
			where.append(" AND t1.ACT_DISTRIBUCION = ?");
			params.add(acciones.getActDistribucion());
		}
		if (acciones != null && acciones.getActDistribucionAdmitida() != null) {
			where.append(" AND t1.ACT_DISTRIBUCION_ADMITIDA = ?");
			params.add(acciones.getActDistribucionAdmitida());
		}
		if (acciones != null && acciones.getActOtros() != null) {
			where.append(" AND t1.ACT_OTROS = ?");
			params.add(acciones.getActOtros());
		}
		if (acciones != null && acciones.getActOtrosAdmitidos() != null) {
			where.append(" AND t1.ACT_OTROS_ADMITIDOS = ?");
			params.add(acciones.getActOtrosAdmitidos());
		}
		if (acciones != null && acciones.getGasFotocopias() != null) {
			where.append(" AND t1.GAS_FOTOCOPIAS = ?");
			params.add(acciones.getGasFotocopias());
		}
		if (acciones != null && acciones.getGasFotocopiasAdmitido() != null) {
			where.append(" AND t1.GAS_FOTOCOPIAS_ADMITIDO = ?");
			params.add(acciones.getGasFotocopiasAdmitido());
		}
		if (acciones != null && acciones.getGasMaterial() != null) {
			where.append(" AND t1.GAS_MATERIAL = ?");
			params.add(acciones.getGasMaterial());
		}
		if (acciones != null && acciones.getGasMaterialAdmitida() != null) {
			where.append(" AND t1.GAS_MATERIAL_ADMITIDA = ?");
			params.add(acciones.getGasMaterialAdmitida());
		}
		if (acciones != null && acciones.getGasDocumentacion() != null) {
			where.append(" AND t1.GAS_DOCUMENTACION = ?");
			params.add(acciones.getGasDocumentacion());
		}
		if (acciones != null && acciones.getGasDocumentacionAdmitida() != null) {
			where.append(" AND t1.GAS_DOCUMENTACION_ADMITIDA = ?");
			params.add(acciones.getGasDocumentacionAdmitida());
		}
		if (acciones != null && acciones.getGasAlquiler() != null) {
			where.append(" AND t1.GAS_ALQUILER = ?");
			params.add(acciones.getGasAlquiler());
		}
		if (acciones != null && acciones.getGasAlquilerAdmitido() != null) {
			where.append(" AND t1.GAS_ALQUILER_ADMITIDO = ?");
			params.add(acciones.getGasAlquilerAdmitido());
		}
		if (acciones != null && acciones.getGasOtros() != null) {
			where.append(" AND t1.GAS_OTROS = ?");
			params.add(acciones.getGasOtros());
		}
		if (acciones != null && acciones.getGasOtrosAdmitidos() != null) {
			where.append(" AND t1.GAS_OTROS_ADMITIDOS = ?");
			params.add(acciones.getGasOtrosAdmitidos());
		}
		if (acciones != null && acciones.getGasAlojamiento() != null) {
			where.append(" AND t1.GAS_ALOJAMIENTO = ?");
			params.add(acciones.getGasAlojamiento());
		}
		if (acciones != null && acciones.getGasAlojamientoAdmitido() != null) {
			where.append(" AND t1.GAS_ALOJAMIENTO_ADMITIDO = ?");
			params.add(acciones.getGasAlojamientoAdmitido());
		}
		if (acciones != null && acciones.getGasTraslado() != null) {
			where.append(" AND t1.GAS_TRASLADO = ?");
			params.add(acciones.getGasTraslado());
		}
		if (acciones != null && acciones.getGasTrasladoAdmitido() != null) {
			where.append(" AND t1.GAS_TRASLADO_ADMITIDO = ?");
			params.add(acciones.getGasTrasladoAdmitido());
		}
		if (acciones != null && acciones.getGasManutencion() != null) {
			where.append(" AND t1.GAS_MANUTENCION = ?");
			params.add(acciones.getGasManutencion());
		}
		if (acciones != null && acciones.getGasManutencionAdmitido() != null) {
			where.append(" AND t1.GAS_MANUTENCION_ADMITIDO = ?");
			params.add(acciones.getGasManutencionAdmitido());
		}
		if (acciones != null && acciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(acciones.getFechaRegistro());
		}
		if (acciones != null && acciones.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (acciones != null && acciones.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(acciones.getFechaUltmodificacion());
		}
		if (acciones != null && acciones.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(acciones.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + acciones.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
