package com.ejie.ab60.dao.DIV;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DIV.EntidadesSolicitantes;
import com.ejie.ab60.model.DIV.TiposAsociacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * EntidadesSolicitantesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class EntidadesSolicitantesDaoImpl implements EntidadesSolicitantesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDENTIDADSOLICITANTE", "ORGANODIRECTIVOMUJERES",
			"ORGANODIRECTIVOHOMBRES", "ANTIGUEDADENTIDAD", "NSOCIOSTOTAL", "NSOCIOSMUJERES", "NSOCIOSHOMBRES",
			"FECHAREGISTRO", "USUARIOREGISTRO", "TIPOSASOCIACIONIDTIPOASOCIACION",
			"TIPOSASOCIACIONDESCRIPCIONCASTELLANO", "TIPOSASOCIACIONDESCRIPCIONEUSKERA", "TIPOSASOCIACIONFECHAREGISTRO",
			"TIPOSASOCIACIONUSUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<EntidadesSolicitantes> rwMap = new RowMapper<EntidadesSolicitantes>() {
		public EntidadesSolicitantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EntidadesSolicitantes(resultSet.getInt("IDENTIDADSOLICITANTE"),
					resultSet.getLong("ORGANODIRECTIVOMUJERES"), resultSet.getLong("ORGANODIRECTIVOHOMBRES"),
					resultSet.getLong("ANTIGUEDADENTIDAD"), resultSet.getLong("NSOCIOSTOTAL"),
					resultSet.getLong("NSOCIOSMUJERES"), resultSet.getLong("NSOCIOSHOMBRES"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new TiposAsociacion(resultSet.getLong("TiposAsociacionIDTIPOASOCIACION"),
							resultSet.getString("TiposAsociacionDESCRIPCIONCASTELLANO"),
							resultSet.getString("TiposAsociacionDESCRIPCIONEUSKERA"),
							resultSet.getDate("TiposAsociacionFECHAREGISTRO"),
							resultSet.getString("TiposAsociacionUSUARIOREGISTRO")));
		}
	};

	private RowMapper<EntidadesSolicitantes> rwMapPK = new RowMapper<EntidadesSolicitantes>() {
		public EntidadesSolicitantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EntidadesSolicitantes(resultSet.getInt("IDENTIDADSOLICITANTE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<EntidadesSolicitantes>> rwMapJerarquia = new RowMapper<JerarquiaDto<EntidadesSolicitantes>>() {
		public JerarquiaDto<EntidadesSolicitantes> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			EntidadesSolicitantes entidadessolicitantes = new EntidadesSolicitantes(
					resultSet.getInt("IDENTIDADSOLICITANTE"), resultSet.getLong("ORGANODIRECTIVOMUJERES"),
					resultSet.getLong("ORGANODIRECTIVOHOMBRES"), resultSet.getLong("ANTIGUEDADENTIDAD"),
					resultSet.getLong("NSOCIOSTOTAL"), resultSet.getLong("NSOCIOSMUJERES"),
					resultSet.getLong("NSOCIOSHOMBRES"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new TiposAsociacion(resultSet.getLong("TiposAsociacionIDTIPOASOCIACION"),
							resultSet.getString("TiposAsociacionDESCRIPCIONCASTELLANO"),
							resultSet.getString("TiposAsociacionDESCRIPCIONEUSKERA"),
							resultSet.getDate("TiposAsociacionFECHAREGISTRO"),
							resultSet.getString("TiposAsociacionUSUARIOREGISTRO")));

			JerarquiaDto<EntidadesSolicitantes> jerarquia = new JerarquiaDto<EntidadesSolicitantes>();
			jerarquia.setModel(entidadessolicitantes);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the EntidadesSolicitantes table.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @return EntidadesSolicitantes
	 */
	public EntidadesSolicitantes add(EntidadesSolicitantes entidadessolicitantes) {
		String query = "INSERT INTO ENTIDADES_SOLICITANTES (ID_ENTIDAD_SOLICITANTE, ID_TIPO_ASOCIACION, ORGANO_DIRECTIVO_MUJERES, ORGANO_DIRECTIVO_HOMBRES, ANTIGUEDAD_ENTIDAD, N_SOCIOS_TOTAL, N_SOCIOS_MUJERES, N_SOCIOS_HOMBRES, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?,?)";
		Object getTiposAsociacionIdTipoAsociacionAux = null;
		if (entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion() != null) {
			getTiposAsociacionIdTipoAsociacionAux = entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion();
		}
		this.jdbcTemplate.update(query, entidadessolicitantes.getIdEntidadSolicitante(),
				getTiposAsociacionIdTipoAsociacionAux, entidadessolicitantes.getOrganoDirectivoMujeres(),
				entidadessolicitantes.getOrganoDirectivoHombres(), entidadessolicitantes.getAntiguedadEntidad(),
				entidadessolicitantes.getNSociosTotal(), entidadessolicitantes.getNSociosMujeres(),
				entidadessolicitantes.getNSociosHombres(), entidadessolicitantes.getFechaRegistro(),
				entidadessolicitantes.getUsuarioRegistro());
		return entidadessolicitantes;
	}

	/**
	 * Updates a single row in the EntidadesSolicitantes table.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @return EntidadesSolicitantes
	 */
	public EntidadesSolicitantes update(EntidadesSolicitantes entidadessolicitantes) {
		String query = "UPDATE ENTIDADES_SOLICITANTES SET ID_TIPO_ASOCIACION=?, ORGANO_DIRECTIVO_MUJERES=?, ORGANO_DIRECTIVO_HOMBRES=?, ANTIGUEDAD_ENTIDAD=?, N_SOCIOS_TOTAL=?, N_SOCIOS_MUJERES=?, N_SOCIOS_HOMBRES=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_ENTIDAD_SOLICITANTE=?";
		Object getTiposAsociacionIdTipoAsociacionAux = null;
		if (entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion() != null) {
			getTiposAsociacionIdTipoAsociacionAux = entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion();
		}
		this.jdbcTemplate.update(query, getTiposAsociacionIdTipoAsociacionAux,
				entidadessolicitantes.getOrganoDirectivoMujeres(), entidadessolicitantes.getOrganoDirectivoHombres(),
				entidadessolicitantes.getAntiguedadEntidad(), entidadessolicitantes.getNSociosTotal(),
				entidadessolicitantes.getNSociosMujeres(), entidadessolicitantes.getNSociosHombres(),
				entidadessolicitantes.getFechaRegistro(), entidadessolicitantes.getUsuarioRegistro(),
				entidadessolicitantes.getIdEntidadSolicitante());
		return entidadessolicitantes;
	}

	/**
	 * Finds a single row in the EntidadesSolicitantes table.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @return EntidadesSolicitantes
	 */
	@Transactional(readOnly = true)
	public EntidadesSolicitantes find(EntidadesSolicitantes entidadessolicitantes) {
		String query = "SELECT t1.ID_ENTIDAD_SOLICITANTE IDENTIDADSOLICITANTE, t1.ORGANO_DIRECTIVO_MUJERES ORGANODIRECTIVOMUJERES, t1.ORGANO_DIRECTIVO_HOMBRES ORGANODIRECTIVOHOMBRES, t1.ANTIGUEDAD_ENTIDAD ANTIGUEDADENTIDAD, t1.N_SOCIOS_TOTAL NSOCIOSTOTAL, t1.N_SOCIOS_MUJERES NSOCIOSMUJERES, t1.N_SOCIOS_HOMBRES NSOCIOSHOMBRES, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_TIPO_ASOCIACION TIPOSASOCIACIONIDTIPOASOCIACION, t2.DESCRIPCION_CASTELLANO TIPOSASOCIACIONDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA TIPOSASOCIACIONDESCRIPCIONEUSKERA, t2.FECHA_REGISTRO TIPOSASOCIACIONFECHAREGISTRO, t2.USUARIO_REGISTRO TIPOSASOCIACIONUSUARIOREGISTRO FROM ENTIDADES_SOLICITANTES t1 , TIPOS_ASOCIACION t2  WHERE t1.ID_ENTIDAD_SOLICITANTE = ?   AND t1.ID_TIPO_ASOCIACION= t2.ID_TIPO_ASOCIACION(+)";

		List<EntidadesSolicitantes> entidadessolicitantesList = this.jdbcTemplate.query(query, this.rwMap,
				entidadessolicitantes.getIdEntidadSolicitante());
		return (EntidadesSolicitantes) DataAccessUtils.uniqueResult(entidadessolicitantesList);
	}

	/**
	 * Removes a single row in the EntidadesSolicitantes table.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @return
	 */
	public void remove(EntidadesSolicitantes entidadessolicitantes) {
		String query = "DELETE FROM ENTIDADES_SOLICITANTES WHERE ID_ENTIDAD_SOLICITANTE=?";
		this.jdbcTemplate.update(query, entidadessolicitantes.getIdEntidadSolicitante());
	}

	/**
	 * Finds a list of rows in the EntidadesSolicitantes table.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<EntidadesSolicitantes>
	 */
	@Transactional(readOnly = true)
	public List<EntidadesSolicitantes> findAll(EntidadesSolicitantes entidadessolicitantes,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ENTIDAD_SOLICITANTE IDENTIDADSOLICITANTE,t1.ORGANO_DIRECTIVO_MUJERES ORGANODIRECTIVOMUJERES,t1.ORGANO_DIRECTIVO_HOMBRES ORGANODIRECTIVOHOMBRES,t1.ANTIGUEDAD_ENTIDAD ANTIGUEDADENTIDAD,t1.N_SOCIOS_TOTAL NSOCIOSTOTAL,t1.N_SOCIOS_MUJERES NSOCIOSMUJERES,t1.N_SOCIOS_HOMBRES NSOCIOSHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_ASOCIACION TIPOSASOCIACIONIDTIPOASOCIACION,t2.DESCRIPCION_CASTELLANO TIPOSASOCIACIONDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSASOCIACIONDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSASOCIACIONFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSASOCIACIONUSUARIOREGISTRO ");
		query.append("FROM ENTIDADES_SOLICITANTES t1 ,TIPOS_ASOCIACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(entidadessolicitantes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_ASOCIACION= t2.ID_TIPO_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EntidadesSolicitantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EntidadesSolicitantes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the EntidadesSolicitantes table using like.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<EntidadesSolicitantes>
	 */
	@Transactional(readOnly = true)
	public List<EntidadesSolicitantes> findAllLike(EntidadesSolicitantes entidadessolicitantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ENTIDAD_SOLICITANTE IDENTIDADSOLICITANTE,t1.ORGANO_DIRECTIVO_MUJERES ORGANODIRECTIVOMUJERES,t1.ORGANO_DIRECTIVO_HOMBRES ORGANODIRECTIVOHOMBRES,t1.ANTIGUEDAD_ENTIDAD ANTIGUEDADENTIDAD,t1.N_SOCIOS_TOTAL NSOCIOSTOTAL,t1.N_SOCIOS_MUJERES NSOCIOSMUJERES,t1.N_SOCIOS_HOMBRES NSOCIOSHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_ASOCIACION TIPOSASOCIACIONIDTIPOASOCIACION,t2.DESCRIPCION_CASTELLANO TIPOSASOCIACIONDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSASOCIACIONDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSASOCIACIONFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSASOCIACIONUSUARIOREGISTRO ");
		query.append("FROM ENTIDADES_SOLICITANTES t1 ,TIPOS_ASOCIACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(entidadessolicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_ASOCIACION= t2.ID_TIPO_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EntidadesSolicitantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EntidadesSolicitantes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the EntidadesSolicitantes table.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(EntidadesSolicitantes entidadessolicitantes) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ENTIDADES_SOLICITANTES t1 , TIPOS_ASOCIACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(entidadessolicitantes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_ASOCIACION= t2.ID_TIPO_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the EntidadesSolicitantes table using like.
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(EntidadesSolicitantes entidadessolicitantes, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ENTIDADES_SOLICITANTES t1 ,TIPOS_ASOCIACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(entidadessolicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_ASOCIACION= t2.ID_TIPO_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of EntidadesSolicitantes selected for rup_table
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EntidadesSolicitantes>>
	 */
	@Override
	public List<TableRowDto<EntidadesSolicitantes>> reorderSelection(EntidadesSolicitantes entidadessolicitantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_SOLICITANTE IDENTIDADSOLICITANTE,t1.ORGANO_DIRECTIVO_MUJERES ORGANODIRECTIVOMUJERES,t1.ORGANO_DIRECTIVO_HOMBRES ORGANODIRECTIVOHOMBRES,t1.ANTIGUEDAD_ENTIDAD ANTIGUEDADENTIDAD,t1.N_SOCIOS_TOTAL NSOCIOSTOTAL,t1.N_SOCIOS_MUJERES NSOCIOSMUJERES,t1.N_SOCIOS_HOMBRES NSOCIOSHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_ASOCIACION TIPOSASOCIACIONIDTIPOASOCIACION,t2.DESCRIPCION_CASTELLANO TIPOSASOCIACIONDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSASOCIACIONDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSASOCIACIONFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSASOCIACIONUSUARIOREGISTRO ");
		// FROM
		query.append("FROM ENTIDADES_SOLICITANTES t1 ,TIPOS_ASOCIACION t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(entidadessolicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_ASOCIACION= t2.ID_TIPO_ASOCIACION(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				EntidadesSolicitantes.class, filterParamList, "ID_ENTIDAD_SOLICITANTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EntidadesSolicitantes>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            EntidadesSolicitantes
	 * @param searchParams
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EntidadesSolicitantes>>
	 */
	@Override
	public List<TableRowDto<EntidadesSolicitantes>> search(EntidadesSolicitantes filterParams,
			EntidadesSolicitantes searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_SOLICITANTE IDENTIDADSOLICITANTE,t1.ORGANO_DIRECTIVO_MUJERES ORGANODIRECTIVOMUJERES,t1.ORGANO_DIRECTIVO_HOMBRES ORGANODIRECTIVOHOMBRES,t1.ANTIGUEDAD_ENTIDAD ANTIGUEDADENTIDAD,t1.N_SOCIOS_TOTAL NSOCIOSTOTAL,t1.N_SOCIOS_MUJERES NSOCIOSMUJERES,t1.N_SOCIOS_HOMBRES NSOCIOSHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_ASOCIACION TIPOSASOCIACIONIDTIPOASOCIACION,t2.DESCRIPCION_CASTELLANO TIPOSASOCIACIONDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSASOCIACIONDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSASOCIACIONFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSASOCIACIONUSUARIOREGISTRO ");
		// FROM
		query.append("FROM ENTIDADES_SOLICITANTES t1 ,TIPOS_ASOCIACION t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_ASOCIACION= t2.ID_TIPO_ASOCIACION(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				EntidadesSolicitantes.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_ENTIDAD_SOLICITANTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EntidadesSolicitantes>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterentidadessolicitantes
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(EntidadesSolicitantes filterentidadessolicitantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_SOLICITANTE IDENTIDADSOLICITANTE,t1.ORGANO_DIRECTIVO_MUJERES ORGANODIRECTIVOMUJERES,t1.ORGANO_DIRECTIVO_HOMBRES ORGANODIRECTIVOHOMBRES,t1.ANTIGUEDAD_ENTIDAD ANTIGUEDADENTIDAD,t1.N_SOCIOS_TOTAL NSOCIOSTOTAL,t1.N_SOCIOS_MUJERES NSOCIOSMUJERES,t1.N_SOCIOS_HOMBRES NSOCIOSHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_ASOCIACION TIPOSASOCIACIONIDTIPOASOCIACION,t2.DESCRIPCION_CASTELLANO TIPOSASOCIACIONDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSASOCIACIONDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSASOCIACIONFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSASOCIACIONUSUARIOREGISTRO ");
		// FROM
		query.append("FROM ENTIDADES_SOLICITANTES t1 ,TIPOS_ASOCIACION t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterentidadessolicitantes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				EntidadesSolicitantes.class, query, params, "ID_ENTIDAD_SOLICITANTE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical EntidadesSolicitantes table.
	 *
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<EntidadesSolicitantes>>
	 */
	@Override
	public List<JerarquiaDto<EntidadesSolicitantes>> findAllLikeJerarquia(
			EntidadesSolicitantes filterEntidadesSolicitantes, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_SOLICITANTE IDENTIDADSOLICITANTE,t1.ORGANO_DIRECTIVO_MUJERES ORGANODIRECTIVOMUJERES,t1.ORGANO_DIRECTIVO_HOMBRES ORGANODIRECTIVOHOMBRES,t1.ANTIGUEDAD_ENTIDAD ANTIGUEDADENTIDAD,t1.N_SOCIOS_TOTAL NSOCIOSTOTAL,t1.N_SOCIOS_MUJERES NSOCIOSMUJERES,t1.N_SOCIOS_HOMBRES NSOCIOSHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TIPO_ASOCIACION TIPOSASOCIACIONIDTIPOASOCIACION,t2.DESCRIPCION_CASTELLANO TIPOSASOCIACIONDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSASOCIACIONDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSASOCIACIONFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSASOCIACIONUSUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ENTIDADES_SOLICITANTES
		// t1 ,TIPOS_ASOCIACION t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ENTIDADES_SOLICITANTES");
		from.add("TIPOS_ASOCIACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEntidadesSolicitantes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ENTIDAD_SOLICITANTE",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					EntidadesSolicitantesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(EntidadesSolicitantes filterEntidadesSolicitantes,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ENTIDADES_SOLICITANTES
		// t1 ,TIPOS_ASOCIACION t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ENTIDADES_SOLICITANTES");
		from.add("TIPOS_ASOCIACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEntidadesSolicitantes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_ENTIDAD_SOLICITANTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<EntidadesSolicitantes>>
	 */
	@Override
	public List<TableRowDto<EntidadesSolicitantes>> findAllChild(EntidadesSolicitantes filterEntidadesSolicitantes,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ENTIDADES_SOLICITANTES
		// t1 ,TIPOS_ASOCIACION t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ENTIDADES_SOLICITANTES");
		from.add("TIPOS_ASOCIACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEntidadesSolicitantes, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_ENTIDAD_SOLICITANTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<EntidadesSolicitantes>(this.rwMapPK, "ID_ENTIDAD_SOLICITANTE"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the EntidadesSolicitantes entity
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(EntidadesSolicitantes entidadessolicitantes) {

		StringBuilder where = new StringBuilder(EntidadesSolicitantesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (entidadessolicitantes != null && entidadessolicitantes.getIdEntidadSolicitante() != null) {
			where.append(" AND t1.ID_ENTIDAD_SOLICITANTE = ?");
			params.add(entidadessolicitantes.getIdEntidadSolicitante());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion() != null) {
			where.append(" AND t2.ID_TIPO_ASOCIACION = ?");
			params.add(entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(entidadessolicitantes.getTiposAsociacion().getDescripcionCastellano());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(entidadessolicitantes.getTiposAsociacion().getDescripcionEuskera());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(entidadessolicitantes.getTiposAsociacion().getFechaRegistro());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(entidadessolicitantes.getTiposAsociacion().getUsuarioRegistro());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getOrganoDirectivoMujeres() != null) {
			where.append(" AND t1.ORGANO_DIRECTIVO_MUJERES = ?");
			params.add(entidadessolicitantes.getOrganoDirectivoMujeres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getOrganoDirectivoHombres() != null) {
			where.append(" AND t1.ORGANO_DIRECTIVO_HOMBRES = ?");
			params.add(entidadessolicitantes.getOrganoDirectivoHombres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getAntiguedadEntidad() != null) {
			where.append(" AND t1.ANTIGUEDAD_ENTIDAD = ?");
			params.add(entidadessolicitantes.getAntiguedadEntidad());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getNSociosTotal() != null) {
			where.append(" AND t1.N_SOCIOS_TOTAL = ?");
			params.add(entidadessolicitantes.getNSociosTotal());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getNSociosMujeres() != null) {
			where.append(" AND t1.N_SOCIOS_MUJERES = ?");
			params.add(entidadessolicitantes.getNSociosMujeres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getNSociosHombres() != null) {
			where.append(" AND t1.N_SOCIOS_HOMBRES = ?");
			params.add(entidadessolicitantes.getNSociosHombres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(entidadessolicitantes.getFechaRegistro());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(entidadessolicitantes.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the EntidadesSolicitantes entity
	 *
	 * @param entidadessolicitantes
	 *            EntidadesSolicitantes Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(EntidadesSolicitantes entidadessolicitantes, Boolean startsWith) {

		StringBuilder where = new StringBuilder(EntidadesSolicitantesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (entidadessolicitantes != null && entidadessolicitantes.getIdEntidadSolicitante() != null) {
			where.append(" AND t1.ID_ENTIDAD_SOLICITANTE = ?");
			params.add(entidadessolicitantes.getIdEntidadSolicitante());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion() != null) {
			where.append(" AND t2.ID_TIPO_ASOCIACION = ?");
			params.add(entidadessolicitantes.getTiposAsociacion().getIdTipoAsociacion());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(entidadessolicitantes.getTiposAsociacion().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + entidadessolicitantes.getTiposAsociacion().getDescripcionCastellano().toUpperCase()
						+ "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(entidadessolicitantes.getTiposAsociacion().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add(
						"%" + entidadessolicitantes.getTiposAsociacion().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(entidadessolicitantes.getTiposAsociacion().getFechaRegistro());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getTiposAsociacion() != null
				&& entidadessolicitantes.getTiposAsociacion().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(entidadessolicitantes.getTiposAsociacion().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + entidadessolicitantes.getTiposAsociacion().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getOrganoDirectivoMujeres() != null) {
			where.append(" AND t1.ORGANO_DIRECTIVO_MUJERES = ?");
			params.add(entidadessolicitantes.getOrganoDirectivoMujeres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getOrganoDirectivoHombres() != null) {
			where.append(" AND t1.ORGANO_DIRECTIVO_HOMBRES = ?");
			params.add(entidadessolicitantes.getOrganoDirectivoHombres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getAntiguedadEntidad() != null) {
			where.append(" AND t1.ANTIGUEDAD_ENTIDAD = ?");
			params.add(entidadessolicitantes.getAntiguedadEntidad());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getNSociosTotal() != null) {
			where.append(" AND t1.N_SOCIOS_TOTAL = ?");
			params.add(entidadessolicitantes.getNSociosTotal());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getNSociosMujeres() != null) {
			where.append(" AND t1.N_SOCIOS_MUJERES = ?");
			params.add(entidadessolicitantes.getNSociosMujeres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getNSociosHombres() != null) {
			where.append(" AND t1.N_SOCIOS_HOMBRES = ?");
			params.add(entidadessolicitantes.getNSociosHombres());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(entidadessolicitantes.getFechaRegistro());
		}
		if (entidadessolicitantes != null && entidadessolicitantes.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(entidadessolicitantes.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + entidadessolicitantes.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
