package com.ejie.ab60.dao.DIV;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DIV.EntidadesSolicitantes;
import com.ejie.ab60.model.DIV.RelExpEntSol;
import com.ejie.ab60.model.DIV.TiposAsociacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpEntSolDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelExpEntSolDaoImpl implements RelExpEntSolDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELEXPENTSOL", "IDEXPEDIENTE", "FECHAREGISTRO",
			"USUARIOREGISTRO", "ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE",
			"ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES", "ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES",
			"ENTIDADESSOLICITANTESANTIGUEDADENTIDAD", "ENTIDADESSOLICITANTESNSOCIOSTOTAL",
			"ENTIDADESSOLICITANTESNSOCIOSMUJERES", "ENTIDADESSOLICITANTESNSOCIOSHOMBRES",
			"ENTIDADESSOLICITANTESFECHAREGISTRO", "ENTIDADESSOLICITANTESUSUARIOREGISTRO",
			"ENTIDADESSOLICITANTESIDTIPOASOCIACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelExpEntSol> rwMap = new RowMapper<RelExpEntSol>() {
		public RelExpEntSol mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpEntSol(resultSet.getInt("IDRELEXPENTSOL"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new EntidadesSolicitantes(resultSet.getInt("EntidadesSolicitantesIDENTIDADSOLICITANTE"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOMUJERES"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOHOMBRES"),
							resultSet.getLong("EntidadesSolicitantesANTIGUEDADENTIDAD"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSTOTAL"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSMUJERES"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSHOMBRES"),
							resultSet.getDate("EntidadesSolicitantesFECHAREGISTRO"),
							resultSet.getString("EntidadesSolicitantesUSUARIOREGISTRO"),
							new TiposAsociacion(resultSet.getLong("EntidadesSolicitantesIDTIPOASOCIACION"), null, null,
									null, null, null)));
		}
	};

	private RowMapper<RelExpEntSol> rwMapPK = new RowMapper<RelExpEntSol>() {
		public RelExpEntSol mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpEntSol(resultSet.getInt("IDRELEXPENTSOL"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelExpEntSol>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelExpEntSol>>() {
		public JerarquiaDto<RelExpEntSol> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpEntSol relexpentsol = new RelExpEntSol(resultSet.getInt("IDRELEXPENTSOL"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new EntidadesSolicitantes(resultSet.getInt("EntidadesSolicitantesIDENTIDADSOLICITANTE"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOMUJERES"),
							resultSet.getLong("EntidadesSolicitantesORGANODIRECTIVOHOMBRES"),
							resultSet.getLong("EntidadesSolicitantesANTIGUEDADENTIDAD"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSTOTAL"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSMUJERES"),
							resultSet.getLong("EntidadesSolicitantesNSOCIOSHOMBRES"),
							resultSet.getDate("EntidadesSolicitantesFECHAREGISTRO"),
							resultSet.getString("EntidadesSolicitantesUSUARIOREGISTRO"),
							new TiposAsociacion(resultSet.getLong("EntidadesSolicitantesIDTIPOASOCIACION"), null, null,
									null, null, null)));

			JerarquiaDto<RelExpEntSol> jerarquia = new JerarquiaDto<RelExpEntSol>();
			jerarquia.setModel(relexpentsol);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelExpEntSol table.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @return RelExpEntSol
	 */
	public RelExpEntSol add(RelExpEntSol relexpentsol) {
		String query = "INSERT INTO REL_EXP_ENT_SOL (ID_REL_EXP_ENT_SOL, ID_ENTIDAD_SOLICITANTE, ID_EXPEDIENTE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		Object getEntidadesSolicitantesIdEntidadSolicitanteAux = null;
		if (relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			getEntidadesSolicitantesIdEntidadSolicitanteAux = relexpentsol.getEntidadesSolicitantes()
					.getIdEntidadSolicitante();
		}
		this.jdbcTemplate.update(query, relexpentsol.getIdRelExpEntSol(),
				getEntidadesSolicitantesIdEntidadSolicitanteAux, relexpentsol.getIdExpediente(),
				relexpentsol.getFechaRegistro(), relexpentsol.getUsuarioRegistro());
		return relexpentsol;
	}

	/**
	 * Updates a single row in the RelExpEntSol table.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @return RelExpEntSol
	 */
	public RelExpEntSol update(RelExpEntSol relexpentsol) {
		String query = "UPDATE REL_EXP_ENT_SOL SET ID_ENTIDAD_SOLICITANTE=?, ID_EXPEDIENTE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_REL_EXP_ENT_SOL=?";
		Object getEntidadesSolicitantesIdEntidadSolicitanteAux = null;
		if (relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			getEntidadesSolicitantesIdEntidadSolicitanteAux = relexpentsol.getEntidadesSolicitantes()
					.getIdEntidadSolicitante();
		}
		this.jdbcTemplate.update(query, getEntidadesSolicitantesIdEntidadSolicitanteAux, relexpentsol.getIdExpediente(),
				relexpentsol.getFechaRegistro(), relexpentsol.getUsuarioRegistro(), relexpentsol.getIdRelExpEntSol());
		return relexpentsol;
	}

	/**
	 * Finds a single row in the RelExpEntSol table.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @return RelExpEntSol
	 */
	@Transactional(readOnly = true)
	public RelExpEntSol find(RelExpEntSol relexpentsol) {
		String query = "SELECT t1.ID_REL_EXP_ENT_SOL IDRELEXPENTSOL, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE, t2.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES, t2.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES, t2.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD, t2.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL, t2.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES, t2.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES, t2.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO, t2.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO, t2.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION FROM REL_EXP_ENT_SOL t1 , ENTIDADES_SOLICITANTES t2  WHERE t1.ID_REL_EXP_ENT_SOL = ?   AND t1.ID_ENTIDAD_SOLICITANTE= t2.ID_ENTIDAD_SOLICITANTE(+)";

		List<RelExpEntSol> relexpentsolList = this.jdbcTemplate.query(query, this.rwMap,
				relexpentsol.getIdRelExpEntSol());
		return (RelExpEntSol) DataAccessUtils.uniqueResult(relexpentsolList);
	}

	/**
	 * Removes a single row in the RelExpEntSol table.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @return
	 */
	public void remove(RelExpEntSol relexpentsol) {
		String query = "DELETE FROM REL_EXP_ENT_SOL WHERE ID_REL_EXP_ENT_SOL=?";
		this.jdbcTemplate.update(query, relexpentsol.getIdRelExpEntSol());
	}

	/**
	 * Finds a list of rows in the RelExpEntSol table.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpEntSol>
	 */
	@Transactional(readOnly = true)
	public List<RelExpEntSol> findAll(RelExpEntSol relexpentsol, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_ENT_SOL IDRELEXPENTSOL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t2.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t2.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t2.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t2.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t2.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t2.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t2.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t2.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		query.append("FROM REL_EXP_ENT_SOL t1 ,ENTIDADES_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpentsol);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ENTIDAD_SOLICITANTE= t2.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpEntSolDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpEntSol>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelExpEntSol table using like.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpEntSol>
	 */
	@Transactional(readOnly = true)
	public List<RelExpEntSol> findAllLike(RelExpEntSol relexpentsol, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_ENT_SOL IDRELEXPENTSOL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t2.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t2.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t2.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t2.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t2.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t2.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t2.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t2.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		query.append("FROM REL_EXP_ENT_SOL t1 ,ENTIDADES_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpentsol, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ENTIDAD_SOLICITANTE= t2.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpEntSolDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpEntSol>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelExpEntSol table.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelExpEntSol relexpentsol) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_ENT_SOL t1 , ENTIDADES_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpentsol);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ENTIDAD_SOLICITANTE= t2.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelExpEntSol table using like.
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelExpEntSol relexpentsol, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_ENT_SOL t1 ,ENTIDADES_SOLICITANTES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpentsol, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ENTIDAD_SOLICITANTE= t2.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelExpEntSol selected for rup_table
	 *
	 * @param relexpentsol
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpEntSol>>
	 */
	@Override
	public List<TableRowDto<RelExpEntSol>> reorderSelection(RelExpEntSol relexpentsol,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ENT_SOL IDRELEXPENTSOL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t2.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t2.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t2.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t2.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t2.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t2.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t2.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t2.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		query.append("FROM REL_EXP_ENT_SOL t1 ,ENTIDADES_SOLICITANTES t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpentsol, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ENTIDAD_SOLICITANTE= t2.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelExpEntSol.class,
				filterParamList, "ID_REL_EXP_ENT_SOL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpEntSol>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelExpEntSol
	 * @param searchParams
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpEntSol>>
	 */
	@Override
	public List<TableRowDto<RelExpEntSol>> search(RelExpEntSol filterParams, RelExpEntSol searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ENT_SOL IDRELEXPENTSOL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t2.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t2.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t2.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t2.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t2.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t2.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t2.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t2.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		query.append("FROM REL_EXP_ENT_SOL t1 ,ENTIDADES_SOLICITANTES t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ENTIDAD_SOLICITANTE= t2.ID_ENTIDAD_SOLICITANTE(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelExpEntSol.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_EXP_ENT_SOL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpEntSol>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelexpentsol
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelExpEntSol filterrelexpentsol, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ENT_SOL IDRELEXPENTSOL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t2.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t2.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t2.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t2.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t2.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t2.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t2.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t2.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		query.append("FROM REL_EXP_ENT_SOL t1 ,ENTIDADES_SOLICITANTES t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelexpentsol, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelExpEntSol.class,
				query, params, "ID_REL_EXP_ENT_SOL");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelExpEntSol table.
	 *
	 * @param filterRelExpEntSol
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelExpEntSol>>
	 */
	@Override
	public List<JerarquiaDto<RelExpEntSol>> findAllLikeJerarquia(RelExpEntSol filterRelExpEntSol,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ENT_SOL IDRELEXPENTSOL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ENTIDAD_SOLICITANTE ENTIDADESSOLICITANTESIDENTIDADSOLICITANTE,t2.ORGANO_DIRECTIVO_MUJERES ENTIDADESSOLICITANTESORGANODIRECTIVOMUJERES,t2.ORGANO_DIRECTIVO_HOMBRES ENTIDADESSOLICITANTESORGANODIRECTIVOHOMBRES,t2.ANTIGUEDAD_ENTIDAD ENTIDADESSOLICITANTESANTIGUEDADENTIDAD,t2.N_SOCIOS_TOTAL ENTIDADESSOLICITANTESNSOCIOSTOTAL,t2.N_SOCIOS_MUJERES ENTIDADESSOLICITANTESNSOCIOSMUJERES,t2.N_SOCIOS_HOMBRES ENTIDADESSOLICITANTESNSOCIOSHOMBRES,t2.FECHA_REGISTRO ENTIDADESSOLICITANTESFECHAREGISTRO,t2.USUARIO_REGISTRO ENTIDADESSOLICITANTESUSUARIOREGISTRO,t2.ID_TIPO_ASOCIACION ENTIDADESSOLICITANTESIDTIPOASOCIACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ENT_SOL t1
		// ,ENTIDADES_SOLICITANTES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ENT_SOL");
		from.add("ENTIDADES_SOLICITANTES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpEntSol, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_EXP_ENT_SOL", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelExpEntSolDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelExpEntSol
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelExpEntSol filterRelExpEntSol, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ENT_SOL t1
		// ,ENTIDADES_SOLICITANTES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ENT_SOL");
		from.add("ENTIDADES_SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpEntSol, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_EXP_ENT_SOL",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpEntSol
	 *            RelExpEntSol
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpEntSol>>
	 */
	@Override
	public List<TableRowDto<RelExpEntSol>> findAllChild(RelExpEntSol filterRelExpEntSol,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ENT_SOL t1
		// ,ENTIDADES_SOLICITANTES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ENT_SOL");
		from.add("ENTIDADES_SOLICITANTES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpEntSol, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_EXP_ENT_SOL",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelExpEntSol>(this.rwMapPK, "ID_REL_EXP_ENT_SOL"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpEntSol entity
	 *
	 * @param relexpentsol
	 *            RelExpEntSol Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelExpEntSol relexpentsol) {

		StringBuilder where = new StringBuilder(RelExpEntSolDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpentsol != null && relexpentsol.getIdRelExpEntSol() != null) {
			where.append(" AND t1.ID_REL_EXP_ENT_SOL = ?");
			params.add(relexpentsol.getIdRelExpEntSol());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			where.append(" AND t2.ID_ENTIDAD_SOLICITANTE = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getIdEntidadSolicitante());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getTiposAsociacion() != null
				&& relexpentsol.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion() != null) {
			where.append(" AND t2.ID_TIPO_ASOCIACION = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoMujeres() != null) {
			where.append(" AND t2.ORGANO_DIRECTIVO_MUJERES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoMujeres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoHombres() != null) {
			where.append(" AND t2.ORGANO_DIRECTIVO_HOMBRES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoHombres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getAntiguedadEntidad() != null) {
			where.append(" AND t2.ANTIGUEDAD_ENTIDAD = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getAntiguedadEntidad());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getNSociosTotal() != null) {
			where.append(" AND t2.N_SOCIOS_TOTAL = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getNSociosTotal());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getNSociosMujeres() != null) {
			where.append(" AND t2.N_SOCIOS_MUJERES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getNSociosMujeres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getNSociosHombres() != null) {
			where.append(" AND t2.N_SOCIOS_HOMBRES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getNSociosHombres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getFechaRegistro());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getUsuarioRegistro());
		}
		if (relexpentsol != null && relexpentsol.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpentsol.getIdExpediente());
		}
		if (relexpentsol != null && relexpentsol.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpentsol.getFechaRegistro());
		}
		if (relexpentsol != null && relexpentsol.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relexpentsol.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpEntSol entity
	 *
	 * @param relexpentsol
	 *            RelExpEntSol Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelExpEntSol relexpentsol, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelExpEntSolDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpentsol != null && relexpentsol.getIdRelExpEntSol() != null) {
			where.append(" AND t1.ID_REL_EXP_ENT_SOL = ?");
			params.add(relexpentsol.getIdRelExpEntSol());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getIdEntidadSolicitante() != null) {
			where.append(" AND t2.ID_ENTIDAD_SOLICITANTE = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getIdEntidadSolicitante());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getTiposAsociacion() != null
				&& relexpentsol.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion() != null) {
			where.append(" AND t2.ID_TIPO_ASOCIACION = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getTiposAsociacion().getIdTipoAsociacion());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoMujeres() != null) {
			where.append(" AND t2.ORGANO_DIRECTIVO_MUJERES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoMujeres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoHombres() != null) {
			where.append(" AND t2.ORGANO_DIRECTIVO_HOMBRES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getOrganoDirectivoHombres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getAntiguedadEntidad() != null) {
			where.append(" AND t2.ANTIGUEDAD_ENTIDAD = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getAntiguedadEntidad());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getNSociosTotal() != null) {
			where.append(" AND t2.N_SOCIOS_TOTAL = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getNSociosTotal());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getNSociosMujeres() != null) {
			where.append(" AND t2.N_SOCIOS_MUJERES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getNSociosMujeres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getNSociosHombres() != null) {
			where.append(" AND t2.N_SOCIOS_HOMBRES = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getNSociosHombres());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpentsol.getEntidadesSolicitantes().getFechaRegistro());
		}
		if (relexpentsol != null && relexpentsol.getEntidadesSolicitantes() != null
				&& relexpentsol.getEntidadesSolicitantes().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpentsol.getEntidadesSolicitantes().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpentsol.getEntidadesSolicitantes().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relexpentsol != null && relexpentsol.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpentsol.getIdExpediente());
		}
		if (relexpentsol != null && relexpentsol.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpentsol.getFechaRegistro());
		}
		if (relexpentsol != null && relexpentsol.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpentsol.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpentsol.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
