package com.ejie.ab60.dao.DIV;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DIV.TiposActividad;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposActividadDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposActividadDaoImpl implements TiposActividadDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOACTIVIDAD", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "LIMITEACTIVIDAD", "MAXIMOHORA", "LIMITECONTRATACION", "LIMITERESTO", "FECHAREGISTRO",
			"USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposActividad> rwMap = new RowMapper<TiposActividad>() {
		public TiposActividad mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposActividad(resultSet.getLong("IDTIPOACTIVIDAD"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getBigDecimal("LIMITEACTIVIDAD"), resultSet.getBigDecimal("MAXIMOHORA"),
					resultSet.getBigDecimal("LIMITECONTRATACION"), resultSet.getBigDecimal("LIMITERESTO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<TiposActividad> rwMapPK = new RowMapper<TiposActividad>() {
		public TiposActividad mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposActividad(resultSet.getLong("IDTIPOACTIVIDAD"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposActividad>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposActividad>>() {
		public JerarquiaDto<TiposActividad> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposActividad tiposactividad = new TiposActividad(resultSet.getLong("IDTIPOACTIVIDAD"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getBigDecimal("LIMITEACTIVIDAD"), resultSet.getBigDecimal("MAXIMOHORA"),
					resultSet.getBigDecimal("LIMITECONTRATACION"), resultSet.getBigDecimal("LIMITERESTO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<TiposActividad> jerarquia = new JerarquiaDto<TiposActividad>();
			jerarquia.setModel(tiposactividad);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposActividad table.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @return TiposActividad
	 */
	public TiposActividad add(TiposActividad tiposactividad) {
		String query = "INSERT INTO TIPOS_ACTIVIDAD (ID_TIPO_ACTIVIDAD, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, LIMITE_ACTIVIDAD, MAXIMO_HORA, LIMITE_CONTRATACION, LIMITE_RESTO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, tiposactividad.getIdTipoActividad(), tiposactividad.getDescripcionCastellano(),
				tiposactividad.getDescripcionEuskera(), tiposactividad.getLimiteActividad(),
				tiposactividad.getMaximoHora(), tiposactividad.getLimiteContratacion(), tiposactividad.getLimiteResto(),
				tiposactividad.getFechaRegistro(), tiposactividad.getUsuarioRegistro());
		return tiposactividad;
	}

	/**
	 * Updates a single row in the TiposActividad table.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @return TiposActividad
	 */
	public TiposActividad update(TiposActividad tiposactividad) {
		String query = "UPDATE TIPOS_ACTIVIDAD SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, LIMITE_ACTIVIDAD=?, MAXIMO_HORA=?, LIMITE_CONTRATACION=?, LIMITE_RESTO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_TIPO_ACTIVIDAD=?";
		this.jdbcTemplate.update(query, tiposactividad.getDescripcionCastellano(),
				tiposactividad.getDescripcionEuskera(), tiposactividad.getLimiteActividad(),
				tiposactividad.getMaximoHora(), tiposactividad.getLimiteContratacion(), tiposactividad.getLimiteResto(),
				tiposactividad.getFechaRegistro(), tiposactividad.getUsuarioRegistro(),
				tiposactividad.getIdTipoActividad());
		return tiposactividad;
	}

	/**
	 * Finds a single row in the TiposActividad table.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @return TiposActividad
	 */
	@Transactional(readOnly = true)
	public TiposActividad find(TiposActividad tiposactividad) {
		String query = "SELECT t1.ID_TIPO_ACTIVIDAD IDTIPOACTIVIDAD, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.LIMITE_ACTIVIDAD LIMITEACTIVIDAD, t1.MAXIMO_HORA MAXIMOHORA, t1.LIMITE_CONTRATACION LIMITECONTRATACION, t1.LIMITE_RESTO LIMITERESTO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_ACTIVIDAD t1  WHERE t1.ID_TIPO_ACTIVIDAD = ?  ";

		List<TiposActividad> tiposactividadList = this.jdbcTemplate.query(query, this.rwMap,
				tiposactividad.getIdTipoActividad());
		return (TiposActividad) DataAccessUtils.uniqueResult(tiposactividadList);
	}

	/**
	 * Removes a single row in the TiposActividad table.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @return
	 */
	public void remove(TiposActividad tiposactividad) {
		String query = "DELETE FROM TIPOS_ACTIVIDAD WHERE ID_TIPO_ACTIVIDAD=?";
		this.jdbcTemplate.update(query, tiposactividad.getIdTipoActividad());
	}

	/**
	 * Finds a list of rows in the TiposActividad table.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposActividad>
	 */
	@Transactional(readOnly = true)
	public List<TiposActividad> findAll(TiposActividad tiposactividad, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_ACTIVIDAD IDTIPOACTIVIDAD,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ACTIVIDAD LIMITEACTIVIDAD,t1.MAXIMO_HORA MAXIMOHORA,t1.LIMITE_CONTRATACION LIMITECONTRATACION,t1.LIMITE_RESTO LIMITERESTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_ACTIVIDAD t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposactividad);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposActividadDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposActividad>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposActividad table using like.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposActividad>
	 */
	@Transactional(readOnly = true)
	public List<TiposActividad> findAllLike(TiposActividad tiposactividad, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_ACTIVIDAD IDTIPOACTIVIDAD,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ACTIVIDAD LIMITEACTIVIDAD,t1.MAXIMO_HORA MAXIMOHORA,t1.LIMITE_CONTRATACION LIMITECONTRATACION,t1.LIMITE_RESTO LIMITERESTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_ACTIVIDAD t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposactividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposActividadDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposActividad>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposActividad table.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposActividad tiposactividad) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_ACTIVIDAD t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposactividad);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposActividad table using like.
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposActividad tiposactividad, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_ACTIVIDAD t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposactividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposActividad selected for rup_table
	 *
	 * @param tiposactividad
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposActividad>>
	 */
	@Override
	public List<TableRowDto<TiposActividad>> reorderSelection(TiposActividad tiposactividad,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ACTIVIDAD IDTIPOACTIVIDAD,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ACTIVIDAD LIMITEACTIVIDAD,t1.MAXIMO_HORA MAXIMOHORA,t1.LIMITE_CONTRATACION LIMITECONTRATACION,t1.LIMITE_RESTO LIMITERESTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_ACTIVIDAD t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposactividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				TiposActividad.class, filterParamList, "ID_TIPO_ACTIVIDAD");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposActividad>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposActividad
	 * @param searchParams
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposActividad>>
	 */
	@Override
	public List<TableRowDto<TiposActividad>> search(TiposActividad filterParams, TiposActividad searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ACTIVIDAD IDTIPOACTIVIDAD,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ACTIVIDAD LIMITEACTIVIDAD,t1.MAXIMO_HORA MAXIMOHORA,t1.LIMITE_CONTRATACION LIMITECONTRATACION,t1.LIMITE_RESTO LIMITERESTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_ACTIVIDAD t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				TiposActividad.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_TIPO_ACTIVIDAD");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposActividad>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertiposactividad
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposActividad filtertiposactividad, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ACTIVIDAD IDTIPOACTIVIDAD,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ACTIVIDAD LIMITEACTIVIDAD,t1.MAXIMO_HORA MAXIMOHORA,t1.LIMITE_CONTRATACION LIMITECONTRATACION,t1.LIMITE_RESTO LIMITERESTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_ACTIVIDAD t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertiposactividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, TiposActividad.class,
				query, params, "ID_TIPO_ACTIVIDAD");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposActividad table.
	 *
	 * @param filterTiposActividad
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposActividad>>
	 */
	@Override
	public List<JerarquiaDto<TiposActividad>> findAllLikeJerarquia(TiposActividad filterTiposActividad,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ACTIVIDAD IDTIPOACTIVIDAD,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.LIMITE_ACTIVIDAD LIMITEACTIVIDAD,t1.MAXIMO_HORA MAXIMOHORA,t1.LIMITE_CONTRATACION LIMITECONTRATACION,t1.LIMITE_RESTO LIMITERESTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_ACTIVIDAD t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_ACTIVIDAD");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposActividad, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_ACTIVIDAD", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposActividadDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposActividad
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposActividad filterTiposActividad, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_ACTIVIDAD t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_ACTIVIDAD");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposActividad, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_ACTIVIDAD",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposActividad
	 *            TiposActividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposActividad>>
	 */
	@Override
	public List<TableRowDto<TiposActividad>> findAllChild(TiposActividad filterTiposActividad,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_ACTIVIDAD t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_ACTIVIDAD");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposActividad, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_TIPO_ACTIVIDAD",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposActividad>(this.rwMapPK, "ID_TIPO_ACTIVIDAD"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposActividad entity
	 *
	 * @param tiposactividad
	 *            TiposActividad Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposActividad tiposactividad) {

		StringBuilder where = new StringBuilder(TiposActividadDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposactividad != null && tiposactividad.getIdTipoActividad() != null) {
			where.append(" AND t1.ID_TIPO_ACTIVIDAD = ?");
			params.add(tiposactividad.getIdTipoActividad());
		}
		if (tiposactividad != null && tiposactividad.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposactividad.getDescripcionCastellano());
		}
		if (tiposactividad != null && tiposactividad.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposactividad.getDescripcionEuskera());
		}
		if (tiposactividad != null && tiposactividad.getLimiteActividad() != null) {
			where.append(" AND t1.LIMITE_ACTIVIDAD = ?");
			params.add(tiposactividad.getLimiteActividad());
		}
		if (tiposactividad != null && tiposactividad.getMaximoHora() != null) {
			where.append(" AND t1.MAXIMO_HORA = ?");
			params.add(tiposactividad.getMaximoHora());
		}
		if (tiposactividad != null && tiposactividad.getLimiteContratacion() != null) {
			where.append(" AND t1.LIMITE_CONTRATACION = ?");
			params.add(tiposactividad.getLimiteContratacion());
		}
		if (tiposactividad != null && tiposactividad.getLimiteResto() != null) {
			where.append(" AND t1.LIMITE_RESTO = ?");
			params.add(tiposactividad.getLimiteResto());
		}
		if (tiposactividad != null && tiposactividad.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposactividad.getFechaRegistro());
		}
		if (tiposactividad != null && tiposactividad.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposactividad.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposActividad entity
	 *
	 * @param tiposactividad
	 *            TiposActividad Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposActividad tiposactividad, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposActividadDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposactividad != null && tiposactividad.getIdTipoActividad() != null) {
			where.append(" AND t1.ID_TIPO_ACTIVIDAD = ?");
			params.add(tiposactividad.getIdTipoActividad());
		}
		if (tiposactividad != null && tiposactividad.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposactividad.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tiposactividad.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tiposactividad != null && tiposactividad.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposactividad.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tiposactividad.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tiposactividad != null && tiposactividad.getLimiteActividad() != null) {
			where.append(" AND t1.LIMITE_ACTIVIDAD = ?");
			params.add(tiposactividad.getLimiteActividad());
		}
		if (tiposactividad != null && tiposactividad.getMaximoHora() != null) {
			where.append(" AND t1.MAXIMO_HORA = ?");
			params.add(tiposactividad.getMaximoHora());
		}
		if (tiposactividad != null && tiposactividad.getLimiteContratacion() != null) {
			where.append(" AND t1.LIMITE_CONTRATACION = ?");
			params.add(tiposactividad.getLimiteContratacion());
		}
		if (tiposactividad != null && tiposactividad.getLimiteResto() != null) {
			where.append(" AND t1.LIMITE_RESTO = ?");
			params.add(tiposactividad.getLimiteResto());
		}
		if (tiposactividad != null && tiposactividad.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposactividad.getFechaRegistro());
		}
		if (tiposactividad != null && tiposactividad.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposactividad.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tiposactividad.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
