package com.ejie.ab60.dao.DIV;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.DIV.TiposAsociacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposAsociacionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposAsociacionDaoImpl implements TiposAsociacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOASOCIACION", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposAsociacion> rwMap = new RowMapper<TiposAsociacion>() {
		public TiposAsociacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposAsociacion(resultSet.getLong("IDTIPOASOCIACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<TiposAsociacion> rwMapPK = new RowMapper<TiposAsociacion>() {
		public TiposAsociacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposAsociacion(resultSet.getLong("IDTIPOASOCIACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposAsociacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposAsociacion>>() {
		public JerarquiaDto<TiposAsociacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposAsociacion tiposasociacion = new TiposAsociacion(resultSet.getLong("IDTIPOASOCIACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<TiposAsociacion> jerarquia = new JerarquiaDto<TiposAsociacion>();
			jerarquia.setModel(tiposasociacion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposAsociacion table.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @return TiposAsociacion
	 */
	public TiposAsociacion add(TiposAsociacion tiposasociacion) {
		String query = "INSERT INTO TIPOS_ASOCIACION (ID_TIPO_ASOCIACION, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, tiposasociacion.getIdTipoAsociacion(),
				tiposasociacion.getDescripcionCastellano(), tiposasociacion.getDescripcionEuskera(),
				tiposasociacion.getFechaRegistro(), tiposasociacion.getUsuarioRegistro());
		return tiposasociacion;
	}

	/**
	 * Updates a single row in the TiposAsociacion table.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @return TiposAsociacion
	 */
	public TiposAsociacion update(TiposAsociacion tiposasociacion) {
		String query = "UPDATE TIPOS_ASOCIACION SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_TIPO_ASOCIACION=?";
		this.jdbcTemplate.update(query, tiposasociacion.getDescripcionCastellano(),
				tiposasociacion.getDescripcionEuskera(), tiposasociacion.getFechaRegistro(),
				tiposasociacion.getUsuarioRegistro(), tiposasociacion.getIdTipoAsociacion());
		return tiposasociacion;
	}

	/**
	 * Finds a single row in the TiposAsociacion table.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @return TiposAsociacion
	 */
	@Transactional(readOnly = true)
	public TiposAsociacion find(TiposAsociacion tiposasociacion) {
		String query = "SELECT t1.ID_TIPO_ASOCIACION IDTIPOASOCIACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_ASOCIACION t1  WHERE t1.ID_TIPO_ASOCIACION = ?  ";

		List<TiposAsociacion> tiposasociacionList = this.jdbcTemplate.query(query, this.rwMap,
				tiposasociacion.getIdTipoAsociacion());
		return (TiposAsociacion) DataAccessUtils.uniqueResult(tiposasociacionList);
	}

	/**
	 * Removes a single row in the TiposAsociacion table.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @return
	 */
	public void remove(TiposAsociacion tiposasociacion) {
		String query = "DELETE FROM TIPOS_ASOCIACION WHERE ID_TIPO_ASOCIACION=?";
		this.jdbcTemplate.update(query, tiposasociacion.getIdTipoAsociacion());
	}

	/**
	 * Finds a list of rows in the TiposAsociacion table.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposAsociacion>
	 */
	@Transactional(readOnly = true)
	public List<TiposAsociacion> findAll(TiposAsociacion tiposasociacion, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_ASOCIACION IDTIPOASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_ASOCIACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposasociacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposAsociacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposAsociacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposAsociacion table using like.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposAsociacion>
	 */
	@Transactional(readOnly = true)
	public List<TiposAsociacion> findAllLike(TiposAsociacion tiposasociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_ASOCIACION IDTIPOASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_ASOCIACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposAsociacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposAsociacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposAsociacion table.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposAsociacion tiposasociacion) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_ASOCIACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposasociacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposAsociacion table using like.
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposAsociacion tiposasociacion, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_ASOCIACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposAsociacion selected for rup_table
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposAsociacion>>
	 */
	@Override
	public List<TableRowDto<TiposAsociacion>> reorderSelection(TiposAsociacion tiposasociacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ASOCIACION IDTIPOASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_ASOCIACION t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				TiposAsociacion.class, filterParamList, "ID_TIPO_ASOCIACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposAsociacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposAsociacion
	 * @param searchParams
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposAsociacion>>
	 */
	@Override
	public List<TableRowDto<TiposAsociacion>> search(TiposAsociacion filterParams, TiposAsociacion searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ASOCIACION IDTIPOASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_ASOCIACION t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				TiposAsociacion.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_TIPO_ASOCIACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposAsociacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertiposasociacion
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposAsociacion filtertiposasociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ASOCIACION IDTIPOASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_ASOCIACION t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertiposasociacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				TiposAsociacion.class, query, params, "ID_TIPO_ASOCIACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposAsociacion table.
	 *
	 * @param filterTiposAsociacion
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposAsociacion>>
	 */
	@Override
	public List<JerarquiaDto<TiposAsociacion>> findAllLikeJerarquia(TiposAsociacion filterTiposAsociacion,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ASOCIACION IDTIPOASOCIACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_ASOCIACION t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_ASOCIACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposAsociacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_ASOCIACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposAsociacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposAsociacion
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposAsociacion filterTiposAsociacion, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_ASOCIACION t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_ASOCIACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposAsociacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_ASOCIACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposAsociacion
	 *            TiposAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposAsociacion>>
	 */
	@Override
	public List<TableRowDto<TiposAsociacion>> findAllChild(TiposAsociacion filterTiposAsociacion,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_ASOCIACION t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_ASOCIACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposAsociacion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_TIPO_ASOCIACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposAsociacion>(this.rwMapPK, "ID_TIPO_ASOCIACION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposAsociacion entity
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposAsociacion tiposasociacion) {

		StringBuilder where = new StringBuilder(TiposAsociacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposasociacion != null && tiposasociacion.getIdTipoAsociacion() != null) {
			where.append(" AND t1.ID_TIPO_ASOCIACION = ?");
			params.add(tiposasociacion.getIdTipoAsociacion());
		}
		if (tiposasociacion != null && tiposasociacion.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposasociacion.getDescripcionCastellano());
		}
		if (tiposasociacion != null && tiposasociacion.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposasociacion.getDescripcionEuskera());
		}
		if (tiposasociacion != null && tiposasociacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposasociacion.getFechaRegistro());
		}
		if (tiposasociacion != null && tiposasociacion.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposasociacion.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposAsociacion entity
	 *
	 * @param tiposasociacion
	 *            TiposAsociacion Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposAsociacion tiposasociacion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposAsociacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposasociacion != null && tiposasociacion.getIdTipoAsociacion() != null) {
			where.append(" AND t1.ID_TIPO_ASOCIACION = ?");
			params.add(tiposasociacion.getIdTipoAsociacion());
		}
		if (tiposasociacion != null && tiposasociacion.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposasociacion.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tiposasociacion.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tiposasociacion != null && tiposasociacion.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposasociacion.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tiposasociacion.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tiposasociacion != null && tiposasociacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposasociacion.getFechaRegistro());
		}
		if (tiposasociacion != null && tiposasociacion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposasociacion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tiposasociacion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
