package com.ejie.ab60.dao;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.model.EntidadesBancarias;

/**
 * EntidadesBancariasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class EntidadesBancariasDaoImpl implements EntidadesBancariasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDENTIDADBANCARIA", "IDRELEXPACTSUB",
			"ENTIDADBANCARIA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<EntidadesBancarias> rwMap = new RowMapper<EntidadesBancarias>() {
		public EntidadesBancarias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EntidadesBancarias(resultSet.getInt("IDENTIDADBANCARIA"), resultSet.getInt("IDRELEXPACTSUB"),
					resultSet.getString("ENTIDADBANCARIA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<EntidadesBancarias> rwMapPK = new RowMapper<EntidadesBancarias>() {
		public EntidadesBancarias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EntidadesBancarias(resultSet.getInt("IDENTIDADBANCARIA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<EntidadesBancarias>> rwMapJerarquia = new RowMapper<JerarquiaDto<EntidadesBancarias>>() {
		public JerarquiaDto<EntidadesBancarias> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			EntidadesBancarias entidadesbancarias = new EntidadesBancarias(resultSet.getInt("IDENTIDADBANCARIA"),
					resultSet.getInt("IDRELEXPACTSUB"), resultSet.getString("ENTIDADBANCARIA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<EntidadesBancarias> jerarquia = new JerarquiaDto<EntidadesBancarias>();
			jerarquia.setModel(entidadesbancarias);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the EntidadesBancarias table.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @return EntidadesBancarias
	 */
	public EntidadesBancarias add(EntidadesBancarias entidadesbancarias) {

		int idEntidadBancaria = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6067T00"));
		entidadesbancarias.setIdEntidadBancaria(idEntidadBancaria);

		String query = "INSERT INTO ENTIDADES_BANCARIAS (ID_ENTIDAD_BANCARIA, ID_REL_EXP_ACT_SUB, ENTIDAD_BANCARIA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,sysdate,?)";
		this.jdbcTemplate.update(query, entidadesbancarias.getIdEntidadBancaria(),
				entidadesbancarias.getIdRelExpActSub(), entidadesbancarias.getEntidadBancaria(),
				entidadesbancarias.getUsuarioRegistro());
		return entidadesbancarias;
	}

	/**
	 * Updates a single row in the EntidadesBancarias table.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @return EntidadesBancarias
	 */
	public EntidadesBancarias update(EntidadesBancarias entidadesbancarias) {
		String query = "UPDATE ENTIDADES_BANCARIAS SET ID_REL_EXP_ACT_SUB=?, ENTIDAD_BANCARIA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_ENTIDAD_BANCARIA=?";
		this.jdbcTemplate.update(query, entidadesbancarias.getIdRelExpActSub(), entidadesbancarias.getEntidadBancaria(),
				entidadesbancarias.getFechaRegistro(), entidadesbancarias.getUsuarioRegistro(),
				entidadesbancarias.getIdEntidadBancaria());
		return entidadesbancarias;
	}

	/**
	 * Finds a single row in the EntidadesBancarias table.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @return EntidadesBancarias
	 */
	@Transactional(readOnly = true)
	public EntidadesBancarias find(EntidadesBancarias entidadesbancarias) {
		String query = "SELECT t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ENTIDAD_BANCARIA ENTIDADBANCARIA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM ENTIDADES_BANCARIAS t1  WHERE t1.ID_ENTIDAD_BANCARIA = ?  ";

		List<EntidadesBancarias> entidadesbancariasList = this.jdbcTemplate.query(query, this.rwMap,
				entidadesbancarias.getIdEntidadBancaria());
		return (EntidadesBancarias) DataAccessUtils.uniqueResult(entidadesbancariasList);
	}

	@Override
	public EntidadesBancarias findByIdRelExpActSub(EntidadesBancarias entidadesBancarias) {
		String query = "SELECT t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ENTIDAD_BANCARIA ENTIDADBANCARIA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM ENTIDADES_BANCARIAS t1  WHERE t1.ID_REL_EXP_ACT_SUB = ?  ";

		List<EntidadesBancarias> entidadesbancariasList = this.jdbcTemplate.query(query, this.rwMap,
				entidadesBancarias.getIdRelExpActSub());
		return (EntidadesBancarias) DataAccessUtils.uniqueResult(entidadesbancariasList);
	}

	/**
	 * Removes a single row in the EntidadesBancarias table.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @return
	 */
	public void remove(EntidadesBancarias entidadesbancarias) {
		String query = "DELETE FROM ENTIDADES_BANCARIAS WHERE ID_ENTIDAD_BANCARIA=?";
		this.jdbcTemplate.update(query, entidadesbancarias.getIdEntidadBancaria());
	}

	/**
	 * Finds a list of rows in the EntidadesBancarias table.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<EntidadesBancarias>
	 */
	@Transactional(readOnly = true)
	public List<EntidadesBancarias> findAll(EntidadesBancarias entidadesbancarias, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ENTIDAD_BANCARIA ENTIDADBANCARIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM ENTIDADES_BANCARIAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(entidadesbancarias);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EntidadesBancariasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EntidadesBancarias>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the EntidadesBancarias table using like.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<EntidadesBancarias>
	 */
	@Transactional(readOnly = true)
	public List<EntidadesBancarias> findAllLike(EntidadesBancarias entidadesbancarias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ENTIDAD_BANCARIA ENTIDADBANCARIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM ENTIDADES_BANCARIAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(entidadesbancarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EntidadesBancariasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EntidadesBancarias>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the EntidadesBancarias table.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(EntidadesBancarias entidadesbancarias) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ENTIDADES_BANCARIAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(entidadesbancarias);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the EntidadesBancarias table using like.
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(EntidadesBancarias entidadesbancarias, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ENTIDADES_BANCARIAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(entidadesbancarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of EntidadesBancarias selected for rup_table
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EntidadesBancarias>>
	 */
	@Override
	public List<TableRowDto<EntidadesBancarias>> reorderSelection(EntidadesBancarias entidadesbancarias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ENTIDAD_BANCARIA ENTIDADBANCARIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM ENTIDADES_BANCARIAS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(entidadesbancarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				EntidadesBancarias.class, filterParamList, "ID_ENTIDAD_BANCARIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EntidadesBancarias>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            EntidadesBancarias
	 * @param searchParams
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EntidadesBancarias>>
	 */
	@Override
	public List<TableRowDto<EntidadesBancarias>> search(EntidadesBancarias filterParams,
			EntidadesBancarias searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ENTIDAD_BANCARIA ENTIDADBANCARIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM ENTIDADES_BANCARIAS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				EntidadesBancarias.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_ENTIDAD_BANCARIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EntidadesBancarias>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterentidadesbancarias
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(EntidadesBancarias filterentidadesbancarias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ENTIDAD_BANCARIA ENTIDADBANCARIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM ENTIDADES_BANCARIAS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterentidadesbancarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				EntidadesBancarias.class, query, params, "ID_ENTIDAD_BANCARIA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical EntidadesBancarias table.
	 *
	 * @param filterEntidadesBancarias
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<EntidadesBancarias>>
	 */
	@Override
	public List<JerarquiaDto<EntidadesBancarias>> findAllLikeJerarquia(EntidadesBancarias filterEntidadesBancarias,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ENTIDAD_BANCARIA IDENTIDADBANCARIA,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ENTIDAD_BANCARIA ENTIDADBANCARIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ENTIDADES_BANCARIAS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("ENTIDADES_BANCARIAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEntidadesBancarias, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ENTIDAD_BANCARIA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					EntidadesBancariasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterEntidadesBancarias
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(EntidadesBancarias filterEntidadesBancarias,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ENTIDADES_BANCARIAS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("ENTIDADES_BANCARIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEntidadesBancarias, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ENTIDAD_BANCARIA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterEntidadesBancarias
	 *            EntidadesBancarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<EntidadesBancarias>>
	 */
	@Override
	public List<TableRowDto<EntidadesBancarias>> findAllChild(EntidadesBancarias filterEntidadesBancarias,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ENTIDADES_BANCARIAS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("ENTIDADES_BANCARIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEntidadesBancarias, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_ENTIDAD_BANCARIA", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<EntidadesBancarias>(this.rwMapPK, "ID_ENTIDAD_BANCARIA"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the EntidadesBancarias entity
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(EntidadesBancarias entidadesbancarias) {

		StringBuilder where = new StringBuilder(EntidadesBancariasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (entidadesbancarias != null && entidadesbancarias.getIdEntidadBancaria() != null) {
			where.append(" AND t1.ID_ENTIDAD_BANCARIA = ?");
			params.add(entidadesbancarias.getIdEntidadBancaria());
		}
		if (entidadesbancarias != null && entidadesbancarias.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(entidadesbancarias.getIdRelExpActSub());
		}
		if (entidadesbancarias != null && entidadesbancarias.getEntidadBancaria() != null) {
			where.append(" AND t1.ENTIDAD_BANCARIA = ?");
			params.add(entidadesbancarias.getEntidadBancaria());
		}
		if (entidadesbancarias != null && entidadesbancarias.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(entidadesbancarias.getFechaRegistro());
		}
		if (entidadesbancarias != null && entidadesbancarias.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(entidadesbancarias.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the EntidadesBancarias entity
	 *
	 * @param entidadesbancarias
	 *            EntidadesBancarias Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(EntidadesBancarias entidadesbancarias, Boolean startsWith) {

		StringBuilder where = new StringBuilder(EntidadesBancariasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (entidadesbancarias != null && entidadesbancarias.getIdEntidadBancaria() != null) {
			where.append(" AND t1.ID_ENTIDAD_BANCARIA = ?");
			params.add(entidadesbancarias.getIdEntidadBancaria());
		}
		if (entidadesbancarias != null && entidadesbancarias.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(entidadesbancarias.getIdRelExpActSub());
		}
		if (entidadesbancarias != null && entidadesbancarias.getEntidadBancaria() != null) {
			where.append(" AND UPPER(t1.ENTIDAD_BANCARIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(entidadesbancarias.getEntidadBancaria().toUpperCase() + "%");
			} else {
				params.add("%" + entidadesbancarias.getEntidadBancaria().toUpperCase() + "%");
			}
			where.append(" AND t1.ENTIDAD_BANCARIA IS NOT NULL");
		}
		if (entidadesbancarias != null && entidadesbancarias.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(entidadesbancarias.getFechaRegistro());
		}
		if (entidadesbancarias != null && entidadesbancarias.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(entidadesbancarias.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + entidadesbancarias.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
