package com.ejie.ab60.dao.MEC;

import java.math.BigDecimal;
import java.util.List;

import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * FacturasDao  
 * 
 *  
 */

public interface FacturasDao {

	/**
	 * Finds el siguiente al ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */

	Facturas findUltimoId();

	/**
	 * Inserts a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas add(Facturas facturas);

	/**
	 * Updates a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas update(Facturas facturas);

	/**
	 * Updates a Importe admitidor row in the Facturas table
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas updateImporte(Facturas facturas);

	/**
	 * Update el importe Admitido de null a cero
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas updateImporteAdmitidoDeNullACero(Facturas facturas);

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas find(Facturas facturas);

	/**
	 * Sumatorio de importe admitido de la tabla de facturas, por expediente y
	 * relacion subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return facturas
	 */
	Facturas findFacturasPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion);

	Facturas getImportesTotales(Integer idRelacion);

	/**
	 * Removes a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 */
	void remove(Facturas facturas);

	/**
	 * Finds a List of rows in the Facturas table.
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List
	 */
	Facturas findFacturasPorExpediente(Integer idExpediente);

	/**
	 * Finds a List of rows in the Facturas table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List
	 */
	List<Facturas> findFacturasPorRelExpActSub(Integer idRelExpActSub);

	/**
	 * Finds a List of rows in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<Facturas> findAll(Facturas facturas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Facturas table using like.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Facturas> findAllLike(Facturas facturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the Facturas table using like.
	 *
	 * @param facturas
	 *            Facturas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(Facturas facturas, Boolean startsWith);

	/**
	 * Counts rows in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Long
	 */
	Long findAllCount(Facturas facturas);

	/**
	 * Reorder selection.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Facturas>>
	 */
	List<TableRowDto<Facturas>> reorderSelection(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param searchFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Facturas>>
	 */
	List<TableRowDto<Facturas>> search(Facturas filterFacturas, Facturas searchFacturas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Facturas>>
	 */
	List<JerarquiaDto<Facturas>> findAllLikeJerarquia(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Facturas>>
	 */
	List<TableRowDto<Facturas>> findAllChild(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto);

	List<Facturas> findFacturasMarcarInspeccionable(Integer idRelExpActSub);

	Facturas editEMCO(Integer idRelacion, Facturas factura, Usuario usuario);

	Facturas addEMCO(Integer idRelacion, Facturas factura, Usuario usuario);

	BigDecimal sumaFacturasEMCO(Integer idRelacion);

	Facturas updateEMCO(Facturas facturas);

	Facturas findFacturasPorExpedientePorIdActSub(Integer idExpediente, Integer idActSubHijo);

	List<Facturas> findFacturasMarcarInspeccionableEMCO(Integer idExpediente);
}
