package com.ejie.ab60.dao.MEC;

import java.math.BigDecimal;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.justificacion.RelTipGasCon;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * FacturasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class FacturasDaoImpl implements FacturasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDFACTURA", "FECHAFACTURA", "NUMEROFACTURA",
			"DESCRIPCION", "PROVEEDOR", "IMPORTE", "PAGADO", "FECHAPAGADO", "IMPORTEADMITIDO",
			"OBSERVACIONESCASTELLANO", "OBSERVACIONESEUSKERA", "INSPECCIONABLE", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "RELEXPACTSUBIDRELEXPACTSUB", "RELEXPACTSUBIDEXPEDIENTE",
			"RELEXPACTSUBFECHAREGISTRO", "RELEXPACTSUBUSUARIOREGISTRO", "RELEXPACTSUBIDACTSUB", "SUMAIMPORTES",
			"IDACTSUB", "DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Facturas> rwMap = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Facturas(resultSet.getInt("IDFACTURA"), resultSet.getDate("FECHAFACTURA"),
					resultSet.getString("NUMEROFACTURA"), resultSet.getString("DESCRIPCION"),
					resultSet.getString("PROVEEDOR"), resultSet.getBigDecimal("IMPORTE"), resultSet.getInt("PAGADO"),
					resultSet.getDate("FECHAPAGADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getString("OBSERVACIONESEUSKERA"), resultSet.getString("OBSERVACIONESCASTELLANO"),
					resultSet.getInt("INSPECCIONABLE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")),
					new RelTipGasCon(null, resultSet.getLong("IDTIPOGASTO"), null, null, null));
		}
	};

	private RowMapper<Facturas> rwMapFacturasPorRelExpActSub = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Facturas(resultSet.getInt("IDFACTURA"), resultSet.getString("NUMEROFACTURA"),
					resultSet.getDate("FECHAFACTURA"), resultSet.getString("DESCRIPCION"),
					resultSet.getString("PROVEEDOR"), resultSet.getBigDecimal("IMPORTE"), resultSet.getInt("PAGADO"),
					resultSet.getDate("FECHAPAGADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getString("OBSERVACIONESEUSKERA"), resultSet.getString("OBSERVACIONESCASTELLANO"),
					resultSet.getInt("INSPECCIONABLE"), new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE")));
		}
	};

	private RowMapper<Facturas> rwMapFacturasPorExpediente = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Facturas(resultSet.getBigDecimal("PRESENTADO"), resultSet.getBigDecimal("ADMITIDO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDEXPEDIENTE")));
		}
	};

	private RowMapper<Facturas> rwMapFacturasPorExpedientePorRelacion = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Facturas factura = new Facturas();

			factura.setImporte(resultSet.getBigDecimal("PRESENTADO"));
			factura.setImporteAdmitido(resultSet.getBigDecimal("ADMITIDO"));

			return factura;
		}
	};

	private RowMapper<Facturas> rwMapImportesTotales = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Facturas(resultSet.getBigDecimal("IMPORTE"), resultSet.getBigDecimal("IMPORTEADMITIDO"));
		}
	};

	private RowMapper<Facturas> rwMapPK = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Facturas(resultSet.getInt("IDFACTURA"));
		}
	};

	private RowMapper<Facturas> rwMapFacturasMarcarInspeccionable = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Facturas factura = new Facturas();

			factura.setIdFactura(resultSet.getInt("ID_FACTURA"));
			factura.setFechaFactura(resultSet.getDate("FECHA_FACTURA"));
			factura.setNumeroFactura(resultSet.getString("NUMERO_FACTURA"));
			factura.setDescripcion(resultSet.getString("DESCRIPCION"));
			factura.setProveedor(resultSet.getString("PROVEEDOR"));
			factura.setImporte(resultSet.getBigDecimal("IMPORTE"));
			factura.setImporteAdmitido(resultSet.getBigDecimal("IMPORTE_ADMITIDO"));
			factura.setObservacionesEuskera(resultSet.getString("OBSERVACIONES_EUSKERA"));
			factura.setObservacionesCastellano(resultSet.getString("OBSERVACIONES_CASTELLANO"));
			factura.setInspeccionable(resultSet.getInt("INSPECCIONABLE"));
			factura.setEnviadoInspeccionar(resultSet.getInt("ENVIADO_INSPECCIONAR"));

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			factura.setActSubvencionable(actSubvencionable);

			return factura;
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Facturas>> rwMapJerarquia = new RowMapper<JerarquiaDto<Facturas>>() {
		public JerarquiaDto<Facturas> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Facturas facturas = new Facturas(resultSet.getInt("IDFACTURA"), resultSet.getDate("FECHAFACTURA"),
					resultSet.getString("NUMEROFACTURA"), resultSet.getString("DESCRIPCION"),
					resultSet.getString("PROVEEDOR"), resultSet.getBigDecimal("IMPORTE"), resultSet.getInt("PAGADO"),
					resultSet.getDate("FECHAPAGADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getString("OBSERVACIONESEUSKERA"), resultSet.getString("OBSERVACIONESCASTELLANO"),
					resultSet.getInt("INSPECCIONABLE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")),
					new RelTipGasCon(null, resultSet.getLong("IDTIPOGASTO"), null, null, null));

			JerarquiaDto<Facturas> jerarquia = new JerarquiaDto<Facturas>();
			jerarquia.setModel(facturas);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	private RowMapper<Facturas> rwMapSumaFacturasEMCO = new RowMapper<Facturas>() {
		public Facturas mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Facturas factura = new Facturas();

			factura.setImporte(resultSet.getBigDecimal("SUMAIMPORTES"));

			return factura;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Finds el siguiente al ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public Facturas findUltimoId() {
		String query = "SELECT S_AB6007T00.NEXTVAL IDFACTURA FROM dual";
		List<Facturas> facturasId = this.jdbcTemplate.query(query, this.rwMapPK);
		return (Facturas) DataAccessUtils.uniqueResult(facturasId);

	}

	/**
	 * Inserts a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	public Facturas add(Facturas facturas) {

		String query = "INSERT INTO FACTURAS (ID_FACTURA, ID_REL_EXP_ACT_SUB, FECHA_FACTURA, NUMERO_FACTURA, DESCRIPCION, PROVEEDOR, IMPORTE,OBSERVACIONES_CASTELLANO , OBSERVACIONES_EUSKERA  ,INSPECCIONABLE, FECHA_PAGADO, IMPORTE_ADMITIDO, FECHA_REGISTRO, USUARIO_REGISTRO, ID_TIPO_GASTO_FAC) VALUES( ?, ? , TO_DATE (?,'DD/MM/YYYY'), ?,?, ?,?,?,?, ?, TO_DATE (?,'DD/MM/YYYY'), ?,?, ?, ? )";

		Integer inspecionableAux = null;
		if (null != facturas.getInspeccionable()) {
			inspecionableAux = 1;
		} else {
			inspecionableAux = 0;
		}

		Object getRelExpActSubIdRelExpActSubAux = null;
		if (facturas.getRelExpActSub() != null && facturas.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = facturas.getRelExpActSub().getIdRelExpActSub();
		}
		Object getproveedor = null;
		if (!"".equals(facturas.getProveedor())) {
			getproveedor = facturas.getProveedor();
		}

		Object getobcastellano = null;
		if (facturas.getObservacionesCastellano() != null && !"".equals(facturas.getObservacionesCastellano())) {
			getobcastellano = facturas.getObservacionesCastellano();
		}

		Object getobeuskera = null;
		if (facturas.getObservacionesEuskera() != null && !"".equals(facturas.getObservacionesEuskera())) {
			getobeuskera = facturas.getObservacionesEuskera();
		}

		Object getdescripcion = null;
		if (!"".equals(facturas.getDescripcion())) {
			getdescripcion = facturas.getDescripcion();
		}

		if (facturas.getRelTipGasCon() != null && facturas.getRelTipGasCon().getIdTipoGastoFac() != null) {
			if (facturas.getRelTipGasCon().getIdTipoGastoFac() == 2) {
				getproveedor = null;
				facturas.setFechaPagado(null);
				facturas.setFechaPagadoStr(null);

			}
		}

		this.jdbcTemplate.update(query, facturas.getIdFactura(), getRelExpActSubIdRelExpActSubAux,
				facturas.getFechaFacturaStr(), facturas.getNumeroFactura(), getdescripcion, getproveedor,
				facturas.getImporte(), getobcastellano, getobeuskera, inspecionableAux, facturas.getFechaPagadoStr(),
				facturas.getImporteAdmitido(), facturas.getFechaRegistro(), facturas.getUsuarioRegistro(),
				facturas.getRelTipGasCon().getIdTipoGastoFac());
		return facturas;
	}

	/**
	 * Updates a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	public Facturas update(Facturas facturas) {
		String query = "UPDATE FACTURAS SET ID_REL_EXP_ACT_SUB=?, FECHA_FACTURA=TO_DATE (?,'DD/MM/YYYY'), NUMERO_FACTURA=?,OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?,INSPECCIONABLE=?, DESCRIPCION=?, PROVEEDOR=?, IMPORTE=?, PAGADO=?, FECHA_PAGADO=TO_DATE (?,'DD/MM/YYYY'), IMPORTE_ADMITIDO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, ID_TIPO_GASTO_FAC = ? WHERE ID_FACTURA=?";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (facturas.getRelExpActSub() != null && facturas.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = facturas.getRelExpActSub().getIdRelExpActSub();
		}

		if (facturas.getRelTipGasCon() != null && facturas.getRelTipGasCon().getIdTipoGastoFac() != null) {
			if (facturas.getRelTipGasCon().getIdTipoGastoFac() == 2) {
				facturas.setProveedor(null);
				facturas.setFechaPagado(null);
				facturas.setFechaPagadoStr(null);
			}
		}

		this.jdbcTemplate.update(query, getRelExpActSubIdRelExpActSubAux, facturas.getFechaFacturaStr(),
				facturas.getNumeroFactura(), facturas.getObservacionesCastellano(), facturas.getObservacionesEuskera(),
				facturas.getInspeccionable(), facturas.getDescripcion(), facturas.getProveedor(), facturas.getImporte(),
				facturas.getPagado(), facturas.getFechaPagadoStr(), facturas.getImporteAdmitido(),
				facturas.getFechaUltmodificacion(), facturas.getUsuarioUltmodificacion(),
				facturas.getRelTipGasCon().getIdTipoGastoFac(), facturas.getIdFactura());
		return facturas;
	}

	/**
	 * Updates IMPORTE_ADMITIDO por Importe_Presentado
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	public Facturas updateImporte(Facturas facturas) {
		String query = "UPDATE FACTURAS SET  IMPORTE_ADMITIDO =?, FECHA_ULTMODIFICACION  =?, USUARIO_ULTMODIFICACION=? WHERE ID_FACTURA =?";

		this.jdbcTemplate.update(query, facturas.getImporte(), facturas.getFechaUltmodificacion(),
				facturas.getUsuarioUltmodificacion(), facturas.getIdFactura());
		return facturas;
	}

	/**
	 * Update el importe Admitido de null a cero
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	public Facturas updateImporteAdmitidoDeNullACero(Facturas facturas) {
		String query = "UPDATE FACTURAS SET  IMPORTE_ADMITIDO =?, FECHA_ULTMODIFICACION  =?, USUARIO_ULTMODIFICACION=? WHERE ID_FACTURA =?";

		this.jdbcTemplate.update(query, facturas.getImporteAdmitido(), facturas.getFechaUltmodificacion(),
				facturas.getUsuarioUltmodificacion(), facturas.getIdFactura());
		return facturas;
	}

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	@Transactional(readOnly = true)
	public Facturas find(Facturas facturas) {

		String query = "SELECT t1.ID_FACTURA IDFACTURA, t1.FECHA_FACTURA FECHAFACTURA, t1.NUMERO_FACTURA NUMEROFACTURA, t1.DESCRIPCION DESCRIPCION, t1.PROVEEDOR PROVEEDOR, t1.IMPORTE IMPORTE, t1.PAGADO PAGADO, t1.FECHA_PAGADO FECHAPAGADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE, t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO, t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t1.INSPECCIONABLE INSPECCIONABLE, t1.ID_TIPO_GASTO_FAC IDTIPOGASTO  FROM FACTURAS t1, REL_EXP_ACT_SUB t2 WHERE t1.ID_REL_EXP_ACT_SUB = t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_FACTURA = ? AND t1.ID_REL_EXP_ACT_SUB   = t2.ID_REL_EXP_ACT_SUB(+)";

		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMap, facturas.getIdFactura());
		return (Facturas) DataAccessUtils.uniqueResult(facturasList);
	}

	/**
	 * Finds a List of rows in the Facturas table
	 *
	 * @param Integer
	 *            idconvocatoria
	 * @return facturasList
	 */
	@Transactional(readOnly = true)
	public Facturas findFacturasPorExpediente(Integer idExpediente) {

		String query = "SELECT   SUM(t2.IMPORTE_PRESENTADO) PRESENTADO,  SUM(t2.IMPORTE_ADMITIDO) ADMITIDO,  t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE FROM   REL_EXP_ACT_SUB t2 WHERE  t2.ID_EXPEDIENTE  = ? GROUP BY  t2.ID_EXPEDIENTE";

		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMapFacturasPorExpediente, idExpediente);

		return (Facturas) DataAccessUtils.uniqueResult(facturasList);
	}

	/**
	 * Sumatorio de importe admitido de la tabla de facturas, por expediente y
	 * relacion subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return facturasList
	 */
	@Transactional(readOnly = true)
	public Facturas findFacturasPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion) {

		String query = "SELECT SUM(t2.IMPORTE) PRESENTADO, SUM(t2.IMPORTE_ADMITIDO) ADMITIDO, t1.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB  FROM REL_EXP_ACT_SUB t1, FACTURAS t2, ACT_SUBVENCIONABLE t3 WHERE t1.ID_REL_EXP_ACT_SUB = t2.ID_REL_EXP_ACT_SUB AND t1.ID_ACT_SUB = t3.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? AND  t1.ID_REL_EXP_ACT_SUB =?  GROUP BY t1.ID_REL_EXP_ACT_SUB ";
		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMapFacturasPorExpedientePorRelacion,
				idExpediente, idRelacion);
		return DataAccessUtils.uniqueResult(facturasList);

	}

	@Transactional(readOnly = true)
	public Facturas findFacturasPorExpedientePorIdActSub(Integer idExpediente, Integer idRelacion) {

		String query = "SELECT SUM(t2.IMPORTE) PRESENTADO, SUM(t2.IMPORTE_ADMITIDO) ADMITIDO FROM REL_EXP_ACT_SUB t1, FACTURAS t2, ACT_SUBVENCIONABLE t3 WHERE t1.ID_REL_EXP_ACT_SUB = t2.ID_REL_EXP_ACT_SUB AND t1.ID_ACT_SUB = t3.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? AND t3.ID_ACT_SUB_PADRE = ?";
		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMapFacturasPorExpedientePorRelacion,
				idExpediente, idRelacion);
		return DataAccessUtils.uniqueResult(facturasList);

	}

	@Transactional(readOnly = true)
	public Facturas getImportesTotales(Integer idRelacion) {

		String query = "SELECT SUM(t1.IMPORTE) IMPORTE, SUM(t1.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM FACTURAS t1 WHERE t1.ID_REL_EXP_ACT_SUB = ?";
		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMapImportesTotales, idRelacion);
		return DataAccessUtils.uniqueResult(facturasList);

	}

	/**
	 * Finds a List of rows in the Facturas table
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return facturasList
	 */
	@Transactional(readOnly = true)
	public List<Facturas> findFacturasPorRelExpActSub(Integer idRelExpActSub) {

		String query = "SELECT t1.ID_FACTURA IDFACTURA, t1.NUMERO_FACTURA NUMEROFACTURA, t1.FECHA_FACTURA FECHAFACTURA, t1.DESCRIPCION DESCRIPCION, t1.PROVEEDOR PROVEEDOR, t1.IMPORTE IMPORTE, t1.PAGADO PAGADO, t1.FECHA_PAGADO FECHAPAGADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,  t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE , t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t1.INSPECCIONABLE INSPECCIONABLE  FROM FACTURAS t1, REL_EXP_ACT_SUB t2 WHERE t1.ID_REL_EXP_ACT_SUB = ? AND  t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB";
		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMapFacturasPorRelExpActSub, idRelExpActSub);

		return facturasList;
	}

	/**
	 * Finds a List of rows in the Facturas table
	 *
	 * @param Integer
	 *            idExpediente
	 * @return facturasList
	 */
	@Transactional(readOnly = true)
	public List<Facturas> findFacturasMarcarInspeccionable(Integer idExpediente) {

		String query = "SELECT t2.ORDEN ORDEN, t2.ID_ACT_SUB IDACTSUB, t2.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.ID_FACTURA, t1.FECHA_FACTURA, t1.NUMERO_FACTURA, t1.DESCRIPCION, t1.PROVEEDOR, t1.IMPORTE, t1.IMPORTE_ADMITIDO, t1.INSPECCIONABLE, t1.OBSERVACIONES_CASTELLANO, t1.OBSERVACIONES_EUSKERA, t1.ENVIADO_INSPECCIONAR FROM FACTURAS t1, ACT_SUBVENCIONABLE t2, REL_EXP_ACT_SUB t3 WHERE t2.ID_ACT_SUB = t3.ID_ACT_SUB AND t3.ID_REL_EXP_ACT_SUB = t1.ID_REL_EXP_ACT_SUB(+) AND t3.ID_EXPEDIENTE = ?";
		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMapFacturasMarcarInspeccionable,
				idExpediente);

		return facturasList;
	}

	/**
	 * Finds a List of rows in the Facturas table
	 *
	 * @param Integer
	 *            idExpediente
	 * @return facturasList
	 */
	@Transactional(readOnly = true)
	public List<Facturas> findFacturasMarcarInspeccionableEMCO(Integer idExpediente) {

		String query = "SELECT t2.ORDEN ORDEN, t2.ID_ACT_SUB IDACTSUB, t2.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.ID_FACTURA, t1.FECHA_FACTURA, t1.NUMERO_FACTURA, t1.DESCRIPCION, t1.PROVEEDOR, t1.IMPORTE, t1.IMPORTE_ADMITIDO, t1.INSPECCIONABLE, t1.OBSERVACIONES_CASTELLANO, t1.OBSERVACIONES_EUSKERA, t1.ENVIADO_INSPECCIONAR FROM FACTURAS t1, ACT_SUBVENCIONABLE t2, REL_EXP_ACT_SUB t3 WHERE t2.ID_ACT_SUB = t3.ID_ACT_SUB AND t3.ID_REL_EXP_ACT_SUB = t1.ID_REL_EXP_ACT_SUB(+) AND t3.ID_EXPEDIENTE =  ? AND t2.ID_ACT_SUB_PADRE IS NOT NULL AND t2.ID_ACT_SUB_PADRE <> "
				+ Constantes.ID_AGRUPACION_EMCO_Emprendimiento;
		List<Facturas> facturasList = this.jdbcTemplate.query(query, this.rwMapFacturasMarcarInspeccionable,
				idExpediente);

		return facturasList;
	}

	/**
	 * Removes a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return
	 */
	public void remove(Facturas facturas) {
		String query = "DELETE FROM FACTURAS WHERE ID_FACTURA=?";
		this.jdbcTemplate.update(query, facturas.getIdFactura());
	}

	/**
	 * Finds a list of rows in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Facturas>
	 */
	@Transactional(readOnly = true)
	public List<Facturas> findAll(Facturas facturas, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FACTURA IDFACTURA,t1.FECHA_FACTURA FECHAFACTURA,t1.NUMERO_FACTURA NUMEROFACTURA,t1.DESCRIPCION DESCRIPCION,t1.PROVEEDOR PROVEEDOR,t1.IMPORTE IMPORTE,t1.PAGADO PAGADO,t1.FECHA_PAGADO FECHAPAGADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t1.ID_TIPO_GASTO_FAC IDTIPOGASTO ");
		query.append("FROM FACTURAS t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(facturas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, FacturasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Facturas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Facturas table using like.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Facturas>
	 */
	@Transactional(readOnly = true)
	public List<Facturas> findAllLike(Facturas facturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FACTURA IDFACTURA,t1.FECHA_FACTURA FECHAFACTURA,t1.NUMERO_FACTURA NUMEROFACTURA,t1.DESCRIPCION DESCRIPCION,t1.PROVEEDOR PROVEEDOR,t1.IMPORTE IMPORTE,t1.PAGADO PAGADO,t1.FECHA_PAGADO FECHAPAGADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB,t1.ID_TIPO_GASTO_FAC IDTIPOGASTO ");
		query.append("FROM FACTURAS t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(facturas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, FacturasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Facturas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Facturas facturas) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM FACTURAS t1 , REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(facturas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Facturas table using like.
	 *
	 * @param facturas
	 *            Facturas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Facturas facturas, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM FACTURAS t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(facturas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Facturas selected for rup_table
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Facturas>>
	 */
	@Override
	public List<TableRowDto<Facturas>> reorderSelection(Facturas facturas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTURA IDFACTURA,t1.FECHA_FACTURA FECHAFACTURA,t1.NUMERO_FACTURA NUMEROFACTURA,t1.DESCRIPCION DESCRIPCION,t1.PROVEEDOR PROVEEDOR,t1.IMPORTE IMPORTE,t1.PAGADO PAGADO,t1.FECHA_PAGADO FECHAPAGADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM FACTURAS t1 ,REL_EXP_ACT_SUB t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(facturas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Facturas.class,
				filterParamList, "ID_FACTURA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Facturas>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Facturas
	 * @param searchParams
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Facturas>>
	 */
	@Override
	public List<TableRowDto<Facturas>> search(Facturas filterParams, Facturas searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTURA IDFACTURA,t1.FECHA_FACTURA FECHAFACTURA,t1.NUMERO_FACTURA NUMEROFACTURA,t1.DESCRIPCION DESCRIPCION,t1.PROVEEDOR PROVEEDOR,t1.IMPORTE IMPORTE,t1.PAGADO PAGADO,t1.FECHA_PAGADO FECHAPAGADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM FACTURAS t1 ,REL_EXP_ACT_SUB t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Facturas.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_FACTURA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Facturas>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterfacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Facturas filterfacturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTURA IDFACTURA,t1.FECHA_FACTURA FECHAFACTURA,t1.NUMERO_FACTURA NUMEROFACTURA,t1.DESCRIPCION DESCRIPCION,t1.PROVEEDOR PROVEEDOR,t1.IMPORTE IMPORTE,t1.PAGADO PAGADO,t1.FECHA_PAGADO FECHAPAGADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM FACTURAS t1 ,REL_EXP_ACT_SUB t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterfacturas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Facturas.class,
				query, params, "ID_FACTURA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Facturas>>
	 */
	@Override
	public List<JerarquiaDto<Facturas>> findAllLikeJerarquia(Facturas filterFacturas,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTURA IDFACTURA,t1.FECHA_FACTURA FECHAFACTURA,t1.NUMERO_FACTURA NUMEROFACTURA,t1.DESCRIPCION DESCRIPCION,t1.PROVEEDOR PROVEEDOR,t1.IMPORTE IMPORTE,t1.PAGADO PAGADO,t1.FECHA_PAGADO FECHAPAGADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM FACTURAS t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("FACTURAS");
		from.add("REL_EXP_ACT_SUB");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterFacturas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_FACTURA", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					FacturasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM FACTURAS t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("FACTURAS");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterFacturas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_FACTURA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Facturas>>
	 */
	@Override
	public List<TableRowDto<Facturas>> findAllChild(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM FACTURAS t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("FACTURAS");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterFacturas, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_FACTURA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Facturas>(this.rwMapPK, "ID_FACTURA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Facturas entity
	 *
	 * @param facturas
	 *            Facturas Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Facturas facturas) {

		StringBuilder where = new StringBuilder(FacturasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (facturas != null && facturas.getIdFactura() != null) {
			where.append(" AND t1.ID_FACTURA = ?");
			params.add(facturas.getIdFactura());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(facturas.getRelExpActSub().getIdRelExpActSub());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getActSubvencionable() != null
				&& facturas.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(facturas.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(facturas.getRelExpActSub().getIdExpediente());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(facturas.getRelExpActSub().getFechaRegistro());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(facturas.getRelExpActSub().getUsuarioRegistro());
		}
		if (facturas != null && facturas.getFechaFactura() != null) {
			where.append(" AND t1.FECHA_FACTURA = ?");
			params.add(facturas.getFechaFactura());
		}
		if (facturas != null && facturas.getNumeroFactura() != null) {
			where.append(" AND t1.NUMERO_FACTURA = ?");
			params.add(facturas.getNumeroFactura());
		}
		if (facturas != null && facturas.getDescripcion() != null) {
			where.append(" AND t1.DESCRIPCION = ?");
			params.add(facturas.getDescripcion());
		}
		if (facturas != null && facturas.getProveedor() != null) {
			where.append(" AND t1.PROVEEDOR = ?");
			params.add(facturas.getProveedor());
		}
		if (facturas != null && facturas.getImporte() != null) {
			where.append(" AND t1.IMPORTE = ?");
			params.add(facturas.getImporte());
		}
		if (facturas != null && facturas.getPagado() != null) {
			where.append(" AND t1.PAGADO = ?");
			params.add(facturas.getPagado());
		}
		if (facturas != null && facturas.getFechaPagado() != null) {
			where.append(" AND t1.FECHA_PAGADO = ?");
			params.add(facturas.getFechaPagado());
		}
		if (facturas != null && facturas.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(facturas.getImporteAdmitido());
		}
		if (facturas != null && facturas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(facturas.getFechaRegistro());
		}
		if (facturas != null && facturas.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(facturas.getUsuarioRegistro());
		}
		if (facturas != null && facturas.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(facturas.getFechaUltmodificacion());
		}
		if (facturas != null && facturas.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(facturas.getUsuarioUltmodificacion());
		}

		if (facturas != null && facturas.getRelTipGasCon() != null) {
			where.append(" AND t1.ID_TIPO_GASTO_FAC = ?");
			params.add(facturas.getRelTipGasCon().getIdTipoGastoFac());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Facturas entity
	 *
	 * @param facturas
	 *            Facturas Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Facturas facturas, Boolean startsWith) {

		StringBuilder where = new StringBuilder(FacturasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (facturas != null && facturas.getIdFactura() != null) {
			where.append(" AND t1.ID_FACTURA = ?");
			params.add(facturas.getIdFactura());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(facturas.getRelExpActSub().getIdRelExpActSub());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getActSubvencionable() != null
				&& facturas.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(facturas.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(facturas.getRelExpActSub().getIdExpediente());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(facturas.getRelExpActSub().getFechaRegistro());
		}
		if (facturas != null && facturas.getRelExpActSub() != null
				&& facturas.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(facturas.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + facturas.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (facturas != null && facturas.getFechaFactura() != null) {
			where.append(" AND t1.FECHA_FACTURA = ?");
			params.add(facturas.getFechaFactura());
		}
		if (facturas != null && facturas.getNumeroFactura() != null) {
			where.append(" AND UPPER(t1.NUMERO_FACTURA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(facturas.getNumeroFactura().toUpperCase() + "%");
			} else {
				params.add("%" + facturas.getNumeroFactura().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_FACTURA IS NOT NULL");
		}
		if (facturas != null && facturas.getDescripcion() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(facturas.getDescripcion().toUpperCase() + "%");
			} else {
				params.add("%" + facturas.getDescripcion().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION IS NOT NULL");
		}
		if (facturas != null && facturas.getProveedor() != null) {
			where.append(" AND UPPER(t1.PROVEEDOR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(facturas.getProveedor().toUpperCase() + "%");
			} else {
				params.add("%" + facturas.getProveedor().toUpperCase() + "%");
			}
			where.append(" AND t1.PROVEEDOR IS NOT NULL");
		}
		if (facturas != null && facturas.getImporte() != null) {
			where.append(" AND t1.IMPORTE = ?");
			params.add(facturas.getImporte());
		}
		if (facturas != null && facturas.getPagado() != null) {
			where.append(" AND t1.PAGADO = ?");
			params.add(facturas.getPagado());
		}
		if (facturas != null && facturas.getFechaPagado() != null) {
			where.append(" AND t1.FECHA_PAGADO = ?");
			params.add(facturas.getFechaPagado());
		}
		if (facturas != null && facturas.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(facturas.getImporteAdmitido());
		}
		if (facturas != null && facturas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(facturas.getFechaRegistro());
		}
		if (facturas != null && facturas.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(facturas.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + facturas.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (facturas != null && facturas.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(facturas.getFechaUltmodificacion());
		}
		if (facturas != null && facturas.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(facturas.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + facturas.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		if (facturas != null && facturas.getRelTipGasCon() != null
				&& facturas.getRelTipGasCon().getIdTipoGastoFac() != null) {
			where.append(" AND t1.ID_TIPO_GASTO_FAC = ?");
			params.add(facturas.getRelTipGasCon().getIdTipoGastoFac());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public Facturas editEMCO(Integer idRelacion, Facturas factura, Usuario usuario) {

		if (factura.getFechaPagado() != null) {
			factura.setPagado(1);
		} else {
			factura.setPagado(0);
		}

		String query = "UPDATE FACTURAS SET NUMERO_FACTURA=?, OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?, INSPECCIONABLE=?, DESCRIPCION=?, IMPORTE=?, IMPORTE_ADMITIDO=?, PROVEEDOR=?, FECHA_PAGADO=?, FECHA_FACTURA=?, PAGADO=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_FACTURA=?";

		this.jdbcTemplate.update(query, factura.getNumeroFactura(), factura.getObservacionesCastellano(),
				factura.getObservacionesEuskera(), factura.getInspeccionable(), factura.getDescripcion(),
				factura.getImporte(), factura.getImporteAdmitido(), factura.getProveedor(), factura.getFechaPagado(),
				factura.getFechaFactura(), factura.getPagado(), usuario.getNombreUsuario(), factura.getIdFactura());

		return factura;
	}

	@Override
	public Facturas addEMCO(Integer idRelacion, Facturas factura, Usuario usuario) {
		String query = "INSERT INTO FACTURAS (ID_FACTURA, ID_REL_EXP_ACT_SUB, NUMERO_FACTURA, DESCRIPCION, IMPORTE, OBSERVACIONES_CASTELLANO, OBSERVACIONES_EUSKERA, INSPECCIONABLE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES( AB60.S_AB6007T00.NEXTVAL,?,?,?,?,?,?,?,SYSDATE,? )";

		this.jdbcTemplate.update(query, idRelacion, factura.getNumeroFactura(), factura.getDescripcion(),
				factura.getImporte(), factura.getObservacionesCastellano(), factura.getObservacionesEuskera(),
				factura.getInspeccionable(), usuario.getNombreUsuario());
		return factura;
	}

	@Override
	public BigDecimal sumaFacturasEMCO(Integer idRelacion) {
		String query = "SELECT SUM(IMPORTE) AS SUMAIMPORTES FROM FACTURAS WHERE ID_REL_EXP_ACT_SUB = ?";

		List<Facturas> listaSuma = this.jdbcTemplate.query(query, this.rwMapSumaFacturasEMCO, idRelacion);

		BigDecimal sumaFacturasEMCO = listaSuma.get(0).getImporte();

		return sumaFacturasEMCO;
	}

	@Override
	public Facturas updateEMCO(Facturas facturas) {
		String query = "UPDATE FACTURAS SET ID_REL_EXP_ACT_SUB=?, FECHA_FACTURA=TO_DATE (?,'DD/MM/YYYY'), NUMERO_FACTURA=?,OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?,INSPECCIONABLE=?, DESCRIPCION=?, PROVEEDOR=?, IMPORTE=?, PAGADO=?, FECHA_PAGADO=TO_DATE (?,'DD/MM/YYYY'), IMPORTE_ADMITIDO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, ID_TIPO_GASTO_FAC = ? WHERE ID_FACTURA=?";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (facturas.getRelExpActSub() != null && facturas.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = facturas.getRelExpActSub().getIdRelExpActSub();
		}

		if (facturas.getRelTipGasCon() != null && facturas.getRelTipGasCon().getIdTipoGastoFac() != null) {
			if (facturas.getRelTipGasCon().getIdTipoGastoFac() == 2) {
				facturas.setProveedor(null);
				facturas.setFechaPagado(null);
				facturas.setFechaPagadoStr(null);
			}
		}

		this.jdbcTemplate.update(query, getRelExpActSubIdRelExpActSubAux, facturas.getFechaFacturaStr(),
				facturas.getNumeroFactura(), facturas.getObservacionesCastellano(), facturas.getObservacionesEuskera(),
				facturas.getInspeccionable(), facturas.getDescripcion(), facturas.getProveedor(), facturas.getImporte(),
				facturas.getPagado(), facturas.getFechaPagadoStr(), facturas.getImporteAdmitido(),
				facturas.getFechaUltmodificacion(), facturas.getUsuarioUltmodificacion(),
				facturas.getRelTipGasCon().getIdTipoGastoFac(), facturas.getIdFactura());
		return facturas;
	}
}
