package com.ejie.ab60.dao.MEC;

import java.util.List;

import com.ejie.ab60.model.MEC.Participantes;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ParticipantesDao  
 * 
 *  
 */

public interface ParticipantesDao {

	/**
	 * Inserts a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return Participantes
	 */
	Participantes add(Participantes participantes);

	/**
	 * Updates a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return Participantes
	 */
	Participantes update(Participantes participantes);

	/**
	 * Busca la lista de participantes para la comunidad de bienes ,del
	 * solicitante titular
	 *
	 * @param idTercero
	 *            Integer
	 * @return List<Participantes> Participantes
	 */
	List<Participantes> find(Integer idTercero);

	/**
	 * Busca participante de la comunidad de bienes del solicitante titular
	 *
	 * @param idParticipante
	 *            Integer
	 * @return Participantes participantes
	 */

	public Participantes findParticipante(Integer idParticipante);

	/**
	 * Removes a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 */
	void remove(Participantes participantes);

	/**
	 * Finds a List of rows in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<Participantes> findAll(Participantes participantes, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in Participantes using like.
	 *
	 * @param participantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Participantes> findAllLike(Participantes participantes, Expedientes expediente);

	/**
	 * Finds rows in the Participantes table using like.
	 *
	 * @param participantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Participantes> findAllLike(Participantes participantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the Participantes table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the Participantes table using like.
	 *
	 * @param participantes
	 *            Participantes
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(Participantes participantes, Boolean startsWith);

	/**
	 * Counts rows in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return Long
	 */
	Long findAllCount(Participantes participantes);

	/**
	 * Reorder selection.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Participantes>>
	 */
	List<TableRowDto<Participantes>> reorderSelection(Participantes filterParticipantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param searchParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Participantes>>
	 */
	List<TableRowDto<Participantes>> search(Participantes filterParticipantes, Participantes searchParticipantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical Participantes table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Participantes>>
	 */
	List<JerarquiaDto<Participantes>> findAllLikeJerarquia(Participantes filterParticipantes,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Participantes>>
	 */
	List<TableRowDto<Participantes>> findAllChild(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto);

}
