package com.ejie.ab60.dao.MEC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;

import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.MEC.Participantes;
import com.ejie.ab60.model.expedientes.Expedientes;

import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ParticipantesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ParticipantesDaoImpl implements ParticipantesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPARTICIPANTE", "IDEMPRESA", "IDTIPODOCUMENTO",
			"TIPODOCUMENTOCASTELLANO", "TIPODOCUMENTOEUSKERA", "TIPODOCUMENTOFECHAREGISTRO",
			"TIPODOCUMENTOUSUARIOREGISTRO", "NUMERO", "NOMBRE", "APELLIDO1", "APELLIDO2", "IDSEXO", "SEXOCASTELLANO",
			"SEXOEUSKERA", "SEXOFECHAREGISTRO", "SEXOUSUARIOREGISTRO", "PORCENTAJEPARTICIPACION", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/**
	 * 
	 * 
	 * /** Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * ROW_MAPPERS
	 * 
	 */
	private RowMapper<Participantes> rwMap = new RowMapper<Participantes>() {
		public Participantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Participantes(resultSet.getInt("IDPARTICIPANTE"), resultSet.getInt("IDTERCERO"),
					resultSet.getLong("IDTIPODOCUMENTO"), resultSet.getString("NUMERO"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"), resultSet.getLong("IDSEXO"),
					resultSet.getBigDecimal("porcentajeParticipacion"), null, null, null, null);
		}
	};

	/*
	 * ROW_MAPPERS
	 * 
	 */
	private RowMapper<Participantes> rwMapParticipante = new RowMapper<Participantes>() {
		public Participantes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Participantes(resultSet.getInt("IDPARTICIPANTE"), resultSet.getInt("IDTERCERO"),
					resultSet.getLong("IDTIPODOCUMENTO"), resultSet.getString("NUMERO"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"), resultSet.getLong("IDSEXO"),
					resultSet.getBigDecimal("porcentajeParticipacion"), null, null, null, null);
		}
	};
	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return Participantes
	 */
	public Participantes add(Participantes participantes) {
		String query = "INSERT INTO  PARTICIPANTES (ID_PARTICIPANTE, ID_TIPO_DOCUMENTO, NUMERO, NOMBRE, APELLIDO1, APELLIDO2, ID_SEXO, PORCENTAJE_PARTICIPACION,ID_TERCERO, FECHA_REGISTRO, USUARIO_REGISTRO)  VALUES (S_AB6014T00.NEXTVAL,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, participantes.getIdTipoDocumento(), participantes.getNumero(),
				participantes.getNombre(), participantes.getApellido1(), participantes.getApellido2(),
				participantes.getIdSexo(), participantes.getPorcentajeParticipacion(), participantes.getIdTercero(),
				new Date(), participantes.getUsuarioRegistro());
		return participantes;
	}

	/**
	 * Updates a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return Participantes
	 */
	public Participantes update(Participantes participantes) {
		String query = "UPDATE PARTICIPANTES SET ID_TIPO_DOCUMENTO= ?, NUMERO=?, NOMBRE=?, APELLIDO1=?, APELLIDO2=?, ID_SEXO=?, PORCENTAJE_PARTICIPACION=?, FECHA_ULTMODIFICACION=sysdate, USUARIO_ULTMODIFICACION=? WHERE ID_PARTICIPANTE=?";

		this.jdbcTemplate.update(query, participantes.getIdTipoDocumento(), participantes.getNumero(),
				participantes.getNombre(), participantes.getApellido1(), participantes.getApellido2(),
				participantes.getIdSexo(), participantes.getPorcentajeParticipacion(),
				participantes.getUsuarioUltmodificacion(), participantes.getIdParticipante());
		return participantes;
	}

	/**
	 * Busca la lista de participantes para la comunidad de bienes ,del
	 * solicitante titular
	 *
	 * @param idTercero
	 *            Integer
	 * @return List<Participantes> Participantes
	 */
	@Transactional(readOnly = true)
	public List<Participantes> find(Integer idTercero) {
		String query = "SELECT ID_PARTICIPANTE AS IDPARTICIPANTE,ID_TIPO_DOCUMENTO AS IDTIPODOCUMENTO, NUMERO AS NUMERO,NOMBRE AS NOMBRE, APELLIDO1 AS APELLIDO1, APELLIDO2 AS APELLIDO2, ID_SEXO AS IDSEXO, PORCENTAJE_PARTICIPACION AS PORCENTAJEPARTICIPACION, ID_TERCERO AS IDTERCERO FROM PARTICIPANTES WHERE ID_TERCERO = ?";
		List<Participantes> participantesList = this.jdbcTemplate.query(query, this.rwMap, idTercero);
		return participantesList;
	}

	/**
	 * Busca participante de la comunidad de bienes del solicitante titular
	 *
	 * @param idParticipante
	 *            Integer
	 * @return Participantes participantes
	 */
	@Transactional(readOnly = true)
	public Participantes findParticipante(Integer idParticipante) {
		String query = "SELECT ID_PARTICIPANTE AS IDPARTICIPANTE,ID_TERCERO AS IDTERCERO,ID_TIPO_DOCUMENTO AS IDTIPODOCUMENTO, NUMERO AS NUMERO,NOMBRE AS NOMBRE, APELLIDO1 AS APELLIDO1, APELLIDO2 AS APELLIDO2, ID_SEXO AS IDSEXO, PORCENTAJE_PARTICIPACION AS PORCENTAJEPARTICIPACION FROM PARTICIPANTES WHERE ID_PARTICIPANTE = ?";
		List<Participantes> participantesList = this.jdbcTemplate.query(query, this.rwMapParticipante, idParticipante);

		return (Participantes) DataAccessUtils.uniqueResult(participantesList);
	}

	/**
	 * Removes a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return
	 */
	public void remove(Participantes participantes) {
		String query = "DELETE FROM PARTICIPANTES WHERE ID_PARTICIPANTE=?";
		this.jdbcTemplate.update(query, participantes.getIdParticipante());
	}

	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public List<Participantes> findAll(Participantes participantes, JQGridRequestDto jqGridRequestDto) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<Participantes> findAllLike(Participantes participantes, Expedientes expediente) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<Participantes> findAllLike(Participantes participantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public void removeMultiple(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// TODO Auto-generated method stub

	}

	@Override
	public Long findAllLikeCount(Participantes participantes, Boolean startsWith) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Long findAllCount(Participantes participantes) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<TableRowDto<Participantes>> reorderSelection(Participantes filterParticipantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<TableRowDto<Participantes>> search(Participantes filterParticipantes, Participantes searchParticipantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<JerarquiaDto<Participantes>> findAllLikeJerarquia(Participantes filterParticipantes,
			JQGridRequestDto jqGridRequestDto) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Long findAllLikeCountJerarquia(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<TableRowDto<Participantes>> findAllChild(Participantes filterParticipantes,
			JQGridRequestDto jqGridRequestDto) {
		// TODO Auto-generated method stub
		return null;
	}
}
