package com.ejie.ab60.dao.MEC;

import com.ejie.ab60.model.MEC.RelFacMotDen;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotDen;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * RelFacMotDenDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelFacMotDenDaoImpl implements RelFacMotDenDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELFACMOTDEN", "IDFACTURA",
			"IDMOTIVODENEGACION", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelFacMotDen> rwMap = new RowMapper<RelFacMotDen>() {
		public RelFacMotDen mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelFacMotDen(resultSet.getInt("IDRELFACMOTDEN"), resultSet.getInt("IDFACTURA"),
					resultSet.getLong("IDMOTIVODENEGACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<RelFacMotDen> rwMapfindIdsFacturaMotivosDenegaciones = new RowMapper<RelFacMotDen>() {
		public RelFacMotDen mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelFacMotDen(null, null, resultSet.getLong("IDMOTIVODENEGACION"), null, null, null, null);
		}
	};
	private RowMapper<RelFacMotDen> rwMapPK = new RowMapper<RelFacMotDen>() {
		public RelFacMotDen mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelFacMotDen(resultSet.getInt("IDRELFACMOTDEN"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelFacMotDen>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelFacMotDen>>() {
		public JerarquiaDto<RelFacMotDen> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelFacMotDen relfacmotden = new RelFacMotDen(resultSet.getInt("IDRELFACMOTDEN"),
					resultSet.getInt("IDFACTURA"), resultSet.getLong("IDMOTIVODENEGACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<RelFacMotDen> jerarquia = new JerarquiaDto<RelFacMotDen>();
			jerarquia.setModel(relfacmotden);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelFacMotDen table.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @return RelFacMotDen
	 */
	public RelFacMotDen add(RelFacMotDen relfacmotden) {

		String query = "INSERT INTO REL_FAC_MOT_DEN (ID_REL_FAC_MOT_DEN, ID_FACTURA, ID_MOTIVO_DENEGACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6063T00.NEXTVAL,?,?,?,?)";
		this.jdbcTemplate.update(query, relfacmotden.getIdFactura(), relfacmotden.getIdMotivoDenegacion(),
				relfacmotden.getFechaRegistro(), relfacmotden.getUsuarioRegistro());
		return relfacmotden;
	}

	/**
	 * Updates a single row in the RelFacMotDen table.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @return RelFacMotDen
	 */
	public RelFacMotDen update(RelFacMotDen relfacmotden) {
		String query = "UPDATE REL_FAC_MOT_DEN SET ID_FACTURA=?, ID_MOTIVO_DENEGACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_FAC_MOT_DEN=?";
		this.jdbcTemplate.update(query, relfacmotden.getIdFactura(), relfacmotden.getIdMotivoDenegacion(),
				relfacmotden.getFechaRegistro(), relfacmotden.getUsuarioRegistro(),
				relfacmotden.getFechaUltmodificacion(), relfacmotden.getUsuarioUltmodificacion(),
				relfacmotden.getIdRelFacMotDen());
		return relfacmotden;
	}

	/**
	 * Finds a single row in the RelFacMotDen table.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @return RelFacMotDen
	 */
	@Transactional(readOnly = true)
	public RelFacMotDen find(RelFacMotDen relfacmotden) {
		String query = "SELECT t1.ID_REL_FAC_MOT_DEN IDRELFACMOTDEN, t1.ID_FACTURA IDFACTURA, t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM REL_FAC_MOT_DEN t1  WHERE t1.ID_REL_FAC_MOT_DEN = ?  ";

		List<RelFacMotDen> relfacmotdenList = this.jdbcTemplate.query(query, this.rwMap,
				relfacmotden.getIdRelFacMotDen());
		return (RelFacMotDen) DataAccessUtils.uniqueResult(relfacmotdenList);
	}

	/**
	 * Saca los ids de motivos de denegacion
	 *
	 * @param idFactura
	 *            Integer
	 * 
	 * @return List<RelActSubMotDen>
	 */
	@Transactional(readOnly = true)
	public List<RelFacMotDen> findIdsFacturaMotivosDenegaciones(Integer idFactura) {
		String query = "SELECT  t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION FROM REL_FAC_MOT_DEN t1  WHERE t1.ID_FACTURA = ?  ";
		List<RelFacMotDen> relactsubmotdenList = this.jdbcTemplate.query(query,
				this.rwMapfindIdsFacturaMotivosDenegaciones, idFactura);
		return relactsubmotdenList;
	}

	/**
	 * Removes a single row in the RelFacMotDen table.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @return
	 */
	public void remove(RelFacMotDen relfacmotden) {
		String query = "DELETE FROM REL_FAC_MOT_DEN WHERE ID_FACTURA=?";
		this.jdbcTemplate.update(query, relfacmotden.getIdFactura());
	}

	/**
	 * Finds a list of rows in the RelFacMotDen table.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelFacMotDen>
	 */
	@Transactional(readOnly = true)
	public List<RelFacMotDen> findAll(RelFacMotDen relfacmotden, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_FAC_MOT_DEN IDRELFACMOTDEN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_FAC_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relfacmotden);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelFacMotDenDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelFacMotDen>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelFacMotDen table using like.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelFacMotDen>
	 */
	@Transactional(readOnly = true)
	public List<RelFacMotDen> findAllLike(RelFacMotDen relfacmotden, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_FAC_MOT_DEN IDRELFACMOTDEN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_FAC_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relfacmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelFacMotDenDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelFacMotDen>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelFacMotDen table.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelFacMotDen relfacmotden) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_FAC_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relfacmotden);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelFacMotDen table using like.
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelFacMotDen relfacmotden, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_FAC_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relfacmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelFacMotDen selected for rup_table
	 *
	 * @param relfacmotden
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelFacMotDen>>
	 */
	@Override
	public List<TableRowDto<RelFacMotDen>> reorderSelection(RelFacMotDen relfacmotden,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_DEN IDRELFACMOTDEN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_FAC_MOT_DEN t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relfacmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelFacMotDen.class,
				filterParamList, "ID_REL_FAC_MOT_DEN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelFacMotDen>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelFacMotDen
	 * @param searchParams
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelFacMotDen>>
	 */
	@Override
	public List<TableRowDto<RelFacMotDen>> search(RelFacMotDen filterParams, RelFacMotDen searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_DEN IDRELFACMOTDEN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_FAC_MOT_DEN t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelFacMotDen.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_FAC_MOT_DEN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelFacMotDen>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelfacmotden
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelFacMotDen filterrelfacmotden, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_DEN IDRELFACMOTDEN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_FAC_MOT_DEN t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelfacmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelFacMotDen.class,
				query, params, "ID_REL_FAC_MOT_DEN");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelFacMotDen table.
	 *
	 * @param filterRelFacMotDen
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelFacMotDen>>
	 */
	@Override
	public List<JerarquiaDto<RelFacMotDen>> findAllLikeJerarquia(RelFacMotDen filterRelFacMotDen,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_DEN IDRELFACMOTDEN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_FAC_MOT_DEN t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_FAC_MOT_DEN");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelFacMotDen, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_FAC_MOT_DEN", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelFacMotDenDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelFacMotDen
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelFacMotDen filterRelFacMotDen, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_FAC_MOT_DEN t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_FAC_MOT_DEN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelFacMotDen, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_FAC_MOT_DEN",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelFacMotDen
	 *            RelFacMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelFacMotDen>>
	 */
	@Override
	public List<TableRowDto<RelFacMotDen>> findAllChild(RelFacMotDen filterRelFacMotDen,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_FAC_MOT_DEN t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_FAC_MOT_DEN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelFacMotDen, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_FAC_MOT_DEN",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelFacMotDen>(this.rwMapPK, "ID_REL_FAC_MOT_DEN"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelFacMotDen entity
	 *
	 * @param relfacmotden
	 *            RelFacMotDen Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelFacMotDen relfacmotden) {

		StringBuilder where = new StringBuilder(RelFacMotDenDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relfacmotden != null && relfacmotden.getIdRelFacMotDen() != null) {
			where.append(" AND t1.ID_REL_FAC_MOT_DEN = ?");
			params.add(relfacmotden.getIdRelFacMotDen());
		}
		if (relfacmotden != null && relfacmotden.getIdFactura() != null) {
			where.append(" AND t1.ID_FACTURA = ?");
			params.add(relfacmotden.getIdFactura());
		}
		if (relfacmotden != null && relfacmotden.getIdMotivoDenegacion() != null) {
			where.append(" AND t1.ID_MOTIVO_DENEGACION = ?");
			params.add(relfacmotden.getIdMotivoDenegacion());
		}
		if (relfacmotden != null && relfacmotden.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relfacmotden.getFechaRegistro());
		}
		if (relfacmotden != null && relfacmotden.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relfacmotden.getUsuarioRegistro());
		}
		if (relfacmotden != null && relfacmotden.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relfacmotden.getFechaUltmodificacion());
		}
		if (relfacmotden != null && relfacmotden.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(relfacmotden.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelFacMotDen entity
	 *
	 * @param relfacmotden
	 *            RelFacMotDen Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelFacMotDen relfacmotden, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelFacMotDenDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relfacmotden != null && relfacmotden.getIdRelFacMotDen() != null) {
			where.append(" AND t1.ID_REL_FAC_MOT_DEN = ?");
			params.add(relfacmotden.getIdRelFacMotDen());
		}
		if (relfacmotden != null && relfacmotden.getIdFactura() != null) {
			where.append(" AND t1.ID_FACTURA = ?");
			params.add(relfacmotden.getIdFactura());
		}
		if (relfacmotden != null && relfacmotden.getIdMotivoDenegacion() != null) {
			where.append(" AND t1.ID_MOTIVO_DENEGACION = ?");
			params.add(relfacmotden.getIdMotivoDenegacion());
		}
		if (relfacmotden != null && relfacmotden.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relfacmotden.getFechaRegistro());
		}
		if (relfacmotden != null && relfacmotden.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relfacmotden.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relfacmotden.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relfacmotden != null && relfacmotden.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relfacmotden.getFechaUltmodificacion());
		}
		if (relfacmotden != null && relfacmotden.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relfacmotden.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relfacmotden.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
