package com.ejie.ab60.dao.MEC;

import com.ejie.ab60.model.MEC.RelFacMotMin;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * RelFacMotMinDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelFacMotMinDaoImpl implements RelFacMotMinDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELFACMOTMIN", "IDFACTURA",
			"IDMOTIVOMINORACION", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelFacMotMin> rwMap = new RowMapper<RelFacMotMin>() {
		public RelFacMotMin mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelFacMotMin(resultSet.getInt("IDRELFACMOTMIN"), resultSet.getInt("IDFACTURA"),
					resultSet.getLong("IDMOTIVOMINORACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<RelFacMotMin> rwMapfindIdsFacturaMotivosMinoraciones = new RowMapper<RelFacMotMin>() {
		public RelFacMotMin mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelFacMotMin(null, null, resultSet.getLong("IDMOTIVOMINORACION"), null, null, null, null);
		}
	};

	private RowMapper<RelFacMotMin> rwMapPK = new RowMapper<RelFacMotMin>() {
		public RelFacMotMin mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelFacMotMin(resultSet.getInt("IDRELFACMOTMIN"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelFacMotMin>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelFacMotMin>>() {
		public JerarquiaDto<RelFacMotMin> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelFacMotMin relfacmotmin = new RelFacMotMin(resultSet.getInt("IDRELFACMOTMIN"),
					resultSet.getInt("IDFACTURA"), resultSet.getLong("IDMOTIVOMINORACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<RelFacMotMin> jerarquia = new JerarquiaDto<RelFacMotMin>();
			jerarquia.setModel(relfacmotmin);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelFacMotMin table.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @return RelFacMotMin
	 */
	public RelFacMotMin add(RelFacMotMin relfacmotmin) {

		String query = "INSERT INTO REL_FAC_MOT_MIN (ID_REL_FAC_MOT_MIN, ID_FACTURA, ID_MOTIVO_MINORACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6062T00.NEXTVAL,?,?,?,?)";
		this.jdbcTemplate.update(query, relfacmotmin.getIdFactura(), relfacmotmin.getIdMotivoMinoracion(),
				relfacmotmin.getFechaRegistro(), relfacmotmin.getUsuarioRegistro());
		return relfacmotmin;
	}

	/**
	 * Updates a single row in the RelFacMotMin table.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @return RelFacMotMin
	 */
	public RelFacMotMin update(RelFacMotMin relfacmotmin) {
		String query = "UPDATE REL_FAC_MOT_MIN SET ID_FACTURA=?, ID_MOTIVO_MINORACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_FAC_MOT_MIN=?";
		this.jdbcTemplate.update(query, relfacmotmin.getIdFactura(), relfacmotmin.getIdMotivoMinoracion(),
				relfacmotmin.getFechaRegistro(), relfacmotmin.getUsuarioRegistro(),
				relfacmotmin.getFechaUltmodificacion(), relfacmotmin.getUsuarioUltmodificacion(),
				relfacmotmin.getIdRelFacMotMin());
		return relfacmotmin;
	}

	/**
	 * Finds a single row in the RelFacMotMin table.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @return RelFacMotMin
	 */
	@Transactional(readOnly = true)
	public RelFacMotMin find(RelFacMotMin relfacmotmin) {
		String query = "SELECT t1.ID_REL_FAC_MOT_MIN IDRELFACMOTMIN, t1.ID_FACTURA IDFACTURA, t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM REL_FAC_MOT_MIN t1  WHERE t1.ID_REL_FAC_MOT_MIN = ?  ";

		List<RelFacMotMin> relfacmotminList = this.jdbcTemplate.query(query, this.rwMap,
				relfacmotmin.getIdRelFacMotMin());
		return (RelFacMotMin) DataAccessUtils.uniqueResult(relfacmotminList);
	}

	/**
	 * Saca los ids de motivos de minoracion de factura
	 *
	 * @param idFactura
	 *            Integer
	 * 
	 * @return List<RelActSubMotDen>
	 */
	@Transactional(readOnly = true)
	public List<RelFacMotMin> findIdsFacturaMotivosMinoraciones(Integer idFactura, Integer origenMotivosMinoracion) {
		String query = "SELECT  t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION FROM REL_FAC_MOT_MIN t1, MOTIVOS_MINORACION t2  WHERE t1.ID_MOTIVO_MINORACION = t2.ID_MOTIVO_MINORACION AND t1.ID_FACTURA = ? AND t2.ORIGEN = ? ";
		List<RelFacMotMin> relactsubmotdenList = this.jdbcTemplate.query(query,
				this.rwMapfindIdsFacturaMotivosMinoraciones, idFactura, origenMotivosMinoracion);
		return relactsubmotdenList;
	}

	/**
	 * Removes a single row in the RelFacMotMin table.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @return
	 */
	public void remove(RelFacMotMin relfacmotmin) {
		String query = "DELETE FROM REL_FAC_MOT_MIN WHERE ID_FACTURA=?";
		this.jdbcTemplate.update(query, relfacmotmin.getIdFactura());
	}

	/**
	 * Finds a list of rows in the RelFacMotMin table.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelFacMotMin>
	 */
	@Transactional(readOnly = true)
	public List<RelFacMotMin> findAll(RelFacMotMin relfacmotmin, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_FAC_MOT_MIN IDRELFACMOTMIN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_FAC_MOT_MIN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relfacmotmin);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelFacMotMinDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelFacMotMin>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelFacMotMin table using like.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelFacMotMin>
	 */
	@Transactional(readOnly = true)
	public List<RelFacMotMin> findAllLike(RelFacMotMin relfacmotmin, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_FAC_MOT_MIN IDRELFACMOTMIN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_FAC_MOT_MIN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relfacmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelFacMotMinDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelFacMotMin>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelFacMotMin table.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelFacMotMin relfacmotmin) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_FAC_MOT_MIN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relfacmotmin);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelFacMotMin table using like.
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelFacMotMin relfacmotmin, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_FAC_MOT_MIN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relfacmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelFacMotMin selected for rup_table
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelFacMotMin>>
	 */
	@Override
	public List<TableRowDto<RelFacMotMin>> reorderSelection(RelFacMotMin relfacmotmin,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_MIN IDRELFACMOTMIN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_FAC_MOT_MIN t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relfacmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelFacMotMin.class,
				filterParamList, "ID_REL_FAC_MOT_MIN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelFacMotMin>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelFacMotMin
	 * @param searchParams
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelFacMotMin>>
	 */
	@Override
	public List<TableRowDto<RelFacMotMin>> search(RelFacMotMin filterParams, RelFacMotMin searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_MIN IDRELFACMOTMIN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_FAC_MOT_MIN t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelFacMotMin.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_FAC_MOT_MIN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelFacMotMin>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelfacmotmin
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelFacMotMin filterrelfacmotmin, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_MIN IDRELFACMOTMIN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_FAC_MOT_MIN t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelfacmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelFacMotMin.class,
				query, params, "ID_REL_FAC_MOT_MIN");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelFacMotMin table.
	 *
	 * @param filterRelFacMotMin
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelFacMotMin>>
	 */
	@Override
	public List<JerarquiaDto<RelFacMotMin>> findAllLikeJerarquia(RelFacMotMin filterRelFacMotMin,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_FAC_MOT_MIN IDRELFACMOTMIN,t1.ID_FACTURA IDFACTURA,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_FAC_MOT_MIN t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_FAC_MOT_MIN");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelFacMotMin, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_FAC_MOT_MIN", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelFacMotMinDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelFacMotMin
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelFacMotMin filterRelFacMotMin, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_FAC_MOT_MIN t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_FAC_MOT_MIN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelFacMotMin, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_FAC_MOT_MIN",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelFacMotMin
	 *            RelFacMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelFacMotMin>>
	 */
	@Override
	public List<TableRowDto<RelFacMotMin>> findAllChild(RelFacMotMin filterRelFacMotMin,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_FAC_MOT_MIN t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_FAC_MOT_MIN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelFacMotMin, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_FAC_MOT_MIN",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelFacMotMin>(this.rwMapPK, "ID_REL_FAC_MOT_MIN"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelFacMotMin entity
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelFacMotMin relfacmotmin) {

		StringBuilder where = new StringBuilder(RelFacMotMinDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relfacmotmin != null && relfacmotmin.getIdRelFacMotMin() != null) {
			where.append(" AND t1.ID_REL_FAC_MOT_MIN = ?");
			params.add(relfacmotmin.getIdRelFacMotMin());
		}
		if (relfacmotmin != null && relfacmotmin.getIdFactura() != null) {
			where.append(" AND t1.ID_FACTURA = ?");
			params.add(relfacmotmin.getIdFactura());
		}
		if (relfacmotmin != null && relfacmotmin.getIdMotivoMinoracion() != null) {
			where.append(" AND t1.ID_MOTIVO_MINORACION = ?");
			params.add(relfacmotmin.getIdMotivoMinoracion());
		}
		if (relfacmotmin != null && relfacmotmin.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relfacmotmin.getFechaRegistro());
		}
		if (relfacmotmin != null && relfacmotmin.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relfacmotmin.getUsuarioRegistro());
		}
		if (relfacmotmin != null && relfacmotmin.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relfacmotmin.getFechaUltmodificacion());
		}
		if (relfacmotmin != null && relfacmotmin.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(relfacmotmin.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelFacMotMin entity
	 *
	 * @param relfacmotmin
	 *            RelFacMotMin Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelFacMotMin relfacmotmin, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelFacMotMinDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relfacmotmin != null && relfacmotmin.getIdRelFacMotMin() != null) {
			where.append(" AND t1.ID_REL_FAC_MOT_MIN = ?");
			params.add(relfacmotmin.getIdRelFacMotMin());
		}
		if (relfacmotmin != null && relfacmotmin.getIdFactura() != null) {
			where.append(" AND t1.ID_FACTURA = ?");
			params.add(relfacmotmin.getIdFactura());
		}
		if (relfacmotmin != null && relfacmotmin.getIdMotivoMinoracion() != null) {
			where.append(" AND t1.ID_MOTIVO_MINORACION = ?");
			params.add(relfacmotmin.getIdMotivoMinoracion());
		}
		if (relfacmotmin != null && relfacmotmin.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relfacmotmin.getFechaRegistro());
		}
		if (relfacmotmin != null && relfacmotmin.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relfacmotmin.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relfacmotmin.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relfacmotmin != null && relfacmotmin.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relfacmotmin.getFechaUltmodificacion());
		}
		if (relfacmotmin != null && relfacmotmin.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relfacmotmin.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relfacmotmin.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
