package com.ejie.ab60.dao.OTC;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.OTC.OficinasTecnicas;
import com.ejie.ab60.model.OTC.Zonas;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * OficinasTecnicasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class OficinasTecnicasDaoImpl implements OficinasTecnicasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDOFICINATECNICA", "SUBVENCIONSOLICITADA",
			"SUBVENCIONADMITIDA", "FECHAINICIO", "MATERIALES", "ECONOMICOS", "PERSONALES", "NOMBRERESPONSABLE",
			"REMUNEACIONECONOMICA", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICAION", "USUARIOULTMODIFICAION",
			"ZONASIDZONA", "ZONASDESCRIPCIONCASTELLANO", "ZONASDESCRIPCIONEUSKERA", "ZONASFECHAREGISTRO",
			"ZONASUSUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<OficinasTecnicas> rwMap = new RowMapper<OficinasTecnicas>() {
		public OficinasTecnicas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new OficinasTecnicas(resultSet.getInt("IDOFICINATECNICA"),
					resultSet.getBigDecimal("SUBVENCIONSOLICITADA"), resultSet.getBigDecimal("SUBVENCIONADMITIDA"),
					resultSet.getDate("FECHAINICIO"), resultSet.getString("MATERIALES"),
					resultSet.getString("ECONOMICOS"), resultSet.getString("PERSONALES"),
					resultSet.getString("NOMBRERESPONSABLE"), resultSet.getBigDecimal("REMUNEACIONECONOMICA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICAION"), resultSet.getString("USUARIOULTMODIFICAION"),
					new Zonas(resultSet.getLong("ZonasIDZONA"), resultSet.getString("ZonasDESCRIPCIONCASTELLANO"),
							resultSet.getString("ZonasDESCRIPCIONEUSKERA"), resultSet.getDate("ZonasFECHAREGISTRO"),
							resultSet.getString("ZonasUSUARIOREGISTRO")));
		}
	};

	private RowMapper<OficinasTecnicas> rwMapPK = new RowMapper<OficinasTecnicas>() {
		public OficinasTecnicas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new OficinasTecnicas(resultSet.getInt("IDOFICINATECNICA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<OficinasTecnicas>> rwMapJerarquia = new RowMapper<JerarquiaDto<OficinasTecnicas>>() {
		public JerarquiaDto<OficinasTecnicas> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			OficinasTecnicas oficinastecnicas = new OficinasTecnicas(resultSet.getInt("IDOFICINATECNICA"),
					resultSet.getBigDecimal("SUBVENCIONSOLICITADA"), resultSet.getBigDecimal("SUBVENCIONADMITIDA"),
					resultSet.getDate("FECHAINICIO"), resultSet.getString("MATERIALES"),
					resultSet.getString("ECONOMICOS"), resultSet.getString("PERSONALES"),
					resultSet.getString("NOMBRERESPONSABLE"), resultSet.getBigDecimal("REMUNEACIONECONOMICA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICAION"), resultSet.getString("USUARIOULTMODIFICAION"),
					new Zonas(resultSet.getLong("ZonasIDZONA"), resultSet.getString("ZonasDESCRIPCIONCASTELLANO"),
							resultSet.getString("ZonasDESCRIPCIONEUSKERA"), resultSet.getDate("ZonasFECHAREGISTRO"),
							resultSet.getString("ZonasUSUARIOREGISTRO")));

			JerarquiaDto<OficinasTecnicas> jerarquia = new JerarquiaDto<OficinasTecnicas>();
			jerarquia.setModel(oficinastecnicas);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the OficinasTecnicas table.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @return OficinasTecnicas
	 */
	public OficinasTecnicas add(OficinasTecnicas oficinastecnicas) {
		String query = "INSERT INTO OFICINAS_TECNICAS (ID_OFICINA_TECNICA, ID_ZONA, SUBVENCION_SOLICITADA, SUBVENCION_ADMITIDA, FECHA_INICIO, MATERIALES, ECONOMICOS, PERSONALES, NOMBRE_RESPONSABLE, REMUNEACION_ECONOMICA, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICAION, USUARIO_ULTMODIFICAION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		Object getZonasIdZonaAux = null;
		if (oficinastecnicas.getZonas() != null && oficinastecnicas.getZonas().getIdZona() != null) {
			getZonasIdZonaAux = oficinastecnicas.getZonas().getIdZona();
		}
		this.jdbcTemplate.update(query, oficinastecnicas.getIdOficinaTecnica(), getZonasIdZonaAux,
				oficinastecnicas.getSubvencionSolicitada(), oficinastecnicas.getSubvencionAdmitida(),
				oficinastecnicas.getFechaInicio(), oficinastecnicas.getMateriales(), oficinastecnicas.getEconomicos(),
				oficinastecnicas.getPersonales(), oficinastecnicas.getNombreResponsable(),
				oficinastecnicas.getRemuneacionEconomica(), oficinastecnicas.getFechaRegistro(),
				oficinastecnicas.getUsuarioRegistro(), oficinastecnicas.getFechaUltmodificaion(),
				oficinastecnicas.getUsuarioUltmodificaion());
		return oficinastecnicas;
	}

	/**
	 * Updates a single row in the OficinasTecnicas table.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @return OficinasTecnicas
	 */
	public OficinasTecnicas update(OficinasTecnicas oficinastecnicas) {
		String query = "UPDATE OFICINAS_TECNICAS SET ID_ZONA=?, SUBVENCION_SOLICITADA=?, SUBVENCION_ADMITIDA=?, FECHA_INICIO=?, MATERIALES=?, ECONOMICOS=?, PERSONALES=?, NOMBRE_RESPONSABLE=?, REMUNEACION_ECONOMICA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICAION=?, USUARIO_ULTMODIFICAION=? WHERE ID_OFICINA_TECNICA=?";
		Object getZonasIdZonaAux = null;
		if (oficinastecnicas.getZonas() != null && oficinastecnicas.getZonas().getIdZona() != null) {
			getZonasIdZonaAux = oficinastecnicas.getZonas().getIdZona();
		}
		this.jdbcTemplate.update(query, getZonasIdZonaAux, oficinastecnicas.getSubvencionSolicitada(),
				oficinastecnicas.getSubvencionAdmitida(), oficinastecnicas.getFechaInicio(),
				oficinastecnicas.getMateriales(), oficinastecnicas.getEconomicos(), oficinastecnicas.getPersonales(),
				oficinastecnicas.getNombreResponsable(), oficinastecnicas.getRemuneacionEconomica(),
				oficinastecnicas.getFechaRegistro(), oficinastecnicas.getUsuarioRegistro(),
				oficinastecnicas.getFechaUltmodificaion(), oficinastecnicas.getUsuarioUltmodificaion(),
				oficinastecnicas.getIdOficinaTecnica());
		return oficinastecnicas;
	}

	/**
	 * Finds a single row in the OficinasTecnicas table.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @return OficinasTecnicas
	 */
	@Transactional(readOnly = true)
	public OficinasTecnicas find(OficinasTecnicas oficinastecnicas) {
		String query = "SELECT t1.ID_OFICINA_TECNICA IDOFICINATECNICA, t1.SUBVENCION_SOLICITADA SUBVENCIONSOLICITADA, t1.SUBVENCION_ADMITIDA SUBVENCIONADMITIDA, t1.FECHA_INICIO FECHAINICIO, t1.MATERIALES MATERIALES, t1.ECONOMICOS ECONOMICOS, t1.PERSONALES PERSONALES, t1.NOMBRE_RESPONSABLE NOMBRERESPONSABLE, t1.REMUNEACION_ECONOMICA REMUNEACIONECONOMICA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICAION FECHAULTMODIFICAION, t1.USUARIO_ULTMODIFICAION USUARIOULTMODIFICAION, t2.ID_ZONA ZONASIDZONA, t2.DESCRIPCION_CASTELLANO ZONASDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA ZONASDESCRIPCIONEUSKERA, t2.FECHA_REGISTRO ZONASFECHAREGISTRO, t2.USUARIO_REGISTRO ZONASUSUARIOREGISTRO FROM OFICINAS_TECNICAS t1 , ZONAS t2  WHERE t1.ID_OFICINA_TECNICA = ?   AND t1.ID_ZONA= t2.ID_ZONA(+)";

		List<OficinasTecnicas> oficinastecnicasList = this.jdbcTemplate.query(query, this.rwMap,
				oficinastecnicas.getIdOficinaTecnica());
		return (OficinasTecnicas) DataAccessUtils.uniqueResult(oficinastecnicasList);
	}

	/**
	 * Removes a single row in the OficinasTecnicas table.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @return
	 */
	public void remove(OficinasTecnicas oficinastecnicas) {
		String query = "DELETE FROM OFICINAS_TECNICAS WHERE ID_OFICINA_TECNICA=?";
		this.jdbcTemplate.update(query, oficinastecnicas.getIdOficinaTecnica());
	}

	/**
	 * Finds a list of rows in the OficinasTecnicas table.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<OficinasTecnicas>
	 */
	@Transactional(readOnly = true)
	public List<OficinasTecnicas> findAll(OficinasTecnicas oficinastecnicas, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_OFICINA_TECNICA IDOFICINATECNICA,t1.SUBVENCION_SOLICITADA SUBVENCIONSOLICITADA,t1.SUBVENCION_ADMITIDA SUBVENCIONADMITIDA,t1.FECHA_INICIO FECHAINICIO,t1.MATERIALES MATERIALES,t1.ECONOMICOS ECONOMICOS,t1.PERSONALES PERSONALES,t1.NOMBRE_RESPONSABLE NOMBRERESPONSABLE,t1.REMUNEACION_ECONOMICA REMUNEACIONECONOMICA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICAION FECHAULTMODIFICAION,t1.USUARIO_ULTMODIFICAION USUARIOULTMODIFICAION,t2.ID_ZONA ZONASIDZONA,t2.DESCRIPCION_CASTELLANO ZONASDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ZONASDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO ZONASFECHAREGISTRO,t2.USUARIO_REGISTRO ZONASUSUARIOREGISTRO ");
		query.append("FROM OFICINAS_TECNICAS t1 ,ZONAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(oficinastecnicas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ZONA= t2.ID_ZONA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					OficinasTecnicasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<OficinasTecnicas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the OficinasTecnicas table using like.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<OficinasTecnicas>
	 */
	@Transactional(readOnly = true)
	public List<OficinasTecnicas> findAllLike(OficinasTecnicas oficinastecnicas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_OFICINA_TECNICA IDOFICINATECNICA,t1.SUBVENCION_SOLICITADA SUBVENCIONSOLICITADA,t1.SUBVENCION_ADMITIDA SUBVENCIONADMITIDA,t1.FECHA_INICIO FECHAINICIO,t1.MATERIALES MATERIALES,t1.ECONOMICOS ECONOMICOS,t1.PERSONALES PERSONALES,t1.NOMBRE_RESPONSABLE NOMBRERESPONSABLE,t1.REMUNEACION_ECONOMICA REMUNEACIONECONOMICA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICAION FECHAULTMODIFICAION,t1.USUARIO_ULTMODIFICAION USUARIOULTMODIFICAION,t2.ID_ZONA ZONASIDZONA,t2.DESCRIPCION_CASTELLANO ZONASDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ZONASDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO ZONASFECHAREGISTRO,t2.USUARIO_REGISTRO ZONASUSUARIOREGISTRO ");
		query.append("FROM OFICINAS_TECNICAS t1 ,ZONAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(oficinastecnicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ZONA= t2.ID_ZONA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					OficinasTecnicasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<OficinasTecnicas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the OficinasTecnicas table.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(OficinasTecnicas oficinastecnicas) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM OFICINAS_TECNICAS t1 , ZONAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(oficinastecnicas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ZONA= t2.ID_ZONA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the OficinasTecnicas table using like.
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(OficinasTecnicas oficinastecnicas, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM OFICINAS_TECNICAS t1 ,ZONAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(oficinastecnicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ZONA= t2.ID_ZONA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of OficinasTecnicas selected for rup_table
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<OficinasTecnicas>>
	 */
	@Override
	public List<TableRowDto<OficinasTecnicas>> reorderSelection(OficinasTecnicas oficinastecnicas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OFICINA_TECNICA IDOFICINATECNICA,t1.SUBVENCION_SOLICITADA SUBVENCIONSOLICITADA,t1.SUBVENCION_ADMITIDA SUBVENCIONADMITIDA,t1.FECHA_INICIO FECHAINICIO,t1.MATERIALES MATERIALES,t1.ECONOMICOS ECONOMICOS,t1.PERSONALES PERSONALES,t1.NOMBRE_RESPONSABLE NOMBRERESPONSABLE,t1.REMUNEACION_ECONOMICA REMUNEACIONECONOMICA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICAION FECHAULTMODIFICAION,t1.USUARIO_ULTMODIFICAION USUARIOULTMODIFICAION,t2.ID_ZONA ZONASIDZONA,t2.DESCRIPCION_CASTELLANO ZONASDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ZONASDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO ZONASFECHAREGISTRO,t2.USUARIO_REGISTRO ZONASUSUARIOREGISTRO ");
		// FROM
		query.append("FROM OFICINAS_TECNICAS t1 ,ZONAS t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(oficinastecnicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ZONA= t2.ID_ZONA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				OficinasTecnicas.class, filterParamList, "ID_OFICINA_TECNICA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<OficinasTecnicas>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            OficinasTecnicas
	 * @param searchParams
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<OficinasTecnicas>>
	 */
	@Override
	public List<TableRowDto<OficinasTecnicas>> search(OficinasTecnicas filterParams, OficinasTecnicas searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OFICINA_TECNICA IDOFICINATECNICA,t1.SUBVENCION_SOLICITADA SUBVENCIONSOLICITADA,t1.SUBVENCION_ADMITIDA SUBVENCIONADMITIDA,t1.FECHA_INICIO FECHAINICIO,t1.MATERIALES MATERIALES,t1.ECONOMICOS ECONOMICOS,t1.PERSONALES PERSONALES,t1.NOMBRE_RESPONSABLE NOMBRERESPONSABLE,t1.REMUNEACION_ECONOMICA REMUNEACIONECONOMICA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICAION FECHAULTMODIFICAION,t1.USUARIO_ULTMODIFICAION USUARIOULTMODIFICAION,t2.ID_ZONA ZONASIDZONA,t2.DESCRIPCION_CASTELLANO ZONASDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ZONASDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO ZONASFECHAREGISTRO,t2.USUARIO_REGISTRO ZONASUSUARIOREGISTRO ");
		// FROM
		query.append("FROM OFICINAS_TECNICAS t1 ,ZONAS t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ZONA= t2.ID_ZONA(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				OficinasTecnicas.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_OFICINA_TECNICA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<OficinasTecnicas>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filteroficinastecnicas
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(OficinasTecnicas filteroficinastecnicas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OFICINA_TECNICA IDOFICINATECNICA,t1.SUBVENCION_SOLICITADA SUBVENCIONSOLICITADA,t1.SUBVENCION_ADMITIDA SUBVENCIONADMITIDA,t1.FECHA_INICIO FECHAINICIO,t1.MATERIALES MATERIALES,t1.ECONOMICOS ECONOMICOS,t1.PERSONALES PERSONALES,t1.NOMBRE_RESPONSABLE NOMBRERESPONSABLE,t1.REMUNEACION_ECONOMICA REMUNEACIONECONOMICA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICAION FECHAULTMODIFICAION,t1.USUARIO_ULTMODIFICAION USUARIOULTMODIFICAION,t2.ID_ZONA ZONASIDZONA,t2.DESCRIPCION_CASTELLANO ZONASDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ZONASDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO ZONASFECHAREGISTRO,t2.USUARIO_REGISTRO ZONASUSUARIOREGISTRO ");
		// FROM
		query.append("FROM OFICINAS_TECNICAS t1 ,ZONAS t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filteroficinastecnicas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				OficinasTecnicas.class, query, params, "ID_OFICINA_TECNICA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical OficinasTecnicas table.
	 *
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<OficinasTecnicas>>
	 */
	@Override
	public List<JerarquiaDto<OficinasTecnicas>> findAllLikeJerarquia(OficinasTecnicas filterOficinasTecnicas,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OFICINA_TECNICA IDOFICINATECNICA,t1.SUBVENCION_SOLICITADA SUBVENCIONSOLICITADA,t1.SUBVENCION_ADMITIDA SUBVENCIONADMITIDA,t1.FECHA_INICIO FECHAINICIO,t1.MATERIALES MATERIALES,t1.ECONOMICOS ECONOMICOS,t1.PERSONALES PERSONALES,t1.NOMBRE_RESPONSABLE NOMBRERESPONSABLE,t1.REMUNEACION_ECONOMICA REMUNEACIONECONOMICA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICAION FECHAULTMODIFICAION,t1.USUARIO_ULTMODIFICAION USUARIOULTMODIFICAION,t2.ID_ZONA ZONASIDZONA,t2.DESCRIPCION_CASTELLANO ZONASDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ZONASDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO ZONASFECHAREGISTRO,t2.USUARIO_REGISTRO ZONASUSUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM OFICINAS_TECNICAS t1
		// ,ZONAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("OFICINAS_TECNICAS");
		from.add("ZONAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOficinasTecnicas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_OFICINA_TECNICA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					OficinasTecnicasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(OficinasTecnicas filterOficinasTecnicas, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM OFICINAS_TECNICAS t1
		// ,ZONAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("OFICINAS_TECNICAS");
		from.add("ZONAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOficinasTecnicas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_OFICINA_TECNICA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<OficinasTecnicas>>
	 */
	@Override
	public List<TableRowDto<OficinasTecnicas>> findAllChild(OficinasTecnicas filterOficinasTecnicas,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM OFICINAS_TECNICAS t1
		// ,ZONAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("OFICINAS_TECNICAS");
		from.add("ZONAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOficinasTecnicas, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_OFICINA_TECNICA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<OficinasTecnicas>(this.rwMapPK, "ID_OFICINA_TECNICA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the OficinasTecnicas entity
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(OficinasTecnicas oficinastecnicas) {

		StringBuilder where = new StringBuilder(OficinasTecnicasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (oficinastecnicas != null && oficinastecnicas.getIdOficinaTecnica() != null) {
			where.append(" AND t1.ID_OFICINA_TECNICA = ?");
			params.add(oficinastecnicas.getIdOficinaTecnica());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getIdZona() != null) {
			where.append(" AND t2.ID_ZONA = ?");
			params.add(oficinastecnicas.getZonas().getIdZona());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(oficinastecnicas.getZonas().getDescripcionCastellano());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(oficinastecnicas.getZonas().getDescripcionEuskera());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(oficinastecnicas.getZonas().getFechaRegistro());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(oficinastecnicas.getZonas().getUsuarioRegistro());
		}
		if (oficinastecnicas != null && oficinastecnicas.getSubvencionSolicitada() != null) {
			where.append(" AND t1.SUBVENCION_SOLICITADA = ?");
			params.add(oficinastecnicas.getSubvencionSolicitada());
		}
		if (oficinastecnicas != null && oficinastecnicas.getSubvencionAdmitida() != null) {
			where.append(" AND t1.SUBVENCION_ADMITIDA = ?");
			params.add(oficinastecnicas.getSubvencionAdmitida());
		}
		if (oficinastecnicas != null && oficinastecnicas.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(oficinastecnicas.getFechaInicio());
		}
		if (oficinastecnicas != null && oficinastecnicas.getMateriales() != null) {
			where.append(" AND t1.MATERIALES = ?");
			params.add(oficinastecnicas.getMateriales());
		}
		if (oficinastecnicas != null && oficinastecnicas.getEconomicos() != null) {
			where.append(" AND t1.ECONOMICOS = ?");
			params.add(oficinastecnicas.getEconomicos());
		}
		if (oficinastecnicas != null && oficinastecnicas.getPersonales() != null) {
			where.append(" AND t1.PERSONALES = ?");
			params.add(oficinastecnicas.getPersonales());
		}
		if (oficinastecnicas != null && oficinastecnicas.getNombreResponsable() != null) {
			where.append(" AND t1.NOMBRE_RESPONSABLE = ?");
			params.add(oficinastecnicas.getNombreResponsable());
		}
		if (oficinastecnicas != null && oficinastecnicas.getRemuneacionEconomica() != null) {
			where.append(" AND t1.REMUNEACION_ECONOMICA = ?");
			params.add(oficinastecnicas.getRemuneacionEconomica());
		}
		if (oficinastecnicas != null && oficinastecnicas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(oficinastecnicas.getFechaRegistro());
		}
		if (oficinastecnicas != null && oficinastecnicas.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(oficinastecnicas.getUsuarioRegistro());
		}
		if (oficinastecnicas != null && oficinastecnicas.getFechaUltmodificaion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICAION = ?");
			params.add(oficinastecnicas.getFechaUltmodificaion());
		}
		if (oficinastecnicas != null && oficinastecnicas.getUsuarioUltmodificaion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICAION = ?");
			params.add(oficinastecnicas.getUsuarioUltmodificaion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the OficinasTecnicas entity
	 *
	 * @param oficinastecnicas
	 *            OficinasTecnicas Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(OficinasTecnicas oficinastecnicas, Boolean startsWith) {

		StringBuilder where = new StringBuilder(OficinasTecnicasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (oficinastecnicas != null && oficinastecnicas.getIdOficinaTecnica() != null) {
			where.append(" AND t1.ID_OFICINA_TECNICA = ?");
			params.add(oficinastecnicas.getIdOficinaTecnica());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getIdZona() != null) {
			where.append(" AND t2.ID_ZONA = ?");
			params.add(oficinastecnicas.getZonas().getIdZona());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getZonas().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getZonas().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getZonas().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getZonas().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(oficinastecnicas.getZonas().getFechaRegistro());
		}
		if (oficinastecnicas != null && oficinastecnicas.getZonas() != null
				&& oficinastecnicas.getZonas().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getZonas().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getZonas().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getSubvencionSolicitada() != null) {
			where.append(" AND t1.SUBVENCION_SOLICITADA = ?");
			params.add(oficinastecnicas.getSubvencionSolicitada());
		}
		if (oficinastecnicas != null && oficinastecnicas.getSubvencionAdmitida() != null) {
			where.append(" AND t1.SUBVENCION_ADMITIDA = ?");
			params.add(oficinastecnicas.getSubvencionAdmitida());
		}
		if (oficinastecnicas != null && oficinastecnicas.getFechaInicio() != null) {
			where.append(" AND t1.FECHA_INICIO = ?");
			params.add(oficinastecnicas.getFechaInicio());
		}
		if (oficinastecnicas != null && oficinastecnicas.getMateriales() != null) {
			where.append(" AND UPPER(t1.MATERIALES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getMateriales().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getMateriales().toUpperCase() + "%");
			}
			where.append(" AND t1.MATERIALES IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getEconomicos() != null) {
			where.append(" AND UPPER(t1.ECONOMICOS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getEconomicos().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getEconomicos().toUpperCase() + "%");
			}
			where.append(" AND t1.ECONOMICOS IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getPersonales() != null) {
			where.append(" AND UPPER(t1.PERSONALES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getPersonales().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getPersonales().toUpperCase() + "%");
			}
			where.append(" AND t1.PERSONALES IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getNombreResponsable() != null) {
			where.append(" AND UPPER(t1.NOMBRE_RESPONSABLE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getNombreResponsable().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getNombreResponsable().toUpperCase() + "%");
			}
			where.append(" AND t1.NOMBRE_RESPONSABLE IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getRemuneacionEconomica() != null) {
			where.append(" AND t1.REMUNEACION_ECONOMICA = ?");
			params.add(oficinastecnicas.getRemuneacionEconomica());
		}
		if (oficinastecnicas != null && oficinastecnicas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(oficinastecnicas.getFechaRegistro());
		}
		if (oficinastecnicas != null && oficinastecnicas.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (oficinastecnicas != null && oficinastecnicas.getFechaUltmodificaion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICAION = ?");
			params.add(oficinastecnicas.getFechaUltmodificaion());
		}
		if (oficinastecnicas != null && oficinastecnicas.getUsuarioUltmodificaion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICAION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(oficinastecnicas.getUsuarioUltmodificaion().toUpperCase() + "%");
			} else {
				params.add("%" + oficinastecnicas.getUsuarioUltmodificaion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICAION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
