package com.ejie.ab60.dao.OTC;

import java.util.List;

import com.ejie.ab60.model.OTC.Zonas;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ZonasDao  
 * 
 *  
 */

public interface ZonasDao {

	/**
	 * Inserts a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @return Zonas
	 */
	Zonas add(Zonas zonas);

	/**
	 * Updates a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @return Zonas
	 */
	Zonas update(Zonas zonas);

	/**
	 * Finds a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @return Zonas
	 */
	Zonas find(Zonas zonas);

	/**
	 * Removes a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 */
	void remove(Zonas zonas);

	/**
	 * Finds a List of rows in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<Zonas> findAll(Zonas zonas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Zonas table using like.
	 *
	 * @param zonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Zonas> findAllLike(Zonas zonas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Zonas filterZonas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the Zonas table using like.
	 *
	 * @param zonas
	 *            Zonas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(Zonas zonas, Boolean startsWith);

	/**
	 * Counts rows in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @return Long
	 */
	Long findAllCount(Zonas zonas);

	/**
	 * Reorder selection.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Zonas>>
	 */
	List<TableRowDto<Zonas>> reorderSelection(Zonas filterZonas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param searchZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Zonas>>
	 */
	List<TableRowDto<Zonas>> search(Zonas filterZonas, Zonas searchZonas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Zonas>>
	 */
	List<JerarquiaDto<Zonas>> findAllLikeJerarquia(Zonas filterZonas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(Zonas filterZonas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Zonas>>
	 */
	List<TableRowDto<Zonas>> findAllChild(Zonas filterZonas, JQGridRequestDto jqGridRequestDto);

}
