package com.ejie.ab60.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.OtrosIngresos;

/**
 * OtrosIngresosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class OtrosIngresosDaoImpl implements OtrosIngresosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDOTROSINGRESOS", "IDRELEXPACTSUB", "IMPORTE",
			"FASE", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<OtrosIngresos> rwMap = new RowMapper<OtrosIngresos>() {
		public OtrosIngresos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new OtrosIngresos(resultSet.getInt("IDOTROSINGRESOS"), resultSet.getInt("IDRELEXPACTSUB"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getInt("FASE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the OtrosIngresos table.
	 *
	 * @param otrosingresos
	 *            OtrosIngresos
	 * @return OtrosIngresos
	 */
	public OtrosIngresos add(OtrosIngresos otrosingresos) {
		String query = "INSERT INTO OTROS_INGRESOS (ID_OTROS_INGRESOS, ID_REL_EXP_ACT_SUB, IMPORTE, FASE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (S_AB6091T00.NEXTVAL,?,?,?,?,?)";
		this.jdbcTemplate.update(query, otrosingresos.getIdRelExpActSub(), otrosingresos.getImporte(),
				otrosingresos.getFase(), otrosingresos.getFechaRegistro(), otrosingresos.getUsuarioRegistro());
		return otrosingresos;
	}

	/**
	 * Updates a single row in the OtrosIngresos table.
	 *
	 * @param otrosingresos
	 *            OtrosIngresos
	 * @return OtrosIngresos
	 */
	public OtrosIngresos update(OtrosIngresos otrosingresos) {
		String query = "UPDATE OTROS_INGRESOS SET ID_REL_EXP_ACT_SUB=?, IMPORTE=?, FASE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_OTROS_INGRESOS=?";
		this.jdbcTemplate.update(query, otrosingresos.getIdRelExpActSub(), otrosingresos.getImporte(),
				otrosingresos.getFase(), otrosingresos.getFechaRegistro(), otrosingresos.getUsuarioRegistro(),
				otrosingresos.getIdOtrosIngresos());
		return otrosingresos;
	}

	@Override
	public OtrosIngresos updateImporte(OtrosIngresos otrosIngresos) {
		String query = "UPDATE OTROS_INGRESOS SET IMPORTE=? WHERE ID_REL_EXP_ACT_SUB=? AND FASE = ? ";
		this.jdbcTemplate.update(query, otrosIngresos.getImporte(), otrosIngresos.getIdRelExpActSub(),
				otrosIngresos.getFase());

		return otrosIngresos;
	}

	/**
	 * Finds a single row in the OtrosIngresos table.
	 *
	 * @param otrosingresos
	 *            OtrosIngresos
	 * @return OtrosIngresos
	 */
	@Transactional(readOnly = true)
	public OtrosIngresos find(OtrosIngresos otrosingresos) {
		String query = "SELECT t1.ID_OTROS_INGRESOS IDOTROSINGRESOS, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE IMPORTE, t1.FASE FASE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM OTROS_INGRESOS t1  WHERE t1.ID_OTROS_INGRESOS = ?  ";

		List<OtrosIngresos> otrosingresosList = this.jdbcTemplate.query(query, this.rwMap,
				otrosingresos.getIdOtrosIngresos());
		return (OtrosIngresos) DataAccessUtils.uniqueResult(otrosingresosList);
	}

	/**
	 * Finds a single row in the OtrosIngresos table.
	 *
	 * @param otrosingresos
	 *            OtrosIngresos
	 * @return OtrosIngresos
	 */
	@Transactional(readOnly = true)
	public OtrosIngresos findByIdRelExpActSub(OtrosIngresos otrosingresos) {
		String query = "SELECT t1.ID_OTROS_INGRESOS IDOTROSINGRESOS, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE IMPORTE, t1.FASE FASE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM OTROS_INGRESOS t1  WHERE t1.ID_REL_EXP_ACT_SUB = ? AND t1.FASE = ? ";

		List<OtrosIngresos> otrosingresosList = this.jdbcTemplate.query(query, this.rwMap,
				otrosingresos.getIdRelExpActSub(), otrosingresos.getFase());
		return (OtrosIngresos) DataAccessUtils.uniqueResult(otrosingresosList);
	}

	/**
	 * Removes a single row in the OtrosIngresos table.
	 *
	 * @param otrosingresos
	 *            OtrosIngresos
	 * @return
	 */
	public void remove(OtrosIngresos otrosingresos) {
		String query = "DELETE FROM OTROS_INGRESOS WHERE ID_OTROS_INGRESOS=?";
		this.jdbcTemplate.update(query, otrosingresos.getIdOtrosIngresos());
	}

	@Override
	public void removeImporte(OtrosIngresos otrosIngresos) {
		String query = "DELETE FROM OTROS_INGRESOS WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, otrosIngresos.getIdRelExpActSub());
	}

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
