package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.PTT.AmbitosTerritoriales;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AmbitosTerritorialesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class AmbitosTerritorialesDaoImpl implements AmbitosTerritorialesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDAMBITOTERRITORIAL", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<AmbitosTerritoriales> rwMap = new RowMapper<AmbitosTerritoriales>() {
		public AmbitosTerritoriales mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AmbitosTerritoriales(resultSet.getLong("IDAMBITOTERRITORIAL"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<AmbitosTerritoriales> rwMapPK = new RowMapper<AmbitosTerritoriales>() {
		public AmbitosTerritoriales mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AmbitosTerritoriales(resultSet.getLong("IDAMBITOTERRITORIAL"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<AmbitosTerritoriales>> rwMapJerarquia = new RowMapper<JerarquiaDto<AmbitosTerritoriales>>() {
		public JerarquiaDto<AmbitosTerritoriales> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			AmbitosTerritoriales ambitosterritoriales = new AmbitosTerritoriales(
					resultSet.getLong("IDAMBITOTERRITORIAL"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<AmbitosTerritoriales> jerarquia = new JerarquiaDto<AmbitosTerritoriales>();
			jerarquia.setModel(ambitosterritoriales);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the AmbitosTerritoriales table.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @return AmbitosTerritoriales
	 */
	public AmbitosTerritoriales add(AmbitosTerritoriales ambitosterritoriales) {
		String query = "INSERT INTO AMBITOS_TERRITORIALES (ID_AMBITO_TERRITORIAL, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, ambitosterritoriales.getIdAmbitoTerritorial(),
				ambitosterritoriales.getDescripcionCastellano(), ambitosterritoriales.getDescripcionEuskera(),
				ambitosterritoriales.getFechaRegistro(), ambitosterritoriales.getUsuarioRegistro());
		return ambitosterritoriales;
	}

	/**
	 * Updates a single row in the AmbitosTerritoriales table.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @return AmbitosTerritoriales
	 */
	public AmbitosTerritoriales update(AmbitosTerritoriales ambitosterritoriales) {
		String query = "UPDATE AMBITOS_TERRITORIALES SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_AMBITO_TERRITORIAL=?";
		this.jdbcTemplate.update(query, ambitosterritoriales.getDescripcionCastellano(),
				ambitosterritoriales.getDescripcionEuskera(), ambitosterritoriales.getFechaRegistro(),
				ambitosterritoriales.getUsuarioRegistro(), ambitosterritoriales.getIdAmbitoTerritorial());
		return ambitosterritoriales;
	}

	/**
	 * Finds a single row in the AmbitosTerritoriales table.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @return AmbitosTerritoriales
	 */
	@Transactional(readOnly = true)
	public AmbitosTerritoriales find(AmbitosTerritoriales ambitosterritoriales) {
		String query = "SELECT t1.ID_AMBITO_TERRITORIAL IDAMBITOTERRITORIAL, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM AMBITOS_TERRITORIALES t1  WHERE t1.ID_AMBITO_TERRITORIAL = ?  ";

		List<AmbitosTerritoriales> ambitosterritorialesList = this.jdbcTemplate.query(query, this.rwMap,
				ambitosterritoriales.getIdAmbitoTerritorial());
		return (AmbitosTerritoriales) DataAccessUtils.uniqueResult(ambitosterritorialesList);
	}

	/**
	 * Removes a single row in the AmbitosTerritoriales table.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @return
	 */
	public void remove(AmbitosTerritoriales ambitosterritoriales) {
		String query = "DELETE FROM AMBITOS_TERRITORIALES WHERE ID_AMBITO_TERRITORIAL=?";
		this.jdbcTemplate.update(query, ambitosterritoriales.getIdAmbitoTerritorial());
	}

	/**
	 * Finds a list of rows in the AmbitosTerritoriales table.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<AmbitosTerritoriales>
	 */
	@Transactional(readOnly = true)
	public List<AmbitosTerritoriales> findAll(AmbitosTerritoriales ambitosterritoriales,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_AMBITO_TERRITORIAL IDAMBITOTERRITORIAL,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM AMBITOS_TERRITORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ambitosterritoriales);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AmbitosTerritorialesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AmbitosTerritoriales>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the AmbitosTerritoriales table using like.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<AmbitosTerritoriales>
	 */
	@Transactional(readOnly = true)
	public List<AmbitosTerritoriales> findAllLike(AmbitosTerritoriales ambitosterritoriales,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_AMBITO_TERRITORIAL IDAMBITOTERRITORIAL,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM AMBITOS_TERRITORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ambitosterritoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AmbitosTerritorialesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AmbitosTerritoriales>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the AmbitosTerritoriales table.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(AmbitosTerritoriales ambitosterritoriales) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AMBITOS_TERRITORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ambitosterritoriales);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the AmbitosTerritoriales table using like.
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(AmbitosTerritoriales ambitosterritoriales, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AMBITOS_TERRITORIALES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ambitosterritoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of AmbitosTerritoriales selected for rup_table
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AmbitosTerritoriales>>
	 */
	@Override
	public List<TableRowDto<AmbitosTerritoriales>> reorderSelection(AmbitosTerritoriales ambitosterritoriales,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_AMBITO_TERRITORIAL IDAMBITOTERRITORIAL,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM AMBITOS_TERRITORIALES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ambitosterritoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				AmbitosTerritoriales.class, filterParamList, "ID_AMBITO_TERRITORIAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AmbitosTerritoriales>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            AmbitosTerritoriales
	 * @param searchParams
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AmbitosTerritoriales>>
	 */
	@Override
	public List<TableRowDto<AmbitosTerritoriales>> search(AmbitosTerritoriales filterParams,
			AmbitosTerritoriales searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_AMBITO_TERRITORIAL IDAMBITOTERRITORIAL,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM AMBITOS_TERRITORIALES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				AmbitosTerritoriales.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_AMBITO_TERRITORIAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AmbitosTerritoriales>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterambitosterritoriales
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(AmbitosTerritoriales filterambitosterritoriales, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_AMBITO_TERRITORIAL IDAMBITOTERRITORIAL,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM AMBITOS_TERRITORIALES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterambitosterritoriales, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				AmbitosTerritoriales.class, query, params, "ID_AMBITO_TERRITORIAL");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical AmbitosTerritoriales table.
	 *
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<AmbitosTerritoriales>>
	 */
	@Override
	public List<JerarquiaDto<AmbitosTerritoriales>> findAllLikeJerarquia(
			AmbitosTerritoriales filterAmbitosTerritoriales, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_AMBITO_TERRITORIAL IDAMBITOTERRITORIAL,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AMBITOS_TERRITORIALES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("AMBITOS_TERRITORIALES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAmbitosTerritoriales, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_AMBITO_TERRITORIAL", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					AmbitosTerritorialesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(AmbitosTerritoriales filterAmbitosTerritoriales,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AMBITOS_TERRITORIALES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("AMBITOS_TERRITORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAmbitosTerritoriales, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_AMBITO_TERRITORIAL",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<AmbitosTerritoriales>>
	 */
	@Override
	public List<TableRowDto<AmbitosTerritoriales>> findAllChild(AmbitosTerritoriales filterAmbitosTerritoriales,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AMBITOS_TERRITORIALES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("AMBITOS_TERRITORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAmbitosTerritoriales, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_AMBITO_TERRITORIAL", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<AmbitosTerritoriales>(this.rwMapPK, "ID_AMBITO_TERRITORIAL"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AmbitosTerritoriales entity
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(AmbitosTerritoriales ambitosterritoriales) {

		StringBuilder where = new StringBuilder(AmbitosTerritorialesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ambitosterritoriales != null && ambitosterritoriales.getIdAmbitoTerritorial() != null) {
			where.append(" AND t1.ID_AMBITO_TERRITORIAL = ?");
			params.add(ambitosterritoriales.getIdAmbitoTerritorial());
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(ambitosterritoriales.getDescripcionCastellano());
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(ambitosterritoriales.getDescripcionEuskera());
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ambitosterritoriales.getFechaRegistro());
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ambitosterritoriales.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AmbitosTerritoriales entity
	 *
	 * @param ambitosterritoriales
	 *            AmbitosTerritoriales Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(AmbitosTerritoriales ambitosterritoriales, Boolean startsWith) {

		StringBuilder where = new StringBuilder(AmbitosTerritorialesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ambitosterritoriales != null && ambitosterritoriales.getIdAmbitoTerritorial() != null) {
			where.append(" AND t1.ID_AMBITO_TERRITORIAL = ?");
			params.add(ambitosterritoriales.getIdAmbitoTerritorial());
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ambitosterritoriales.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + ambitosterritoriales.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ambitosterritoriales.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + ambitosterritoriales.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ambitosterritoriales.getFechaRegistro());
		}
		if (ambitosterritoriales != null && ambitosterritoriales.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ambitosterritoriales.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ambitosterritoriales.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
