package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.PTT.Competitividad;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * CompetitividadDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class CompetitividadDaoImpl implements CompetitividadDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCONPETITIVIDAD", "NEMPRESASDISTINTAS",
			"NTRABAJADORES", "NMUJERES", "NHOMBRES", "FECHAREGISTRO", "USUARIOREGISTRO", "RELEXPACTSUBIDRELEXPACTSUB",
			"RELEXPACTSUBIDEXPEDIENTE", "RELEXPACTSUBFECHAREGISTRO", "RELEXPACTSUBUSUARIOREGISTRO",
			"RELEXPACTSUBIDACTSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Competitividad> rwMap = new RowMapper<Competitividad>() {
		public Competitividad mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Competitividad(resultSet.getInt("IDCONPETITIVIDAD"), resultSet.getLong("NEMPRESASDISTINTAS"),
					resultSet.getLong("NTRABAJADORES"), resultSet.getLong("NMUJERES"), resultSet.getLong("NHOMBRES"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));
		}
	};

	private RowMapper<Competitividad> rwMapPK = new RowMapper<Competitividad>() {
		public Competitividad mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Competitividad(resultSet.getInt("IDCONPETITIVIDAD"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Competitividad>> rwMapJerarquia = new RowMapper<JerarquiaDto<Competitividad>>() {
		public JerarquiaDto<Competitividad> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Competitividad competitividad = new Competitividad(resultSet.getInt("IDCONPETITIVIDAD"),
					resultSet.getLong("NEMPRESASDISTINTAS"), resultSet.getLong("NTRABAJADORES"),
					resultSet.getLong("NMUJERES"), resultSet.getLong("NHOMBRES"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));

			JerarquiaDto<Competitividad> jerarquia = new JerarquiaDto<Competitividad>();
			jerarquia.setModel(competitividad);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return Competitividad
	 */
	public Competitividad add(Competitividad competitividad) {
		String query = "INSERT INTO COMPETITIVIDAD (ID_CONPETITIVIDAD, ID_REL_EXP_ACT_SUB, N_EMPRESAS_DISTINTAS, N_TRABAJADORES, N_MUJERES, N_HOMBRES, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?)";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (competitividad.getRelExpActSub() != null && competitividad.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = competitividad.getRelExpActSub().getIdRelExpActSub();
		}
		this.jdbcTemplate.update(query, competitividad.getIdCompetitividad(), getRelExpActSubIdRelExpActSubAux,
				competitividad.getNEmpresasDistintas(), competitividad.getNTrabajadores(), competitividad.getNMujeres(),
				competitividad.getNHombres(), competitividad.getFechaRegistro(), competitividad.getUsuarioRegistro());
		return competitividad;
	}

	/**
	 * Updates a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return Competitividad
	 */
	public Competitividad update(Competitividad competitividad) {
		String query = "UPDATE COMPETITIVIDAD SET ID_REL_EXP_ACT_SUB=?, N_EMPRESAS_DISTINTAS=?, N_TRABAJADORES=?, N_MUJERES=?, N_HOMBRES=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_CONPETITIVIDAD=?";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (competitividad.getRelExpActSub() != null && competitividad.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = competitividad.getRelExpActSub().getIdRelExpActSub();
		}
		this.jdbcTemplate.update(query, getRelExpActSubIdRelExpActSubAux, competitividad.getNEmpresasDistintas(),
				competitividad.getNTrabajadores(), competitividad.getNMujeres(), competitividad.getNHombres(),
				competitividad.getFechaRegistro(), competitividad.getUsuarioRegistro(),
				competitividad.getIdCompetitividad());
		return competitividad;
	}

	/**
	 * Finds a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return Competitividad
	 */
	@Transactional(readOnly = true)
	public Competitividad find(Competitividad competitividad) {
		String query = "SELECT t1.ID_CONPETITIVIDAD IDCONPETITIVIDAD, t1.N_EMPRESAS_DISTINTAS NEMPRESASDISTINTAS, t1.N_TRABAJADORES NTRABAJADORES, t1.N_MUJERES NMUJERES, t1.N_HOMBRES NHOMBRES, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE, t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO, t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB FROM COMPETITIVIDAD t1 , REL_EXP_ACT_SUB t2  WHERE t1.ID_CONPETITIVIDAD = ?   AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+)";

		List<Competitividad> competitividadList = this.jdbcTemplate.query(query, this.rwMap,
				competitividad.getIdCompetitividad());
		return (Competitividad) DataAccessUtils.uniqueResult(competitividadList);
	}

	/**
	 * Removes a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return
	 */
	public void remove(Competitividad competitividad) {
		String query = "DELETE FROM COMPETITIVIDAD WHERE ID_CONPETITIVIDAD=?";
		this.jdbcTemplate.update(query, competitividad.getIdCompetitividad());
	}

	/**
	 * Finds a list of rows in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Competitividad>
	 */
	@Transactional(readOnly = true)
	public List<Competitividad> findAll(Competitividad competitividad, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONPETITIVIDAD IDCONPETITIVIDAD,t1.N_EMPRESAS_DISTINTAS NEMPRESASDISTINTAS,t1.N_TRABAJADORES NTRABAJADORES,t1.N_MUJERES NMUJERES,t1.N_HOMBRES NHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM COMPETITIVIDAD t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(competitividad);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CompetitividadDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Competitividad>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Competitividad table using like.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Competitividad>
	 */
	@Transactional(readOnly = true)
	public List<Competitividad> findAllLike(Competitividad competitividad, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONPETITIVIDAD IDCONPETITIVIDAD,t1.N_EMPRESAS_DISTINTAS NEMPRESASDISTINTAS,t1.N_TRABAJADORES NTRABAJADORES,t1.N_MUJERES NMUJERES,t1.N_HOMBRES NHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM COMPETITIVIDAD t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(competitividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CompetitividadDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Competitividad>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Competitividad competitividad) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM COMPETITIVIDAD t1 , REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(competitividad);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Competitividad table using like.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Competitividad competitividad, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM COMPETITIVIDAD t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(competitividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Competitividad selected for rup_table
	 *
	 * @param competitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Competitividad>>
	 */
	@Override
	public List<TableRowDto<Competitividad>> reorderSelection(Competitividad competitividad,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONPETITIVIDAD IDCONPETITIVIDAD,t1.N_EMPRESAS_DISTINTAS NEMPRESASDISTINTAS,t1.N_TRABAJADORES NTRABAJADORES,t1.N_MUJERES NMUJERES,t1.N_HOMBRES NHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM COMPETITIVIDAD t1 ,REL_EXP_ACT_SUB t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(competitividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				Competitividad.class, filterParamList, "ID_CONPETITIVIDAD");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Competitividad>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Competitividad
	 * @param searchParams
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Competitividad>>
	 */
	@Override
	public List<TableRowDto<Competitividad>> search(Competitividad filterParams, Competitividad searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONPETITIVIDAD IDCONPETITIVIDAD,t1.N_EMPRESAS_DISTINTAS NEMPRESASDISTINTAS,t1.N_TRABAJADORES NTRABAJADORES,t1.N_MUJERES NMUJERES,t1.N_HOMBRES NHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM COMPETITIVIDAD t1 ,REL_EXP_ACT_SUB t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				Competitividad.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_CONPETITIVIDAD");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Competitividad>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtercompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Competitividad filtercompetitividad, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONPETITIVIDAD IDCONPETITIVIDAD,t1.N_EMPRESAS_DISTINTAS NEMPRESASDISTINTAS,t1.N_TRABAJADORES NTRABAJADORES,t1.N_MUJERES NMUJERES,t1.N_HOMBRES NHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM COMPETITIVIDAD t1 ,REL_EXP_ACT_SUB t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtercompetitividad, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Competitividad.class,
				query, params, "ID_CONPETITIVIDAD");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Competitividad table.
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Competitividad>>
	 */
	@Override
	public List<JerarquiaDto<Competitividad>> findAllLikeJerarquia(Competitividad filterCompetitividad,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONPETITIVIDAD IDCONPETITIVIDAD,t1.N_EMPRESAS_DISTINTAS NEMPRESASDISTINTAS,t1.N_TRABAJADORES NTRABAJADORES,t1.N_MUJERES NMUJERES,t1.N_HOMBRES NHOMBRES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM COMPETITIVIDAD t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("COMPETITIVIDAD");
		from.add("REL_EXP_ACT_SUB");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCompetitividad, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CONPETITIVIDAD", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					CompetitividadDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Competitividad filterCompetitividad, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM COMPETITIVIDAD t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("COMPETITIVIDAD");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCompetitividad, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CONPETITIVIDAD",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Competitividad>>
	 */
	@Override
	public List<TableRowDto<Competitividad>> findAllChild(Competitividad filterCompetitividad,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM COMPETITIVIDAD t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("COMPETITIVIDAD");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCompetitividad, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CONPETITIVIDAD",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Competitividad>(this.rwMapPK, "ID_CONPETITIVIDAD"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Competitividad entity
	 *
	 * @param competitividad
	 *            Competitividad Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Competitividad competitividad) {

		StringBuilder where = new StringBuilder(CompetitividadDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (competitividad != null && competitividad.getIdCompetitividad() != null) {
			where.append(" AND t1.ID_CONPETITIVIDAD = ?");
			params.add(competitividad.getIdCompetitividad());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(competitividad.getRelExpActSub().getIdRelExpActSub());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getActSubvencionable() != null
				&& competitividad.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(competitividad.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(competitividad.getRelExpActSub().getIdExpediente());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(competitividad.getRelExpActSub().getFechaRegistro());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(competitividad.getRelExpActSub().getUsuarioRegistro());
		}
		if (competitividad != null && competitividad.getNEmpresasDistintas() != null) {
			where.append(" AND t1.N_EMPRESAS_DISTINTAS = ?");
			params.add(competitividad.getNEmpresasDistintas());
		}
		if (competitividad != null && competitividad.getNTrabajadores() != null) {
			where.append(" AND t1.N_TRABAJADORES = ?");
			params.add(competitividad.getNTrabajadores());
		}
		if (competitividad != null && competitividad.getNMujeres() != null) {
			where.append(" AND t1.N_MUJERES = ?");
			params.add(competitividad.getNMujeres());
		}
		if (competitividad != null && competitividad.getNHombres() != null) {
			where.append(" AND t1.N_HOMBRES = ?");
			params.add(competitividad.getNHombres());
		}
		if (competitividad != null && competitividad.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(competitividad.getFechaRegistro());
		}
		if (competitividad != null && competitividad.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(competitividad.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Competitividad entity
	 *
	 * @param competitividad
	 *            Competitividad Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Competitividad competitividad, Boolean startsWith) {

		StringBuilder where = new StringBuilder(CompetitividadDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (competitividad != null && competitividad.getIdCompetitividad() != null) {
			where.append(" AND t1.ID_CONPETITIVIDAD = ?");
			params.add(competitividad.getIdCompetitividad());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(competitividad.getRelExpActSub().getIdRelExpActSub());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getActSubvencionable() != null
				&& competitividad.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(competitividad.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(competitividad.getRelExpActSub().getIdExpediente());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(competitividad.getRelExpActSub().getFechaRegistro());
		}
		if (competitividad != null && competitividad.getRelExpActSub() != null
				&& competitividad.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(competitividad.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + competitividad.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (competitividad != null && competitividad.getNEmpresasDistintas() != null) {
			where.append(" AND t1.N_EMPRESAS_DISTINTAS = ?");
			params.add(competitividad.getNEmpresasDistintas());
		}
		if (competitividad != null && competitividad.getNTrabajadores() != null) {
			where.append(" AND t1.N_TRABAJADORES = ?");
			params.add(competitividad.getNTrabajadores());
		}
		if (competitividad != null && competitividad.getNMujeres() != null) {
			where.append(" AND t1.N_MUJERES = ?");
			params.add(competitividad.getNMujeres());
		}
		if (competitividad != null && competitividad.getNHombres() != null) {
			where.append(" AND t1.N_HOMBRES = ?");
			params.add(competitividad.getNHombres());
		}
		if (competitividad != null && competitividad.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(competitividad.getFechaRegistro());
		}
		if (competitividad != null && competitividad.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(competitividad.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + competitividad.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
