package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.PTT.ContratacionesPersonal;
import com.ejie.ab60.model.PTT.ModalidadesContrato;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.terceros.Sexo;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ContratacionesPersonalDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ContratacionesPersonalDaoImpl implements ContratacionesPersonalDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCONTRATACIONPERSONAL", "NOMBREYAPELLIDOS",
			"IDSEXO", "PERIODOCONTRATACION", "EMPRESACONTRATADA", "IMPORTE", "IMPORTEADMITIDO", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "RELEXPACTSUBIDRELEXPACTSUB",
			"RELEXPACTSUBIDEXPEDIENTE", "RELEXPACTSUBFECHAREGISTRO", "RELEXPACTSUBUSUARIOREGISTRO",
			"IDMODALIDADCONTRATO", "DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "MOD_CONT_FECHAREGISTRO",
			"MOD_CONT_USUARIOREGISTRO", "RELEXPACTSUBIDACTSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ContratacionesPersonal> rwMap = new RowMapper<ContratacionesPersonal>() {
		public ContratacionesPersonal mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ContratacionesPersonal(resultSet.getInt("IDCONTRATACIONPERSONAL"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"), resultSet.getLong("IDSEXO"),
					resultSet.getString("PERIODOCONTRATACION"), resultSet.getString("EMPRESACONTRATADA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"), resultSet.getBigDecimal("IMPORTE"),
							resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getInt("INSPECCIONABLE"),
							resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getString("OBSERVACIONESEUSKERA"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null)),
					new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"),
							resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
							resultSet.getDate("MOD_CONT_FECHAREGISTRO"),
							resultSet.getString("MOD_CONT_USUARIOREGISTRO")));
		}
	};

	private RowMapper<ContratacionesPersonal> rwMapContratacionesPersonal = new RowMapper<ContratacionesPersonal>() {
		public ContratacionesPersonal mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ContratacionesPersonal(resultSet.getInt("IDCONTRATACIONPERSONAL"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"), resultSet.getLong("IDSEXO"),
					resultSet.getString("PERIODOCONTRATACION"), resultSet.getString("EMPRESACONTRATADA"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"), resultSet.getBigDecimal("IMPORTE"),
							resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getInt("INSPECCIONABLE"),
							resultSet.getString("OBSERVACIONESCASTELLANO"),
							resultSet.getString("OBSERVACIONESEUSKERA")),
					new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"),
							resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA")));
		}
	};

	private RowMapper<ContratacionesPersonal> rwMapContratacionesPersonalPorRelExpActSub = new RowMapper<ContratacionesPersonal>() {
		public ContratacionesPersonal mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ContratacionesPersonal(resultSet.getInt("IDCONTRATACIONPERSONAL"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"),
					new Sexo(resultSet.getLong("IDSEXO"), resultSet.getString("DESCRIPCIONCASTELLANOSEXO"),
							resultSet.getString("DESCRIPCIONEUSKERASEXO")),
					resultSet.getString("PERIODOCONTRATACION"), resultSet.getString("EMPRESACONTRATADA"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getBigDecimal("IMPORTEPRESENTADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
							resultSet.getInt("INSPECCIONABLE"), resultSet.getString("OBSERVACIONESCASTELLANO"),
							resultSet.getString("OBSERVACIONESEUSKERA")),
					new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"),
							resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA")));
		}
	};

	private RowMapper<ContratacionesPersonal> rwMapPK = new RowMapper<ContratacionesPersonal>() {
		public ContratacionesPersonal mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ContratacionesPersonal(resultSet.getInt("IDCONTRATACIONPERSONAL"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ContratacionesPersonal>> rwMapJerarquia = new RowMapper<JerarquiaDto<ContratacionesPersonal>>() {
		public JerarquiaDto<ContratacionesPersonal> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ContratacionesPersonal contratacionespersonal = new ContratacionesPersonal(
					resultSet.getInt("IDCONTRATACIONPERSONAL"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"), resultSet.getLong("IDSEXO"),
					resultSet.getString("PERIODOCONTRATACION"), resultSet.getString("EMPRESACONTRATADA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"), resultSet.getBigDecimal("IMPORTE"),
							resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getInt("INSPECCIONABLE"),
							resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getString("OBSERVACIONESEUSKERA"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null)),
					new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"),
							resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
							resultSet.getDate("MOD_CONT_FECHAREGISTRO"),
							resultSet.getString("MOD_CONT_USUARIOREGISTRO")));

			JerarquiaDto<ContratacionesPersonal> jerarquia = new JerarquiaDto<ContratacionesPersonal>();
			jerarquia.setModel(contratacionespersonal);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @return ContratacionesPersonal
	 */
	public ContratacionesPersonal add(ContratacionesPersonal contratacionespersonal) {
		String query = "INSERT INTO CONTRATACIONES_PERSONAL (ID_CONTRATACION_PERSONAL, ID_REL_EXP_ACT_SUB, ID_MODALIDAD_CONTRATO, NOMBRE, APELLIDO1, APELLIDO2, ID_SEXO, PERIODO_CONTRATACION, EMPRESA_CONTRATADA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6040T00.NEXTVAL,?,?,?,?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, contratacionespersonal.getIdRelExpActSub(),
				contratacionespersonal.getIdModalidadContrato(), contratacionespersonal.getNombre(),
				contratacionespersonal.getApellido1(), contratacionespersonal.getApellido2(),
				contratacionespersonal.getIdSexo(), contratacionespersonal.getPeriodoContratacion(),
				contratacionespersonal.getEmpresaContratada(), contratacionespersonal.getFechaRegistro(),
				contratacionespersonal.getUsuarioRegistro());
		return contratacionespersonal;
	}

	/**
	 * Updates a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @return ContratacionesPersonal
	 */
	public ContratacionesPersonal update(ContratacionesPersonal contratacionespersonal) {
		String query = "UPDATE CONTRATACIONES_PERSONAL SET ID_REL_EXP_ACT_SUB=?, ID_MODALIDAD_CONTRATO=?, NOMBRE=?, APELLIDO1=?, APELLIDO2=?, ID_SEXO=?, PERIODO_CONTRATACION=?, EMPRESA_CONTRATADA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_CONTRATACION_PERSONAL=?";

		this.jdbcTemplate.update(query, contratacionespersonal.getIdRelExpActSub(),
				contratacionespersonal.getIdModalidadContrato(), contratacionespersonal.getNombre(),
				contratacionespersonal.getApellido1(), contratacionespersonal.getApellido2(),
				contratacionespersonal.getIdSexo(), contratacionespersonal.getPeriodoContratacion(),
				contratacionespersonal.getEmpresaContratada(), contratacionespersonal.getFechaUltmodificacion(),
				contratacionespersonal.getUsuarioUltmodificacion(), contratacionespersonal.getIdContratacionPersonal());
		return contratacionespersonal;
	}

	/**
	 * Finds a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @return ContratacionesPersonal
	 */
	@Transactional(readOnly = true)
	public ContratacionesPersonal find(ContratacionesPersonal contratacionespersonal) {
		String query = "SELECT t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL, t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2, t1.ID_SEXO IDSEXO, t1.PERIODO_CONTRATACION PERIODOCONTRATACION, t1.EMPRESA_CONTRATADA EMPRESACONTRATADA, t2.IMPORTE_PRESENTADO IMPORTE, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE, t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO, t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO, t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO, t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA FROM CONTRATACIONES_PERSONAL t1 , REL_EXP_ACT_SUB t2 , MODALIDADES_CONTRATO t3  WHERE t1.ID_CONTRATACION_PERSONAL = ?   AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+)";

		List<ContratacionesPersonal> contratacionespersonalList = this.jdbcTemplate.query(query,
				this.rwMapContratacionesPersonal, contratacionespersonal.getIdContratacionPersonal());
		return (ContratacionesPersonal) DataAccessUtils.uniqueResult(contratacionespersonalList);
	}

	/**
	 * Finds a List of rows in the ContratacionesPersonal table
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return contratacionespersonalList
	 */
	@Transactional(readOnly = true)
	public List<ContratacionesPersonal> findContratacionesPersonalPorRelExpActSub(Integer idRelExpActSub) {
		String query = "SELECT t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL, t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2, t4.ID_SEXO IDSEXO, t4.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANOSEXO, t4.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERASEXO, t1.PERIODO_CONTRATACION PERIODOCONTRATACION, t1.EMPRESA_CONTRATADA EMPRESACONTRATADA, t2.IMPORTE_PRESENTADO IMPORTE, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO, t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA FROM CONTRATACIONES_PERSONAL t1, REL_EXP_ACT_SUB t2, MODALIDADES_CONTRATO t3, SEXO t4 WHERE t1.ID_REL_EXP_ACT_SUB = ? AND t1.ID_REL_EXP_ACT_SUB   = t2.ID_REL_EXP_ACT_SUB AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) AND t1.ID_SEXO = t4.ID_SEXO(+)";
		List<ContratacionesPersonal> contratacionespersonalList = this.jdbcTemplate.query(query,
				this.rwMapContratacionesPersonalPorRelExpActSub, idRelExpActSub);

		return contratacionespersonalList;
	}

	/**
	 * Removes a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @return
	 */
	public void remove(ContratacionesPersonal contratacionespersonal) {
		String query = "DELETE FROM CONTRATACIONES_PERSONAL WHERE ID_CONTRATACION_PERSONAL=?";
		this.jdbcTemplate.update(query, contratacionespersonal.getIdContratacionPersonal());
	}

	/**
	 * Removes a single row in the ContratacionesPersonal table.
	 *
	 * @param idRelExpActSub
	 *            Integer
	 * @return
	 */
	@Override
	public void removeByIdRelExpActSub(Integer idRelExpActSub) {
		String query = "DELETE FROM CONTRATACIONES_PERSONAL WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the ContratacionesPersonal table.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ContratacionesPersonal>
	 */
	@Transactional(readOnly = true)
	public List<ContratacionesPersonal> findAll(ContratacionesPersonal contratacionespersonal,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL,t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2,t1.ID_SEXO IDSEXO,t1.PERIODO_CONTRATACION PERIODOCONTRATACION,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t2.IMPORTE_PRESENTADO IMPORTE,t2.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MOD_CONT_FECHAREGISTRO,t3.USUARIO_REGISTRO MOD_CONT_USUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB,t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		query.append("FROM CONTRATACIONES_PERSONAL t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(contratacionespersonal);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ContratacionesPersonalDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ContratacionesPersonal>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the ContratacionesPersonal table using like.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ContratacionesPersonal>
	 */
	@Transactional(readOnly = true)
	public List<ContratacionesPersonal> findAllLike(ContratacionesPersonal contratacionespersonal,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL,t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2,t1.ID_SEXO IDSEXO,t1.PERIODO_CONTRATACION PERIODOCONTRATACION,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t2.IMPORTE_PRESENTADO IMPORTE,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MOD_CONT_FECHAREGISTRO,t3.USUARIO_REGISTRO MOD_CONT_USUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		query.append("FROM CONTRATACIONES_PERSONAL t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(contratacionespersonal, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ContratacionesPersonalDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ContratacionesPersonal>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ContratacionesPersonal table.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ContratacionesPersonal contratacionespersonal) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM CONTRATACIONES_PERSONAL t1 , REL_EXP_ACT_SUB t2 , MODALIDADES_CONTRATO t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(contratacionespersonal);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ContratacionesPersonal table using like.
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ContratacionesPersonal contratacionespersonal, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM CONTRATACIONES_PERSONAL t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(contratacionespersonal, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ContratacionesPersonal selected for rup_table
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ContratacionesPersonal>>
	 */
	@Override
	public List<TableRowDto<ContratacionesPersonal>> reorderSelection(ContratacionesPersonal contratacionespersonal,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL,t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2,t1.ID_SEXO IDSEXO,t1.PERIODO_CONTRATACION PERIODOCONTRATACION,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t2.IMPORTE_PRESENTADO IMPORTE,t2.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MOD_CONT_FECHAREGISTRO,t3.USUARIO_REGISTRO MOD_CONT_USUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		query.append("FROM CONTRATACIONES_PERSONAL t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(contratacionespersonal, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ContratacionesPersonal.class, filterParamList, "ID_CONTRATACION_PERSONAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ContratacionesPersonal>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ContratacionesPersonal
	 * @param searchParams
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ContratacionesPersonal>>
	 */
	@Override
	public List<TableRowDto<ContratacionesPersonal>> search(ContratacionesPersonal filterParams,
			ContratacionesPersonal searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL,t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2,t1.ID_SEXO IDSEXO,t1.PERIODO_CONTRATACION PERIODOCONTRATACION,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t2.IMPORTE_PRESENTADO IMPORTE,t2.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MOD_CONT_FECHAREGISTRO,t3.USUARIO_REGISTRO MOD_CONT_USUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		query.append("FROM CONTRATACIONES_PERSONAL t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ContratacionesPersonal.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_CONTRATACION_PERSONAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ContratacionesPersonal>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtercontratacionespersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ContratacionesPersonal filtercontratacionespersonal, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL,t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2,t1.ID_SEXO IDSEXO,t1.PERIODO_CONTRATACION PERIODOCONTRATACION,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t2.IMPORTE_PRESENTADO IMPORTE,t2.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MOD_CONT_FECHAREGISTRO,t3.USUARIO_REGISTRO MOD_CONT_USUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		query.append("FROM CONTRATACIONES_PERSONAL t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtercontratacionespersonal, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				ContratacionesPersonal.class, query, params, "ID_CONTRATACION_PERSONAL");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ContratacionesPersonal table.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ContratacionesPersonal>>
	 */
	@Override
	public List<JerarquiaDto<ContratacionesPersonal>> findAllLikeJerarquia(
			ContratacionesPersonal filterContratacionesPersonal, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL,t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2,t1.ID_SEXO IDSEXO,t1.PERIODO_CONTRATACION PERIODOCONTRATACION,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t2.IMPORTE_PRESENTADO IMPORTE,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MOD_CONT_FECHAREGISTRO,t3.USUARIO_REGISTRO MOD_CONT_USUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM CONTRATACIONES_PERSONAL
		// t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");
		List<String> from = new ArrayList<String>();
		from.add("CONTRATACIONES_PERSONAL");
		from.add("REL_EXP_ACT_SUB");
		from.add("MODALIDADES_CONTRATO");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterContratacionesPersonal, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CONTRATACION_PERSONAL",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ContratacionesPersonalDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ContratacionesPersonal filterContratacionesPersonal,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM CONTRATACIONES_PERSONAL
		// t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");
		List<String> from = new ArrayList<String>();
		from.add("CONTRATACIONES_PERSONAL");
		from.add("REL_EXP_ACT_SUB");
		from.add("MODALIDADES_CONTRATO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterContratacionesPersonal, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_CONTRATACION_PERSONAL", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ContratacionesPersonal>>
	 */
	@Override
	public List<TableRowDto<ContratacionesPersonal>> findAllChild(ContratacionesPersonal filterContratacionesPersonal,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM CONTRATACIONES_PERSONAL
		// t1 ,REL_EXP_ACT_SUB t2 ,MODALIDADES_CONTRATO t3 ");
		List<String> from = new ArrayList<String>();
		from.add("CONTRATACIONES_PERSONAL");
		from.add("REL_EXP_ACT_SUB");
		from.add("MODALIDADES_CONTRATO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterContratacionesPersonal, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_CONTRATACION_PERSONAL", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ContratacionesPersonal>(this.rwMapPK, "ID_CONTRATACION_PERSONAL"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ContratacionesPersonal entity
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ContratacionesPersonal contratacionespersonal) {

		StringBuilder where = new StringBuilder(ContratacionesPersonalDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (contratacionespersonal != null && contratacionespersonal.getIdContratacionPersonal() != null) {
			where.append(" AND t1.ID_CONTRATACION_PERSONAL = ?");
			params.add(contratacionespersonal.getIdContratacionPersonal());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(contratacionespersonal.getRelExpActSub().getIdRelExpActSub());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getActSubvencionable() != null
				&& contratacionespersonal.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(contratacionespersonal.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(contratacionespersonal.getRelExpActSub().getIdExpediente());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getFechaRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getUsuarioRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getIdModalidadContrato() != null) {
			where.append(" AND t3.ID_MODALIDAD_CONTRATO = ?");
			params.add(contratacionespersonal.getModalidadesContrato().getIdModalidadContrato());
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getDescripcionCastellano() != null) {
			where.append(" AND t3.DESCRIPCION_CASTELLANO = ?");
			params.add(contratacionespersonal.getModalidadesContrato().getDescripcionCastellano());
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getDescripcionEuskera() != null) {
			where.append(" AND t3.DESCRIPCION_EUSKERA = ?");
			params.add(contratacionespersonal.getModalidadesContrato().getDescripcionEuskera());
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(contratacionespersonal.getModalidadesContrato().getFechaRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(contratacionespersonal.getModalidadesContrato().getUsuarioRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getNombre() != null) {
			where.append(" AND t1.NOMBRE = ?");
			params.add(contratacionespersonal.getNombre());
		}
		if (contratacionespersonal != null && contratacionespersonal.getApellido1() != null) {
			where.append(" AND t1.APELLIDO1 = ?");
			params.add(contratacionespersonal.getApellido1());
		}
		if (contratacionespersonal != null && contratacionespersonal.getApellido2() != null) {
			where.append(" AND t1.APELLIDO2 = ?");
			params.add(contratacionespersonal.getApellido2());
		}
		if (contratacionespersonal != null && contratacionespersonal.getIdSexo() != null) {
			where.append(" AND t1.ID_SEXO = ?");
			params.add(contratacionespersonal.getIdSexo());
		}
		if (contratacionespersonal != null && contratacionespersonal.getPeriodoContratacion() != null) {
			where.append(" AND t1.PERIODO_CONTRATACION = ?");
			params.add(contratacionespersonal.getPeriodoContratacion());
		}
		if (contratacionespersonal != null && contratacionespersonal.getEmpresaContratada() != null) {
			where.append(" AND t1.EMPRESA_CONTRATADA = ?");
			params.add(contratacionespersonal.getEmpresaContratada());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub().getImportePresentado() != null) {
			where.append(" AND t2.IMPORTE_PRESENTADO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getImportePresentado());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub().getImporteAdmitido() != null) {
			where.append(" AND t2.IMPORTE_ADMITIDO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getImporteAdmitido());
		}
		if (contratacionespersonal != null && contratacionespersonal.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(contratacionespersonal.getFechaRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(contratacionespersonal.getUsuarioRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(contratacionespersonal.getFechaUltmodificacion());
		}
		if (contratacionespersonal != null && contratacionespersonal.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(contratacionespersonal.getUsuarioUltmodificacion());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub().getInspeccionable() != null) {
			where.append(" AND t2.INSPECCIONABLE = ?");
			params.add(contratacionespersonal.getRelExpActSub().getInspeccionable());
		}
		if (contratacionespersonal != null
				&& contratacionespersonal.getRelExpActSub().getObservacionesCastellano() != null) {
			where.append(" AND t2.OBSERVACIONES_CASTELLANO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getObservacionesCastellano());
		}
		if (contratacionespersonal != null
				&& contratacionespersonal.getRelExpActSub().getObservacionesEuskera() != null) {
			where.append(" AND t2.OBSERVACIONES_EUSKERA = ?");
			params.add(contratacionespersonal.getRelExpActSub().getObservacionesEuskera());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ContratacionesPersonal entity
	 *
	 * @param contratacionespersonal
	 *            ContratacionesPersonal Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ContratacionesPersonal contratacionespersonal, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ContratacionesPersonalDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (contratacionespersonal != null && contratacionespersonal.getIdContratacionPersonal() != null) {
			where.append(" AND t1.ID_CONTRATACION_PERSONAL = ?");
			params.add(contratacionespersonal.getIdContratacionPersonal());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(contratacionespersonal.getRelExpActSub().getIdRelExpActSub());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getActSubvencionable() != null
				&& contratacionespersonal.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(contratacionespersonal.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(contratacionespersonal.getRelExpActSub().getIdExpediente());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getFechaRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub() != null
				&& contratacionespersonal.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getIdModalidadContrato() != null) {
			where.append(" AND t3.ID_MODALIDAD_CONTRATO = ?");
			params.add(contratacionespersonal.getModalidadesContrato().getIdModalidadContrato());
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(
						contratacionespersonal.getModalidadesContrato().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add(
						"%" + contratacionespersonal.getModalidadesContrato().getDescripcionCastellano().toUpperCase()
								+ "%");
			}
			where.append(" AND t3.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getModalidadesContrato().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getModalidadesContrato().getDescripcionEuskera().toUpperCase()
						+ "%");
			}
			where.append(" AND t3.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(contratacionespersonal.getModalidadesContrato().getFechaRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getModalidadesContrato() != null
				&& contratacionespersonal.getModalidadesContrato().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getModalidadesContrato().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add(
						"%" + contratacionespersonal.getModalidadesContrato().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getNombre() != null) {
			where.append(" AND UPPER(t1.NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getNombre().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getNombre().toUpperCase() + "%");
			}
			where.append(" AND t1.NOMBRE IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getApellido1() != null) {
			where.append(" AND UPPER(t1.APELLIDO1) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getApellido1().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getApellido1().toUpperCase() + "%");
			}
			where.append(" AND t1.APELLIDO1 IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getApellido2() != null) {
			where.append(" AND UPPER(t1.APELLIDO2) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getApellido2().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getApellido2().toUpperCase() + "%");
			}
			where.append(" AND t1.APELLIDO2 IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getIdSexo() != null) {
			where.append(" AND t1.ID_SEXO = ?");
			params.add(contratacionespersonal.getIdSexo());
		}
		if (contratacionespersonal != null && contratacionespersonal.getPeriodoContratacion() != null) {
			where.append(" AND t1.PERIODO_CONTRATACION = ?");
			params.add(contratacionespersonal.getPeriodoContratacion());
		}
		if (contratacionespersonal != null && contratacionespersonal.getEmpresaContratada() != null) {
			where.append(" AND UPPER(t1.EMPRESA_CONTRATADA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getEmpresaContratada().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getEmpresaContratada().toUpperCase() + "%");
			}
			where.append(" AND t1.EMPRESA_CONTRATADA IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub().getImportePresentado() != null) {
			where.append(" AND t2.IMPORTE_PRESENTADO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getImportePresentado());
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub().getImporteAdmitido() != null) {
			where.append(" AND t2.IMPORTE_ADMITIDO = ?");
			params.add(contratacionespersonal.getRelExpActSub().getImporteAdmitido());
		}
		if (contratacionespersonal != null && contratacionespersonal.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(contratacionespersonal.getFechaRegistro());
		}
		if (contratacionespersonal != null && contratacionespersonal.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(contratacionespersonal.getFechaUltmodificacion());
		}
		if (contratacionespersonal != null && contratacionespersonal.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (contratacionespersonal != null && contratacionespersonal.getRelExpActSub().getInspeccionable() != null) {
			where.append(" AND t2.INSPECCIONABLE = ?");
			params.add(contratacionespersonal.getRelExpActSub().getInspeccionable());
		}
		if (contratacionespersonal != null
				&& contratacionespersonal.getRelExpActSub().getObservacionesCastellano() != null) {
			where.append(" AND UPPER(t2.OBSERVACIONES_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getRelExpActSub().getObservacionesCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + contratacionespersonal.getRelExpActSub().getObservacionesCastellano().toUpperCase()
						+ "%");
			}
			where.append(" AND t2.OBSERVACIONES_CASTELLANO IS NOT NULL");
		}
		if (contratacionespersonal != null
				&& contratacionespersonal.getRelExpActSub().getObservacionesEuskera() != null) {
			where.append(" AND UPPER(t2.OBSERVACIONES_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(contratacionespersonal.getRelExpActSub().getObservacionesEuskera().toUpperCase() + "%");
			} else {
				params.add(
						"%" + contratacionespersonal.getRelExpActSub().getObservacionesEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES_EUSKERA IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
