package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.model.PTT.GastosTuristicos;
import com.ejie.ab60.model.PTT.ProductosTuristicos;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * GastosTuristicosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class GastosTuristicosDaoImpl implements GastosTuristicosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDGASTOSTURISTICOS", "DENOMIMACION",
			"FECHAREGISTRO", "USUARIOREGISTRO", "RELEXPACTSUBIDRELEXPACTSUB", "RELEXPACTSUBIDEXPEDIENTE",
			"RELEXPACTSUBFECHAREGISTRO", "RELEXPACTSUBUSUARIOREGISTRO", "PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO",
			"PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO", "PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA",
			"PRODUCTOSTURISTICOSFECHAREGISTRO", "PRODUCTOSTURISTICOSUSUARIOREGISTRO", "RELEXPACTSUBIDACTSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<GastosTuristicos> rwMap = new RowMapper<GastosTuristicos>() {
		public GastosTuristicos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new GastosTuristicos(resultSet.getInt("IDGASTOSTURISTICOS"), resultSet.getString("DENOMIMACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")),
					new ProductosTuristicos(resultSet.getLong("ProductosTuristicosIDPRODUCTOTURISTICO"),
							resultSet.getString("ProductosTuristicosDESCRIPCIONCASTELLANO"),
							resultSet.getString("ProductosTuristicosDESCRIPCIONEUSKERA"),
							resultSet.getDate("ProductosTuristicosFECHAREGISTRO"),
							resultSet.getString("ProductosTuristicosUSUARIOREGISTRO")));
		}
	};

	private RowMapper<GastosTuristicos> rwMapAbreviado = new RowMapper<GastosTuristicos>() {
		public GastosTuristicos mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			GastosTuristicos gastosTuristicos = new GastosTuristicos();
			gastosTuristicos.setIdGastosTuristicos(resultSet.getInt("IDGASTOSTURISTICOS"));
			gastosTuristicos.setDenominacion(resultSet.getString("DENOMIMACION"));
			ProductosTuristicos productosTuristicos = new ProductosTuristicos();
			productosTuristicos.setIdProductoTuristico(resultSet.getLong("IDPRODUCTOTURISTICO"));
			productosTuristicos.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			productosTuristicos.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			gastosTuristicos.setProductosTuristicos(productosTuristicos);
			return gastosTuristicos;
		}
	};

	private RowMapper<GastosTuristicos> rwMapPK = new RowMapper<GastosTuristicos>() {
		public GastosTuristicos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new GastosTuristicos(resultSet.getInt("IDGASTOSTURISTICOS"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<GastosTuristicos>> rwMapJerarquia = new RowMapper<JerarquiaDto<GastosTuristicos>>() {
		public JerarquiaDto<GastosTuristicos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			GastosTuristicos gastosturisticos = new GastosTuristicos(resultSet.getInt("IDGASTOSTURISTICOS"),
					resultSet.getString("DENOMIMACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")),
					new ProductosTuristicos(resultSet.getLong("ProductosTuristicosIDPRODUCTOTURISTICO"),
							resultSet.getString("ProductosTuristicosDESCRIPCIONCASTELLANO"),
							resultSet.getString("ProductosTuristicosDESCRIPCIONEUSKERA"),
							resultSet.getDate("ProductosTuristicosFECHAREGISTRO"),
							resultSet.getString("ProductosTuristicosUSUARIOREGISTRO")));

			JerarquiaDto<GastosTuristicos> jerarquia = new JerarquiaDto<GastosTuristicos>();
			jerarquia.setModel(gastosturisticos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the GastosTuristicos table.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @return GastosTuristicos
	 */
	public GastosTuristicos add(GastosTuristicos gastosturisticos) {
		String query = "INSERT INTO GASTOS_TURISTICOS (ID_GASTOS_TURISTICOS, ID_REL_EXP_ACT_SUB, ID_PRODUCTO_TURISTICO, DENOMIMACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?)";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = gastosturisticos.getRelExpActSub().getIdRelExpActSub();
		}
		Object getProductosTuristicosIdProductoTuristicoAux = null;
		if (gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getIdProductoTuristico() != null) {
			getProductosTuristicosIdProductoTuristicoAux = gastosturisticos.getProductosTuristicos()
					.getIdProductoTuristico();
		}
		if (gastosturisticos.getIdGastosTuristicos() == null) {
			gastosturisticos.setIdGastosTuristicos(
					this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6044T00")));
		}
		this.jdbcTemplate.update(query, gastosturisticos.getIdGastosTuristicos(), getRelExpActSubIdRelExpActSubAux,
				getProductosTuristicosIdProductoTuristicoAux, gastosturisticos.getDenominacion(),
				gastosturisticos.getFechaRegistro(), gastosturisticos.getUsuarioRegistro());
		return gastosturisticos;
	}

	/**
	 * Updates a single row in the GastosTuristicos table.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @return GastosTuristicos
	 */
	public GastosTuristicos update(GastosTuristicos gastosturisticos) {
		String query = "UPDATE GASTOS_TURISTICOS SET ID_REL_EXP_ACT_SUB=?, ID_PRODUCTO_TURISTICO=?, DENOMIMACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_GASTOS_TURISTICOS=?";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = gastosturisticos.getRelExpActSub().getIdRelExpActSub();
		}
		Object getProductosTuristicosIdProductoTuristicoAux = null;
		if (gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getIdProductoTuristico() != null) {
			getProductosTuristicosIdProductoTuristicoAux = gastosturisticos.getProductosTuristicos()
					.getIdProductoTuristico();
		}
		this.jdbcTemplate.update(query, getRelExpActSubIdRelExpActSubAux, getProductosTuristicosIdProductoTuristicoAux,
				gastosturisticos.getDenominacion(), gastosturisticos.getFechaRegistro(),
				gastosturisticos.getUsuarioRegistro(), gastosturisticos.getIdGastosTuristicos());
		return gastosturisticos;
	}

	/**
	 * Updates a single row in the GastosTuristicos table.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @return GastosTuristicos
	 */
	public GastosTuristicos updateGastosTuristicos(GastosTuristicos gastosturisticos) {
		String query = "UPDATE GASTOS_TURISTICOS SET ID_PRODUCTO_TURISTICO=?, DENOMIMACION=? WHERE ID_REL_EXP_ACT_SUB=?";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = gastosturisticos.getRelExpActSub().getIdRelExpActSub();
		}
		Object getProductosTuristicosIdProductoTuristicoAux = null;
		if (gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getIdProductoTuristico() != null) {
			getProductosTuristicosIdProductoTuristicoAux = gastosturisticos.getProductosTuristicos()
					.getIdProductoTuristico();
		}
		this.jdbcTemplate.update(query, getProductosTuristicosIdProductoTuristicoAux,
				gastosturisticos.getDenominacion(), getRelExpActSubIdRelExpActSubAux);
		return gastosturisticos;
	}

	/**
	 * Finds a single row in the GastosTuristicos table.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @return GastosTuristicos
	 */
	@Transactional(readOnly = true)
	public GastosTuristicos find(GastosTuristicos gastosturisticos) {
		String query = "SELECT t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS, t1.DENOMIMACION DENOMIMACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE, t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO, t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO, t3.ID_PRODUCTO_TURISTICO PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO, t3.DESCRIPCION_CASTELLANO PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA, t3.FECHA_REGISTRO PRODUCTOSTURISTICOSFECHAREGISTRO, t3.USUARIO_REGISTRO PRODUCTOSTURISTICOSUSUARIOREGISTRO, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB FROM GASTOS_TURISTICOS t1 , REL_EXP_ACT_SUB t2 , PRODUCTOS_TURISTICOS t3  WHERE t1.ID_GASTOS_TURISTICOS = ?   AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_PRODUCTO_TURISTICO= t3.ID_PRODUCTO_TURISTICO(+)";

		List<GastosTuristicos> gastosturisticosList = this.jdbcTemplate.query(query, this.rwMap,
				gastosturisticos.getIdGastosTuristicos());
		return (GastosTuristicos) DataAccessUtils.uniqueResult(gastosturisticosList);
	}

	/**
	 * findGastosTuristicosPorRelExpActSub
	 * 
	 * @param idRelExpActSub
	 *            Integer
	 */
	@Override
	@Transactional(readOnly = true)
	public GastosTuristicos findGastosTuristicosPorRelExpActSub(Integer idRelExpActSub) {
		String query = "SELECT t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS, t1.DENOMIMACION DENOMIMACION, t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO, "
				+ " t2.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA "
				+ " FROM GASTOS_TURISTICOS t1, PRODUCTOS_TURISTICOS t2  "
				+ " WHERE t1.ID_PRODUCTO_TURISTICO = t2.ID_PRODUCTO_TURISTICO AND " + " t1.ID_REL_EXP_ACT_SUB = ?  ";

		List<GastosTuristicos> gastosturisticosList = this.jdbcTemplate.query(query, this.rwMapAbreviado,
				idRelExpActSub);
		return (GastosTuristicos) DataAccessUtils.uniqueResult(gastosturisticosList);
	}

	/**
	 * Removes a single row in the GastosTuristicos table.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @return
	 */
	public void remove(GastosTuristicos gastosturisticos) {
		String query = "DELETE FROM GASTOS_TURISTICOS WHERE ID_GASTOS_TURISTICOS=?";
		this.jdbcTemplate.update(query, gastosturisticos.getIdGastosTuristicos());
	}

	/**
	 * Finds a list of rows in the GastosTuristicos table.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<GastosTuristicos>
	 */
	@Transactional(readOnly = true)
	public List<GastosTuristicos> findAll(GastosTuristicos gastosturisticos, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS,t1.DENOMIMACION DENOMIMACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_PRODUCTO_TURISTICO PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO,t3.DESCRIPCION_CASTELLANO PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO PRODUCTOSTURISTICOSFECHAREGISTRO,t3.USUARIO_REGISTRO PRODUCTOSTURISTICOSUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM GASTOS_TURISTICOS t1 ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(gastosturisticos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_PRODUCTO_TURISTICO= t3.ID_PRODUCTO_TURISTICO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					GastosTuristicosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<GastosTuristicos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the GastosTuristicos table using like.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<GastosTuristicos>
	 */
	@Transactional(readOnly = true)
	public List<GastosTuristicos> findAllLike(GastosTuristicos gastosturisticos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS,t1.DENOMIMACION DENOMIMACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_PRODUCTO_TURISTICO PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO,t3.DESCRIPCION_CASTELLANO PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO PRODUCTOSTURISTICOSFECHAREGISTRO,t3.USUARIO_REGISTRO PRODUCTOSTURISTICOSUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM GASTOS_TURISTICOS t1 ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(gastosturisticos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_PRODUCTO_TURISTICO= t3.ID_PRODUCTO_TURISTICO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					GastosTuristicosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<GastosTuristicos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the GastosTuristicos table.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(GastosTuristicos gastosturisticos) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM GASTOS_TURISTICOS t1 , REL_EXP_ACT_SUB t2 , PRODUCTOS_TURISTICOS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(gastosturisticos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_PRODUCTO_TURISTICO= t3.ID_PRODUCTO_TURISTICO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the GastosTuristicos table using like.
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(GastosTuristicos gastosturisticos, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM GASTOS_TURISTICOS t1 ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(gastosturisticos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_PRODUCTO_TURISTICO= t3.ID_PRODUCTO_TURISTICO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of GastosTuristicos selected for rup_table
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<GastosTuristicos>>
	 */
	@Override
	public List<TableRowDto<GastosTuristicos>> reorderSelection(GastosTuristicos gastosturisticos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS,t1.DENOMIMACION DENOMIMACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_PRODUCTO_TURISTICO PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO,t3.DESCRIPCION_CASTELLANO PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO PRODUCTOSTURISTICOSFECHAREGISTRO,t3.USUARIO_REGISTRO PRODUCTOSTURISTICOSUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM GASTOS_TURISTICOS t1 ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(gastosturisticos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_PRODUCTO_TURISTICO= t3.ID_PRODUCTO_TURISTICO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				GastosTuristicos.class, filterParamList, "ID_GASTOS_TURISTICOS");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<GastosTuristicos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            GastosTuristicos
	 * @param searchParams
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<GastosTuristicos>>
	 */
	@Override
	public List<TableRowDto<GastosTuristicos>> search(GastosTuristicos filterParams, GastosTuristicos searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS,t1.DENOMIMACION DENOMIMACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_PRODUCTO_TURISTICO PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO,t3.DESCRIPCION_CASTELLANO PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO PRODUCTOSTURISTICOSFECHAREGISTRO,t3.USUARIO_REGISTRO PRODUCTOSTURISTICOSUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM GASTOS_TURISTICOS t1 ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) AND t1.ID_PRODUCTO_TURISTICO= t3.ID_PRODUCTO_TURISTICO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				GastosTuristicos.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_GASTOS_TURISTICOS");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<GastosTuristicos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtergastosturisticos
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(GastosTuristicos filtergastosturisticos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS,t1.DENOMIMACION DENOMIMACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_PRODUCTO_TURISTICO PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO,t3.DESCRIPCION_CASTELLANO PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO PRODUCTOSTURISTICOSFECHAREGISTRO,t3.USUARIO_REGISTRO PRODUCTOSTURISTICOSUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM GASTOS_TURISTICOS t1 ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtergastosturisticos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				GastosTuristicos.class, query, params, "ID_GASTOS_TURISTICOS");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical GastosTuristicos table.
	 *
	 * @param filterGastosTuristicos
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<GastosTuristicos>>
	 */
	@Override
	public List<JerarquiaDto<GastosTuristicos>> findAllLikeJerarquia(GastosTuristicos filterGastosTuristicos,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS,t1.DENOMIMACION DENOMIMACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t3.ID_PRODUCTO_TURISTICO PRODUCTOSTURISTICOSIDPRODUCTOTURISTICO,t3.DESCRIPCION_CASTELLANO PRODUCTOSTURISTICOSDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA PRODUCTOSTURISTICOSDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO PRODUCTOSTURISTICOSFECHAREGISTRO,t3.USUARIO_REGISTRO PRODUCTOSTURISTICOSUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM GASTOS_TURISTICOS t1
		// ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("GASTOS_TURISTICOS");
		from.add("REL_EXP_ACT_SUB");
		from.add("PRODUCTOS_TURISTICOS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterGastosTuristicos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_GASTOS_TURISTICOS", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					GastosTuristicosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterGastosTuristicos
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(GastosTuristicos filterGastosTuristicos, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM GASTOS_TURISTICOS t1
		// ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("GASTOS_TURISTICOS");
		from.add("REL_EXP_ACT_SUB");
		from.add("PRODUCTOS_TURISTICOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterGastosTuristicos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_GASTOS_TURISTICOS",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterGastosTuristicos
	 *            GastosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<GastosTuristicos>>
	 */
	@Override
	public List<TableRowDto<GastosTuristicos>> findAllChild(GastosTuristicos filterGastosTuristicos,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM GASTOS_TURISTICOS t1
		// ,REL_EXP_ACT_SUB t2 ,PRODUCTOS_TURISTICOS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("GASTOS_TURISTICOS");
		from.add("REL_EXP_ACT_SUB");
		from.add("PRODUCTOS_TURISTICOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterGastosTuristicos, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_GASTOS_TURISTICOS", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<GastosTuristicos>(this.rwMapPK, "ID_GASTOS_TURISTICOS"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the GastosTuristicos entity
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(GastosTuristicos gastosturisticos) {

		StringBuilder where = new StringBuilder(GastosTuristicosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (gastosturisticos != null && gastosturisticos.getIdGastosTuristicos() != null) {
			where.append(" AND t1.ID_GASTOS_TURISTICOS = ?");
			params.add(gastosturisticos.getIdGastosTuristicos());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(gastosturisticos.getRelExpActSub().getIdRelExpActSub());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getActSubvencionable() != null
				&& gastosturisticos.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(gastosturisticos.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(gastosturisticos.getRelExpActSub().getIdExpediente());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(gastosturisticos.getRelExpActSub().getFechaRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(gastosturisticos.getRelExpActSub().getUsuarioRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getIdProductoTuristico() != null) {
			where.append(" AND t3.ID_PRODUCTO_TURISTICO = ?");
			params.add(gastosturisticos.getProductosTuristicos().getIdProductoTuristico());
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getDescripcionCastellano() != null) {
			where.append(" AND t3.DESCRIPCION_CASTELLANO = ?");
			params.add(gastosturisticos.getProductosTuristicos().getDescripcionCastellano());
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getDescripcionEuskera() != null) {
			where.append(" AND t3.DESCRIPCION_EUSKERA = ?");
			params.add(gastosturisticos.getProductosTuristicos().getDescripcionEuskera());
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(gastosturisticos.getProductosTuristicos().getFechaRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(gastosturisticos.getProductosTuristicos().getUsuarioRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getDenominacion() != null) {
			where.append(" AND t1.DENOMIMACION = ?");
			params.add(gastosturisticos.getDenominacion());
		}
		if (gastosturisticos != null && gastosturisticos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(gastosturisticos.getFechaRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(gastosturisticos.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the GastosTuristicos entity
	 *
	 * @param gastosturisticos
	 *            GastosTuristicos Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(GastosTuristicos gastosturisticos, Boolean startsWith) {

		StringBuilder where = new StringBuilder(GastosTuristicosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (gastosturisticos != null && gastosturisticos.getIdGastosTuristicos() != null) {
			where.append(" AND t1.ID_GASTOS_TURISTICOS = ?");
			params.add(gastosturisticos.getIdGastosTuristicos());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(gastosturisticos.getRelExpActSub().getIdRelExpActSub());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getActSubvencionable() != null
				&& gastosturisticos.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(gastosturisticos.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(gastosturisticos.getRelExpActSub().getIdExpediente());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(gastosturisticos.getRelExpActSub().getFechaRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getRelExpActSub() != null
				&& gastosturisticos.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(gastosturisticos.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + gastosturisticos.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getIdProductoTuristico() != null) {
			where.append(" AND t3.ID_PRODUCTO_TURISTICO = ?");
			params.add(gastosturisticos.getProductosTuristicos().getIdProductoTuristico());
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(gastosturisticos.getProductosTuristicos().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add(
						"%" + gastosturisticos.getProductosTuristicos().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(gastosturisticos.getProductosTuristicos().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + gastosturisticos.getProductosTuristicos().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(gastosturisticos.getProductosTuristicos().getFechaRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getProductosTuristicos() != null
				&& gastosturisticos.getProductosTuristicos().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(gastosturisticos.getProductosTuristicos().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + gastosturisticos.getProductosTuristicos().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (gastosturisticos != null && gastosturisticos.getDenominacion() != null) {
			where.append(" AND UPPER(t1.DENOMIMACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(gastosturisticos.getDenominacion().toUpperCase() + "%");
			} else {
				params.add("%" + gastosturisticos.getDenominacion().toUpperCase() + "%");
			}
			where.append(" AND t1.DENOMIMACION IS NOT NULL");
		}
		if (gastosturisticos != null && gastosturisticos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(gastosturisticos.getFechaRegistro());
		}
		if (gastosturisticos != null && gastosturisticos.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(gastosturisticos.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + gastosturisticos.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
