package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.PTT.ModalidadesContrato;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ModalidadesContratoDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ModalidadesContratoDaoImpl implements ModalidadesContratoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMODALIDADCONTRATO", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ModalidadesContrato> rwMap = new RowMapper<ModalidadesContrato>() {
		public ModalidadesContrato mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<ModalidadesContrato> rwMapPK = new RowMapper<ModalidadesContrato>() {
		public ModalidadesContrato mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ModalidadesContrato>> rwMapJerarquia = new RowMapper<JerarquiaDto<ModalidadesContrato>>() {
		public JerarquiaDto<ModalidadesContrato> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ModalidadesContrato modalidadescontrato = new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<ModalidadesContrato> jerarquia = new JerarquiaDto<ModalidadesContrato>();
			jerarquia.setModel(modalidadescontrato);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Lista de ModalidadesContrato
	 */

	@Override
	public List<ModalidadesContrato> findModalidadesContrato() {
		String query = "SELECT t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM MODALIDADES_CONTRATO t1 ";

		return (List<ModalidadesContrato>) this.jdbcTemplate.query(query, this.rwMap);

	}

	/**
	 * Inserts a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @return ModalidadesContrato
	 */
	public ModalidadesContrato add(ModalidadesContrato modalidadescontrato) {
		String query = "INSERT INTO MODALIDADES_CONTRATO (ID_MODALIDAD_CONTRATO, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, modalidadescontrato.getIdModalidadContrato(),
				modalidadescontrato.getDescripcionCastellano(), modalidadescontrato.getDescripcionEuskera(),
				modalidadescontrato.getFechaRegistro(), modalidadescontrato.getUsuarioRegistro());
		return modalidadescontrato;
	}

	/**
	 * Updates a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @return ModalidadesContrato
	 */
	public ModalidadesContrato update(ModalidadesContrato modalidadescontrato) {
		String query = "UPDATE MODALIDADES_CONTRATO SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_MODALIDAD_CONTRATO=?";
		this.jdbcTemplate.update(query, modalidadescontrato.getDescripcionCastellano(),
				modalidadescontrato.getDescripcionEuskera(), modalidadescontrato.getFechaRegistro(),
				modalidadescontrato.getUsuarioRegistro(), modalidadescontrato.getIdModalidadContrato());
		return modalidadescontrato;
	}

	/**
	 * Finds a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @return ModalidadesContrato
	 */
	@Transactional(readOnly = true)
	public ModalidadesContrato find(ModalidadesContrato modalidadescontrato) {
		String query = "SELECT t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM MODALIDADES_CONTRATO t1  WHERE t1.ID_MODALIDAD_CONTRATO = ?  ";

		List<ModalidadesContrato> modalidadescontratoList = this.jdbcTemplate.query(query, this.rwMap,
				modalidadescontrato.getIdModalidadContrato());
		return (ModalidadesContrato) DataAccessUtils.uniqueResult(modalidadescontratoList);
	}

	/**
	 * Removes a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @return
	 */
	public void remove(ModalidadesContrato modalidadescontrato) {
		String query = "DELETE FROM MODALIDADES_CONTRATO WHERE ID_MODALIDAD_CONTRATO=?";
		this.jdbcTemplate.update(query, modalidadescontrato.getIdModalidadContrato());
	}

	/**
	 * Finds a list of rows in the ModalidadesContrato table.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ModalidadesContrato>
	 */
	@Transactional(readOnly = true)
	public List<ModalidadesContrato> findAll(ModalidadesContrato modalidadescontrato,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM MODALIDADES_CONTRATO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(modalidadescontrato);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ModalidadesContratoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ModalidadesContrato>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the ModalidadesContrato table using like.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ModalidadesContrato>
	 */
	@Transactional(readOnly = true)
	public List<ModalidadesContrato> findAllLike(ModalidadesContrato modalidadescontrato,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM MODALIDADES_CONTRATO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(modalidadescontrato, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ModalidadesContratoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ModalidadesContrato>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ModalidadesContrato table.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ModalidadesContrato modalidadescontrato) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MODALIDADES_CONTRATO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(modalidadescontrato);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ModalidadesContrato table using like.
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ModalidadesContrato modalidadescontrato, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MODALIDADES_CONTRATO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(modalidadescontrato, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ModalidadesContrato selected for rup_table
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ModalidadesContrato>>
	 */
	@Override
	public List<TableRowDto<ModalidadesContrato>> reorderSelection(ModalidadesContrato modalidadescontrato,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MODALIDADES_CONTRATO t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(modalidadescontrato, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ModalidadesContrato.class, filterParamList, "ID_MODALIDAD_CONTRATO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ModalidadesContrato>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ModalidadesContrato
	 * @param searchParams
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ModalidadesContrato>>
	 */
	@Override
	public List<TableRowDto<ModalidadesContrato>> search(ModalidadesContrato filterParams,
			ModalidadesContrato searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MODALIDADES_CONTRATO t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ModalidadesContrato.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_MODALIDAD_CONTRATO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ModalidadesContrato>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtermodalidadescontrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ModalidadesContrato filtermodalidadescontrato, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MODALIDADES_CONTRATO t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtermodalidadescontrato, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				ModalidadesContrato.class, query, params, "ID_MODALIDAD_CONTRATO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ModalidadesContrato table.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ModalidadesContrato>>
	 */
	@Override
	public List<JerarquiaDto<ModalidadesContrato>> findAllLikeJerarquia(ModalidadesContrato filterModalidadesContrato,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM MODALIDADES_CONTRATO t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MODALIDADES_CONTRATO");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterModalidadesContrato, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MODALIDAD_CONTRATO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ModalidadesContratoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ModalidadesContrato filterModalidadesContrato,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM MODALIDADES_CONTRATO t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MODALIDADES_CONTRATO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterModalidadesContrato, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_MODALIDAD_CONTRATO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ModalidadesContrato>>
	 */
	@Override
	public List<TableRowDto<ModalidadesContrato>> findAllChild(ModalidadesContrato filterModalidadesContrato,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM MODALIDADES_CONTRATO t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MODALIDADES_CONTRATO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterModalidadesContrato, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_MODALIDAD_CONTRATO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ModalidadesContrato>(this.rwMapPK, "ID_MODALIDAD_CONTRATO"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ModalidadesContrato entity
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ModalidadesContrato modalidadescontrato) {

		StringBuilder where = new StringBuilder(ModalidadesContratoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (modalidadescontrato != null && modalidadescontrato.getIdModalidadContrato() != null) {
			where.append(" AND t1.ID_MODALIDAD_CONTRATO = ?");
			params.add(modalidadescontrato.getIdModalidadContrato());
		}
		if (modalidadescontrato != null && modalidadescontrato.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(modalidadescontrato.getDescripcionCastellano());
		}
		if (modalidadescontrato != null && modalidadescontrato.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(modalidadescontrato.getDescripcionEuskera());
		}
		if (modalidadescontrato != null && modalidadescontrato.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(modalidadescontrato.getFechaRegistro());
		}
		if (modalidadescontrato != null && modalidadescontrato.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(modalidadescontrato.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ModalidadesContrato entity
	 *
	 * @param modalidadescontrato
	 *            ModalidadesContrato Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ModalidadesContrato modalidadescontrato, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ModalidadesContratoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (modalidadescontrato != null && modalidadescontrato.getIdModalidadContrato() != null) {
			where.append(" AND t1.ID_MODALIDAD_CONTRATO = ?");
			params.add(modalidadescontrato.getIdModalidadContrato());
		}
		if (modalidadescontrato != null && modalidadescontrato.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(modalidadescontrato.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + modalidadescontrato.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (modalidadescontrato != null && modalidadescontrato.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(modalidadescontrato.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + modalidadescontrato.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (modalidadescontrato != null && modalidadescontrato.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(modalidadescontrato.getFechaRegistro());
		}
		if (modalidadescontrato != null && modalidadescontrato.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(modalidadescontrato.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + modalidadescontrato.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
