package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.PTT.ModalidadesContrato;
import com.ejie.ab60.model.PTT.PersonasContratadas;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.terceros.Sexo;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PersonasContratadasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PersonasContratadasDaoImpl implements PersonasContratadasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPERSONACONTRATADA", "NOMBREAPELLIDOS",
			"IDSEXO", "EMPRESACONTRATADA", "NEMPRESASN1", "HORASSUBVENCIONABLESN1", "NEMPRESASN2",
			"HORASSUBVENCIONABLESN2", "COSTEHORACONTRATADA", "COSTEHORASUBVENCIONABLE", "BASESUBVENCIONABLE",
			"FECHAREGISTRO", "USUARIOREGISTRO", "MODALIDADESCONTRATOIDMODALIDADCONTRATO",
			"MODALIDADESCONTRATODESCRIPCIONCASTELLANO", "MODALIDADESCONTRATODESCRIPCIONEUSKERA",
			"MODALIDADESCONTRATOFECHAREGISTRO", "MODALIDADESCONTRATOUSUARIOREGISTRO", "PROGRAMASIDPROGRAMA",
			"PROGRAMASDESCRIPCIONCASTELLANO", "PROGRAMASDESCRIPCIONEUSKERA", "PROGRAMASFECHAREGISTRO",
			"PROGRAMASUSUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<PersonasContratadas> rwMap = new RowMapper<PersonasContratadas>() {
		public PersonasContratadas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PersonasContratadas(resultSet.getInt("IDPERSONACONTRATADA"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"), resultSet.getLong("IDSEXO"),
					resultSet.getString("EMPRESACONTRATADA"), resultSet.getLong("NEMPRESASN1"),
					resultSet.getLong("HORASSUBVENCIONABLESN1"), resultSet.getLong("NEMPRESASN2"),
					resultSet.getLong("HORASSUBVENCIONABLESN2"), resultSet.getBigDecimal("COSTEHORACONTRATADA"),
					resultSet.getBigDecimal("COSTEHORASUBVENCIONABLE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new ModalidadesContrato(resultSet.getLong("ModalidadesContratoIDMODALIDADCONTRATO"),
							resultSet.getString("ModalidadesContratoDESCRIPCIONCASTELLANO"),
							resultSet.getString("ModalidadesContratoDESCRIPCIONEUSKERA"),
							resultSet.getDate("ModalidadesContratoFECHAREGISTRO"),
							resultSet.getString("ModalidadesContratoUSUARIOREGISTRO")));
		}
	};

	private RowMapper<PersonasContratadas> rwMapPersonasContratadasPorRelExpActSub = new RowMapper<PersonasContratadas>() {
		public PersonasContratadas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PersonasContratadas(resultSet.getInt("IDPERSONACONTRATADA"), resultSet.getString("NOMBRE"),
					resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"),
					new Sexo(resultSet.getLong("IDSEXO"), resultSet.getString("DESCRIPCIONCASTELLANOSEXO"),
							resultSet.getString("DESCRIPCIONEUSKERASEXO")),
					resultSet.getString("EMPRESACONTRATADA"), resultSet.getLong("NEMPRESASN1"),
					resultSet.getLong("HORASSUBVENCIONABLESN1"), resultSet.getLong("NEMPRESASN2"),
					resultSet.getLong("HORASSUBVENCIONABLESN2"), resultSet.getBigDecimal("COSTEHORACONTRATADA"),
					resultSet.getBigDecimal("COSTEHORASUBVENCIONABLE"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"), resultSet.getInt("INSPECCIONABLE"),
							resultSet.getString("OBSERVACIONESCASTELLANO"),
							resultSet.getString("OBSERVACIONESEUSKERA")),
					new ModalidadesContrato(resultSet.getLong("IDMODALIDADCONTRATO"),
							resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA")));
		}
	};

	private RowMapper<PersonasContratadas> rwMapPK = new RowMapper<PersonasContratadas>() {
		public PersonasContratadas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PersonasContratadas(resultSet.getInt("IDPERSONACONTRATADA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<PersonasContratadas>> rwMapJerarquia = new RowMapper<JerarquiaDto<PersonasContratadas>>() {
		public JerarquiaDto<PersonasContratadas> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			PersonasContratadas personascontratadas = new PersonasContratadas(resultSet.getInt("IDPERSONACONTRATADA"),
					resultSet.getString("NOMBRE"), resultSet.getString("APELLIDO1"), resultSet.getString("APELLIDO2"),
					resultSet.getLong("IDSEXO"), resultSet.getString("EMPRESACONTRATADA"),
					resultSet.getLong("NEMPRESASN1"), resultSet.getLong("HORASSUBVENCIONABLESN1"),
					resultSet.getLong("NEMPRESASN2"), resultSet.getLong("HORASSUBVENCIONABLESN2"),
					resultSet.getBigDecimal("COSTEHORACONTRATADA"), resultSet.getBigDecimal("COSTEHORASUBVENCIONABLE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new ModalidadesContrato(resultSet.getLong("ModalidadesContratoIDMODALIDADCONTRATO"),
							resultSet.getString("ModalidadesContratoDESCRIPCIONCASTELLANO"),
							resultSet.getString("ModalidadesContratoDESCRIPCIONEUSKERA"),
							resultSet.getDate("ModalidadesContratoFECHAREGISTRO"),
							resultSet.getString("ModalidadesContratoUSUARIOREGISTRO")));

			JerarquiaDto<PersonasContratadas> jerarquia = new JerarquiaDto<PersonasContratadas>();
			jerarquia.setModel(personascontratadas);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the PersonasContratadas table.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @return PersonasContratadas
	 */
	public PersonasContratadas add(PersonasContratadas personascontratadas) {
		String query = "INSERT INTO PERSONAS_CONTRATADAS (ID_PERSONA_CONTRATADA, ID_REL_EXP_ACT_SUB, ID_MODALIDAD_CONTRATO, NOMBRE, APELLIDO1, APELLIDO2, ID_SEXO, EMPRESA_CONTRATADA, N_EMPRESAS_N1, HORAS_SUBVENCIONABLES_N1, N_EMPRESAS_N2, HORAS_SUBVENCIONABLES_N2, COSTE_HORA_CONTRATADA, COSTE_HORA_SUBVENCIONABLE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6051T00.NEXTVAL,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";

		Object getModalidadesContratoIdModalidadContratoAux = null;
		if (personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getIdModalidadContrato() != null) {
			getModalidadesContratoIdModalidadContratoAux = personascontratadas.getModalidadesContrato()
					.getIdModalidadContrato();
		}

		this.jdbcTemplate.update(query, personascontratadas.getIdRelExpActSub(),
				getModalidadesContratoIdModalidadContratoAux, personascontratadas.getNombrePC(),
				personascontratadas.getApellido1PC(), personascontratadas.getApellido2PC(),
				personascontratadas.getIdSexo(), personascontratadas.getEmpresaContratada(),
				personascontratadas.getNEmpresasN1(), personascontratadas.getHorasSubvencionablesN1(),
				personascontratadas.getNEmpresasN2(), personascontratadas.getHorasSubvencionablesN2(),
				personascontratadas.getCosteHoraContratada(), personascontratadas.getCosteHoraSubvencionable(),
				personascontratadas.getFechaRegistro(), personascontratadas.getUsuarioRegistro());
		return personascontratadas;
	}

	/**
	 * Updates a single row in the PersonasContratadas table.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @return PersonasContratadas
	 */
	public PersonasContratadas update(PersonasContratadas personascontratadas) {
		String query = "UPDATE PERSONAS_CONTRATADAS SET ID_MODALIDAD_CONTRATO=?, NOMBRE=?, APELLIDO1=?, APELLIDO2=?, ID_SEXO=?, EMPRESA_CONTRATADA=?, N_EMPRESAS_N1=?, HORAS_SUBVENCIONABLES_N1=?, N_EMPRESAS_N2=?, HORAS_SUBVENCIONABLES_N2=?, COSTE_HORA_CONTRATADA=?, COSTE_HORA_SUBVENCIONABLE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PERSONA_CONTRATADA=?";

		Object getModalidadesContratoIdModalidadContratoAux = null;
		if (personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getIdModalidadContrato() != null) {
			getModalidadesContratoIdModalidadContratoAux = personascontratadas.getModalidadesContrato()
					.getIdModalidadContrato();
		}
		this.jdbcTemplate.update(query, getModalidadesContratoIdModalidadContratoAux, personascontratadas.getNombrePC(),
				personascontratadas.getApellido1PC(), personascontratadas.getApellido2PC(),
				personascontratadas.getIdSexo(), personascontratadas.getEmpresaContratada(),
				personascontratadas.getNEmpresasN1(), personascontratadas.getHorasSubvencionablesN1(),
				personascontratadas.getNEmpresasN2(), personascontratadas.getHorasSubvencionablesN2(),
				personascontratadas.getCosteHoraContratada(), personascontratadas.getCosteHoraSubvencionable(),
				personascontratadas.getFechaUltimaModificacion(), personascontratadas.getUsuarioUltimaModificacion(),
				personascontratadas.getIdPersonaContratada());
		return personascontratadas;
	}

	/**
	 * Finds a single row in the PersonasContratadas table.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @return PersonasContratadas
	 */
	@Transactional(readOnly = true)
	public PersonasContratadas find(PersonasContratadas personascontratadas) {
		String query = "SELECT t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA, t1.NOMBRE_APELLIDOS NOMBREAPELLIDOS, t1.ID_SEXO IDSEXO, t1.EMPRESA_CONTRATADA EMPRESACONTRATADA, t1.N_EMPRESAS_N1 NEMPRESASN1, t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1, t1.N_EMPRESAS_N2 NEMPRESASN2, t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2, t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA, t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t3.ID_MODALIDAD_CONTRATO MODALIDADESCONTRATOIDMODALIDADCONTRATO, t3.DESCRIPCION_CASTELLANO MODALIDADESCONTRATODESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA MODALIDADESCONTRATODESCRIPCIONEUSKERA, t3.FECHA_REGISTRO MODALIDADESCONTRATOFECHAREGISTRO, t3.USUARIO_REGISTRO MODALIDADESCONTRATOUSUARIOREGISTRO FROM PERSONAS_CONTRATADAS t1 , MODALIDADES_CONTRATO t3  WHERE t1.ID_PERSONA_CONTRATADA = ?  AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ";

		List<PersonasContratadas> personascontratadasList = this.jdbcTemplate.query(query, this.rwMap,
				personascontratadas.getIdPersonaContratada());
		return (PersonasContratadas) DataAccessUtils.uniqueResult(personascontratadasList);
	}

	/**
	 * Finds a List of rows in the ContratacionesPersonal table
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return contratacionespersonalList
	 */
	@Transactional(readOnly = true)
	public List<PersonasContratadas> findPersonasContratadasPorRelExpActSub(Integer idRelExpActSub) {
		String query = "SELECT t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA, t1.NOMBRE NOMBRE, t1.APELLIDO1 APELLIDO1, t1.APELLIDO2 APELLIDO2, t4.ID_SEXO IDSEXO, t4.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANOSEXO, t4.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERASEXO, t1.EMPRESA_CONTRATADA EMPRESACONTRATADA, t1.N_EMPRESAS_N1 NEMPRESASN1, t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1, t1.N_EMPRESAS_N2 NEMPRESASN2, t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2, t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA, t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE,   t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATO, t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB, t2.INSPECCIONABLE INSPECCIONABLE, t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA FROM PERSONAS_CONTRATADAS t1,  REL_EXP_ACT_SUB t2, MODALIDADES_CONTRATO t3, SEXO t4 WHERE t1.ID_REL_EXP_ACT_SUB = ? AND t1.ID_REL_EXP_ACT_SUB = t2.ID_REL_EXP_ACT_SUB AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) AND t1.ID_SEXO = t4.ID_SEXO(+)";

		List<PersonasContratadas> personascontratadasList = this.jdbcTemplate.query(query,
				this.rwMapPersonasContratadasPorRelExpActSub, idRelExpActSub);

		return personascontratadasList;
	}

	/**
	 * Removes a single row in the PersonasContratadas table.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @return
	 */
	public void remove(PersonasContratadas personascontratadas) {
		String query = "DELETE FROM PERSONAS_CONTRATADAS WHERE ID_PERSONA_CONTRATADA=?";
		this.jdbcTemplate.update(query, personascontratadas.getIdPersonaContratada());
	}

	/**
	 * Removes a single row in the PersonasContratadas table.
	 *
	 * @param idRelExpActSub
	 *            Integer
	 * @return
	 */
	@Override
	public void removeByIdRelExpActSub(Integer idRelExpActSub) {
		String query = "DELETE FROM PERSONAS_CONTRATADAS WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the PersonasContratadas table.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PersonasContratadas>
	 */
	@Transactional(readOnly = true)
	public List<PersonasContratadas> findAll(PersonasContratadas personascontratadas,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA,t1.NOMBRE_APELLIDOS NOMBREAPELLIDOS,t1.ID_SEXO IDSEXO,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t1.N_EMPRESAS_N1 NEMPRESASN1,t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1,t1.N_EMPRESAS_N2 NEMPRESASN2,t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2,t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA,t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t3.ID_MODALIDAD_CONTRATO MODALIDADESCONTRATOIDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO MODALIDADESCONTRATODESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA MODALIDADESCONTRATODESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MODALIDADESCONTRATOFECHAREGISTRO,t3.USUARIO_REGISTRO MODALIDADESCONTRATOUSUARIOREGISTRO ");
		query.append("FROM PERSONAS_CONTRATADAS t1 ,MODALIDADES_CONTRATO t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(personascontratadas);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PersonasContratadasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PersonasContratadas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the PersonasContratadas table using like.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PersonasContratadas>
	 */
	@Transactional(readOnly = true)
	public List<PersonasContratadas> findAllLike(PersonasContratadas personascontratadas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA,t1.NOMBRE_APELLIDOS NOMBREAPELLIDOS,t1.ID_SEXO IDSEXO,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t1.N_EMPRESAS_N1 NEMPRESASN1,t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1,t1.N_EMPRESAS_N2 NEMPRESASN2,t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2,t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA,t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t3.ID_MODALIDAD_CONTRATO MODALIDADESCONTRATOIDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO MODALIDADESCONTRATODESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA MODALIDADESCONTRATODESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MODALIDADESCONTRATOFECHAREGISTRO,t3.USUARIO_REGISTRO MODALIDADESCONTRATOUSUARIOREGISTRO ");
		query.append("FROM PERSONAS_CONTRATADAS t1 ,MODALIDADES_CONTRATO t3  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(personascontratadas, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1  AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PersonasContratadasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PersonasContratadas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the PersonasContratadas table.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(PersonasContratadas personascontratadas) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM PERSONAS_CONTRATADAS t1 ,  MODALIDADES_CONTRATO t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(personascontratadas);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1  AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the PersonasContratadas table using like.
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(PersonasContratadas personascontratadas, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM PERSONAS_CONTRATADAS t1 ,MODALIDADES_CONTRATO t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(personascontratadas, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1  AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of PersonasContratadas selected for rup_table
	 *
	 * @param personascontratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PersonasContratadas>>
	 */
	@Override
	public List<TableRowDto<PersonasContratadas>> reorderSelection(PersonasContratadas personascontratadas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA,t1.NOMBRE_APELLIDOS NOMBREAPELLIDOS,t1.ID_SEXO IDSEXO,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t1.N_EMPRESAS_N1 NEMPRESASN1,t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1,t1.N_EMPRESAS_N2 NEMPRESASN2,t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2,t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA,t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t3.ID_MODALIDAD_CONTRATO MODALIDADESCONTRATOIDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO MODALIDADESCONTRATODESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA MODALIDADESCONTRATODESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MODALIDADESCONTRATOFECHAREGISTRO,t3.USUARIO_REGISTRO MODALIDADESCONTRATOUSUARIOREGISTRO ");
		// FROM
		query.append("FROM PERSONAS_CONTRATADAS t1 ,MODALIDADES_CONTRATO t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(personascontratadas, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1  AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				PersonasContratadas.class, filterParamList, "ID_PERSONA_CONTRATADA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PersonasContratadas>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            PersonasContratadas
	 * @param searchParams
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PersonasContratadas>>
	 */
	@Override
	public List<TableRowDto<PersonasContratadas>> search(PersonasContratadas filterParams,
			PersonasContratadas searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA,t1.NOMBRE_APELLIDOS NOMBREAPELLIDOS,t1.ID_SEXO IDSEXO,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t1.N_EMPRESAS_N1 NEMPRESASN1,t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1,t1.N_EMPRESAS_N2 NEMPRESASN2,t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2,t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA,t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t3.ID_MODALIDAD_CONTRATO MODALIDADESCONTRATOIDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO MODALIDADESCONTRATODESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA MODALIDADESCONTRATODESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MODALIDADESCONTRATOFECHAREGISTRO,t3.USUARIO_REGISTRO MODALIDADESCONTRATOUSUARIOREGISTRO ");
		// FROM
		query.append("FROM PERSONAS_CONTRATADAS t1 ,MODALIDADES_CONTRATO t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1  AND t1.ID_MODALIDAD_CONTRATO= t3.ID_MODALIDAD_CONTRATO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				PersonasContratadas.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_PERSONA_CONTRATADA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PersonasContratadas>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterpersonascontratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(PersonasContratadas filterpersonascontratadas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA,t1.NOMBRE_APELLIDOS NOMBREAPELLIDOS,t1.ID_SEXO IDSEXO,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t1.N_EMPRESAS_N1 NEMPRESASN1,t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1,t1.N_EMPRESAS_N2 NEMPRESASN2,t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2,t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA,t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t3.ID_MODALIDAD_CONTRATO MODALIDADESCONTRATOIDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO MODALIDADESCONTRATODESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA MODALIDADESCONTRATODESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MODALIDADESCONTRATOFECHAREGISTRO,t3.USUARIO_REGISTRO MODALIDADESCONTRATOUSUARIOREGISTRO ");
		// FROM
		query.append("FROM PERSONAS_CONTRATADAS t1 ,MODALIDADES_CONTRATO t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterpersonascontratadas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				PersonasContratadas.class, query, params, "ID_PERSONA_CONTRATADA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical PersonasContratadas table.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<PersonasContratadas>>
	 */
	@Override
	public List<JerarquiaDto<PersonasContratadas>> findAllLikeJerarquia(PersonasContratadas filterPersonasContratadas,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA,t1.NOMBRE_APELLIDOS NOMBREAPELLIDOS,t1.ID_SEXO IDSEXO,t1.EMPRESA_CONTRATADA EMPRESACONTRATADA,t1.N_EMPRESAS_N1 NEMPRESASN1,t1.HORAS_SUBVENCIONABLES_N1 HORASSUBVENCIONABLESN1,t1.N_EMPRESAS_N2 NEMPRESASN2,t1.HORAS_SUBVENCIONABLES_N2 HORASSUBVENCIONABLESN2,t1.COSTE_HORA_CONTRATADA COSTEHORACONTRATADA,t1.COSTE_HORA_SUBVENCIONABLE COSTEHORASUBVENCIONABLE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t3.ID_MODALIDAD_CONTRATO MODALIDADESCONTRATOIDMODALIDADCONTRATO,t3.DESCRIPCION_CASTELLANO MODALIDADESCONTRATODESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA MODALIDADESCONTRATODESCRIPCIONEUSKERA,t3.FECHA_REGISTRO MODALIDADESCONTRATOFECHAREGISTRO,t3.USUARIO_REGISTRO MODALIDADESCONTRATOUSUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PERSONAS_CONTRATADAS t1
		// ,COMPETITIVIDAD t2 ,MODALIDADES_CONTRATO t3 ,PROGRAMAS t4 ");
		List<String> from = new ArrayList<String>();
		from.add("PERSONAS_CONTRATADAS");
		from.add("MODALIDADES_CONTRATO");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPersonasContratadas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PERSONA_CONTRATADA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					PersonasContratadasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(PersonasContratadas filterPersonasContratadas,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PERSONAS_CONTRATADAS t1
		// ,COMPETITIVIDAD t2 ,MODALIDADES_CONTRATO t3 ,PROGRAMAS t4 ");
		List<String> from = new ArrayList<String>();
		from.add("PERSONAS_CONTRATADAS");
		from.add("MODALIDADES_CONTRATO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPersonasContratadas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PERSONA_CONTRATADA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<PersonasContratadas>>
	 */
	@Override
	public List<TableRowDto<PersonasContratadas>> findAllChild(PersonasContratadas filterPersonasContratadas,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PERSONAS_CONTRATADAS t1
		// ,COMPETITIVIDAD t2 ,MODALIDADES_CONTRATO t3 ,PROGRAMAS t4 ");
		List<String> from = new ArrayList<String>();
		from.add("PERSONAS_CONTRATADAS");
		from.add("MODALIDADES_CONTRATO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPersonasContratadas, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_PERSONA_CONTRATADA", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<PersonasContratadas>(this.rwMapPK, "ID_PERSONA_CONTRATADA"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PersonasContratadas entity
	 *
	 * @param personascontratadas
	 *            PersonasContratadas Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(PersonasContratadas personascontratadas) {

		StringBuilder where = new StringBuilder(PersonasContratadasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (personascontratadas != null && personascontratadas.getIdPersonaContratada() != null) {
			where.append(" AND t1.ID_PERSONA_CONTRATADA = ?");
			params.add(personascontratadas.getIdPersonaContratada());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getIdModalidadContrato() != null) {
			where.append(" AND t3.ID_MODALIDAD_CONTRATO = ?");
			params.add(personascontratadas.getModalidadesContrato().getIdModalidadContrato());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getDescripcionCastellano() != null) {
			where.append(" AND t3.DESCRIPCION_CASTELLANO = ?");
			params.add(personascontratadas.getModalidadesContrato().getDescripcionCastellano());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getDescripcionEuskera() != null) {
			where.append(" AND t3.DESCRIPCION_EUSKERA = ?");
			params.add(personascontratadas.getModalidadesContrato().getDescripcionEuskera());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(personascontratadas.getModalidadesContrato().getFechaRegistro());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(personascontratadas.getModalidadesContrato().getUsuarioRegistro());
		}
		if (personascontratadas != null && personascontratadas.getNombrePC() != null) {
			where.append(" AND t1.NOMBRE = ?");
			params.add(personascontratadas.getNombrePC());
		}
		if (personascontratadas != null && personascontratadas.getApellido1PC() != null) {
			where.append(" AND t1.APELLIDO1 = ?");
			params.add(personascontratadas.getApellido1PC());
		}
		if (personascontratadas != null && personascontratadas.getApellido2PC() != null) {
			where.append(" AND t1.APELLIDO2 = ?");
			params.add(personascontratadas.getApellido2PC());
		}
		if (personascontratadas != null && personascontratadas.getIdSexo() != null) {
			where.append(" AND t1.ID_SEXO = ?");
			params.add(personascontratadas.getIdSexo());
		}
		if (personascontratadas != null && personascontratadas.getEmpresaContratada() != null) {
			where.append(" AND t1.EMPRESA_CONTRATADA = ?");
			params.add(personascontratadas.getEmpresaContratada());
		}
		if (personascontratadas != null && personascontratadas.getNEmpresasN1() != null) {
			where.append(" AND t1.N_EMPRESAS_N1 = ?");
			params.add(personascontratadas.getNEmpresasN1());
		}
		if (personascontratadas != null && personascontratadas.getHorasSubvencionablesN1() != null) {
			where.append(" AND t1.HORAS_SUBVENCIONABLES_N1 = ?");
			params.add(personascontratadas.getHorasSubvencionablesN1());
		}
		if (personascontratadas != null && personascontratadas.getNEmpresasN2() != null) {
			where.append(" AND t1.N_EMPRESAS_N2 = ?");
			params.add(personascontratadas.getNEmpresasN2());
		}
		if (personascontratadas != null && personascontratadas.getHorasSubvencionablesN2() != null) {
			where.append(" AND t1.HORAS_SUBVENCIONABLES_N2 = ?");
			params.add(personascontratadas.getHorasSubvencionablesN2());
		}
		if (personascontratadas != null && personascontratadas.getCosteHoraContratada() != null) {
			where.append(" AND t1.COSTE_HORA_CONTRATADA = ?");
			params.add(personascontratadas.getCosteHoraContratada());
		}
		if (personascontratadas != null && personascontratadas.getCosteHoraSubvencionable() != null) {
			where.append(" AND t1.COSTE_HORA_SUBVENCIONABLE = ?");
			params.add(personascontratadas.getCosteHoraSubvencionable());
		}
		if (personascontratadas != null && personascontratadas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(personascontratadas.getFechaRegistro());
		}
		if (personascontratadas != null && personascontratadas.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(personascontratadas.getUsuarioRegistro());
		}
		if (personascontratadas != null && personascontratadas.getFechaUltimaModificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(personascontratadas.getFechaUltimaModificacion());
		}
		if (personascontratadas != null && personascontratadas.getUsuarioUltimaModificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(personascontratadas.getUsuarioUltimaModificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PersonasContratadas entity
	 *
	 * @param personascontratadas
	 *            PersonasContratadas Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(PersonasContratadas personascontratadas, Boolean startsWith) {

		StringBuilder where = new StringBuilder(PersonasContratadasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (personascontratadas != null && personascontratadas.getIdPersonaContratada() != null) {
			where.append(" AND t1.ID_PERSONA_CONTRATADA = ?");
			params.add(personascontratadas.getIdPersonaContratada());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getIdModalidadContrato() != null) {
			where.append(" AND t3.ID_MODALIDAD_CONTRATO = ?");
			params.add(personascontratadas.getModalidadesContrato().getIdModalidadContrato());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getModalidadesContrato().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getModalidadesContrato().getDescripcionCastellano().toUpperCase()
						+ "%");
			}
			where.append(" AND t3.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getModalidadesContrato().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add(
						"%" + personascontratadas.getModalidadesContrato().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(personascontratadas.getModalidadesContrato().getFechaRegistro());
		}
		if (personascontratadas != null && personascontratadas.getModalidadesContrato() != null
				&& personascontratadas.getModalidadesContrato().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getModalidadesContrato().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getModalidadesContrato().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getNombrePC() != null) {
			where.append(" AND UPPER(t1.NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getNombrePC().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getNombrePC().toUpperCase() + "%");
			}
			where.append(" AND t1.NOMBRE IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getApellido1PC() != null) {
			where.append(" AND UPPER(t1.APELLIDO1) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getApellido1PC().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getApellido1PC().toUpperCase() + "%");
			}
			where.append(" AND t1.APELLIDO1 IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getApellido2PC() != null) {
			where.append(" AND UPPER(t1.APELLIDO2) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getApellido2PC().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getApellido2PC().toUpperCase() + "%");
			}
			where.append(" AND t1.APELLIDO2 IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getIdSexo() != null) {
			where.append(" AND t1.ID_SEXO = ?");
			params.add(personascontratadas.getIdSexo());
		}
		if (personascontratadas != null && personascontratadas.getEmpresaContratada() != null) {
			where.append(" AND UPPER(t1.EMPRESA_CONTRATADA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getEmpresaContratada().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getEmpresaContratada().toUpperCase() + "%");
			}
			where.append(" AND t1.EMPRESA_CONTRATADA IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getNEmpresasN1() != null) {
			where.append(" AND t1.N_EMPRESAS_N1 = ?");
			params.add(personascontratadas.getNEmpresasN1());
		}
		if (personascontratadas != null && personascontratadas.getHorasSubvencionablesN1() != null) {
			where.append(" AND t1.HORAS_SUBVENCIONABLES_N1 = ?");
			params.add(personascontratadas.getHorasSubvencionablesN1());
		}
		if (personascontratadas != null && personascontratadas.getNEmpresasN2() != null) {
			where.append(" AND t1.N_EMPRESAS_N2 = ?");
			params.add(personascontratadas.getNEmpresasN2());
		}
		if (personascontratadas != null && personascontratadas.getHorasSubvencionablesN2() != null) {
			where.append(" AND t1.HORAS_SUBVENCIONABLES_N2 = ?");
			params.add(personascontratadas.getHorasSubvencionablesN2());
		}
		if (personascontratadas != null && personascontratadas.getCosteHoraContratada() != null) {
			where.append(" AND t1.COSTE_HORA_CONTRATADA = ?");
			params.add(personascontratadas.getCosteHoraContratada());
		}
		if (personascontratadas != null && personascontratadas.getCosteHoraSubvencionable() != null) {
			where.append(" AND t1.COSTE_HORA_SUBVENCIONABLE = ?");
			params.add(personascontratadas.getCosteHoraSubvencionable());
		}
		if (personascontratadas != null && personascontratadas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(personascontratadas.getFechaRegistro());
		}
		if (personascontratadas != null && personascontratadas.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (personascontratadas != null && personascontratadas.getFechaUltimaModificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(personascontratadas.getFechaUltimaModificacion());
		}
		if (personascontratadas != null && personascontratadas.getUsuarioUltimaModificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(personascontratadas.getUsuarioUltimaModificacion().toUpperCase() + "%");
			} else {
				params.add("%" + personascontratadas.getUsuarioUltimaModificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
