package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.model.PTT.PertenenciasRedes;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PertenenciasRedesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PertenenciasRedesDaoImpl implements PertenenciasRedesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPERTENENCIAREDES", "DENOMINACION",
			"FECHAREGISTRO", "USUARIOREGISTRO", "RELEXPACTSUBIDRELEXPACTSUB", "RELEXPACTSUBIDEXPEDIENTE",
			"RELEXPACTSUBFECHAREGISTRO", "RELEXPACTSUBUSUARIOREGISTRO", "RELEXPACTSUBIDACTSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<PertenenciasRedes> rwMap = new RowMapper<PertenenciasRedes>() {
		public PertenenciasRedes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PertenenciasRedes(resultSet.getInt("IDPERTENENCIAREDES"), resultSet.getString("DENOMINACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));
		}
	};

	private RowMapper<PertenenciasRedes> rwMapPK = new RowMapper<PertenenciasRedes>() {
		public PertenenciasRedes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PertenenciasRedes(resultSet.getInt("IDPERTENENCIAREDES"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<PertenenciasRedes>> rwMapJerarquia = new RowMapper<JerarquiaDto<PertenenciasRedes>>() {
		public JerarquiaDto<PertenenciasRedes> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			PertenenciasRedes pertenenciasredes = new PertenenciasRedes(resultSet.getInt("IDPERTENENCIAREDES"),
					resultSet.getString("DENOMINACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));

			JerarquiaDto<PertenenciasRedes> jerarquia = new JerarquiaDto<PertenenciasRedes>();
			jerarquia.setModel(pertenenciasredes);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the PertenenciasRedes table.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @return PertenenciasRedes
	 */
	public PertenenciasRedes add(PertenenciasRedes pertenenciasredes) {
		String query = "INSERT INTO PERTENENCIAS_REDES (ID_PERTENENCIA_REDES, ID_REL_EXP_ACT_SUB, DENOMINACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = pertenenciasredes.getRelExpActSub().getIdRelExpActSub();
		}
		if (pertenenciasredes.getIdPertenenciaRedes() == null) {
			pertenenciasredes.setIdPertenenciaRedes(
					this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6042T00")));
		}
		this.jdbcTemplate.update(query, pertenenciasredes.getIdPertenenciaRedes(), getRelExpActSubIdRelExpActSubAux,
				pertenenciasredes.getDenominacion(), pertenenciasredes.getFechaRegistro(),
				pertenenciasredes.getUsuarioRegistro());
		return pertenenciasredes;
	}

	/**
	 * Updates a single row in the PertenenciasRedes table.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @return PertenenciasRedes
	 */
	public PertenenciasRedes update(PertenenciasRedes pertenenciasredes) {
		String query = "UPDATE PERTENENCIAS_REDES SET  DENOMINACION=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PERTENENCIA_REDES=?";

		this.jdbcTemplate.update(query, pertenenciasredes.getDenominacion(),
				pertenenciasredes.getFechaUltimaModificacion(), pertenenciasredes.getUsuarioUltimaModificacion(),
				pertenenciasredes.getIdPertenenciaRedes());
		return pertenenciasredes;
	}

	/**
	 * Updates a single row in the PertenenciasRedes table.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @return PertenenciasRedes
	 */
	public PertenenciasRedes updateDenominacionRedes(PertenenciasRedes pertenenciasredes) {
		String query = "UPDATE PERTENENCIAS_REDES SET DENOMINACION=? WHERE ID_REL_EXP_ACT_SUB=?";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = pertenenciasredes.getRelExpActSub().getIdRelExpActSub();
		}
		this.jdbcTemplate.update(query, pertenenciasredes.getDenominacion(), getRelExpActSubIdRelExpActSubAux);
		return pertenenciasredes;
	}

	/**
	 * Finds a single row in the PertenenciasRedes table.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @return PertenenciasRedes
	 */
	@Transactional(readOnly = true)
	public PertenenciasRedes find(PertenenciasRedes pertenenciasredes) {
		String query = "SELECT t1.ID_PERTENENCIA_REDES IDPERTENENCIAREDES, t1.DENOMINACION DENOMINACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE, t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO, t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO, t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB FROM PERTENENCIAS_REDES t1 , REL_EXP_ACT_SUB t2  WHERE t1.ID_PERTENENCIA_REDES = ?   AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+)";

		List<PertenenciasRedes> pertenenciasredesList = this.jdbcTemplate.query(query, this.rwMap,
				pertenenciasredes.getIdPertenenciaRedes());
		return (PertenenciasRedes) DataAccessUtils.uniqueResult(pertenenciasredesList);
	}

	/**
	 * Removes a single row in the PertenenciasRedes table.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @return
	 */
	public void remove(PertenenciasRedes pertenenciasredes) {
		String query = "DELETE FROM PERTENENCIAS_REDES WHERE ID_PERTENENCIA_REDES=?";
		this.jdbcTemplate.update(query, pertenenciasredes.getIdPertenenciaRedes());
	}

	/**
	 * Finds a list of rows in the PertenenciasRedes table.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PertenenciasRedes>
	 */
	@Transactional(readOnly = true)
	public List<PertenenciasRedes> findAll(PertenenciasRedes pertenenciasredes, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PERTENENCIA_REDES IDPERTENENCIAREDES,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM PERTENENCIAS_REDES t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(pertenenciasredes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PertenenciasRedesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PertenenciasRedes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the PertenenciasRedes table using like.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PertenenciasRedes>
	 */
	@Transactional(readOnly = true)
	public List<PertenenciasRedes> findAllLike(PertenenciasRedes pertenenciasredes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PERTENENCIA_REDES IDPERTENENCIAREDES,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		query.append("FROM PERTENENCIAS_REDES t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pertenenciasredes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PertenenciasRedesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PertenenciasRedes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the PertenenciasRedes table.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(PertenenciasRedes pertenenciasredes) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PERTENENCIAS_REDES t1 , REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(pertenenciasredes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the PertenenciasRedes table using like.
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(PertenenciasRedes pertenenciasredes, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PERTENENCIAS_REDES t1 ,REL_EXP_ACT_SUB t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pertenenciasredes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of PertenenciasRedes selected for rup_table
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PertenenciasRedes>>
	 */
	@Override
	public List<TableRowDto<PertenenciasRedes>> reorderSelection(PertenenciasRedes pertenenciasredes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERTENENCIA_REDES IDPERTENENCIAREDES,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM PERTENENCIAS_REDES t1 ,REL_EXP_ACT_SUB t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pertenenciasredes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				PertenenciasRedes.class, filterParamList, "ID_PERTENENCIA_REDES");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PertenenciasRedes>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            PertenenciasRedes
	 * @param searchParams
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PertenenciasRedes>>
	 */
	@Override
	public List<TableRowDto<PertenenciasRedes>> search(PertenenciasRedes filterParams, PertenenciasRedes searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERTENENCIA_REDES IDPERTENENCIAREDES,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM PERTENENCIAS_REDES t1 ,REL_EXP_ACT_SUB t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				PertenenciasRedes.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_PERTENENCIA_REDES");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PertenenciasRedes>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterpertenenciasredes
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(PertenenciasRedes filterpertenenciasredes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERTENENCIA_REDES IDPERTENENCIAREDES,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		query.append("FROM PERTENENCIAS_REDES t1 ,REL_EXP_ACT_SUB t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterpertenenciasredes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				PertenenciasRedes.class, query, params, "ID_PERTENENCIA_REDES");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical PertenenciasRedes table.
	 *
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<PertenenciasRedes>>
	 */
	@Override
	public List<JerarquiaDto<PertenenciasRedes>> findAllLikeJerarquia(PertenenciasRedes filterPertenenciasRedes,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PERTENENCIA_REDES IDPERTENENCIAREDES,t1.DENOMINACION DENOMINACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB,t2.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE,t2.FECHA_REGISTRO RELEXPACTSUBFECHAREGISTRO,t2.USUARIO_REGISTRO RELEXPACTSUBUSUARIOREGISTRO,t2.ID_ACT_SUB RELEXPACTSUBIDACTSUB ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PERTENENCIAS_REDES t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("PERTENENCIAS_REDES");
		from.add("REL_EXP_ACT_SUB");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPertenenciasRedes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PERTENENCIA_REDES", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					PertenenciasRedesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(PertenenciasRedes filterPertenenciasRedes,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PERTENENCIAS_REDES t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("PERTENENCIAS_REDES");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPertenenciasRedes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PERTENENCIA_REDES",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<PertenenciasRedes>>
	 */
	@Override
	public List<TableRowDto<PertenenciasRedes>> findAllChild(PertenenciasRedes filterPertenenciasRedes,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PERTENENCIAS_REDES t1
		// ,REL_EXP_ACT_SUB t2 ");
		List<String> from = new ArrayList<String>();
		from.add("PERTENENCIAS_REDES");
		from.add("REL_EXP_ACT_SUB");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPertenenciasRedes, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_PERTENENCIA_REDES", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<PertenenciasRedes>(this.rwMapPK, "ID_PERTENENCIA_REDES"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PertenenciasRedes entity
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(PertenenciasRedes pertenenciasredes) {

		StringBuilder where = new StringBuilder(PertenenciasRedesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (pertenenciasredes != null && pertenenciasredes.getIdPertenenciaRedes() != null) {
			where.append(" AND t1.ID_PERTENENCIA_REDES = ?");
			params.add(pertenenciasredes.getIdPertenenciaRedes());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(pertenenciasredes.getRelExpActSub().getIdRelExpActSub());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getActSubvencionable() != null
				&& pertenenciasredes.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(pertenenciasredes.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(pertenenciasredes.getRelExpActSub().getIdExpediente());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(pertenenciasredes.getRelExpActSub().getFechaRegistro());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(pertenenciasredes.getRelExpActSub().getUsuarioRegistro());
		}
		if (pertenenciasredes != null && pertenenciasredes.getDenominacion() != null) {
			where.append(" AND t1.DENOMINACION = ?");
			params.add(pertenenciasredes.getDenominacion());
		}
		if (pertenenciasredes != null && pertenenciasredes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(pertenenciasredes.getFechaRegistro());
		}
		if (pertenenciasredes != null && pertenenciasredes.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(pertenenciasredes.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PertenenciasRedes entity
	 *
	 * @param pertenenciasredes
	 *            PertenenciasRedes Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(PertenenciasRedes pertenenciasredes, Boolean startsWith) {

		StringBuilder where = new StringBuilder(PertenenciasRedesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (pertenenciasredes != null && pertenenciasredes.getIdPertenenciaRedes() != null) {
			where.append(" AND t1.ID_PERTENENCIA_REDES = ?");
			params.add(pertenenciasredes.getIdPertenenciaRedes());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getIdRelExpActSub() != null) {
			where.append(" AND t2.ID_REL_EXP_ACT_SUB = ?");
			params.add(pertenenciasredes.getRelExpActSub().getIdRelExpActSub());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getActSubvencionable() != null
				&& pertenenciasredes.getRelExpActSub().getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(pertenenciasredes.getRelExpActSub().getActSubvencionable().getIdActSub());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getIdExpediente() != null) {
			where.append(" AND t2.ID_EXPEDIENTE = ?");
			params.add(pertenenciasredes.getRelExpActSub().getIdExpediente());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(pertenenciasredes.getRelExpActSub().getFechaRegistro());
		}
		if (pertenenciasredes != null && pertenenciasredes.getRelExpActSub() != null
				&& pertenenciasredes.getRelExpActSub().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pertenenciasredes.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + pertenenciasredes.getRelExpActSub().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (pertenenciasredes != null && pertenenciasredes.getDenominacion() != null) {
			where.append(" AND UPPER(t1.DENOMINACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pertenenciasredes.getDenominacion().toUpperCase() + "%");
			} else {
				params.add("%" + pertenenciasredes.getDenominacion().toUpperCase() + "%");
			}
			where.append(" AND t1.DENOMINACION IS NOT NULL");
		}
		if (pertenenciasredes != null && pertenenciasredes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(pertenenciasredes.getFechaRegistro());
		}
		if (pertenenciasredes != null && pertenenciasredes.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pertenenciasredes.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + pertenenciasredes.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
