package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.PTT.ProductosTuristicos;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ProductosTuristicosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ProductosTuristicosDaoImpl implements ProductosTuristicosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPRODUCTOTURISTICO", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ProductosTuristicos> rwMap = new RowMapper<ProductosTuristicos>() {
		public ProductosTuristicos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ProductosTuristicos(resultSet.getLong("IDPRODUCTOTURISTICO"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<ProductosTuristicos> rwMapPK = new RowMapper<ProductosTuristicos>() {
		public ProductosTuristicos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ProductosTuristicos(resultSet.getLong("IDPRODUCTOTURISTICO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ProductosTuristicos>> rwMapJerarquia = new RowMapper<JerarquiaDto<ProductosTuristicos>>() {
		public JerarquiaDto<ProductosTuristicos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ProductosTuristicos productosturisticos = new ProductosTuristicos(resultSet.getLong("IDPRODUCTOTURISTICO"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<ProductosTuristicos> jerarquia = new JerarquiaDto<ProductosTuristicos>();
			jerarquia.setModel(productosturisticos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ProductosTuristicos table.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @return ProductosTuristicos
	 */
	public ProductosTuristicos add(ProductosTuristicos productosturisticos) {
		String query = "INSERT INTO PRODUCTOS_TURISTICOS (ID_PRODUCTO_TURISTICO, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, productosturisticos.getIdProductoTuristico(),
				productosturisticos.getDescripcionCastellano(), productosturisticos.getDescripcionEuskera(),
				productosturisticos.getFechaRegistro(), productosturisticos.getUsuarioRegistro());
		return productosturisticos;
	}

	/**
	 * Updates a single row in the ProductosTuristicos table.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @return ProductosTuristicos
	 */
	public ProductosTuristicos update(ProductosTuristicos productosturisticos) {
		String query = "UPDATE PRODUCTOS_TURISTICOS SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_PRODUCTO_TURISTICO=?";
		this.jdbcTemplate.update(query, productosturisticos.getDescripcionCastellano(),
				productosturisticos.getDescripcionEuskera(), productosturisticos.getFechaRegistro(),
				productosturisticos.getUsuarioRegistro(), productosturisticos.getIdProductoTuristico());
		return productosturisticos;
	}

	/**
	 * Finds a single row in the ProductosTuristicos table.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @return ProductosTuristicos
	 */
	@Transactional(readOnly = true)
	public ProductosTuristicos find(ProductosTuristicos productosturisticos) {
		String query = "SELECT t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM PRODUCTOS_TURISTICOS t1  WHERE t1.ID_PRODUCTO_TURISTICO = ?  ";

		List<ProductosTuristicos> productosturisticosList = this.jdbcTemplate.query(query, this.rwMap,
				productosturisticos.getIdProductoTuristico());
		return (ProductosTuristicos) DataAccessUtils.uniqueResult(productosturisticosList);
	}

	/**
	 * Removes a single row in the ProductosTuristicos table.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @return
	 */
	public void remove(ProductosTuristicos productosturisticos) {
		String query = "DELETE FROM PRODUCTOS_TURISTICOS WHERE ID_PRODUCTO_TURISTICO=?";
		this.jdbcTemplate.update(query, productosturisticos.getIdProductoTuristico());
	}

	/**
	 * Finds a list of rows in the ProductosTuristicos table.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ProductosTuristicos>
	 */
	@Transactional(readOnly = true)
	public List<ProductosTuristicos> findAll(ProductosTuristicos productosturisticos,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM PRODUCTOS_TURISTICOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(productosturisticos);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ProductosTuristicosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ProductosTuristicos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds a single row in the ProductosTuristicos table.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @return ProductosTuristicos
	 */
	@Transactional(readOnly = true)
	public List<ProductosTuristicos> findProductosTuristicos(ProductosTuristicos productosTuristicos) {
		String query = "SELECT t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM PRODUCTOS_TURISTICOS t1 WHERE ID_CONVOCATORIA = ?";

		return (List<ProductosTuristicos>) this.jdbcTemplate.query(query, this.rwMap,
				productosTuristicos.getIdConvocatoria());
	}

	/**
	 * Finds rows in the ProductosTuristicos table using like.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ProductosTuristicos>
	 */
	@Transactional(readOnly = true)
	public List<ProductosTuristicos> findAllLike(ProductosTuristicos productosturisticos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM PRODUCTOS_TURISTICOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(productosturisticos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ProductosTuristicosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ProductosTuristicos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ProductosTuristicos table.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ProductosTuristicos productosturisticos) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PRODUCTOS_TURISTICOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(productosturisticos);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ProductosTuristicos table using like.
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ProductosTuristicos productosturisticos, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PRODUCTOS_TURISTICOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(productosturisticos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ProductosTuristicos selected for rup_table
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ProductosTuristicos>>
	 */
	@Override
	public List<TableRowDto<ProductosTuristicos>> reorderSelection(ProductosTuristicos productosturisticos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM PRODUCTOS_TURISTICOS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(productosturisticos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ProductosTuristicos.class, filterParamList, "ID_PRODUCTO_TURISTICO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ProductosTuristicos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ProductosTuristicos
	 * @param searchParams
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ProductosTuristicos>>
	 */
	@Override
	public List<TableRowDto<ProductosTuristicos>> search(ProductosTuristicos filterParams,
			ProductosTuristicos searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM PRODUCTOS_TURISTICOS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ProductosTuristicos.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_PRODUCTO_TURISTICO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ProductosTuristicos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterproductosturisticos
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ProductosTuristicos filterproductosturisticos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM PRODUCTOS_TURISTICOS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterproductosturisticos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				ProductosTuristicos.class, query, params, "ID_PRODUCTO_TURISTICO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ProductosTuristicos table.
	 *
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ProductosTuristicos>>
	 */
	@Override
	public List<JerarquiaDto<ProductosTuristicos>> findAllLikeJerarquia(ProductosTuristicos filterProductosTuristicos,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PRODUCTOS_TURISTICOS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("PRODUCTOS_TURISTICOS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProductosTuristicos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PRODUCTO_TURISTICO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ProductosTuristicosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ProductosTuristicos filterProductosTuristicos,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PRODUCTOS_TURISTICOS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("PRODUCTOS_TURISTICOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProductosTuristicos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PRODUCTO_TURISTICO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ProductosTuristicos>>
	 */
	@Override
	public List<TableRowDto<ProductosTuristicos>> findAllChild(ProductosTuristicos filterProductosTuristicos,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PRODUCTOS_TURISTICOS t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("PRODUCTOS_TURISTICOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProductosTuristicos, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_PRODUCTO_TURISTICO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ProductosTuristicos>(this.rwMapPK, "ID_PRODUCTO_TURISTICO"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ProductosTuristicos entity
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ProductosTuristicos productosturisticos) {

		StringBuilder where = new StringBuilder(ProductosTuristicosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (productosturisticos != null && productosturisticos.getIdProductoTuristico() != null) {
			where.append(" AND t1.ID_PRODUCTO_TURISTICO = ?");
			params.add(productosturisticos.getIdProductoTuristico());
		}
		if (productosturisticos != null && productosturisticos.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(productosturisticos.getDescripcionCastellano());
		}
		if (productosturisticos != null && productosturisticos.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(productosturisticos.getDescripcionEuskera());
		}
		if (productosturisticos != null && productosturisticos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(productosturisticos.getFechaRegistro());
		}
		if (productosturisticos != null && productosturisticos.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(productosturisticos.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ProductosTuristicos entity
	 *
	 * @param productosturisticos
	 *            ProductosTuristicos Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ProductosTuristicos productosturisticos, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ProductosTuristicosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (productosturisticos != null && productosturisticos.getIdProductoTuristico() != null) {
			where.append(" AND t1.ID_PRODUCTO_TURISTICO = ?");
			params.add(productosturisticos.getIdProductoTuristico());
		}
		if (productosturisticos != null && productosturisticos.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(productosturisticos.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + productosturisticos.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (productosturisticos != null && productosturisticos.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(productosturisticos.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + productosturisticos.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (productosturisticos != null && productosturisticos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(productosturisticos.getFechaRegistro());
		}
		if (productosturisticos != null && productosturisticos.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(productosturisticos.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + productosturisticos.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
