package com.ejie.ab60.dao.PTT;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.PTT.AmbitosTerritoriales;
import com.ejie.ab60.model.PTT.RelExpAmbTer;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpAmbTerDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelExpAmbTerDaoImpl implements RelExpAmbTerDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELEXPAMBTER", "IDEXPEDIENTE", "FECHAREGISTRO",
			"USUARIOREGISTRO", "AMBITOSTERRITORIALESIDAMBITOTERRITORIAL", "AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO",
			"AMBITOSTERRITORIALESDESCRIPCIONEUSKERA", "AMBITOSTERRITORIALESFECHAREGISTRO",
			"AMBITOSTERRITORIALESUSUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelExpAmbTer> rwMap = new RowMapper<RelExpAmbTer>() {
		public RelExpAmbTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpAmbTer(resultSet.getInt("IDRELEXPAMBTER"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new AmbitosTerritoriales(resultSet.getLong("AmbitosTerritorialesIDAMBITOTERRITORIAL"),
							resultSet.getString("AmbitosTerritorialesDESCRIPCIONCASTELLANO"),
							resultSet.getString("AmbitosTerritorialesDESCRIPCIONEUSKERA"),
							resultSet.getDate("AmbitosTerritorialesFECHAREGISTRO"),
							resultSet.getString("AmbitosTerritorialesUSUARIOREGISTRO")));
		}
	};

	private RowMapper<RelExpAmbTer> rwMapPK = new RowMapper<RelExpAmbTer>() {
		public RelExpAmbTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpAmbTer(resultSet.getInt("IDRELEXPAMBTER"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelExpAmbTer>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelExpAmbTer>>() {
		public JerarquiaDto<RelExpAmbTer> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpAmbTer relexpambter = new RelExpAmbTer(resultSet.getInt("IDRELEXPAMBTER"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new AmbitosTerritoriales(resultSet.getLong("AmbitosTerritorialesIDAMBITOTERRITORIAL"),
							resultSet.getString("AmbitosTerritorialesDESCRIPCIONCASTELLANO"),
							resultSet.getString("AmbitosTerritorialesDESCRIPCIONEUSKERA"),
							resultSet.getDate("AmbitosTerritorialesFECHAREGISTRO"),
							resultSet.getString("AmbitosTerritorialesUSUARIOREGISTRO")));

			JerarquiaDto<RelExpAmbTer> jerarquia = new JerarquiaDto<RelExpAmbTer>();
			jerarquia.setModel(relexpambter);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelExpAmbTer table.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @return RelExpAmbTer
	 */
	public RelExpAmbTer add(RelExpAmbTer relexpambter) {
		String query = "INSERT INTO REL_EXP_AMB_TER (ID_REL_EXP_AMB_TER, ID_AMBITO_TERRITORIAL, ID_EXPEDIENTE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		Object getAmbitosTerritorialesIdAmbitoTerritorialAux = null;
		if (relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getIdAmbitoTerritorial() != null) {
			getAmbitosTerritorialesIdAmbitoTerritorialAux = relexpambter.getAmbitosTerritoriales()
					.getIdAmbitoTerritorial();
		}
		this.jdbcTemplate.update(query, relexpambter.getIdRelExpAmbTer(), getAmbitosTerritorialesIdAmbitoTerritorialAux,
				relexpambter.getIdExpediente(), relexpambter.getFechaRegistro(), relexpambter.getUsuarioRegistro());
		return relexpambter;
	}

	/**
	 * Updates a single row in the RelExpAmbTer table.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @return RelExpAmbTer
	 */
	public RelExpAmbTer update(RelExpAmbTer relexpambter) {
		String query = "UPDATE REL_EXP_AMB_TER SET ID_AMBITO_TERRITORIAL=?, ID_EXPEDIENTE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_REL_EXP_AMB_TER=?";
		Object getAmbitosTerritorialesIdAmbitoTerritorialAux = null;
		if (relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getIdAmbitoTerritorial() != null) {
			getAmbitosTerritorialesIdAmbitoTerritorialAux = relexpambter.getAmbitosTerritoriales()
					.getIdAmbitoTerritorial();
		}
		this.jdbcTemplate.update(query, getAmbitosTerritorialesIdAmbitoTerritorialAux, relexpambter.getIdExpediente(),
				relexpambter.getFechaRegistro(), relexpambter.getUsuarioRegistro(), relexpambter.getIdRelExpAmbTer());
		return relexpambter;
	}

	/**
	 * Finds a single row in the RelExpAmbTer table.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @return RelExpAmbTer
	 */
	@Transactional(readOnly = true)
	public RelExpAmbTer find(RelExpAmbTer relexpambter) {
		String query = "SELECT t1.ID_REL_EXP_AMB_TER IDRELEXPAMBTER, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_AMBITO_TERRITORIAL AMBITOSTERRITORIALESIDAMBITOTERRITORIAL, t2.DESCRIPCION_CASTELLANO AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA AMBITOSTERRITORIALESDESCRIPCIONEUSKERA, t2.FECHA_REGISTRO AMBITOSTERRITORIALESFECHAREGISTRO, t2.USUARIO_REGISTRO AMBITOSTERRITORIALESUSUARIOREGISTRO FROM REL_EXP_AMB_TER t1 , AMBITOS_TERRITORIALES t2  WHERE t1.ID_REL_EXP_AMB_TER = ?   AND t1.ID_AMBITO_TERRITORIAL= t2.ID_AMBITO_TERRITORIAL(+)";

		List<RelExpAmbTer> relexpambterList = this.jdbcTemplate.query(query, this.rwMap,
				relexpambter.getIdRelExpAmbTer());
		return (RelExpAmbTer) DataAccessUtils.uniqueResult(relexpambterList);
	}

	/**
	 * Removes a single row in the RelExpAmbTer table.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @return
	 */
	public void remove(RelExpAmbTer relexpambter) {
		String query = "DELETE FROM REL_EXP_AMB_TER WHERE ID_REL_EXP_AMB_TER=?";
		this.jdbcTemplate.update(query, relexpambter.getIdRelExpAmbTer());
	}

	/**
	 * Finds a list of rows in the RelExpAmbTer table.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpAmbTer>
	 */
	@Transactional(readOnly = true)
	public List<RelExpAmbTer> findAll(RelExpAmbTer relexpambter, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_AMB_TER IDRELEXPAMBTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_AMBITO_TERRITORIAL AMBITOSTERRITORIALESIDAMBITOTERRITORIAL,t2.DESCRIPCION_CASTELLANO AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA AMBITOSTERRITORIALESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO AMBITOSTERRITORIALESFECHAREGISTRO,t2.USUARIO_REGISTRO AMBITOSTERRITORIALESUSUARIOREGISTRO ");
		query.append("FROM REL_EXP_AMB_TER t1 ,AMBITOS_TERRITORIALES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpambter);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_AMBITO_TERRITORIAL= t2.ID_AMBITO_TERRITORIAL(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpAmbTerDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpAmbTer>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelExpAmbTer table using like.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpAmbTer>
	 */
	@Transactional(readOnly = true)
	public List<RelExpAmbTer> findAllLike(RelExpAmbTer relexpambter, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_AMB_TER IDRELEXPAMBTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_AMBITO_TERRITORIAL AMBITOSTERRITORIALESIDAMBITOTERRITORIAL,t2.DESCRIPCION_CASTELLANO AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA AMBITOSTERRITORIALESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO AMBITOSTERRITORIALESFECHAREGISTRO,t2.USUARIO_REGISTRO AMBITOSTERRITORIALESUSUARIOREGISTRO ");
		query.append("FROM REL_EXP_AMB_TER t1 ,AMBITOS_TERRITORIALES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpambter, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_AMBITO_TERRITORIAL= t2.ID_AMBITO_TERRITORIAL(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpAmbTerDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpAmbTer>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelExpAmbTer table.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelExpAmbTer relexpambter) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_AMB_TER t1 , AMBITOS_TERRITORIALES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpambter);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_AMBITO_TERRITORIAL= t2.ID_AMBITO_TERRITORIAL(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelExpAmbTer table using like.
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelExpAmbTer relexpambter, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_AMB_TER t1 ,AMBITOS_TERRITORIALES t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpambter, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_AMBITO_TERRITORIAL= t2.ID_AMBITO_TERRITORIAL(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelExpAmbTer selected for rup_table
	 *
	 * @param relexpambter
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpAmbTer>>
	 */
	@Override
	public List<TableRowDto<RelExpAmbTer>> reorderSelection(RelExpAmbTer relexpambter,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_AMB_TER IDRELEXPAMBTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_AMBITO_TERRITORIAL AMBITOSTERRITORIALESIDAMBITOTERRITORIAL,t2.DESCRIPCION_CASTELLANO AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA AMBITOSTERRITORIALESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO AMBITOSTERRITORIALESFECHAREGISTRO,t2.USUARIO_REGISTRO AMBITOSTERRITORIALESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_AMB_TER t1 ,AMBITOS_TERRITORIALES t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpambter, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_AMBITO_TERRITORIAL= t2.ID_AMBITO_TERRITORIAL(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelExpAmbTer.class,
				filterParamList, "ID_REL_EXP_AMB_TER");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpAmbTer>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelExpAmbTer
	 * @param searchParams
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpAmbTer>>
	 */
	@Override
	public List<TableRowDto<RelExpAmbTer>> search(RelExpAmbTer filterParams, RelExpAmbTer searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_AMB_TER IDRELEXPAMBTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_AMBITO_TERRITORIAL AMBITOSTERRITORIALESIDAMBITOTERRITORIAL,t2.DESCRIPCION_CASTELLANO AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA AMBITOSTERRITORIALESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO AMBITOSTERRITORIALESFECHAREGISTRO,t2.USUARIO_REGISTRO AMBITOSTERRITORIALESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_AMB_TER t1 ,AMBITOS_TERRITORIALES t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_AMBITO_TERRITORIAL= t2.ID_AMBITO_TERRITORIAL(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelExpAmbTer.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_EXP_AMB_TER");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpAmbTer>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelexpambter
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelExpAmbTer filterrelexpambter, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_AMB_TER IDRELEXPAMBTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_AMBITO_TERRITORIAL AMBITOSTERRITORIALESIDAMBITOTERRITORIAL,t2.DESCRIPCION_CASTELLANO AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA AMBITOSTERRITORIALESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO AMBITOSTERRITORIALESFECHAREGISTRO,t2.USUARIO_REGISTRO AMBITOSTERRITORIALESUSUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_AMB_TER t1 ,AMBITOS_TERRITORIALES t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelexpambter, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelExpAmbTer.class,
				query, params, "ID_REL_EXP_AMB_TER");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelExpAmbTer table.
	 *
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelExpAmbTer>>
	 */
	@Override
	public List<JerarquiaDto<RelExpAmbTer>> findAllLikeJerarquia(RelExpAmbTer filterRelExpAmbTer,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_AMB_TER IDRELEXPAMBTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_AMBITO_TERRITORIAL AMBITOSTERRITORIALESIDAMBITOTERRITORIAL,t2.DESCRIPCION_CASTELLANO AMBITOSTERRITORIALESDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA AMBITOSTERRITORIALESDESCRIPCIONEUSKERA,t2.FECHA_REGISTRO AMBITOSTERRITORIALESFECHAREGISTRO,t2.USUARIO_REGISTRO AMBITOSTERRITORIALESUSUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_AMB_TER t1
		// ,AMBITOS_TERRITORIALES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_AMB_TER");
		from.add("AMBITOS_TERRITORIALES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpAmbTer, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_EXP_AMB_TER", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelExpAmbTerDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelExpAmbTer filterRelExpAmbTer, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_AMB_TER t1
		// ,AMBITOS_TERRITORIALES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_AMB_TER");
		from.add("AMBITOS_TERRITORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpAmbTer, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_EXP_AMB_TER",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpAmbTer>>
	 */
	@Override
	public List<TableRowDto<RelExpAmbTer>> findAllChild(RelExpAmbTer filterRelExpAmbTer,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_AMB_TER t1
		// ,AMBITOS_TERRITORIALES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_AMB_TER");
		from.add("AMBITOS_TERRITORIALES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpAmbTer, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_EXP_AMB_TER",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelExpAmbTer>(this.rwMapPK, "ID_REL_EXP_AMB_TER"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpAmbTer entity
	 *
	 * @param relexpambter
	 *            RelExpAmbTer Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelExpAmbTer relexpambter) {

		StringBuilder where = new StringBuilder(RelExpAmbTerDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpambter != null && relexpambter.getIdRelExpAmbTer() != null) {
			where.append(" AND t1.ID_REL_EXP_AMB_TER = ?");
			params.add(relexpambter.getIdRelExpAmbTer());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getIdAmbitoTerritorial() != null) {
			where.append(" AND t2.ID_AMBITO_TERRITORIAL = ?");
			params.add(relexpambter.getAmbitosTerritoriales().getIdAmbitoTerritorial());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(relexpambter.getAmbitosTerritoriales().getDescripcionCastellano());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(relexpambter.getAmbitosTerritoriales().getDescripcionEuskera());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpambter.getAmbitosTerritoriales().getFechaRegistro());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(relexpambter.getAmbitosTerritoriales().getUsuarioRegistro());
		}
		if (relexpambter != null && relexpambter.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpambter.getIdExpediente());
		}
		if (relexpambter != null && relexpambter.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpambter.getFechaRegistro());
		}
		if (relexpambter != null && relexpambter.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relexpambter.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpAmbTer entity
	 *
	 * @param relexpambter
	 *            RelExpAmbTer Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelExpAmbTer relexpambter, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelExpAmbTerDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpambter != null && relexpambter.getIdRelExpAmbTer() != null) {
			where.append(" AND t1.ID_REL_EXP_AMB_TER = ?");
			params.add(relexpambter.getIdRelExpAmbTer());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getIdAmbitoTerritorial() != null) {
			where.append(" AND t2.ID_AMBITO_TERRITORIAL = ?");
			params.add(relexpambter.getAmbitosTerritoriales().getIdAmbitoTerritorial());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpambter.getAmbitosTerritoriales().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + relexpambter.getAmbitosTerritoriales().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpambter.getAmbitosTerritoriales().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + relexpambter.getAmbitosTerritoriales().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpambter.getAmbitosTerritoriales().getFechaRegistro());
		}
		if (relexpambter != null && relexpambter.getAmbitosTerritoriales() != null
				&& relexpambter.getAmbitosTerritoriales().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpambter.getAmbitosTerritoriales().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpambter.getAmbitosTerritoriales().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relexpambter != null && relexpambter.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpambter.getIdExpediente());
		}
		if (relexpambter != null && relexpambter.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpambter.getFechaRegistro());
		}
		if (relexpambter != null && relexpambter.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpambter.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpambter.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
