package com.ejie.ab60.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.RelExpIns;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpInsDaoImpl  
 * 
 * 
 *  
 */

@Repository
@Transactional
public class RelExpInsDaoImpl implements RelExpInsDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELEXPINS", "IDEXPEDIENTE", "IDINSPECCION",
			"TIPOINSPECCION", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * Finds a single row in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @return RelExpIns
	 */
	@Transactional(readOnly = true)
	public RelExpIns findTipoInspeccion(RelExpIns relexpins) {
		String query = "SELECT t1.ID_REL_EXP_INS IDRELEXPINS, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_INSPECCION IDINSPECCION, t1.TIPO_INSPECCION TIPOINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_EXP_INS t1  WHERE t1.ID_EXPEDIENTE = ?  AND t1.TIPO_INSPECCION = ?";

		List<RelExpIns> relexpinsList = this.jdbcTemplate.query(query, this.rwMap, relexpins.getIdExpediente(),
				relexpins.getTipoInspeccion());
		return (RelExpIns) DataAccessUtils.uniqueResult(relexpinsList);
	}

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelExpIns> rwMap = new RowMapper<RelExpIns>() {
		public RelExpIns mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpIns(resultSet.getInt("IDRELEXPINS"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getInt("IDINSPECCION"), resultSet.getInt("TIPOINSPECCION"),
					resultSet.getString("IDENTIFICADORINSPECCION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<RelExpIns> rwMapPK = new RowMapper<RelExpIns>() {
		public RelExpIns mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpIns(resultSet.getInt("IDRELEXPINS"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelExpIns>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelExpIns>>() {
		public JerarquiaDto<RelExpIns> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpIns relexpins = new RelExpIns(resultSet.getInt("IDRELEXPINS"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getInt("IDINSPECCION"), resultSet.getInt("TIPOINSPECCION"),
					resultSet.getString("IDENTIFICADORINSPECCION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<RelExpIns> jerarquia = new JerarquiaDto<RelExpIns>();
			jerarquia.setModel(relexpins);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @return RelExpIns
	 */
	public RelExpIns add(RelExpIns relexpins) {
		String query = "INSERT INTO REL_EXP_INS (ID_REL_EXP_INS, ID_EXPEDIENTE, ID_INSPECCION, TIPO_INSPECCION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, relexpins.getIdRelExpIns(), relexpins.getIdExpediente(),
				relexpins.getIdInspeccion(), relexpins.getTipoInspeccion(), relexpins.getFechaRegistro(),
				relexpins.getUsuarioRegistro());
		return relexpins;
	}

	/**
	 * Updates a single row in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @return RelExpIns
	 */
	public RelExpIns update(RelExpIns relexpins) {
		String query = "UPDATE REL_EXP_INS SET ID_EXPEDIENTE=?, ID_INSPECCION=?, TIPO_INSPECCION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_REL_EXP_INS=?";
		this.jdbcTemplate.update(query, relexpins.getIdExpediente(), relexpins.getIdInspeccion(),
				relexpins.getTipoInspeccion(), relexpins.getFechaRegistro(), relexpins.getUsuarioRegistro(),
				relexpins.getIdRelExpIns());
		return relexpins;
	}

	/**
	 * Finds a single row in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @return RelExpIns
	 */
	@Transactional(readOnly = true)
	public RelExpIns find(RelExpIns relexpins) {
		String query = "SELECT t1.ID_REL_EXP_INS IDRELEXPINS, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_INSPECCION IDINSPECCION, t1.TIPO_INSPECCION TIPOINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_EXP_INS t1 WHERE t1.ID_REL_EXP_INS = ? ";

		List<RelExpIns> relexpinsList = this.jdbcTemplate.query(query, this.rwMap, relexpins.getIdRelExpIns());
		return (RelExpIns) DataAccessUtils.uniqueResult(relexpinsList);
	}

	/**
	 * Finds a single row in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @return RelExpIns
	 */
	@Transactional(readOnly = true)
	public RelExpIns findByIdExpediente(RelExpIns relexpins) {
		String query = "SELECT t1.ID_REL_EXP_INS IDRELEXPINS, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_INSPECCION IDINSPECCION, t1.TIPO_INSPECCION TIPOINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_EXP_INS t1 WHERE t1.ID_EXPEDIENTE = ? AND t1.TIPO_INSPECCION = ? ";

		List<RelExpIns> relexpinsList = this.jdbcTemplate.query(query, this.rwMap, relexpins.getIdExpediente(),
				relexpins.getTipoInspeccion());
		return (RelExpIns) DataAccessUtils.uniqueResult(relexpinsList);
	}

	@Override
	public List<RelExpIns> findIdentificadorInspeccionByIdExpediente(RelExpIns relExpIns) {
		String query = "SELECT t1.ID_REL_EXP_INS IDRELEXPINS, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_INSPECCION IDINSPECCION, t1.TIPO_INSPECCION TIPOINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_EXP_INS t1, EXPEDIENTES t2 WHERE t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t1.ID_EXPEDIENTE = ?";

		return this.jdbcTemplate.query(query, this.rwMap, relExpIns.getIdExpediente());
	}

	@Override
	public RelExpIns findByIdentificadorInspeccion(RelExpIns relExpIns) {
		String query = "SELECT t1.ID_REL_EXP_INS IDRELEXPINS, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_INSPECCION IDINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.TIPO_INSPECCION TIPOINSPECCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_EXP_INS t1 WHERE t1.IDENTIFICADOR_INSPECCION = ?";

		List<RelExpIns> relexpinsList = this.jdbcTemplate.query(query, this.rwMap,
				relExpIns.getIdentificadorInspeccion());
		return (RelExpIns) DataAccessUtils.uniqueResult(relexpinsList);
	}

	@Override
	public RelExpIns findByIdInspeccion(RelExpIns relExpIns) {
		String query = "SELECT t1.ID_REL_EXP_INS IDRELEXPINS, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_INSPECCION IDINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.TIPO_INSPECCION TIPOINSPECCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_EXP_INS t1 WHERE t1.ID_INSPECCION = ?";

		List<RelExpIns> relexpinsList = this.jdbcTemplate.query(query, this.rwMap, relExpIns.getIdInspeccion());
		return (RelExpIns) DataAccessUtils.uniqueResult(relexpinsList);
	}

	/**
	 * Removes a single row in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @return
	 */
	public void remove(RelExpIns relexpins) {
		String query = "DELETE FROM REL_EXP_INS WHERE ID_REL_EXP_INS=?";
		this.jdbcTemplate.update(query, relexpins.getIdRelExpIns());
	}

	/**
	 * Finds a list of rows in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpIns>
	 */
	@Transactional(readOnly = true)
	public List<RelExpIns> findAll(RelExpIns relexpins, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_INS IDRELEXPINS,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_INSPECCION IDINSPECCION,t1.TIPO_INSPECCION TIPOINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_EXP_INS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpins);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpInsDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpIns>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelExpIns table using like.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpIns>
	 */
	@Transactional(readOnly = true)
	public List<RelExpIns> findAllLike(RelExpIns relexpins, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_INS IDRELEXPINS,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_INSPECCION IDINSPECCION,t1.TIPO_INSPECCION TIPOINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_EXP_INS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpins, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpInsDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpIns>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelExpIns table.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelExpIns relexpins) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_INS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpins);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelExpIns table using like.
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelExpIns relexpins, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_INS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpins, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelExpIns selected for rup_table
	 *
	 * @param relexpins
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpIns>>
	 */
	@Override
	public List<TableRowDto<RelExpIns>> reorderSelection(RelExpIns relexpins, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_INS IDRELEXPINS,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_INSPECCION IDINSPECCION,t1.TIPO_INSPECCION TIPOINSPECCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_INS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpins, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelExpIns.class,
				filterParamList, "ID_REL_EXP_INS");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpIns>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelExpIns
	 * @param searchParams
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpIns>>
	 */
	@Override
	public List<TableRowDto<RelExpIns>> search(RelExpIns filterParams, RelExpIns searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_INS IDRELEXPINS,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_INSPECCION IDINSPECCION,t1.TIPO_INSPECCION TIPOINSPECCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_INS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelExpIns.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_EXP_INS");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpIns>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelexpins
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelExpIns filterrelexpins, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_INS IDRELEXPINS,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_INSPECCION IDINSPECCION,t1.TIPO_INSPECCION TIPOINSPECCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_INS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelexpins, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelExpIns.class,
				query, params, "ID_REL_EXP_INS");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelExpIns table.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelExpIns>>
	 */
	@Override
	public List<JerarquiaDto<RelExpIns>> findAllLikeJerarquia(RelExpIns filterRelExpIns,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_INS IDRELEXPINS,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_INSPECCION IDINSPECCION,t1.TIPO_INSPECCION TIPOINSPECCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_INS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_INS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append(" AND t1.EJIE = ? "); businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpIns, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_EXP_INS", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelExpInsDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelExpIns filterRelExpIns, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_INS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_INS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpIns, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_EXP_INS",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpIns>>
	 */
	@Override
	public List<TableRowDto<RelExpIns>> findAllChild(RelExpIns filterRelExpIns, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_INS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_INS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append(" AND t1.EJIE = ? "); businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpIns, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_EXP_INS",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelExpIns>(this.rwMapPK, "ID_REL_EXP_INS"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpIns entity
	 *
	 * @param relexpins
	 *            RelExpIns Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelExpIns relexpins) {

		StringBuilder where = new StringBuilder(RelExpInsDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpins != null && relexpins.getIdRelExpIns() != null) {
			where.append(" AND t1.ID_REL_EXP_INS = ?");
			params.add(relexpins.getIdRelExpIns());
		}
		if (relexpins != null && relexpins.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpins.getIdExpediente());
		}
		if (relexpins != null && relexpins.getIdInspeccion() != null) {
			where.append(" AND t1.ID_INSPECCION = ?");
			params.add(relexpins.getIdInspeccion());
		}
		if (relexpins != null && relexpins.getTipoInspeccion() != null) {
			where.append(" AND t1.TIPO_INSPECCION = ?");
			params.add(relexpins.getTipoInspeccion());
		}
		if (relexpins != null && relexpins.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpins.getFechaRegistro());
		}
		if (relexpins != null && relexpins.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relexpins.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpIns entity
	 *
	 * @param relexpins
	 *            RelExpIns Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelExpIns relexpins, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelExpInsDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpins != null && relexpins.getIdRelExpIns() != null) {
			where.append(" AND t1.ID_REL_EXP_INS = ?");
			params.add(relexpins.getIdRelExpIns());
		}
		if (relexpins != null && relexpins.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpins.getIdExpediente());
		}
		if (relexpins != null && relexpins.getIdInspeccion() != null) {
			where.append(" AND t1.ID_INSPECCION = ?");
			params.add(relexpins.getIdInspeccion());
		}
		if (relexpins != null && relexpins.getTipoInspeccion() != null) {
			where.append(" AND t1.TIPO_INSPECCION = ?");
			params.add(relexpins.getTipoInspeccion());
		}
		if (relexpins != null && relexpins.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpins.getFechaRegistro());
		}
		if (relexpins != null && relexpins.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE '\\'");
			if (startsWith) {
				params.add(relexpins.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpins.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public Integer obtenerID(String identificadorInspeccion) {
		String query = "SELECT t1.ID_INSPECCION FROM REL_EXP_INS t1  WHERE t1.IDENTIFICADOR_INSPECCION = ?";

		Integer idInspeccion = this.jdbcTemplate.queryForInt(query, identificadorInspeccion);
		return idInspeccion;
	}
}
