package com.ejie.ab60.dao;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.VExpInfContable;

/**
 * VExpInfContableDaoImpl  
 *  
 */

@Repository
@Transactional
public class VExpInfContableDaoImpl implements VExpInfContableDao {


    public static final String[] ORDER_BY_WHITE_LIST = new String[] {"IDPROCEDIMIENTO", "IDEXPEDIENTE", "EXPEDIENTE", "CONCEPTORESUMIDO", "SUBVENCIONRESUELTA", "APLICACIONPRESUPUESTARIA", "EJERCICIOAPLPRE", "AGRUPACION", "GASTOINGRESO", "SECCION", "SERVICIO", "CENTRO", "TERRITORIO", "CAC", "SC", "PROGRAMA", "PARTIDA", "LETRACONTROL", "EJERCICIOREFINT", "ANYOORIGEN", "NUMERO", "DISPONIBLE", "TERCEROMOSTRAR", "TERCERO", "FECHADOCUMENTOD", "REFINTD", "REFINTO", "TIPODOCUMENTO"};

    private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<VExpInfContable> rwMap = new RowMapper<VExpInfContable>() {
		public VExpInfContable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
           return new VExpInfContable(
               resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getInt("IDEXPEDIENTE"), resultSet.getString("EXPEDIENTE"), resultSet.getString("CONCEPTORESUMIDO"), resultSet.getBigDecimal("SUBVENCIONRESUELTA"), resultSet.getString("APLICACIONPRESUPUESTARIA"), resultSet.getLong("EJERCICIOAPLPRE"), resultSet.getInt("AGRUPACION"), resultSet.getInt("GASTOINGRESO"), resultSet.getLong("SECCION"), resultSet.getLong("SERVICIO"), resultSet.getLong("CENTRO"), resultSet.getString("TERRITORIO"), resultSet.getLong("CAC"), resultSet.getLong("SC"), resultSet.getInt("PROGRAMA"), resultSet.getLong("PARTIDA"), resultSet.getString("LETRACONTROL"), resultSet.getLong("EJERCICIOREFINT"), resultSet.getLong("ANYOORIGEN"), resultSet.getInt("NUMERO"), resultSet.getInt("DISPONIBLE"), resultSet.getString("TERCEROMOSTRAR"), resultSet.getString("TERCERO"), resultSet.getDate("FECHADOCUMENTOD"), resultSet.getString("REFINTD"), resultSet.getString("REFINTO"), resultSet.getString("TIPODOCUMENTO")
           ); } } ;

	private RowMapper<VExpInfContable> rwMapPK = new RowMapper<VExpInfContable>() {
		public VExpInfContable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new VExpInfContable(
				resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getInt("IDEXPEDIENTE"), resultSet.getString("EXPEDIENTE"), resultSet.getString("CONCEPTORESUMIDO"), resultSet.getBigDecimal("SUBVENCIONRESUELTA"), resultSet.getString("APLICACIONPRESUPUESTARIA"), resultSet.getLong("EJERCICIOAPLPRE"), resultSet.getInt("AGRUPACION"), resultSet.getInt("GASTOINGRESO"), resultSet.getLong("SECCION"), resultSet.getLong("SERVICIO"), resultSet.getLong("CENTRO"), resultSet.getString("TERRITORIO"), resultSet.getLong("CAC"), resultSet.getLong("SC"), resultSet.getInt("PROGRAMA"), resultSet.getLong("PARTIDA"), resultSet.getString("LETRACONTROL"), resultSet.getLong("EJERCICIOREFINT"), resultSet.getLong("ANYOORIGEN"), resultSet.getInt("NUMERO"), resultSet.getInt("DISPONIBLE"), resultSet.getString("TERCEROMOSTRAR"), resultSet.getString("TERCERO"), resultSet.getDate("FECHADOCUMENTOD"), resultSet.getString("REFINTD"), resultSet.getString("REFINTO"), resultSet.getString("TIPODOCUMENTO")
           ); } } ;

	/**
     * Rowmapper para Jerarquía
     *
     * @param dataSource DataSource
     * @return
     */
	private RowMapper<JerarquiaDto< VExpInfContable>> rwMapJerarquia = new RowMapper<JerarquiaDto<VExpInfContable>>() {
		public JerarquiaDto<VExpInfContable> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			VExpInfContable vexpinfcontable = new VExpInfContable(resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getInt("IDEXPEDIENTE"), resultSet.getString("EXPEDIENTE"), resultSet.getString("CONCEPTORESUMIDO"), resultSet.getBigDecimal("SUBVENCIONRESUELTA"), resultSet.getString("APLICACIONPRESUPUESTARIA"), resultSet.getLong("EJERCICIOAPLPRE"), resultSet.getInt("AGRUPACION"), resultSet.getInt("GASTOINGRESO"), resultSet.getLong("SECCION"), resultSet.getLong("SERVICIO"), resultSet.getLong("CENTRO"), resultSet.getString("TERRITORIO"), resultSet.getLong("CAC"), resultSet.getLong("SC"), resultSet.getInt("PROGRAMA"), resultSet.getLong("PARTIDA"), resultSet.getString("LETRACONTROL"), resultSet.getLong("EJERCICIOREFINT"), resultSet.getLong("ANYOORIGEN"), resultSet.getInt("NUMERO"), resultSet.getInt("DISPONIBLE"), resultSet.getString("TERCEROMOSTRAR"), resultSet.getString("TERCERO"), resultSet.getDate("FECHADOCUMENTOD"), resultSet.getString("REFINTD"), resultSet.getString("REFINTO"), resultSet.getString("TIPODOCUMENTO"));

			JerarquiaDto<VExpInfContable> jerarquia = new JerarquiaDto<VExpInfContable>();
			jerarquia.setModel(vexpinfcontable);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};


	/**
     * Method use to set the datasource.
     *
     * @param dataSource DataSource
     * @return
     */
    @Resource
    public void setDataSource(DataSource dataSource) {
    	this.jdbcTemplate = new JdbcTemplate(dataSource);
    }

	/*
	 * OPERACIONES CRUD
	 */

    /**
     * Inserts a single row in the VExpInfContable table.
     *
     * @param vexpinfcontable VExpInfContable
     * @return VExpInfContable
     */
	public VExpInfContable add(VExpInfContable vexpinfcontable) {
    	String query = "INSERT INTO V_EXP_INF_CONTABLE (ID_PROCEDIMIENTO, ID_EXPEDIENTE, EXPEDIENTE, CONCEPTO_RESUMIDO, SUBVENCION_RESUELTA, APLICACION_PRESUPUESTARIA, EJERCICIO_APL_PRE, AGRUPACION, GASTO_INGRESO, SECCION, SERVICIO, CENTRO, TERRITORIO, CAC, SC, PROGRAMA, PARTIDA, LETRA_CONTROL, EJERCICIO_REF_INT, ANYO_ORIGEN, NUMERO, DISPONIBLE, TERCERO_MOSTRAR, TERCERO, FECHA_DOCUMENTO_D, REF_INT_D, REF_INT_O, TIPO_DOCUMENTO) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, vexpinfcontable.getIdProcedimiento(), vexpinfcontable.getIdExpediente(), vexpinfcontable.getExpediente(), vexpinfcontable.getConceptoResumido(), vexpinfcontable.getSubvencionResuelta(), vexpinfcontable.getAplicacionPresupuestaria(), vexpinfcontable.getEjercicioAplPre(), vexpinfcontable.getAgrupacion(), vexpinfcontable.getGastoIngreso(), vexpinfcontable.getSeccion(), vexpinfcontable.getServicio(), vexpinfcontable.getCentro(), vexpinfcontable.getTerritorio(), vexpinfcontable.getCac(), vexpinfcontable.getSc(), vexpinfcontable.getPrograma(), vexpinfcontable.getPartida(), vexpinfcontable.getLetraControl(), vexpinfcontable.getEjercicioRefInt(), vexpinfcontable.getAnyoOrigen(), vexpinfcontable.getNumero(), vexpinfcontable.getDisponible(), vexpinfcontable.getTerceroMostrar(), vexpinfcontable.getTercero(), vexpinfcontable.getFechaDocumentoD(), vexpinfcontable.getRefIntD(), vexpinfcontable.getRefIntO(), vexpinfcontable.getTipoDocumento());
		return vexpinfcontable;
	}

    /**
     * Updates a single row in the VExpInfContable table.
     *
     * @param vexpinfcontable VExpInfContable
     * @return VExpInfContable
     */
    public VExpInfContable update(VExpInfContable vexpinfcontable) {
		String query = "UPDATE V_EXP_INF_CONTABLE SET  WHERE ID_PROCEDIMIENTO=? AND ID_EXPEDIENTE=? AND EXPEDIENTE=? AND CONCEPTO_RESUMIDO=? AND SUBVENCION_RESUELTA=? AND APLICACION_PRESUPUESTARIA=? AND EJERCICIO_APL_PRE=? AND AGRUPACION=? AND GASTO_INGRESO=? AND SECCION=? AND SERVICIO=? AND CENTRO=? AND TERRITORIO=? AND CAC=? AND SC=? AND PROGRAMA=? AND PARTIDA=? AND LETRA_CONTROL=? AND EJERCICIO_REF_INT=? AND ANYO_ORIGEN=? AND NUMERO=? AND DISPONIBLE=? AND TERCERO_MOSTRAR=? AND TERCERO=? AND FECHA_DOCUMENTO_D=? AND REF_INT_D=? AND REF_INT_O=? AND TIPO_DOCUMENTO=?";
		this.jdbcTemplate.update(query, vexpinfcontable.getIdProcedimiento(), vexpinfcontable.getIdExpediente(), vexpinfcontable.getExpediente(), vexpinfcontable.getConceptoResumido(), vexpinfcontable.getSubvencionResuelta(), vexpinfcontable.getAplicacionPresupuestaria(), vexpinfcontable.getEjercicioAplPre(), vexpinfcontable.getAgrupacion(), vexpinfcontable.getGastoIngreso(), vexpinfcontable.getSeccion(), vexpinfcontable.getServicio(), vexpinfcontable.getCentro(), vexpinfcontable.getTerritorio(), vexpinfcontable.getCac(), vexpinfcontable.getSc(), vexpinfcontable.getPrograma(), vexpinfcontable.getPartida(), vexpinfcontable.getLetraControl(), vexpinfcontable.getEjercicioRefInt(), vexpinfcontable.getAnyoOrigen(), vexpinfcontable.getNumero(), vexpinfcontable.getDisponible(), vexpinfcontable.getTerceroMostrar(), vexpinfcontable.getTercero(), vexpinfcontable.getFechaDocumentoD(), vexpinfcontable.getRefIntD(), vexpinfcontable.getRefIntO(), vexpinfcontable.getTipoDocumento());
		return vexpinfcontable;
	}

    /**
     * Finds a single row in the VExpInfContable table.
     *
     * @param vexpinfcontable VExpInfContable
     * @return VExpInfContable
     */
    @Transactional (readOnly = true)
    public VExpInfContable find(VExpInfContable vexpinfcontable) {
		String query = "SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.EXPEDIENTE EXPEDIENTE, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA, t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE, t1.AGRUPACION AGRUPACION, t1.GASTO_INGRESO GASTOINGRESO, t1.SECCION SECCION, t1.SERVICIO SERVICIO, t1.CENTRO CENTRO, t1.TERRITORIO TERRITORIO, t1.CAC CAC, t1.SC SC, t1.PROGRAMA PROGRAMA, t1.PARTIDA PARTIDA, t1.LETRA_CONTROL LETRACONTROL, t1.EJERCICIO_REF_INT EJERCICIOREFINT, t1.ANYO_ORIGEN ANYOORIGEN, t1.NUMERO NUMERO, t1.DISPONIBLE DISPONIBLE, t1.TERCERO_MOSTRAR TERCEROMOSTRAR, t1.TERCERO TERCERO, t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD, t1.REF_INT_D REFINTD, t1.REF_INT_O REFINTO, t1.TIPO_DOCUMENTO TIPODOCUMENTO FROM V_EXP_INF_CONTABLE t1  WHERE t1.ID_PROCEDIMIENTO = ?   AND t1.ID_EXPEDIENTE = ?   AND t1.EXPEDIENTE = ?   AND t1.CONCEPTO_RESUMIDO = ?   AND t1.SUBVENCION_RESUELTA = ?   AND t1.APLICACION_PRESUPUESTARIA = ?   AND t1.EJERCICIO_APL_PRE = ?   AND t1.AGRUPACION = ?   AND t1.GASTO_INGRESO = ?   AND t1.SECCION = ?   AND t1.SERVICIO = ?   AND t1.CENTRO = ?   AND t1.TERRITORIO = ?   AND t1.CAC = ?   AND t1.SC = ?   AND t1.PROGRAMA = ?   AND t1.PARTIDA = ?   AND t1.LETRA_CONTROL = ?   AND t1.EJERCICIO_REF_INT = ?   AND t1.ANYO_ORIGEN = ?   AND t1.NUMERO = ?   AND t1.DISPONIBLE = ?   AND t1.TERCERO_MOSTRAR = ?   AND t1.TERCERO = ?   AND t1.FECHA_DOCUMENTO_D = ?   AND t1.REF_INT_D = ?   AND t1.REF_INT_O = ?   AND t1.TIPO_DOCUMENTO = ?  ";

		List<VExpInfContable> vexpinfcontableList = this.jdbcTemplate.query(query, this.rwMap, vexpinfcontable.getIdProcedimiento() , vexpinfcontable.getIdExpediente() , vexpinfcontable.getExpediente() , vexpinfcontable.getConceptoResumido() , vexpinfcontable.getSubvencionResuelta() , vexpinfcontable.getAplicacionPresupuestaria() , vexpinfcontable.getEjercicioAplPre() , vexpinfcontable.getAgrupacion() , vexpinfcontable.getGastoIngreso() , vexpinfcontable.getSeccion() , vexpinfcontable.getServicio() , vexpinfcontable.getCentro() , vexpinfcontable.getTerritorio() , vexpinfcontable.getCac() , vexpinfcontable.getSc() , vexpinfcontable.getPrograma() , vexpinfcontable.getPartida() , vexpinfcontable.getLetraControl() , vexpinfcontable.getEjercicioRefInt() , vexpinfcontable.getAnyoOrigen() , vexpinfcontable.getNumero() , vexpinfcontable.getDisponible() , vexpinfcontable.getTerceroMostrar() , vexpinfcontable.getTercero() , vexpinfcontable.getFechaDocumentoD() , vexpinfcontable.getRefIntD() , vexpinfcontable.getRefIntO() , vexpinfcontable.getTipoDocumento());
		return (VExpInfContable) DataAccessUtils.uniqueResult(vexpinfcontableList);
    }

    /**
     * Removes a single row in the VExpInfContable table.
     *
     * @param vexpinfcontable VExpInfContable
     * @return
     */
    public void remove(VExpInfContable vexpinfcontable) {
		String query = "DELETE FROM V_EXP_INF_CONTABLE WHERE ID_PROCEDIMIENTO=? AND ID_EXPEDIENTE=? AND EXPEDIENTE=? AND CONCEPTO_RESUMIDO=? AND SUBVENCION_RESUELTA=? AND APLICACION_PRESUPUESTARIA=? AND EJERCICIO_APL_PRE=? AND AGRUPACION=? AND GASTO_INGRESO=? AND SECCION=? AND SERVICIO=? AND CENTRO=? AND TERRITORIO=? AND CAC=? AND SC=? AND PROGRAMA=? AND PARTIDA=? AND LETRA_CONTROL=? AND EJERCICIO_REF_INT=? AND ANYO_ORIGEN=? AND NUMERO=? AND DISPONIBLE=? AND TERCERO_MOSTRAR=? AND TERCERO=? AND FECHA_DOCUMENTO_D=? AND REF_INT_D=? AND REF_INT_O=? AND TIPO_DOCUMENTO=?";
		this.jdbcTemplate.update(query, vexpinfcontable.getIdProcedimiento() , vexpinfcontable.getIdExpediente() , vexpinfcontable.getExpediente() , vexpinfcontable.getConceptoResumido() , vexpinfcontable.getSubvencionResuelta() , vexpinfcontable.getAplicacionPresupuestaria() , vexpinfcontable.getEjercicioAplPre() , vexpinfcontable.getAgrupacion() , vexpinfcontable.getGastoIngreso() , vexpinfcontable.getSeccion() , vexpinfcontable.getServicio() , vexpinfcontable.getCentro() , vexpinfcontable.getTerritorio() , vexpinfcontable.getCac() , vexpinfcontable.getSc() , vexpinfcontable.getPrograma() , vexpinfcontable.getPartida() , vexpinfcontable.getLetraControl() , vexpinfcontable.getEjercicioRefInt() , vexpinfcontable.getAnyoOrigen() , vexpinfcontable.getNumero() , vexpinfcontable.getDisponible() , vexpinfcontable.getTerceroMostrar() , vexpinfcontable.getTercero() , vexpinfcontable.getFechaDocumentoD() , vexpinfcontable.getRefIntD() , vexpinfcontable.getRefIntO() , vexpinfcontable.getTipoDocumento());
    }

   /**
    * Finds a list of rows in the VExpInfContable table.
    *
    * @param vexpinfcontable VExpInfContable
    * @param jqGridRequestDto JQGridRequestDto
    * @return List<VExpInfContable>
    */
	@Transactional (readOnly = true)
    public List<VExpInfContable> findAll(VExpInfContable vexpinfcontable, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder("SELECT  t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.EXPEDIENTE EXPEDIENTE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA,t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.TERCERO_MOSTRAR TERCEROMOSTRAR,t1.TERCERO TERCERO,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.REF_INT_O REFINTO,t1.TIPO_DOCUMENTO TIPODOCUMENTO ");
		query.append("FROM V_EXP_INF_CONTABLE t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(vexpinfcontable); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, VExpInfContableDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<VExpInfContable>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the VExpInfContable table using like.
     *
     * @param vexpinfcontable VExpInfContable
     * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean
     * @return List<VExpInfContable>
     */
	@Transactional (readOnly = true)
    public List<VExpInfContable> findAllLike(VExpInfContable vexpinfcontable, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT  t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.EXPEDIENTE EXPEDIENTE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA,t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.TERCERO_MOSTRAR TERCEROMOSTRAR,t1.TERCERO TERCERO,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.REF_INT_O REFINTO,t1.TIPO_DOCUMENTO TIPODOCUMENTO ");
        query.append("FROM V_EXP_INF_CONTABLE t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(vexpinfcontable,startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, VExpInfContableDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<VExpInfContable>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

    /**
     * Counts rows in the VExpInfContable table.
     *
     * @param vexpinfcontable VExpInfContable
     * @return Long
     */
    @Transactional (readOnly = true)
    public Long findAllCount(VExpInfContable vexpinfcontable) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM V_EXP_INF_CONTABLE t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(vexpinfcontable); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the VExpInfContable table using like.
     *
     * @param vexpinfcontable VExpInfContable
     * @param startsWith Boolean
     * @return Long
     */
	@Transactional (readOnly = true)
    public Long findAllLikeCount(VExpInfContable vexpinfcontable, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM V_EXP_INF_CONTABLE t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(vexpinfcontable,startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of VExpInfContable selected for rup_table
     *
     * @param vexpinfcontable VExpInfContable
     * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean
     * @return List<TableRowDto<VExpInfContable>>
     */
	@Override
	public List<TableRowDto<VExpInfContable>> reorderSelection(VExpInfContable vexpinfcontable, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.EXPEDIENTE EXPEDIENTE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA,t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.TERCERO_MOSTRAR TERCEROMOSTRAR,t1.TERCERO TERCERO,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.REF_INT_O REFINTO,t1.TIPO_DOCUMENTO TIPODOCUMENTO ");
		// FROM
        query.append("FROM V_EXP_INF_CONTABLE t1 ");
		// FILTRADO
		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(vexpinfcontable,startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL =  JQGridManager.getReorderQuery(query, jqGridRequestDto, VExpInfContable.class, filterParamList, "ID_PROCEDIMIENTO,ID_EXPEDIENTE,EXPEDIENTE,CONCEPTO_RESUMIDO,SUBVENCION_RESUELTA,APLICACION_PRESUPUESTARIA,EJERCICIO_APL_PRE,AGRUPACION,GASTO_INGRESO,SECCION,SERVICIO,CENTRO,TERRITORIO,CAC,SC,PROGRAMA,PARTIDA,LETRA_CONTROL,EJERCICIO_REF_INT,ANYO_ORIGEN,NUMERO,DISPONIBLE,TERCERO_MOSTRAR,TERCERO,FECHA_DOCUMENTO_D,REF_INT_D,REF_INT_O,TIPO_DOCUMENTO" );

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(), new RowNumResultSetExtractor<VExpInfContable>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
     *
     * @param filterParams VExpInfContable
     * @param searchParams VExpInfContable
     * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean
     * @return List<TableRowDto<VExpInfContable>>
     */
	@Override
	public List<TableRowDto<VExpInfContable>> search(VExpInfContable filterParams, VExpInfContable searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.EXPEDIENTE EXPEDIENTE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA,t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.TERCERO_MOSTRAR TERCEROMOSTRAR,t1.TERCERO TERCERO,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.REF_INT_O REFINTO,t1.TIPO_DOCUMENTO TIPODOCUMENTO ");
		// FROM
        query.append("FROM V_EXP_INF_CONTABLE t1 ");
        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, VExpInfContable.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_PROCEDIMIENTO,ID_EXPEDIENTE,EXPEDIENTE,CONCEPTO_RESUMIDO,SUBVENCION_RESUELTA,APLICACION_PRESUPUESTARIA,EJERCICIO_APL_PRE,AGRUPACION,GASTO_INGRESO,SECCION,SERVICIO,CENTRO,TERRITORIO,CAC,SC,PROGRAMA,PARTIDA,LETRA_CONTROL,EJERCICIO_REF_INT,ANYO_ORIGEN,NUMERO,DISPONIBLE,TERCERO_MOSTRAR,TERCERO,FECHA_DOCUMENTO_D,REF_INT_D,REF_INT_O,TIPO_DOCUMENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(), new RowNumResultSetExtractor<VExpInfContable>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
     *
     * @param filtervexpinfcontable VExpInfContable
     * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean
     */
	@Override
	public void removeMultiple(VExpInfContable filtervexpinfcontable, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.EXPEDIENTE EXPEDIENTE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA,t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.TERCERO_MOSTRAR TERCEROMOSTRAR,t1.TERCERO TERCERO,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.REF_INT_O REFINTO,t1.TIPO_DOCUMENTO TIPODOCUMENTO ");
		// FROM
        query.append("FROM V_EXP_INF_CONTABLE t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtervexpinfcontable, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, VExpInfContable.class, query, params, "ID_PROCEDIMIENTO,ID_EXPEDIENTE,EXPEDIENTE,CONCEPTO_RESUMIDO,SUBVENCION_RESUELTA,APLICACION_PRESUPUESTARIA,EJERCICIO_APL_PRE,AGRUPACION,GASTO_INGRESO,SECCION,SERVICIO,CENTRO,TERRITORIO,CAC,SC,PROGRAMA,PARTIDA,LETRA_CONTROL,EJERCICIO_REF_INT,ANYO_ORIGEN,NUMERO,DISPONIBLE,TERCERO_MOSTRAR,TERCERO,FECHA_DOCUMENTO_D,REF_INT_D,REF_INT_O,TIPO_DOCUMENTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical VExpInfContable table.
     *
     * @param filterVExpInfContable VExpInfContable
     * @param jqGridRequestDto JQGridRequestDto
     * @return List<JerarquiaDto<VExpInfContable>>
     */
	@Override
	public List<JerarquiaDto<VExpInfContable>> findAllLikeJerarquia(VExpInfContable filterVExpInfContable, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.EXPEDIENTE EXPEDIENTE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA,t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.TERCERO_MOSTRAR TERCEROMOSTRAR,t1.TERCERO TERCERO,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.REF_INT_O REFINTO,t1.TIPO_DOCUMENTO TIPODOCUMENTO ");
		// FROM
        //StringBuilder from = new StringBuilder("FROM V_EXP_INF_CONTABLE t1 ");
        List<String> from = new ArrayList<String>();
        from.add("V_EXP_INF_CONTABLE");
        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		//FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterVExpInfContable, false);

		//JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PROCEDIMIENTO,ID_EXPEDIENTE,EXPEDIENTE,CONCEPTO_RESUMIDO,SUBVENCION_RESUELTA,APLICACION_PRESUPUESTARIA,EJERCICIO_APL_PRE,AGRUPACION,GASTO_INGRESO,SECCION,SERVICIO,CENTRO,TERRITORIO,CAC,SC,PROGRAMA,PARTIDA,LETRA_CONTROL,EJERCICIO_REF_INT,ANYO_ORIGEN,NUMERO,DISPONIBLE,TERCERO_MOSTRAR,TERCERO,FECHA_DOCUMENTO_D,REF_INT_D,REF_INT_O,TIPO_DOCUMENTO", "ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y condiciones de negocio
		 */
//		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins, businessFilters, businessParams);

		//PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query, VExpInfContableDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
     *
     * @param filterVExpInfContable VExpInfContable
     * @param jqGridRequestDto JQGridRequestDto
     * @return Long
     */
	@Override
	public Long findAllLikeCountJerarquia(VExpInfContable filterVExpInfContable, JQGridRequestDto jqGridRequestDto) {
		// FROM
        //StringBuilder from = new StringBuilder("FROM V_EXP_INF_CONTABLE t1 ");
        List<String> from = new ArrayList<String>();
        from.add("V_EXP_INF_CONTABLE");

        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		//FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterVExpInfContable, false);

		//JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PROCEDIMIENTO,ID_EXPEDIENTE,EXPEDIENTE,CONCEPTO_RESUMIDO,SUBVENCION_RESUELTA,APLICACION_PRESUPUESTARIA,EJERCICIO_APL_PRE,AGRUPACION,GASTO_INGRESO,SECCION,SERVICIO,CENTRO,TERRITORIO,CAC,SC,PROGRAMA,PARTIDA,LETRA_CONTROL,EJERCICIO_REF_INT,ANYO_ORIGEN,NUMERO,DISPONIBLE,TERCERO_MOSTRAR,TERCERO,FECHA_DOCUMENTO_D,REF_INT_D,REF_INT_O,TIPO_DOCUMENTO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y condiciones de negocio
		 */
//		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID", "ID_PADRE", from, from_alias, joins, businessFilters, businessParams);


		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
     *
     * @param filterVExpInfContable VExpInfContable
     * @param jqGridRequestDto JQGridRequestDto
     * @return List<TableRowDto<VExpInfContable>>
     */
	@Override
	public List<TableRowDto<VExpInfContable>> findAllChild(VExpInfContable filterVExpInfContable, JQGridRequestDto jqGridRequestDto) {

		// FROM
        //StringBuilder from = new StringBuilder("FROM V_EXP_INF_CONTABLE t1 ");
        List<String> from = new ArrayList<String>();
        from.add("V_EXP_INF_CONTABLE");

        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		//FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterVExpInfContable, false);

		//MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_PROCEDIMIENTO,ID_EXPEDIENTE,EXPEDIENTE,CONCEPTO_RESUMIDO,SUBVENCION_RESUELTA,APLICACION_PRESUPUESTARIA,EJERCICIO_APL_PRE,AGRUPACION,GASTO_INGRESO,SECCION,SERVICIO,CENTRO,TERRITORIO,CAC,SC,PROGRAMA,PARTIDA,LETRA_CONTROL,EJERCICIO_REF_INT,ANYO_ORIGEN,NUMERO,DISPONIBLE,TERCERO_MOSTRAR,TERCERO,FECHA_DOCUMENTO_D,REF_INT_D,REF_INT_O,TIPO_DOCUMENTO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y condiciones de negocio
		 */
//		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID", "ID_PADRE", from, from_alias, joins, businessFilters, businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(), new RowNumResultSetExtractor<VExpInfContable>(this.rwMapPK, "ID_PROCEDIMIENTO,ID_EXPEDIENTE,EXPEDIENTE,CONCEPTO_RESUMIDO,SUBVENCION_RESUELTA,APLICACION_PRESUPUESTARIA,EJERCICIO_APL_PRE,AGRUPACION,GASTO_INGRESO,SECCION,SERVICIO,CENTRO,TERRITORIO,CAC,SC,PROGRAMA,PARTIDA,LETRA_CONTROL,EJERCICIO_REF_INT,ANYO_ORIGEN,NUMERO,DISPONIBLE,TERCERO_MOSTRAR,TERCERO,FECHA_DOCUMENTO_D,REF_INT_D,REF_INT_O,TIPO_DOCUMENTO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the VExpInfContable entity
	 *
	 * @param vexpinfcontable VExpInfContable
	 *            Bean with the criteria values to filter by.
	 * @return Map created with two keys
	 *         key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap (VExpInfContable vexpinfcontable){

		StringBuilder where = new StringBuilder(VExpInfContableDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (vexpinfcontable  != null  && vexpinfcontable.getIdProcedimiento() != null ) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(vexpinfcontable.getIdProcedimiento());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getIdExpediente() != null ) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(vexpinfcontable.getIdExpediente());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getExpediente() != null ) {
			where.append(" AND t1.EXPEDIENTE = ?");
			params.add(vexpinfcontable.getExpediente());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getConceptoResumido() != null ) {
			where.append(" AND t1.CONCEPTO_RESUMIDO = ?");
			params.add(vexpinfcontable.getConceptoResumido());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getSubvencionResuelta() != null ) {
			where.append(" AND t1.SUBVENCION_RESUELTA = ?");
			params.add(vexpinfcontable.getSubvencionResuelta());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getAplicacionPresupuestaria() != null ) {
			where.append(" AND t1.APLICACION_PRESUPUESTARIA = ?");
			params.add(vexpinfcontable.getAplicacionPresupuestaria());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getEjercicioAplPre() != null ) {
			where.append(" AND t1.EJERCICIO_APL_PRE = ?");
			params.add(vexpinfcontable.getEjercicioAplPre());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getAgrupacion() != null ) {
			where.append(" AND t1.AGRUPACION = ?");
			params.add(vexpinfcontable.getAgrupacion());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getGastoIngreso() != null ) {
			where.append(" AND t1.GASTO_INGRESO = ?");
			params.add(vexpinfcontable.getGastoIngreso());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getSeccion() != null ) {
			where.append(" AND t1.SECCION = ?");
			params.add(vexpinfcontable.getSeccion());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getServicio() != null ) {
			where.append(" AND t1.SERVICIO = ?");
			params.add(vexpinfcontable.getServicio());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getCentro() != null ) {
			where.append(" AND t1.CENTRO = ?");
			params.add(vexpinfcontable.getCentro());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getTerritorio() != null ) {
			where.append(" AND t1.TERRITORIO = ?");
			params.add(vexpinfcontable.getTerritorio());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getCac() != null ) {
			where.append(" AND t1.CAC = ?");
			params.add(vexpinfcontable.getCac());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getSc() != null ) {
			where.append(" AND t1.SC = ?");
			params.add(vexpinfcontable.getSc());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getPrograma() != null ) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(vexpinfcontable.getPrograma());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getPartida() != null ) {
			where.append(" AND t1.PARTIDA = ?");
			params.add(vexpinfcontable.getPartida());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getLetraControl() != null ) {
			where.append(" AND t1.LETRA_CONTROL = ?");
			params.add(vexpinfcontable.getLetraControl());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getEjercicioRefInt() != null ) {
			where.append(" AND t1.EJERCICIO_REF_INT = ?");
			params.add(vexpinfcontable.getEjercicioRefInt());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getAnyoOrigen() != null ) {
			where.append(" AND t1.ANYO_ORIGEN = ?");
			params.add(vexpinfcontable.getAnyoOrigen());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getNumero() != null ) {
			where.append(" AND t1.NUMERO = ?");
			params.add(vexpinfcontable.getNumero());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getDisponible() != null ) {
			where.append(" AND t1.DISPONIBLE = ?");
			params.add(vexpinfcontable.getDisponible());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getTerceroMostrar() != null ) {
			where.append(" AND t1.TERCERO_MOSTRAR = ?");
			params.add(vexpinfcontable.getTerceroMostrar());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getTercero() != null ) {
			where.append(" AND t1.TERCERO = ?");
			params.add(vexpinfcontable.getTercero());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getFechaDocumentoD() != null ) {
			where.append(" AND t1.FECHA_DOCUMENTO_D = ?");
			params.add(vexpinfcontable.getFechaDocumentoD());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getRefIntD() != null ) {
			where.append(" AND t1.REF_INT_D = ?");
			params.add(vexpinfcontable.getRefIntD());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getRefIntO() != null ) {
			where.append(" AND t1.REF_INT_O = ?");
			params.add(vexpinfcontable.getRefIntO());
		}
		if (vexpinfcontable  != null  && vexpinfcontable.getTipoDocumento() != null ) {
			where.append(" AND t1.TIPO_DOCUMENTO = ?");
			params.add(vexpinfcontable.getTipoDocumento());
		}

		Map<String,Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the VExpInfContable entity
	 *
	 * @param vexpinfcontable VExpInfContable
	 *            Bean with the criteria values to filter by.
     * @param startsWith Boolean
	 * @return Map created with two keys
	 *         key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap (VExpInfContable vexpinfcontable, Boolean startsWith){

		StringBuilder where = new StringBuilder(VExpInfContableDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (vexpinfcontable  != null  && vexpinfcontable.getIdProcedimiento() != null ) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(vexpinfcontable.getIdProcedimiento());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getIdExpediente() != null ) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(vexpinfcontable.getIdExpediente());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getExpediente() != null ) {
			where.append(" AND UPPER(t1.EXPEDIENTE) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getExpediente().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getExpediente().toUpperCase() +"%");
			}
			where.append(" AND t1.EXPEDIENTE IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getConceptoResumido() != null ) {
			where.append(" AND UPPER(t1.CONCEPTO_RESUMIDO) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getConceptoResumido().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getConceptoResumido().toUpperCase() +"%");
			}
			where.append(" AND t1.CONCEPTO_RESUMIDO IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getSubvencionResuelta() != null ) {
			where.append(" AND t1.SUBVENCION_RESUELTA = ?");
			params.add(vexpinfcontable.getSubvencionResuelta());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getAplicacionPresupuestaria() != null ) {
			where.append(" AND UPPER(t1.APLICACION_PRESUPUESTARIA) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getAplicacionPresupuestaria().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getAplicacionPresupuestaria().toUpperCase() +"%");
			}
			where.append(" AND t1.APLICACION_PRESUPUESTARIA IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getEjercicioAplPre() != null ) {
			where.append(" AND t1.EJERCICIO_APL_PRE = ?");
			params.add(vexpinfcontable.getEjercicioAplPre());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getAgrupacion() != null ) {
			where.append(" AND t1.AGRUPACION = ?");
			params.add(vexpinfcontable.getAgrupacion());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getGastoIngreso() != null ) {
			where.append(" AND t1.GASTO_INGRESO = ?");
			params.add(vexpinfcontable.getGastoIngreso());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getSeccion() != null ) {
			where.append(" AND t1.SECCION = ?");
			params.add(vexpinfcontable.getSeccion());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getServicio() != null ) {
			where.append(" AND t1.SERVICIO = ?");
			params.add(vexpinfcontable.getServicio());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getCentro() != null ) {
			where.append(" AND t1.CENTRO = ?");
			params.add(vexpinfcontable.getCentro());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getTerritorio() != null ) {
			where.append(" AND UPPER(t1.TERRITORIO) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getTerritorio().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getTerritorio().toUpperCase() +"%");
			}
			where.append(" AND t1.TERRITORIO IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getCac() != null ) {
			where.append(" AND t1.CAC = ?");
			params.add(vexpinfcontable.getCac());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getSc() != null ) {
			where.append(" AND t1.SC = ?");
			params.add(vexpinfcontable.getSc());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getPrograma() != null ) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(vexpinfcontable.getPrograma());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getPartida() != null ) {
			where.append(" AND t1.PARTIDA = ?");
			params.add(vexpinfcontable.getPartida());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getLetraControl() != null ) {
			where.append(" AND UPPER(t1.LETRA_CONTROL) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getLetraControl().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getLetraControl().toUpperCase() +"%");
			}
			where.append(" AND t1.LETRA_CONTROL IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getEjercicioRefInt() != null ) {
			where.append(" AND t1.EJERCICIO_REF_INT = ?");
			params.add(vexpinfcontable.getEjercicioRefInt());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getAnyoOrigen() != null ) {
			where.append(" AND t1.ANYO_ORIGEN = ?");
			params.add(vexpinfcontable.getAnyoOrigen());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getNumero() != null ) {
			where.append(" AND t1.NUMERO = ?");
			params.add(vexpinfcontable.getNumero());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getDisponible() != null ) {
			where.append(" AND t1.DISPONIBLE = ?");
			params.add(vexpinfcontable.getDisponible());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getTerceroMostrar() != null ) {
			where.append(" AND UPPER(t1.TERCERO_MOSTRAR) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getTerceroMostrar().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getTerceroMostrar().toUpperCase() +"%");
			}
			where.append(" AND t1.TERCERO_MOSTRAR IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getTercero() != null ) {
			where.append(" AND UPPER(t1.TERCERO) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getTercero().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getTercero().toUpperCase() +"%");
			}
			where.append(" AND t1.TERCERO IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getFechaDocumentoD() != null ) {
			where.append(" AND t1.FECHA_DOCUMENTO_D = ?");
			params.add(vexpinfcontable.getFechaDocumentoD());
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getRefIntD() != null ) {
			where.append(" AND UPPER(t1.REF_INT_D) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getRefIntD().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getRefIntD().toUpperCase() +"%");
			}
			where.append(" AND t1.REF_INT_D IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getRefIntO() != null ) {
			where.append(" AND UPPER(t1.REF_INT_O) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getRefIntO().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getRefIntO().toUpperCase() +"%");
			}
			where.append(" AND t1.REF_INT_O IS NOT NULL");
	     }
		if (vexpinfcontable  != null  && vexpinfcontable.getTipoDocumento() != null ) {
			where.append(" AND UPPER(t1.TIPO_DOCUMENTO) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(vexpinfcontable.getTipoDocumento().toUpperCase() +"%");
			}else{
				params.add("%"+vexpinfcontable.getTipoDocumento().toUpperCase() +"%");
			}
			where.append(" AND t1.TIPO_DOCUMENTO IS NOT NULL");
	     }

		Map<String,Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	 public static final int STRING_BUILDER_INIT = 4096;}

