package com.ejie.ab60.dao;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.VTInsSinExpediente;

/**
 * VTInsSinExpedienteDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class VTInsSinExpedienteDaoImpl implements VTInsSinExpedienteDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDINSPECCION", "IDENTIFICADORINSPECCION",
			"TITULO", "DOCUMENTO", "DIRECCION", "CODIGOPOSTAL", "IDPROVINCIA", "IDMUNICIPIO", "IDLOCALIDAD" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<VTInsSinExpediente> rwMap = new RowMapper<VTInsSinExpediente>() {
		public VTInsSinExpediente mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new VTInsSinExpediente(resultSet.getInt("IDINSPECCION"),
					resultSet.getString("IDENTIFICADORINSPECCION"), resultSet.getString("TITULO"),
					resultSet.getString("DOCUMENTO"), resultSet.getString("DIRECCION"),
					resultSet.getString("CODIGOPOSTAL"), resultSet.getLong("IDPROVINCIA"),
					resultSet.getLong("IDMUNICIPIO"), resultSet.getLong("IDLOCALIDAD"));
		}
	};

	private RowMapper<VTInsSinExpediente> rwMapPK = new RowMapper<VTInsSinExpediente>() {
		public VTInsSinExpediente mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new VTInsSinExpediente(resultSet.getInt("IDINSPECCION"),
					resultSet.getString("IDENTIFICADORINSPECCION"), resultSet.getString("TITULO"),
					resultSet.getString("DOCUMENTO"), resultSet.getString("DIRECCION"),
					resultSet.getString("CODIGOPOSTAL"), resultSet.getLong("IDPROVINCIA"),
					resultSet.getLong("IDMUNICIPIO"), resultSet.getLong("IDLOCALIDAD"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<VTInsSinExpediente>> rwMapJerarquia = new RowMapper<JerarquiaDto<VTInsSinExpediente>>() {
		public JerarquiaDto<VTInsSinExpediente> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			VTInsSinExpediente vtinssinexpediente = new VTInsSinExpediente(resultSet.getInt("IDINSPECCION"),
					resultSet.getString("IDENTIFICADORINSPECCION"), resultSet.getString("TITULO"),
					resultSet.getString("DOCUMENTO"), resultSet.getString("DIRECCION"),
					resultSet.getString("CODIGOPOSTAL"), resultSet.getLong("IDPROVINCIA"),
					resultSet.getLong("IDMUNICIPIO"), resultSet.getLong("IDLOCALIDAD"));

			JerarquiaDto<VTInsSinExpediente> jerarquia = new JerarquiaDto<VTInsSinExpediente>();
			jerarquia.setModel(vtinssinexpediente);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the VTInsSinExpediente table.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @return VTInsSinExpediente
	 */
	public VTInsSinExpediente add(VTInsSinExpediente vtinssinexpediente) {
		String query = "INSERT INTO V_T_INS_SIN_EXPEDIENTE (ID_INSPECCION, IDENTIFICADOR_INSPECCION, TITULO, DOCUMENTO, DIRECCION, CODIGO_POSTAL, ID_PROVINCIA, ID_MUNICIPIO, ID_LOCALIDAD) VALUES (?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, vtinssinexpediente.getIdInspeccion(),
				vtinssinexpediente.getIdentificadorInspeccion(), vtinssinexpediente.getTitulo(),
				vtinssinexpediente.getDocumento(), vtinssinexpediente.getDireccion(),
				vtinssinexpediente.getCodigoPostal(), vtinssinexpediente.getIdProvincia(),
				vtinssinexpediente.getIdMunicipio(), vtinssinexpediente.getIdLocalidad());
		return vtinssinexpediente;
	}

	/**
	 * Updates a single row in the VTInsSinExpediente table.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @return VTInsSinExpediente
	 */
	public VTInsSinExpediente update(VTInsSinExpediente vtinssinexpediente) {
		String query = "UPDATE V_T_INS_SIN_EXPEDIENTE SET  WHERE ID_INSPECCION=? AND IDENTIFICADOR_INSPECCION=? AND TITULO=? AND DOCUMENTO=? AND DIRECCION=? AND CODIGO_POSTAL=? AND ID_PROVINCIA=? AND ID_MUNICIPIO=? AND ID_LOCALIDAD=?";
		this.jdbcTemplate.update(query, vtinssinexpediente.getIdInspeccion(),
				vtinssinexpediente.getIdentificadorInspeccion(), vtinssinexpediente.getTitulo(),
				vtinssinexpediente.getDocumento(), vtinssinexpediente.getDireccion(),
				vtinssinexpediente.getCodigoPostal(), vtinssinexpediente.getIdProvincia(),
				vtinssinexpediente.getIdMunicipio(), vtinssinexpediente.getIdLocalidad());
		return vtinssinexpediente;
	}

	/**
	 * Finds a single row in the VTInsSinExpediente table.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @return VTInsSinExpediente
	 */
	@Transactional(readOnly = true)
	public VTInsSinExpediente find(VTInsSinExpediente vtinssinexpediente) {
		String query = "SELECT t1.ID_INSPECCION IDINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.TITULO TITULO, t1.DOCUMENTO DOCUMENTO, t1.DIRECCION DIRECCION, t1.CODIGO_POSTAL CODIGOPOSTAL, t1.ID_PROVINCIA IDPROVINCIA, t1.ID_MUNICIPIO IDMUNICIPIO, t1.ID_LOCALIDAD IDLOCALIDAD FROM V_T_INS_SIN_EXPEDIENTE t1  WHERE t1.ID_INSPECCION = ?   AND t1.IDENTIFICADOR_INSPECCION = ?   AND t1.TITULO = ?   AND t1.DOCUMENTO = ?   AND t1.DIRECCION = ?   AND t1.CODIGO_POSTAL = ?   AND t1.ID_PROVINCIA = ?   AND t1.ID_MUNICIPIO = ?   AND t1.ID_LOCALIDAD = ?  ";

		List<VTInsSinExpediente> vtinssinexpedienteList = this.jdbcTemplate.query(query, this.rwMap,
				vtinssinexpediente.getIdInspeccion(), vtinssinexpediente.getIdentificadorInspeccion(),
				vtinssinexpediente.getTitulo(), vtinssinexpediente.getDocumento(), vtinssinexpediente.getDireccion(),
				vtinssinexpediente.getCodigoPostal(), vtinssinexpediente.getIdProvincia(),
				vtinssinexpediente.getIdMunicipio(), vtinssinexpediente.getIdLocalidad());
		return (VTInsSinExpediente) DataAccessUtils.uniqueResult(vtinssinexpedienteList);
	}

	/**
	 * Removes a single row in the VTInsSinExpediente table.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @return
	 */
	public void remove(VTInsSinExpediente vtinssinexpediente) {
		String query = "DELETE FROM V_T_INS_SIN_EXPEDIENTE WHERE ID_INSPECCION=? AND IDENTIFICADOR_INSPECCION=? AND TITULO=? AND DOCUMENTO=? AND DIRECCION=? AND CODIGO_POSTAL=? AND ID_PROVINCIA=? AND ID_MUNICIPIO=? AND ID_LOCALIDAD=?";
		this.jdbcTemplate.update(query, vtinssinexpediente.getIdInspeccion(),
				vtinssinexpediente.getIdentificadorInspeccion(), vtinssinexpediente.getTitulo(),
				vtinssinexpediente.getDocumento(), vtinssinexpediente.getDireccion(),
				vtinssinexpediente.getCodigoPostal(), vtinssinexpediente.getIdProvincia(),
				vtinssinexpediente.getIdMunicipio(), vtinssinexpediente.getIdLocalidad());
	}

	/**
	 * Finds a list of rows in the VTInsSinExpediente table.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<VTInsSinExpediente>
	 */
	@Transactional(readOnly = true)
	public List<VTInsSinExpediente> findAll(VTInsSinExpediente vtinssinexpediente, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_INSPECCION IDINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.TITULO TITULO,t1.DOCUMENTO DOCUMENTO,t1.DIRECCION DIRECCION,t1.CODIGO_POSTAL CODIGOPOSTAL,t1.ID_PROVINCIA IDPROVINCIA,t1.ID_MUNICIPIO IDMUNICIPIO,t1.ID_LOCALIDAD IDLOCALIDAD ");
		query.append("FROM V_T_INS_SIN_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(vtinssinexpediente);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					VTInsSinExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<VTInsSinExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the VTInsSinExpediente table using like.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<VTInsSinExpediente>
	 */
	@Transactional(readOnly = true)
	public List<VTInsSinExpediente> findAllLike(VTInsSinExpediente vtinssinexpediente,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_INSPECCION IDINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.TITULO TITULO,t1.DOCUMENTO DOCUMENTO,t1.DIRECCION DIRECCION,t1.CODIGO_POSTAL CODIGOPOSTAL,t1.ID_PROVINCIA IDPROVINCIA,t1.ID_MUNICIPIO IDMUNICIPIO,t1.ID_LOCALIDAD IDLOCALIDAD ");
		query.append("FROM V_T_INS_SIN_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(vtinssinexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					VTInsSinExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<VTInsSinExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	@Override
	public List<VTInsSinExpediente> findByTitular(String documentosTitular, JQGridRequestDto jqGridRequestDto) {
		String query = "SELECT t1.ID_INSPECCION IDINSPECCION, t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION, t1.TITULO TITULO, t1.DOCUMENTO DOCUMENTO, t1.DIRECCION DIRECCION, t1.CODIGO_POSTAL CODIGOPOSTAL, t1.ID_PROVINCIA IDPROVINCIA, t1.ID_MUNICIPIO IDMUNICIPIO, t1.ID_LOCALIDAD IDLOCALIDAD FROM AB61.V_T_INS_SIN_EXPEDIENTE t1 WHERE t1.DOCUMENTO IN ("
				+ documentosTitular + ") ";

		return (List<VTInsSinExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMap);
	}

	@Override
	public Long findByTitularCount(String documentosTitular) {
		String query = "SELECT COUNT(1) FROM AB61.V_T_INS_SIN_EXPEDIENTE t1 WHERE t1.DOCUMENTO IN (" + documentosTitular
				+ ") ";

		return this.jdbcTemplate.queryForLong(query.toString());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the VTInsSinExpediente table.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(VTInsSinExpediente vtinssinexpediente) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM V_T_INS_SIN_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(vtinssinexpediente);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the VTInsSinExpediente table using like.
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(VTInsSinExpediente vtinssinexpediente, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM V_T_INS_SIN_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(vtinssinexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of VTInsSinExpediente selected for rup_table
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<VTInsSinExpediente>>
	 */
	@Override
	public List<TableRowDto<VTInsSinExpediente>> reorderSelection(VTInsSinExpediente vtinssinexpediente,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_INSPECCION IDINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.TITULO TITULO,t1.DOCUMENTO DOCUMENTO,t1.DIRECCION DIRECCION,t1.CODIGO_POSTAL CODIGOPOSTAL,t1.ID_PROVINCIA IDPROVINCIA,t1.ID_MUNICIPIO IDMUNICIPIO,t1.ID_LOCALIDAD IDLOCALIDAD ");
		// FROM
		query.append("FROM V_T_INS_SIN_EXPEDIENTE t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(vtinssinexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				VTInsSinExpediente.class, filterParamList,
				"ID_INSPECCION,IDENTIFICADOR_INSPECCION,TITULO,DOCUMENTO,DIRECCION,CODIGO_POSTAL,ID_PROVINCIA,ID_MUNICIPIO,ID_LOCALIDAD");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<VTInsSinExpediente>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            VTInsSinExpediente
	 * @param searchParams
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<VTInsSinExpediente>>
	 */
	@Override
	public List<TableRowDto<VTInsSinExpediente>> search(VTInsSinExpediente filterParams,
			VTInsSinExpediente searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_INSPECCION IDINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.TITULO TITULO,t1.DOCUMENTO DOCUMENTO,t1.DIRECCION DIRECCION,t1.CODIGO_POSTAL CODIGOPOSTAL,t1.ID_PROVINCIA IDPROVINCIA,t1.ID_MUNICIPIO IDMUNICIPIO,t1.ID_LOCALIDAD IDLOCALIDAD ");
		// FROM
		query.append("FROM V_T_INS_SIN_EXPEDIENTE t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				VTInsSinExpediente.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_INSPECCION,IDENTIFICADOR_INSPECCION,TITULO,DOCUMENTO,DIRECCION,CODIGO_POSTAL,ID_PROVINCIA,ID_MUNICIPIO,ID_LOCALIDAD");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<VTInsSinExpediente>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtervtinssinexpediente
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(VTInsSinExpediente filtervtinssinexpediente, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_INSPECCION IDINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.TITULO TITULO,t1.DOCUMENTO DOCUMENTO,t1.DIRECCION DIRECCION,t1.CODIGO_POSTAL CODIGOPOSTAL,t1.ID_PROVINCIA IDPROVINCIA,t1.ID_MUNICIPIO IDMUNICIPIO,t1.ID_LOCALIDAD IDLOCALIDAD ");
		// FROM
		query.append("FROM V_T_INS_SIN_EXPEDIENTE t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtervtinssinexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				VTInsSinExpediente.class, query, params,
				"ID_INSPECCION,IDENTIFICADOR_INSPECCION,TITULO,DOCUMENTO,DIRECCION,CODIGO_POSTAL,ID_PROVINCIA,ID_MUNICIPIO,ID_LOCALIDAD");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical VTInsSinExpediente table.
	 *
	 * @param filterVTInsSinExpediente
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<VTInsSinExpediente>>
	 */
	@Override
	public List<JerarquiaDto<VTInsSinExpediente>> findAllLikeJerarquia(VTInsSinExpediente filterVTInsSinExpediente,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_INSPECCION IDINSPECCION,t1.IDENTIFICADOR_INSPECCION IDENTIFICADORINSPECCION,t1.TITULO TITULO,t1.DOCUMENTO DOCUMENTO,t1.DIRECCION DIRECCION,t1.CODIGO_POSTAL CODIGOPOSTAL,t1.ID_PROVINCIA IDPROVINCIA,t1.ID_MUNICIPIO IDMUNICIPIO,t1.ID_LOCALIDAD IDLOCALIDAD ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM V_T_INS_SIN_EXPEDIENTE
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("V_T_INS_SIN_EXPEDIENTE");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterVTInsSinExpediente, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere,
				"ID_INSPECCION,IDENTIFICADOR_INSPECCION,TITULO,DOCUMENTO,DIRECCION,CODIGO_POSTAL,ID_PROVINCIA,ID_MUNICIPIO,ID_LOCALIDAD",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					VTInsSinExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterVTInsSinExpediente
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(VTInsSinExpediente filterVTInsSinExpediente,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM V_T_INS_SIN_EXPEDIENTE
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("V_T_INS_SIN_EXPEDIENTE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterVTInsSinExpediente, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_INSPECCION,IDENTIFICADOR_INSPECCION,TITULO,DOCUMENTO,DIRECCION,CODIGO_POSTAL,ID_PROVINCIA,ID_MUNICIPIO,ID_LOCALIDAD",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterVTInsSinExpediente
	 *            VTInsSinExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<VTInsSinExpediente>>
	 */
	@Override
	public List<TableRowDto<VTInsSinExpediente>> findAllChild(VTInsSinExpediente filterVTInsSinExpediente,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM V_T_INS_SIN_EXPEDIENTE
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("V_T_INS_SIN_EXPEDIENTE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterVTInsSinExpediente, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_INSPECCION,IDENTIFICADOR_INSPECCION,TITULO,DOCUMENTO,DIRECCION,CODIGO_POSTAL,ID_PROVINCIA,ID_MUNICIPIO,ID_LOCALIDAD",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<VTInsSinExpediente>(this.rwMapPK,
						"ID_INSPECCION,IDENTIFICADOR_INSPECCION,TITULO,DOCUMENTO,DIRECCION,CODIGO_POSTAL,ID_PROVINCIA,ID_MUNICIPIO,ID_LOCALIDAD"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the VTInsSinExpediente entity
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(VTInsSinExpediente vtinssinexpediente) {

		StringBuilder where = new StringBuilder(VTInsSinExpedienteDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (vtinssinexpediente != null && vtinssinexpediente.getIdInspeccion() != null) {
			where.append(" AND t1.ID_INSPECCION = ?");
			params.add(vtinssinexpediente.getIdInspeccion());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdentificadorInspeccion() != null) {
			where.append(" AND t1.IDENTIFICADOR_INSPECCION = ?");
			params.add(vtinssinexpediente.getIdentificadorInspeccion());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getTitulo() != null) {
			where.append(" AND t1.TITULO = ?");
			params.add(vtinssinexpediente.getTitulo());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getDocumento() != null) {
			where.append(" AND t1.DOCUMENTO = ?");
			params.add(vtinssinexpediente.getDocumento());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getDireccion() != null) {
			where.append(" AND t1.DIRECCION = ?");
			params.add(vtinssinexpediente.getDireccion());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getCodigoPostal() != null) {
			where.append(" AND t1.CODIGO_POSTAL = ?");
			params.add(vtinssinexpediente.getCodigoPostal());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdProvincia() != null) {
			where.append(" AND t1.ID_PROVINCIA = ?");
			params.add(vtinssinexpediente.getIdProvincia());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdMunicipio() != null) {
			where.append(" AND t1.ID_MUNICIPIO = ?");
			params.add(vtinssinexpediente.getIdMunicipio());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdLocalidad() != null) {
			where.append(" AND t1.ID_LOCALIDAD = ?");
			params.add(vtinssinexpediente.getIdLocalidad());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the VTInsSinExpediente entity
	 *
	 * @param vtinssinexpediente
	 *            VTInsSinExpediente Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(VTInsSinExpediente vtinssinexpediente, Boolean startsWith) {

		StringBuilder where = new StringBuilder(VTInsSinExpedienteDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (vtinssinexpediente != null && vtinssinexpediente.getIdInspeccion() != null) {
			where.append(" AND t1.ID_INSPECCION = ?");
			params.add(vtinssinexpediente.getIdInspeccion());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdentificadorInspeccion() != null) {
			where.append(" AND UPPER(t1.IDENTIFICADOR_INSPECCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(vtinssinexpediente.getIdentificadorInspeccion().toUpperCase() + "%");
			} else {
				params.add("%" + vtinssinexpediente.getIdentificadorInspeccion().toUpperCase() + "%");
			}
			where.append(" AND t1.IDENTIFICADOR_INSPECCION IS NOT NULL");
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getTitulo() != null) {
			where.append(" AND UPPER(t1.TITULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(vtinssinexpediente.getTitulo().toUpperCase() + "%");
			} else {
				params.add("%" + vtinssinexpediente.getTitulo().toUpperCase() + "%");
			}
			where.append(" AND t1.TITULO IS NOT NULL");
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getDocumento() != null) {
			where.append(" AND UPPER(t1.DOCUMENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(vtinssinexpediente.getDocumento().toUpperCase() + "%");
			} else {
				params.add("%" + vtinssinexpediente.getDocumento().toUpperCase() + "%");
			}
			where.append(" AND t1.DOCUMENTO IS NOT NULL");
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getDireccion() != null) {
			where.append(" AND UPPER(t1.DIRECCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(vtinssinexpediente.getDireccion().toUpperCase() + "%");
			} else {
				params.add("%" + vtinssinexpediente.getDireccion().toUpperCase() + "%");
			}
			where.append(" AND t1.DIRECCION IS NOT NULL");
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getCodigoPostal() != null) {
			where.append(" AND UPPER(t1.CODIGO_POSTAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(vtinssinexpediente.getCodigoPostal().toUpperCase() + "%");
			} else {
				params.add("%" + vtinssinexpediente.getCodigoPostal().toUpperCase() + "%");
			}
			where.append(" AND t1.CODIGO_POSTAL IS NOT NULL");
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdProvincia() != null) {
			where.append(" AND t1.ID_PROVINCIA = ?");
			params.add(vtinssinexpediente.getIdProvincia());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdMunicipio() != null) {
			where.append(" AND t1.ID_MUNICIPIO = ?");
			params.add(vtinssinexpediente.getIdMunicipio());
		}
		if (vtinssinexpediente != null && vtinssinexpediente.getIdLocalidad() != null) {
			where.append(" AND t1.ID_LOCALIDAD = ?");
			params.add(vtinssinexpediente.getIdLocalidad());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

}
