package com.ejie.ab60.dao.actuacionesSubvencionables;

import java.io.Serializable;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.estudioTecnico.ErroresCalculo;
import com.ejie.ab60.model.estudioTecnico.RelExpErrCal;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ActSubvencionableDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ActSubvencionableDaoImpl implements ActSubvencionableDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDACTSUB", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "PORCENTAJEACTUACION", "IMPORTEMINIMOINVERSION", "RUTAXMLCARGA", "RUTAXMLHIJOCARGA",
			"FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION",
			"CONVOCATORIASIDCONVOCATORIA", "CONVOCATORIASIDPROCEDIMIENTO", "CONVOCATORIASCONVOCATORIA",
			"CONVOCATORIASFECHARESOLUCION", "CONVOCATORIASIMPORTE", "CONVPORCENTAJESUBV", "CONVCANTMAXSUBV",
			"CONVOCATORIASPLSQLCALCULO", "CONVOCATORIASPLSQLREPARTO", "CONVOCATORIASOBSERVACIONES",
			"CONVIMPORTEMININVERSION", "CONVOCATORIASFECHAORDENDIA", "CONVOCATORIASFECHAREGISTRO",
			"CONVOCATORIASUSUARIOREGISTRO", "CONVFECHAULTMOD", "CONVUSULTMOD", "CONVOCATORIASLIMITELOCAL",
			"CONVIDTIPOCONVOCATORIA", "ENVIADOINSPACT", "INSPECCIONABLEACT", "IMPORTEADMITIDOACT", "OBCASTELLANOACT",
			"OBEUSKERAACT", "ENVIADOINSPCON", "INSPECCIONABLECON", "CONCEPTOS", "IMPORTEADMITIDOCON", "OBCASTELLANOCON",
			"OBEUSKERACON", "IMPORTEPRESENTADOACT", "IMPORTEPRESENTADOCON", "TITULO", "NOMBRE", "APELLIDO1", "APELLIDO2"

	};

	private static final String SEPARATOR = ",";

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ActSubvencionable> rwMap = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActSubvencionable(resultSet.getInt("IDACTSUB"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getBigDecimal("PORCENTAJEACTUACION"),
					resultSet.getBigDecimal("IMPORTEMINIMOINVERSION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new Convocatorias(resultSet.getInt("ConvocatoriasIDCONVOCATORIA"),
							resultSet.getInt("ConvocatoriasIDPROCEDIMIENTO"),
							resultSet.getString("ConvocatoriasCONVOCATORIA"),
							resultSet.getDate("ConvocatoriasFECHARESOLUCION"),
							resultSet.getBigDecimal("ConvocatoriasIMPORTE"),
							resultSet.getBigDecimal("CONVPORCENTAJESUBV"), resultSet.getBigDecimal("CONVCANTMAXSUBV"),
							resultSet.getString("ConvocatoriasPLSQLCALCULO"),
							resultSet.getString("ConvocatoriasPLSQLREPARTO"),
							resultSet.getString("ConvocatoriasOBSERVACIONES"),
							resultSet.getDate("ConvocatoriasFECHAORDENDIA"),
							resultSet.getDate("ConvocatoriasFECHAREGISTRO"),
							resultSet.getString("ConvocatoriasUSUARIOREGISTRO"), resultSet.getDate("CONVFECHAULTMOD"),
							resultSet.getString("CONVUSULTMOD"), resultSet.getBigDecimal("ConvocatoriasLIMITELOCAL"),
							new TiposConvocatoria(resultSet.getLong("CONVIDTIPOCONVOCATORIA"), null, null, null, null,
									null)));
		}
	};

	private RowMapper<ActSubvencionable> rwMapTipo = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActSubvencionable(resultSet.getInt("ORDEN"), resultSet.getInt("IDACTSUB"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"));
		}
	};

	private RowMapper<ActSubvencionable> rwMapPorcentaje = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActSubvencionable(resultSet.getInt("IDACTSUB"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getBigDecimal("PORCENTAJEACTUACION"));
		}
	};

	private RowMapper<MarcarInspeccionableAct> rwMapMarcarInspeccionable = new RowMapper<MarcarInspeccionableAct>() {
		public MarcarInspeccionableAct mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MarcarInspeccionableAct marcarInspeccionableAct = new MarcarInspeccionableAct();

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));

			if (resultSet.getString("TITULO") != null) {
				actSubvencionable.setDescripcionCastellano(
						resultSet.getString("DESCRIPCIONCASTELLANO") + "(" + resultSet.getString("TITULO") + ")");
				actSubvencionable.setDescripcionEuskera(
						resultSet.getString("DESCRIPCIONEUSKERA") + "(" + resultSet.getString("TITULO") + ")");
			} else {
				actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
				actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			}

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPACT") != null ? resultSet.getInt("ENVIADOINSPACT") : null);
			relExpActSub.setInspeccionable(
					resultSet.getObject("INSPECCIONABLEACT") != null ? resultSet.getInt("INSPECCIONABLEACT") : null);
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOACT"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOACT"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBCASTELLANOACT"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBEUSKERAACT"));

			Conceptos conceptos = new Conceptos();
			conceptos.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPCON") != null ? resultSet.getInt("ENVIADOINSPCON") : null);
			conceptos.setInspeccionable(
					resultSet.getObject("INSPECCIONABLECON") != null ? resultSet.getInt("INSPECCIONABLECON") : null);

			if (resultSet.getString("CONCEPTOS") != null) {
				conceptos.setConcepto(resultSet.getString("CONCEPTOS"));
			} else if (resultSet.getString("TITULO") != null) {
				conceptos.setConcepto(resultSet.getString("TITULO"));
			} else if (resultSet.getString("NOMBRE") != null || resultSet.getString("APELLIDO1") != null) {
				String apellido2 = resultSet.getString("APELLIDO2") != null ? resultSet.getString("APELLIDO2") : "";
				conceptos.setConcepto(
						resultSet.getString("NOMBRE") + " " + resultSet.getString("APELLIDO1") + " " + apellido2);
			} else if (resultSet.getString("NOMBREPC") != null || resultSet.getString("APELLIDO1PC") != null) {
				String apellido2PC = resultSet.getString("APELLIDO2PC") != null ? resultSet.getString("APELLIDO2PC")
						: "";
				conceptos.setConcepto(
						resultSet.getString("NOMBREPC") + " " + resultSet.getString("APELLIDO1PC") + " " + apellido2PC);
			}

			conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOCON"));
			conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOCON"));
			conceptos.setObservacionesCastellano(resultSet.getString("OBCASTELLANOCON"));
			conceptos.setObservacionesEuskera(resultSet.getString("OBEUSKERACON"));
			conceptos.setIdConcepto(resultSet.getInt("IDCONCEPTO"));
			conceptos.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));

			marcarInspeccionableAct.setActSubs(actSubvencionable);
			marcarInspeccionableAct.setRelExpActSub(relExpActSub);
			marcarInspeccionableAct.setConceptos(conceptos);

			return marcarInspeccionableAct;

		}
	};

	private RowMapper<MarcarInspeccionableAct> rwMapMarcarInspeccionableDEC = new RowMapper<MarcarInspeccionableAct>() {
		public MarcarInspeccionableAct mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Locale locale = LocaleContextHolder.getLocale();

			MarcarInspeccionableAct marcarInspeccionableAct = new MarcarInspeccionableAct();

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));

			if (resultSet.getString("TITULO") != null) {
				actSubvencionable.setDescripcionCastellano(
						resultSet.getString("DESCRIPCIONCASTELLANO") + "(" + resultSet.getString("TITULO") + ")");
				actSubvencionable.setDescripcionEuskera(
						resultSet.getString("DESCRIPCIONEUSKERA") + "(" + resultSet.getString("TITULO") + ")");
			} else {
				actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
				actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			}

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPACT") != null ? resultSet.getInt("ENVIADOINSPACT") : null);
			relExpActSub.setInspeccionable(
					resultSet.getObject("INSPECCIONABLEACT") != null ? resultSet.getInt("INSPECCIONABLEACT") : null);
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOACT"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOACT"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBCASTELLANOACT"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBEUSKERAACT"));

			Conceptos conceptos = new Conceptos();
			conceptos.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPCON") != null ? resultSet.getInt("ENVIADOINSPCON") : null);
			conceptos.setInspeccionable(
					resultSet.getObject("INSPECCIONABLECON") != null ? resultSet.getInt("INSPECCIONABLECON") : null);

			if (resultSet.getString("CONCEPTOS") != null) {
				conceptos.setConcepto(resultSet.getString("CONCEPTOS"));
			} else if (resultSet.getString("TITULOACTAYUNTAMIENTO") != null) {
				conceptos.setConcepto(resultSet.getString("TITULOACTAYUNTAMIENTO"));
			} else if (resultSet.getString("NOMBRE") != null || resultSet.getString("APELLIDO1") != null) {
				String apellido2 = resultSet.getString("APELLIDO2") != null ? resultSet.getString("APELLIDO2") : "";
				conceptos.setConcepto(
						resultSet.getString("NOMBRE") + " " + resultSet.getString("APELLIDO1") + " " + apellido2);
			} else if (resultSet.getString("NOMBREPC") != null || resultSet.getString("APELLIDO1PC") != null) {
				String apellido2PC = resultSet.getString("APELLIDO2PC") != null ? resultSet.getString("APELLIDO2PC")
						: "";
				conceptos.setConcepto(
						resultSet.getString("NOMBREPC") + " " + resultSet.getString("APELLIDO1PC") + " " + apellido2PC);
			}

			conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOCON"));
			conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOCON"));
			conceptos.setObservacionesCastellano(resultSet.getString("OBCASTELLANOCON"));
			conceptos.setObservacionesEuskera(resultSet.getString("OBEUSKERACON"));
			conceptos.setIdConcepto(resultSet.getInt("IDCONCEPTO"));
			conceptos.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));

			marcarInspeccionableAct.setActSubs(actSubvencionable);
			marcarInspeccionableAct.setRelExpActSub(relExpActSub);
			marcarInspeccionableAct.setConceptos(conceptos);

			return marcarInspeccionableAct;

		}
	};

	private RowMapper<MarcarInspeccionableAct> rwMapMarcarInspeccionableEMCO = new RowMapper<MarcarInspeccionableAct>() {
		public MarcarInspeccionableAct mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MarcarInspeccionableAct marcarInspeccionableAct = new MarcarInspeccionableAct();

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));

			if (resultSet.getString("TITULO") != null) {
				actSubvencionable.setDescripcionCastellano(
						resultSet.getString("DESCRIPCIONCASTELLANO") + "(" + resultSet.getString("TITULO") + ")");
				actSubvencionable.setDescripcionEuskera(
						resultSet.getString("DESCRIPCIONEUSKERA") + "(" + resultSet.getString("TITULO") + ")");
			} else {
				actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
				actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			}

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPACT") != null ? resultSet.getInt("ENVIADOINSPACT") : null);
			relExpActSub.setInspeccionable(
					resultSet.getObject("INSPECCIONABLEACT") != null ? resultSet.getInt("INSPECCIONABLEACT") : null);
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOACT"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOACT"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBCASTELLANOACT"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBEUSKERAACT"));

			Conceptos conceptos = new Conceptos();
			conceptos.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPCON") != null ? resultSet.getInt("ENVIADOINSPCON") : null);
			conceptos.setInspeccionable(
					resultSet.getObject("INSPECCIONABLECON") != null ? resultSet.getInt("INSPECCIONABLECON") : null);

			if (resultSet.getString("CONCEPTOS") != null) {
				conceptos.setConcepto(resultSet.getString("CONCEPTOS"));
			} else if (resultSet.getString("TITULOACTAYUNTAMIENTO") != null) {
				conceptos.setConcepto(resultSet.getString("TITULOACTAYUNTAMIENTO"));
			} else if (resultSet.getString("NOMBRE") != null || resultSet.getString("APELLIDO1") != null) {
				String apellido2 = resultSet.getString("APELLIDO2") != null ? resultSet.getString("APELLIDO2") : "";
				conceptos.setConcepto(
						resultSet.getString("NOMBRE") + " " + resultSet.getString("APELLIDO1") + " " + apellido2);
			} else if (resultSet.getString("NOMBREPC") != null || resultSet.getString("APELLIDO1PC") != null) {
				String apellido2PC = resultSet.getString("APELLIDO2PC") != null ? resultSet.getString("APELLIDO2PC")
						: "";
				conceptos.setConcepto(
						resultSet.getString("NOMBREPC") + " " + resultSet.getString("APELLIDO1PC") + " " + apellido2PC);
			}

			conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOCON"));
			conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOCON"));
			conceptos.setObservacionesCastellano(resultSet.getString("OBCASTELLANOCON"));
			conceptos.setObservacionesEuskera(resultSet.getString("OBEUSKERACON"));
			conceptos.setIdConcepto(resultSet.getInt("IDCONCEPTO"));
			conceptos.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));

			marcarInspeccionableAct.setActSubs(actSubvencionable);
			marcarInspeccionableAct.setRelExpActSub(relExpActSub);
			marcarInspeccionableAct.setConceptos(conceptos);

			return marcarInspeccionableAct;

		}
	};

	private RowMapper<ActSubvencionable> rwMapAgrupacion = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			actSubvencionable.setIdActSubAgrupacion(resultSet.getInt("IDACTSUBAGRUPACION"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			return actSubvencionable;

		}
	};

	private RowMapper<ActSubvencionable> rwMapAgrupacionPadre = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("IDACTSUB"));
			actSubvencionable.setIdActSubPadreAgrupacion(resultSet.getInt("IDACTSUBAGRUPACION"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			return actSubvencionable;

		}
	};

	private RowMapper<ActSubvencionable> rwMapImportes = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setImporte(resultSet.getBigDecimal("IMPORTE"));
			actSubvencionable.setImporteDisponible(resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
			return actSubvencionable;
		}
	};
	private RowMapper<ActSubvencionable> rwMapImporte = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			actSubvencionable.setImporte(resultSet.getBigDecimal("IMPORTE"));
			actSubvencionable.setImporteDisponible(resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			return actSubvencionable;
		}
	};
	private RowMapper<ActSubvencionable> rwMapPK = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActSubvencionable(resultSet.getInt("IDACTSUB"));
		}
	};

	private RowMapper<ActSubvencionable> rwMapPKpadre = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ActSubvencionable(null, null, resultSet.getInt("IDACTSUBPADRE"), null, null,
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"));
		}
	};

	private RowMapper<ActSubvencionable> rwMapObtenerActSub = new RowMapper<ActSubvencionable>() {
		public ActSubvencionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			return actSubvencionable;
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ActSubvencionable>> rwMapJerarquia = new RowMapper<JerarquiaDto<ActSubvencionable>>() {
		public JerarquiaDto<ActSubvencionable> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ActSubvencionable actsubvencionable = new ActSubvencionable(resultSet.getInt("IDACTSUB"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getBigDecimal("PORCENTAJEACTUACION"), resultSet.getBigDecimal("IMPORTEMINIMOINVERSION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new Convocatorias(resultSet.getInt("ConvocatoriasIDCONVOCATORIA"),
							resultSet.getInt("ConvocatoriasIDPROCEDIMIENTO"),
							resultSet.getString("ConvocatoriasCONVOCATORIA"),
							resultSet.getDate("ConvocatoriasFECHARESOLUCION"),
							resultSet.getBigDecimal("ConvocatoriasIMPORTE"),
							resultSet.getBigDecimal("CONVPORCENTAJESUBV"), resultSet.getBigDecimal("CONVCANTMAXSUBV"),
							resultSet.getString("ConvocatoriasPLSQLCALCULO"),
							resultSet.getString("ConvocatoriasPLSQLREPARTO"),
							resultSet.getString("ConvocatoriasOBSERVACIONES"),
							resultSet.getDate("ConvocatoriasFECHAORDENDIA"),
							resultSet.getDate("ConvocatoriasFECHAREGISTRO"),
							resultSet.getString("ConvocatoriasUSUARIOREGISTRO"), resultSet.getDate("CONVFECHAULTMOD"),
							resultSet.getString("CONVUSULTMOD"), resultSet.getBigDecimal("ConvocatoriasLIMITELOCAL"),
							new TiposConvocatoria(resultSet.getLong("CONVIDTIPOCONVOCATORIA"), null, null, null, null,
									null)));

			JerarquiaDto<ActSubvencionable> jerarquia = new JerarquiaDto<ActSubvencionable>();
			jerarquia.setModel(actsubvencionable);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	public ActSubvencionable add(ActSubvencionable actsubvencionable) {
		String query = "INSERT INTO ACT_SUBVENCIONABLE (ID_ACT_SUB, ID_ACT_SUB_PADRE, ID_CONVOCATORIA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, PORCENTAJE_ACTUACION, IMPORTE_INVERSION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6006T00.NEXTVAL,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, actsubvencionable.getIdActSubPadre(),
				actsubvencionable.getConvocatorias().getIdConvocatoria(), actsubvencionable.getDescripcionCastellano(),
				actsubvencionable.getDescripcionEuskera(), actsubvencionable.getPorcentajeActuacion(),
				actsubvencionable.getImporteInversion(), new Date(), actsubvencionable.getUsuarioRegistro());
		return actsubvencionable;
	}

	/**
	 * Updates a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	public ActSubvencionable update(ActSubvencionable actsubvencionable) {
		String query = "UPDATE ACT_SUBVENCIONABLE SET PORCENTAJE_ACTUACION=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_ACT_SUB=?";

		this.jdbcTemplate.update(query, actsubvencionable.getPorcentajeActuacion(),
				actsubvencionable.getFechaUltmodificacion(), actsubvencionable.getUsuarioUltmodificacion(),
				actsubvencionable.getIdActSub());

		return actsubvencionable;
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public ActSubvencionable find(ActSubvencionable actsubvencionable) {
		String query = "SELECT t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION, t1.IMPORTE_MIN_INV IMPORTEMINIMOINVERSION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA, t2.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO, t2.CONVOCATORIA CONVOCATORIASCONVOCATORIA, t2.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION, t2.IMPORTE CONVOCATORIASIMPORTE, t2.PORCENTAJE_SUBVENCION CONVPORCENTAJESUBV, t2.CANT_MAX_SUBVENCION CONVCANTMAXSUBV, t2.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO, t2.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO, t2.OBSERVACIONES CONVOCATORIASOBSERVACIONES, t2.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA, t2.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO, t2.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO, t2.FECHA_ULTMODIFICACION CONVFECHAULTMOD, t2.USUARIO_ULTMODIFICACION CONVUSULTMOD, t2.LIMITE_AT CONVOCATORIASLIMITELOCAL, t2.ID_TIPO_CONVOCATORIA CONVIDTIPOCONVOCATORIA FROM ACT_SUBVENCIONABLE t1 , CONVOCATORIAS t2  WHERE t1.ID_ACT_SUB = ?   AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+)";

		List<ActSubvencionable> actsubvencionableList = this.jdbcTemplate.query(query, this.rwMap,
				actsubvencionable.getIdActSub());
		return (ActSubvencionable) DataAccessUtils.uniqueResult(actsubvencionableList);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public ActSubvencionable findImporteDisponible(ActSubvencionable actsubvencionable) {
		String query = "SELECT T1.IMPORTE IMPORTE, T1.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE FROM ACT_SUBVENCIONABLE t1 WHERE t1.ID_ACT_SUB = ?  ";

		List<ActSubvencionable> actsubvencionableList = this.jdbcTemplate.query(query, this.rwMapImportes,
				actsubvencionable.getIdActSub());
		return (ActSubvencionable) DataAccessUtils.uniqueResult(actsubvencionableList);
	}

	@Transactional(readOnly = true)
	public Integer obtenerIdentificadorAgrupacion(Integer idActuacionSubvencionable) {
		String query = "SELECT ID_AGRUPACION IDAGRUPACION FROM ACT_SUBVENCIONABLE t1 WHERE t1.ID_ACT_SUB = ?  ";

		Integer identificadorAgrupacion = this.jdbcTemplate.queryForInt(query, idActuacionSubvencionable);

		return identificadorAgrupacion;
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public ActSubvencionable findIdActSub(Integer idActSub) {
		String query = "SELECT T1.ID_ACT_SUB_PADRE IDACTSUBPADRE, (SELECT ID_AGRUPACION FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = T1.ID_ACT_SUB_PADRE) IDACTSUBPADREAGRUPACION,  T1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,  T1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE T1 WHERE ID_ACT_SUB = ?";
		List<ActSubvencionable> actsubvencionableList = this.jdbcTemplate.query(query, this.rwMapPKpadre, idActSub);
		return (ActSubvencionable) DataAccessUtils.uniqueResult(actsubvencionableList);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public ActSubvencionable findPorcentaje(ActSubvencionable actsubvencionable) {
		String query = "SELECT t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION FROM ACT_SUBVENCIONABLE t1 , CONVOCATORIAS t2  WHERE t1.ID_ACT_SUB = ?   AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+)";

		List<ActSubvencionable> actsubvencionableList = this.jdbcTemplate.query(query, this.rwMapPorcentaje,
				actsubvencionable.getIdActSub());
		return (ActSubvencionable) DataAccessUtils.uniqueResult(actsubvencionableList);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findTipo(Integer idCriterio) {
		String query = "SELECT T1.ORDEN ORDEN,  T1.ID_ACT_SUB IDACTSUB, T1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE T1 WHERE T1.ID_ACT_SUB_PADRE = ? ORDER BY ORDEN ";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapTipo, idCriterio);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAccionSubvencionablePadre(Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT  ORDEN ORDEN, ID_ACT_SUB IDACTSUB, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB_PADRE = (SELECT T1.ID_ACT_SUB FROM AB6006T00 T1 INNER JOIN AB6023T00 T2 ON T1.ID_ACT_SUB = T2.ID_ACT_SUB WHERE T2.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB_PADRE IS NULL) ORDER BY ORDEN";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapTipo, idExpediente);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findImporteImporteDisponibleActSub(Integer idActSub) {
		String query = "SELECT IMPORTE IMPORTE,IMPORTE_DISPONIBLE IMPORTEDISPONIBLE FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = ?";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapImportes, idActSub);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAccionSubvencionableDEC(Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT ORDEN ORDEN ,ID_ACT_SUB IDACTSUB, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = (SELECT T1.ID_ACT_SUB FROM AB6006T00 T1 INNER JOIN AB6023T00 T2 ON T1.ID_ACT_SUB = T2.ID_ACT_SUB WHERE T2.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB_PADRE IS NULL)  ORDER BY ORDEN";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapTipo, idExpediente);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAccionSubvencionableEMCO(Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT ORDEN ORDEN ,ID_ACT_SUB IDACTSUB, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = (SELECT T1.ID_ACT_SUB FROM AB6006T00 T1 INNER JOIN AB6023T00 T2 ON T1.ID_ACT_SUB = T2.ID_ACT_SUB WHERE T2.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB_PADRE IS NULL)  ORDER BY ORDEN";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapTipo, idExpediente);
	}

	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAccionSubvencionableAsoEMCO(Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT ORDEN ORDEN, ID_ACT_SUB IDACTSUB, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB IN (SELECT T1.ID_ACT_SUB FROM AB6006T00 T1 WHERE T1.ID_ACT_SUB_PADRE = (SELECT T1.ID_ACT_SUB FROM AB6006T00 T1 INNER JOIN AB6023T00 T2 ON T1.ID_ACT_SUB = T2.ID_ACT_SUB WHERE T2.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB_PADRE IS NULL)) ORDER BY ORDEN";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapTipo, idExpediente);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAccionSubvencionablePadrePTT(Integer idConvocatoria) {
		String query = "SELECT DISTINCT t1.ORDEN ORDEN , t1.ID_ACT_SUB IDACTSUB, t1.ID_AGRUPACION IDACTSUBAGRUPACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE t1 WHERE t1.ID_CONVOCATORIA = ? AND t1.ID_ACT_SUB_PADRE IS NULL ORDER BY ORDEN";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapAgrupacionPadre, idConvocatoria);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAccionSubvencionableNieto(Integer idActSub) {
		String query = "SELECT ORDEN ORDEN, ID_ACT_SUB IDACTSUB, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB_PADRE = ? ORDER BY ORDEN";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapTipo, idActSub);
	}

	/**
	 * recupera el importe disponible para cada accion subencionable de una
	 * convocatoria.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @return ActSubvencionable
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findImporteActSubvencionable(Integer idConvocatoria) {
		String query = "SELECT ID_ACT_SUB IDACTSUB, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, IMPORTE IMPORTE, IMPORTE_DISPONIBLE IMPORTEDISPONIBLE FROM ACT_SUBVENCIONABLE WHERE ID_CONVOCATORIA = ? AND IMPORTE IS NOT NULL";

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapImporte, idConvocatoria);
	}

	/**
	 * Finds a single row in the ActSubvencionable table.
	 *
	 * @param idActSubAgrupacion
	 *            Integer
	 * @param existe_Pertenencia_Redes
	 *            Boolean
	 * @return ActSubvencionable
	 */
	@Override
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAccionSubvencionableHijoPTT(Integer idActSubAgrupacion,
			Boolean existe_Pertenencia_Redes) {

		String in = "";
		if (existe_Pertenencia_Redes) {
			in = " ID_AGRUPACION IN(13,15,16,17,18,65,66) ";
		} else {
			in = " ID_AGRUPACION IN(13,14,15,16,17,18,65,66) ";
		}
		String query = "SELECT ORDEN ORDEN, ID_ACT_SUB IDACTSUB, ID_AGRUPACION IDACTSUBAGRUPACION, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB_PADRE = ? AND "
				+ in + " ORDER BY ORDEN";
		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapAgrupacion, idActSubAgrupacion);
	}

	/**
	 * Removes a single row in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return
	 */
	public void remove(ActSubvencionable actsubvencionable) {
		String query = "DELETE FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB=?";
		this.jdbcTemplate.update(query, actsubvencionable.getIdActSub());
	}

	/**
	 * Finds a list of rows in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ActSubvencionable>
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAll(ActSubvencionable actsubvencionable, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.RUTA_XML_CARGA RUTAXMLCARGA,t1.RUTA_XML_HIJO_CARGA RUTAXMLHIJOCARGA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t2.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t2.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t2.IMPORTE CONVOCATORIASIMPORTE,t2.PORCENTAJE_SUBVENCION CONVPORCENTAJESUBV,t2.CANT_MAX_SUBVENCION CONVCANTMAXSUBV,t2.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t2.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t2.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t2.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t2.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CONVFECHAULTMOD,t2.USUARIO_ULTMODIFICACION CONVUSULTMOD,t2.LIMITE_AT CONVOCATORIASLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA CONVIDTIPOCONVOCATORIA ");
		query.append("FROM ACT_SUBVENCIONABLE t1 ,CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(actsubvencionable);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ActSubvencionableDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	@Transactional(readOnly = true)
	public List<ActSubvencionable> findComboMEC(Integer idConvocatoria) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION ");
		query.append("FROM ACT_SUBVENCIONABLE t1 ");
		query.append(" WHERE t1.ID_CONVOCATORIA = ?");

		/*
		 * if (!listaRelExpActSub.isEmpty()) { StringBuilder sbr = new
		 * StringBuilder(); for (int x = 0; x < listaRelExpActSub.size(); x++) {
		 * sbr.append("'" + listaRelExpActSub.get(x).getIdActSub() + "'");
		 * sbr.append(SEPARATOR); }
		 * 
		 * String sb = sbr.toString(); sb = sb.substring(0, sb.length() -
		 * SEPARATOR.length()); query.append(sb + ")"); } else {
		 * query.append("'0')"); }
		 */

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query.toString(), this.rwMapPorcentaje,
				idConvocatoria);
	}

	/**
	 * Finds rows in the ActSubvencionable table using like.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ActSubvencionable>
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAllLike(ActSubvencionable actsubvencionable, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.RUTA_XML_CARGA RUTAXMLCARGA,t1.RUTA_XML_HIJO_CARGA RUTAXMLHIJOCARGA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t2.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t2.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t2.IMPORTE CONVOCATORIASIMPORTE,t2.PORCENTAJE_SUBVENCION CONVPORCENTAJESUBV,t2.CANT_MAX_SUBVENCION CONVCANTMAXSUBV,t2.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t2.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t2.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t2.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t2.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CONVFECHAULTMOD,t2.USUARIO_ULTMODIFICACION CONVUSULTMOD,t2.LIMITE_AT CONVOCATORIASLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA CONVIDTIPOCONVOCATORIA ");
		query.append("FROM ACT_SUBVENCIONABLE t1 ,CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actsubvencionable, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ActSubvencionableDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the ActSubvencionable table using like.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ActSubvencionable>
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findAllLikePorcentaje(ActSubvencionable actsubvencionable,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION ");
		query.append("FROM ACT_SUBVENCIONABLE t1 ,CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actsubvencionable, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ActSubvencionableDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query.toString(), this.rwMapPorcentaje,
				params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ActSubvencionable table.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ActSubvencionable actsubvencionable) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ACT_SUBVENCIONABLE t1 , CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(actsubvencionable);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ActSubvencionable table using like.
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ActSubvencionable actsubvencionable, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ACT_SUBVENCIONABLE t1 ,CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actsubvencionable, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Updates Importe_Disponible en acciones subencionables table.
	 *
	 * @param actSubvencionable
	 *            actSubvencionable
	 * @return ActSubvencionable
	 */
	public ActSubvencionable updateImporteDisponible(ActSubvencionable actSubvencionable) {
		String query = "UPDATE ACT_SUBVENCIONABLE SET IMPORTE_DISPONIBLE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_ACT_SUB=?";

		this.jdbcTemplate.update(query, actSubvencionable.getImporteDisponible(),
				actSubvencionable.getFechaUltmodificacion(), actSubvencionable.getUsuarioUltmodificacion(),
				actSubvencionable.getIdActSub());
		return actSubvencionable;
	}

	/**
	 * Updates Importe en acciones subencionables table.
	 *
	 * @param actSubvencionable
	 *            actSubvencionable
	 * @return ActSubvencionable
	 */
	public ActSubvencionable updateImporte(ActSubvencionable actSubvencionable) {
		String query = "UPDATE ACT_SUBVENCIONABLE SET IMPORTE=?,IMPORTE_DISPONIBLE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_ACT_SUB=?";

		this.jdbcTemplate.update(query, actSubvencionable.getImporte(), actSubvencionable.getImporteDisponible(),
				actSubvencionable.getFechaUltmodificacion(), actSubvencionable.getUsuarioUltmodificacion(),
				actSubvencionable.getIdActSub());
		return actSubvencionable;
	}

	/**
	 * Reorder the data list of ActSubvencionable selected for rup_table
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ActSubvencionable>>
	 */
	@Override
	public List<TableRowDto<ActSubvencionable>> reorderSelection(ActSubvencionable actsubvencionable,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.RUTA_XML_CARGA RUTAXMLCARGA,t1.RUTA_XML_HIJO_CARGA RUTAXMLHIJOCARGA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t2.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t2.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t2.IMPORTE CONVOCATORIASIMPORTE,t2.PORCENTAJE_SUBVENCION CONVPORCENTAJESUBV,t2.CANT_MAX_SUBVENCION CONVCANTMAXSUBV,t2.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t2.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t2.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t2.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t2.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CONVFECHAULTMOD,t2.USUARIO_ULTMODIFICACION CONVUSULTMOD,t2.LIMITE_AT CONVOCATORIASLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA CONVIDTIPOCONVOCATORIA ");
		// FROM
		query.append("FROM ACT_SUBVENCIONABLE t1 ,CONVOCATORIAS t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(actsubvencionable, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ActSubvencionable.class, filterParamList, "ID_ACT_SUB");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ActSubvencionable>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ActSubvencionable
	 * @param searchParams
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ActSubvencionable>>
	 */
	@Override
	public List<TableRowDto<ActSubvencionable>> search(ActSubvencionable filterParams, ActSubvencionable searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.RUTA_XML_CARGA RUTAXMLCARGA,t1.RUTA_XML_HIJO_CARGA RUTAXMLHIJOCARGA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t2.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t2.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t2.IMPORTE CONVOCATORIASIMPORTE,t2.PORCENTAJE_SUBVENCION CONVPORCENTAJESUBV,t2.CANT_MAX_SUBVENCION CONVCANTMAXSUBV,t2.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t2.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t2.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t2.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t2.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CONVFECHAULTMOD,t2.USUARIO_ULTMODIFICACION CONVUSULTMOD,t2.LIMITE_AT CONVOCATORIASLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA CONVIDTIPOCONVOCATORIA ");
		// FROM
		query.append("FROM ACT_SUBVENCIONABLE t1 ,CONVOCATORIAS t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ActSubvencionable.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_ACT_SUB");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ActSubvencionable>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filteractsubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ActSubvencionable filteractsubvencionable, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.RUTA_XML_CARGA RUTAXMLCARGA,t1.RUTA_XML_HIJO_CARGA RUTAXMLHIJOCARGA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t2.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t2.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t2.IMPORTE CONVOCATORIASIMPORTE,t2.PORCENTAJE_SUBVENCION CONVPORCENTAJESUBV,t2.CANT_MAX_SUBVENCION CONVCANTMAXSUBV,t2.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t2.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t2.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t2.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t2.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CONVFECHAULTMOD,t2.USUARIO_ULTMODIFICACION CONVUSULTMOD,t2.LIMITE_AT CONVOCATORIASLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA CONVIDTIPOCONVOCATORIA ");
		// FROM
		query.append("FROM ACT_SUBVENCIONABLE t1 ,CONVOCATORIAS t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filteractsubvencionable, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				ActSubvencionable.class, query, params, "ID_ACT_SUB");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ActSubvencionable table.
	 *
	 * @param filterActSubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ActSubvencionable>>
	 */
	@Override
	public List<JerarquiaDto<ActSubvencionable>> findAllLikeJerarquia(ActSubvencionable filterActSubvencionable,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_SUB IDACTSUB,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.RUTA_XML_CARGA RUTAXMLCARGA,t1.RUTA_XML_HIJO_CARGA RUTAXMLHIJOCARGA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t2.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t2.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t2.IMPORTE CONVOCATORIASIMPORTE,t2.PORCENTAJE_SUBVENCION CONVPORCENTAJESUBV,t2.CANT_MAX_SUBVENCION CONVCANTMAXSUBV,t2.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t2.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t2.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t2.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t2.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CONVFECHAULTMOD,t2.USUARIO_ULTMODIFICACION CONVUSULTMOD,t2.LIMITE_AT CONVOCATORIASLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA CONVIDTIPOCONVOCATORIA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_SUBVENCIONABLE t1
		// ,CONVOCATORIAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_SUBVENCIONABLE");
		from.add("CONVOCATORIAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActSubvencionable, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ACT_SUB", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ActSubvencionableDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterActSubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ActSubvencionable filterActSubvencionable,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_SUBVENCIONABLE t1
		// ,CONVOCATORIAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_SUBVENCIONABLE");
		from.add("CONVOCATORIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActSubvencionable, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ACT_SUB",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterActSubvencionable
	 *            ActSubvencionable
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ActSubvencionable>>
	 */
	@Override
	public List<TableRowDto<ActSubvencionable>> findAllChild(ActSubvencionable filterActSubvencionable,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ACT_SUBVENCIONABLE t1
		// ,CONVOCATORIAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("ACT_SUBVENCIONABLE");
		from.add("CONVOCATORIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterActSubvencionable, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_ACT_SUB",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ActSubvencionable>(this.rwMapPK, "ID_ACT_SUB"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ActSubvencionable entity
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ActSubvencionable actsubvencionable) {

		StringBuilder where = new StringBuilder(ActSubvencionableDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (actsubvencionable != null && actsubvencionable.getIdActSub() != null) {
			where.append(" AND t1.ID_ACT_SUB = ?");
			params.add(actsubvencionable.getIdActSub());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(actsubvencionable.getConvocatorias().getIdConvocatoria());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getTiposConvocatoria() != null
				&& actsubvencionable.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t2.ID_TIPO_CONVOCATORIA = ?");
			params.add(actsubvencionable.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getIdProcedimiento() != null) {
			where.append(" AND t2.ID_PROCEDIMIENTO = ?");
			params.add(actsubvencionable.getConvocatorias().getIdProcedimiento());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getConvocatoria() != null) {
			where.append(" AND t2.CONVOCATORIA = ?");
			params.add(actsubvencionable.getConvocatorias().getConvocatoria());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaResolucion() != null) {
			where.append(" AND t2.FECHA_RESOLUCION = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaResolucion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getImporte() != null) {
			where.append(" AND t2.IMPORTE = ?");
			params.add(actsubvencionable.getConvocatorias().getImporte());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getPorcentajeSubvencion() != null) {
			where.append(" AND t2.PORCENTAJE_SUBVENCION = ?");
			params.add(actsubvencionable.getConvocatorias().getPorcentajeSubvencion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getCantMaxSubvencion() != null) {
			where.append(" AND t2.CANT_MAX_SUBVENCION = ?");
			params.add(actsubvencionable.getConvocatorias().getCantMaxSubvencion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getPlsqlCalculo() != null) {
			where.append(" AND t2.PLSQL_CALCULO = ?");
			params.add(actsubvencionable.getConvocatorias().getPlsqlCalculo());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getPlsqlReparto() != null) {
			where.append(" AND t2.PLSQL_REPARTO = ?");
			params.add(actsubvencionable.getConvocatorias().getPlsqlReparto());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getObservaciones() != null) {
			where.append(" AND t2.OBSERVACIONES = ?");
			params.add(actsubvencionable.getConvocatorias().getObservaciones());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaOrdenDia() != null) {
			where.append(" AND t2.FECHA_ORDEN_DIA = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaOrdenDia());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaRegistro());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(actsubvencionable.getConvocatorias().getUsuarioRegistro());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaUltmodificacion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(actsubvencionable.getConvocatorias().getUsuarioUltmodificacion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getLimiteLocal() != null) {
			where.append(" AND t2.LIMITE_AT = ?");
			params.add(actsubvencionable.getConvocatorias().getLimiteLocal());
		}
		if (actsubvencionable != null && actsubvencionable.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(actsubvencionable.getDescripcionCastellano());
		}
		if (actsubvencionable != null && actsubvencionable.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(actsubvencionable.getDescripcionEuskera());
		}
		if (actsubvencionable != null && actsubvencionable.getPorcentajeActuacion() != null) {
			where.append(" AND t1.PORCENTAJE_ACTUACION = ?");
			params.add(actsubvencionable.getPorcentajeActuacion());
		}
		if (actsubvencionable != null && actsubvencionable.getImporteMinimoInversion() != null) {
			where.append(" AND t1.IMPORTE_MINIMO_INVERSION = ?");
			params.add(actsubvencionable.getImporteMinimoInversion());
		}
		if (actsubvencionable != null && actsubvencionable.getRutaXmlCarga() != null) {
			where.append(" AND t1.RUTA_XML_CARGA = ?");
			params.add(actsubvencionable.getRutaXmlCarga());
		}
		if (actsubvencionable != null && actsubvencionable.getRutaXmlHijoCarga() != null) {
			where.append(" AND t1.RUTA_XML_HIJO_CARGA = ?");
			params.add(actsubvencionable.getRutaXmlHijoCarga());
		}
		if (actsubvencionable != null && actsubvencionable.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(actsubvencionable.getFechaRegistro());
		}
		if (actsubvencionable != null && actsubvencionable.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(actsubvencionable.getUsuarioRegistro());
		}
		if (actsubvencionable != null && actsubvencionable.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(actsubvencionable.getFechaUltmodificacion());
		}
		if (actsubvencionable != null && actsubvencionable.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(actsubvencionable.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ActSubvencionable entity
	 *
	 * @param actsubvencionable
	 *            ActSubvencionable Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ActSubvencionable actsubvencionable, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ActSubvencionableDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (actsubvencionable != null && actsubvencionable.getIdActSub() != null) {
			where.append(" AND t1.ID_ACT_SUB = ?");
			params.add(actsubvencionable.getIdActSub());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(actsubvencionable.getConvocatorias().getIdConvocatoria());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getTiposConvocatoria() != null
				&& actsubvencionable.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t2.ID_TIPO_CONVOCATORIA = ?");
			params.add(actsubvencionable.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getIdProcedimiento() != null) {
			where.append(" AND t2.ID_PROCEDIMIENTO = ?");
			params.add(actsubvencionable.getConvocatorias().getIdProcedimiento());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getConvocatoria() != null) {
			where.append(" AND UPPER(t2.CONVOCATORIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getConvocatorias().getConvocatoria().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getConvocatorias().getConvocatoria().toUpperCase() + "%");
			}
			where.append(" AND t2.CONVOCATORIA IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaResolucion() != null) {
			where.append(" AND t2.FECHA_RESOLUCION = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaResolucion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getImporte() != null) {
			where.append(" AND t2.IMPORTE = ?");
			params.add(actsubvencionable.getConvocatorias().getImporte());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getPorcentajeSubvencion() != null) {
			where.append(" AND t2.PORCENTAJE_SUBVENCION = ?");
			params.add(actsubvencionable.getConvocatorias().getPorcentajeSubvencion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getCantMaxSubvencion() != null) {
			where.append(" AND t2.CANT_MAX_SUBVENCION = ?");
			params.add(actsubvencionable.getConvocatorias().getCantMaxSubvencion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getPlsqlCalculo() != null) {
			where.append(" AND UPPER(t2.PLSQL_CALCULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getConvocatorias().getPlsqlCalculo().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getConvocatorias().getPlsqlCalculo().toUpperCase() + "%");
			}
			where.append(" AND t2.PLSQL_CALCULO IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getPlsqlReparto() != null) {
			where.append(" AND UPPER(t2.PLSQL_REPARTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getConvocatorias().getPlsqlReparto().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getConvocatorias().getPlsqlReparto().toUpperCase() + "%");
			}
			where.append(" AND t2.PLSQL_REPARTO IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getObservaciones() != null) {
			where.append(" AND UPPER(t2.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getConvocatorias().getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getConvocatorias().getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t2.OBSERVACIONES IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaOrdenDia() != null) {
			where.append(" AND t2.FECHA_ORDEN_DIA = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaOrdenDia());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaRegistro());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getConvocatorias().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getConvocatorias().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(actsubvencionable.getConvocatorias().getFechaUltmodificacion());
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getConvocatorias().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getConvocatorias().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getConvocatorias() != null
				&& actsubvencionable.getConvocatorias().getLimiteLocal() != null) {
			where.append(" AND t2.LIMITE_AT = ?");
			params.add(actsubvencionable.getConvocatorias().getLimiteLocal());
		}
		if (actsubvencionable != null && actsubvencionable.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getPorcentajeActuacion() != null) {
			where.append(" AND t1.PORCENTAJE_ACTUACION = ?");
			params.add(actsubvencionable.getPorcentajeActuacion());
		}
		if (actsubvencionable != null && actsubvencionable.getImporteMinimoInversion() != null) {
			where.append(" AND t1.IMPORTE_MINIMO_INVERSION = ?");
			params.add(actsubvencionable.getImporteMinimoInversion());
		}
		if (actsubvencionable != null && actsubvencionable.getRutaXmlCarga() != null) {
			where.append(" AND UPPER(t1.RUTA_XML_CARGA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getRutaXmlCarga().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getRutaXmlCarga().toUpperCase() + "%");
			}
			where.append(" AND t1.RUTA_XML_CARGA IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getRutaXmlHijoCarga() != null) {
			where.append(" AND UPPER(t1.RUTA_XML_HIJO_CARGA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getRutaXmlHijoCarga().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getRutaXmlHijoCarga().toUpperCase() + "%");
			}
			where.append(" AND t1.RUTA_XML_HIJO_CARGA IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(actsubvencionable.getFechaRegistro());
		}
		if (actsubvencionable != null && actsubvencionable.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (actsubvencionable != null && actsubvencionable.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(actsubvencionable.getFechaUltmodificacion());
		}
		if (actsubvencionable != null && actsubvencionable.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(actsubvencionable.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + actsubvencionable.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		where.append(" ORDER BY ORDEN");

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	/**
	 * Busca las act. subvencionables de una convocatoria segun el padre de la
	 * actuacion subvencionable
	 *
	 * @param Idconvocatoria
	 *            Integer
	 * @param idCriterio
	 *            Integer
	 * @return actSubvencionableList
	 */
	@Transactional(readOnly = true)
	public List<ActSubvencionable> findActSubporConvocatoriaPorActSubPadre(Integer Idconvocatoria, Integer idCriterio) {
		String query = "SELECT  t1.ORDEN ORDEN , t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM  ACT_SUBVENCIONABLE t1  WHERE t1.ID_CONVOCATORIA=? AND t1.ID_ACT_SUB_PADRE =? ORDER BY t1.ORDEN";
		List<ActSubvencionable> actSubvencionableList = this.jdbcTemplate.query(query, this.rwMapTipo, Idconvocatoria,
				idCriterio);
		return actSubvencionableList;
	}

	@Override
	public RelExpErrCal obtenerDescripcionActSub(RelExpErrCal relExpErrCal) {
		String query = "SELECT  ORDEN ORDEN, ID_ACT_SUB IDACTSUB, DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = ?";

		List<ActSubvencionable> actSubvencionableList = this.jdbcTemplate.query(query, this.rwMapObtenerActSub,
				relExpErrCal.getErroresCalculo().getActSubvencionable().getIdActSub());

		if (actSubvencionableList.size() != 0) {
			relExpErrCal.getErroresCalculo().getActSubvencionable()
					.setDescripcionCastellano(actSubvencionableList.get(0).getDescripcionCastellano());
			relExpErrCal.getErroresCalculo().getActSubvencionable()
					.setDescripcionEuskera(actSubvencionableList.get(0).getDescripcionEuskera());
		}

		return relExpErrCal;
	}

	@Override
	public List<MarcarInspeccionableAct> findSubActMarcarInspeccionable(Integer idExpediente,
			Convocatorias convocatoria) {
		String query = "SELECT t1.ORDEN ORDEN, t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ENVIADO_INSPECCIONAR ENVIADOINSPACT, t2.INSPECCIONABLE INSPECCIONABLEACT, t2.IMPORTE_ADMITIDO IMPORTEADMITIDOACT, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADOACT, t2. OBSERVACIONES_CASTELLANO OBCASTELLANOACT, t2. OBSERVACIONES_EUSKERA OBEUSKERAACT, t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,  t3.ID_CONCEPTO IDCONCEPTO, t3.ENVIADO_INSPECCIONAR ENVIADOINSPCON, t3.INSPECCIONABLE INSPECCIONABLECON, t3.CONCEPTO CONCEPTOS, t3.IMPORTE_ADMITIDO IMPORTEADMITIDOCON, t3.IMPORTE_PRESENTADO IMPORTEPRESENTADOCON, t3.OBSERVACIONES_CASTELLANO OBCASTELLANOCON, t3.OBSERVACIONES_EUSKERA OBEUSKERACON, t9.TITULO TITULO, t5.NOMBRE NOMBRE,  t5.APELLIDO1 APELLIDO1,  t5.APELLIDO2 APELLIDO2,  t6.NOMBRE NOMBREPC,  t6.APELLIDO1 APELLIDO1PC,  t6.APELLIDO2 APELLIDO2PC FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, ACT_AYUNTAMIENTO t4, CONTRATACIONES_PERSONAL t5, PERSONAS_CONTRATADAS t6, ACT_ASOCIACION t9 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN (SELECT t6.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE t6, EXPEDIENTES t7, CONVOCATORIAS t8 WHERE t6.ID_ACT_SUB_PADRE = t1.ID_ACT_SUB AND t2.ID_EXPEDIENTE = t7.ID_EXPEDIENTE AND t7.ID_PROCEDIMIENTO = t8.ID_PROCEDIMIENTO AND NOT t8.ID_TIPO_AYUDA = "
				+ Constantes.TIPO_AYUDA_CTP
				+ ") AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t5.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t9.ID_REL_EXP_ACT_SUB(+) ORDER BY t1.ORDEN ";
		List<MarcarInspeccionableAct> actSubvencionableList = this.jdbcTemplate.query(query,
				this.rwMapMarcarInspeccionable, idExpediente);

		if (convocatoria.getIdTipoAyuda() != Constantes.TIPO_AYUDA_PTT) {
			for (int i = 0; i < actSubvencionableList.size(); i++) {
				if (actSubvencionableList.size() != 0) {
					if (actSubvencionableList.get(i).getConceptos().getIdConcepto() == 0) {
						actSubvencionableList.remove(i);
						i = i - 1;
					}
				}
			}
		}

		return actSubvencionableList;
	}

	@Override
	public Long findAllLikeCountSubAct(Integer idExpediente, boolean b) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, ACT_AYUNTAMIENTO t4, CONTRATACIONES_PERSONAL t5 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN ( SELECT ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB_PADRE = t1.ID_ACT_SUB) AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t5.ID_REL_EXP_ACT_SUB(+) ");

		return this.jdbcTemplate.queryForLong(query.toString(), idExpediente);
	}

	@Override
	public List<MarcarInspeccionableAct> findSubActMarcarInspeccionableEMCO(Integer idExpediente) {
		String query = "SELECT t1.ORDEN ORDEN, t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ENVIADO_INSPECCIONAR ENVIADOINSPACT, t2.INSPECCIONABLE INSPECCIONABLEACT, t2.IMPORTE_ADMITIDO IMPORTEADMITIDOACT, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADOACT, t2. OBSERVACIONES_INS_CAS OBCASTELLANOACT, t2. OBSERVACIONES_INS_EUS OBEUSKERAACT, t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,  t3.ID_CONCEPTO IDCONCEPTO, t3.ENVIADO_INSPECCIONAR ENVIADOINSPCON, t3.INSPECCIONABLE INSPECCIONABLECON, t3.CONCEPTO CONCEPTOS, t3.IMPORTE_ADMITIDO IMPORTEADMITIDOCON, t3.IMPORTE_PRESENTADO IMPORTEPRESENTADOCON, t3.OBSERVACIONES_CASTELLANO OBCASTELLANOCON, t3.OBSERVACIONES_EUSKERA OBEUSKERACON, t9.TITULO TITULO, t4.TITULO TITULOACTAYUNTAMIENTO, t5.NOMBRE NOMBRE,  t5.APELLIDO1 APELLIDO1,  t5.APELLIDO2 APELLIDO2,  t6.NOMBRE NOMBREPC,  t6.APELLIDO1 APELLIDO1PC,  t6.APELLIDO2 APELLIDO2PC FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, REL_ACT_AYUNTAMIENTO t4, CONTRATACIONES_PERSONAL t5, PERSONAS_CONTRATADAS t6, ACT_ASOCIACION t9 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN (SELECT t6.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE t6, EXPEDIENTES t7, CONVOCATORIAS t8 WHERE t6.ID_ACT_SUB_PADRE = t1.ID_ACT_SUB AND t2.ID_EXPEDIENTE = t7.ID_EXPEDIENTE AND t7.ID_PROCEDIMIENTO = t8.ID_PROCEDIMIENTO AND NOT t8.ID_TIPO_AYUDA = "
				+ Constantes.TIPO_AYUDA_CTP
				+ ") AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t5.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t9.ID_REL_EXP_ACT_SUB(+) ORDER BY t1.ORDEN ";
		List<MarcarInspeccionableAct> actSubvencionableList = this.jdbcTemplate.query(query,
				this.rwMapMarcarInspeccionableEMCO, idExpediente);

		return actSubvencionableList;
	}

	@Override
	public Long findAllLikeCountSubActEMCO(Integer idExpediente, boolean b) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, ACT_AYUNTAMIENTO t4, CONTRATACIONES_PERSONAL t5 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN ( SELECT ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB_PADRE = t1.ID_ACT_SUB) AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t5.ID_REL_EXP_ACT_SUB(+) ");

		return this.jdbcTemplate.queryForLong(query.toString(), idExpediente);
	}

	@Override
	public List<ActSubvencionable> findComboEMCO(Integer idConvocatoria, Integer idActSubHijo) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.PORCENTAJE_ACTUACION PORCENTAJEACTUACION FROM ACT_SUBVENCIONABLE t1 WHERE t1.ID_CONVOCATORIA = ? AND t1.ID_ACT_SUB_PADRE IN (SELECT t1.ID_ACT_SUB FROM ACT_SUBVENCIONABLE t1 WHERE t1.ID_CONVOCATORIA = ? AND t1.ID_ACT_SUB_PADRE = (SELECT t1.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE t1 WHERE t1.ID_ACT_SUB = ?))");

		return (List<ActSubvencionable>) this.jdbcTemplate.query(query.toString(), this.rwMapPorcentaje, idConvocatoria,
				idConvocatoria, idActSubHijo);
	}

	@Override
	public List<ActSubvencionable> getAccionSubvencionableAsoEMCONieto(Integer idActSub, Integer idExpediente) {
		String query = "SELECT T1.ORDEN ORDEN, T1.ID_ACT_SUB IDACTSUB, T1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM ACT_SUBVENCIONABLE T1 WHERE ID_ACT_SUB_PADRE = ? AND T1.ID_ACT_SUB NOT IN (SELECT ID_ACT_SUB FROM REL_EXP_ACT_SUB WHERE ID_EXPEDIENTE = ?) ORDER BY ORDEN";
		return (List<ActSubvencionable>) this.jdbcTemplate.query(query, this.rwMapTipo, idActSub, idExpediente);
	}

	@Override
	public List<MarcarInspeccionableAct> findSubActMarcarInspeccionableDEC(Integer idExpediente,
			Convocatorias convocatoria, Integer idActSubPadre) {

		String query = "SELECT t1.ORDEN ORDEN, t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ENVIADO_INSPECCIONAR ENVIADOINSPACT, t2.INSPECCIONABLE INSPECCIONABLEACT, t2.IMPORTE_ADMITIDO IMPORTEADMITIDOACT, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADOACT, t2. OBSERVACIONES_INS_CAS OBCASTELLANOACT, t2. OBSERVACIONES_INS_EUS OBEUSKERAACT, t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,  t3.ID_CONCEPTO IDCONCEPTO, t3.ENVIADO_INSPECCIONAR ENVIADOINSPCON, t3.INSPECCIONABLE INSPECCIONABLECON, t3.CONCEPTO CONCEPTOS, t3.IMPORTE_ADMITIDO IMPORTEADMITIDOCON, t3.IMPORTE_PRESENTADO IMPORTEPRESENTADOCON, t3.OBSERVACIONES_CASTELLANO OBCASTELLANOCON, t3.OBSERVACIONES_EUSKERA OBEUSKERACON, t9.TITULO TITULO, t4.TITULO TITULOACTAYUNTAMIENTO, t5.NOMBRE NOMBRE,  t5.APELLIDO1 APELLIDO1,  t5.APELLIDO2 APELLIDO2,  t6.NOMBRE NOMBREPC,  t6.APELLIDO1 APELLIDO1PC,  t6.APELLIDO2 APELLIDO2PC FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, ACT_AYUNTAMIENTO t4, CONTRATACIONES_PERSONAL t5, PERSONAS_CONTRATADAS t6, ACT_ASOCIACION t9 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN (SELECT t6.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE t6, EXPEDIENTES t7, CONVOCATORIAS t8 WHERE t6.ID_ACT_SUB_PADRE = t1.ID_ACT_SUB AND t2.ID_EXPEDIENTE = t7.ID_EXPEDIENTE AND t7.ID_PROCEDIMIENTO = t8.ID_PROCEDIMIENTO AND NOT t8.ID_TIPO_AYUDA = "
				+ Constantes.TIPO_AYUDA_CTP
				+ ") AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t5.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t9.ID_REL_EXP_ACT_SUB(+) ORDER BY t1.ORDEN ";
		List<MarcarInspeccionableAct> actSubvencionableList = this.jdbcTemplate.query(query,
				this.rwMapMarcarInspeccionableDEC, idExpediente);

		if (idActSubPadre == Constantes.DEC_ASOCIACION) {
			for (int i = 0; i < actSubvencionableList.size(); i++) {
				if (actSubvencionableList.size() != 0) {
					if (actSubvencionableList.get(i).getConceptos().getIdConcepto() == 0
							|| actSubvencionableList.get(i).getConceptos().getConcepto() == null) {
						actSubvencionableList.remove(i);
						i = i - 1;
					}
				}
			}
		}

		return actSubvencionableList;
	}
}