package com.ejie.ab60.dao.actuacionesSubvencionables;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotDen;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelActSubMotDenDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelActSubMotDenDaoImpl implements RelActSubMotDenDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELACTSUBMOTDEN", "IDRELEXPACTSUB",
			"IDMOTIVODENEGACION", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelActSubMotDen> rwMap = new RowMapper<RelActSubMotDen>() {
		public RelActSubMotDen mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubMotDen(resultSet.getInt("IDRELACTSUBMOTDEN"), resultSet.getInt("IDRELEXPACTSUB"),
					resultSet.getLong("IDMOTIVODENEGACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<RelActSubMotDen> rwMapfindIdsMotivosDenegaciones = new RowMapper<RelActSubMotDen>() {
		public RelActSubMotDen mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubMotDen(null, null, resultSet.getLong("IDMOTIVODENEGACION"), null, null, null, null);
		}
	};

	private RowMapper<RelActSubMotDen> rwMapPK = new RowMapper<RelActSubMotDen>() {
		public RelActSubMotDen mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubMotDen(resultSet.getInt("IDRELACTSUBMOTDEN"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelActSubMotDen>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelActSubMotDen>>() {
		public JerarquiaDto<RelActSubMotDen> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelActSubMotDen relactsubmotden = new RelActSubMotDen(resultSet.getInt("IDRELACTSUBMOTDEN"),
					resultSet.getInt("IDRELEXPACTSUB"), resultSet.getLong("IDMOTIVODENEGACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<RelActSubMotDen> jerarquia = new JerarquiaDto<RelActSubMotDen>();
			jerarquia.setModel(relactsubmotden);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelActSubMotDen table.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @return RelActSubMotDen
	 */
	public RelActSubMotDen add(RelActSubMotDen relactsubmotden) {
		String query = "INSERT INTO REL_ACT_SUB_MOT_DEN (ID_REL_ACT_SUB_MOT_DEN, ID_REL_EXP_ACT_SUB, ID_MOTIVO_DENEGACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6066T00.NEXTVAL,?,?,?,?)";
		this.jdbcTemplate.update(query, relactsubmotden.getIdRelExpActSub(), relactsubmotden.getIdMotivoDenegacion(),
				relactsubmotden.getFechaRegistro(), relactsubmotden.getUsuarioRegistro());
		return relactsubmotden;
	}

	/**
	 * Updates a single row in the RelActSubMotDen table.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @return RelActSubMotDen
	 */
	public RelActSubMotDen update(RelActSubMotDen relactsubmotden) {
		String query = "UPDATE REL_ACT_SUB_MOT_DEN SET ID_REL_EXP_ACT_SUB=?, ID_MOTIVO_DENEGACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_ACT_SUB_MOT_DEN=?";
		this.jdbcTemplate.update(query, relactsubmotden.getIdRelExpActSub(), relactsubmotden.getIdMotivoDenegacion(),
				relactsubmotden.getFechaRegistro(), relactsubmotden.getUsuarioRegistro(),
				relactsubmotden.getFechaUltmodificacion(), relactsubmotden.getUsuarioUltmodificacion(),
				relactsubmotden.getIdRelActSubMotDen());
		return relactsubmotden;
	}

	/**
	 * Finds a single row in the RelActSubMotDen table.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @return RelActSubMotDen
	 */
	@Transactional(readOnly = true)
	public RelActSubMotDen find(RelActSubMotDen relactsubmotden) {
		String query = "SELECT t1.ID_REL_ACT_SUB_MOT_DEN IDRELACTSUBMOTDEN, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM REL_ACT_SUB_MOT_DEN t1  WHERE t1.ID_REL_ACT_SUB_MOT_DEN = ?  ";

		List<RelActSubMotDen> relactsubmotdenList = this.jdbcTemplate.query(query, this.rwMap,
				relactsubmotden.getIdRelActSubMotDen());
		return (RelActSubMotDen) DataAccessUtils.uniqueResult(relactsubmotdenList);
	}

	/**
	 * Saca los ids de motivos de denegacion
	 *
	 * @param idRelActSubMotDen
	 *            Integer
	 * 
	 * @return List<RelActSubMotDen>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubMotDen> findIdsMotivosDenegaciones(Integer idRelActSubMotDen) {
		String query = "SELECT  t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION FROM REL_ACT_SUB_MOT_DEN t1, MOTIVOS_DENEGACION t2 WHERE t1.ID_MOTIVO_DENEGACION = t2.ID_MOTIVO_DENEGACION AND t1.ID_REL_EXP_ACT_SUB = ? AND t2.ORIGEN = 1";
		List<RelActSubMotDen> relactsubmotdenList = this.jdbcTemplate.query(query, this.rwMapfindIdsMotivosDenegaciones,
				idRelActSubMotDen);
		return relactsubmotdenList;
	}

	/**
	 * Removes a single row in the RelActSubMotDen table.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @return
	 */
	public void remove(RelActSubMotDen relactsubmotden, Integer origen) {
		String query = "DELETE FROM REL_ACT_SUB_MOT_DEN WHERE ID_REL_ACT_SUB_MOT_DEN IN (SELECT ID_REL_ACT_SUB_MOT_DEN FROM REL_ACT_SUB_MOT_DEN, MOTIVOS_DENEGACION WHERE REL_ACT_SUB_MOT_DEN.ID_MOTIVO_DENEGACION = MOTIVOS_DENEGACION.ID_MOTIVO_DENEGACION AND ID_REL_EXP_ACT_SUB=? AND ORIGEN =?)";
		this.jdbcTemplate.update(query, relactsubmotden.getIdRelExpActSub(), origen);
	}

	/**
	 * Finds a list of rows in the RelActSubMotDen table.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelActSubMotDen>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubMotDen> findAll(RelActSubMotDen relactsubmotden, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_ACT_SUB_MOT_DEN IDRELACTSUBMOTDEN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_ACT_SUB_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relactsubmotden);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					RelActSubMotDenDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelActSubMotDen>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelActSubMotDen table using like.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelActSubMotDen>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubMotDen> findAllLike(RelActSubMotDen relactsubmotden, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_ACT_SUB_MOT_DEN IDRELACTSUBMOTDEN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_ACT_SUB_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					RelActSubMotDenDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelActSubMotDen>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelActSubMotDen table.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelActSubMotDen relactsubmotden) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_ACT_SUB_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relactsubmotden);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelActSubMotDen table using like.
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelActSubMotDen relactsubmotden, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_ACT_SUB_MOT_DEN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelActSubMotDen selected for rup_table
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelActSubMotDen>>
	 */
	@Override
	public List<TableRowDto<RelActSubMotDen>> reorderSelection(RelActSubMotDen relactsubmotden,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_DEN IDRELACTSUBMOTDEN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_ACT_SUB_MOT_DEN t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				RelActSubMotDen.class, filterParamList, "ID_REL_ACT_SUB_MOT_DEN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelActSubMotDen>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelActSubMotDen
	 * @param searchParams
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelActSubMotDen>>
	 */
	@Override
	public List<TableRowDto<RelActSubMotDen>> search(RelActSubMotDen filterParams, RelActSubMotDen searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_DEN IDRELACTSUBMOTDEN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_ACT_SUB_MOT_DEN t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				RelActSubMotDen.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_REL_ACT_SUB_MOT_DEN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelActSubMotDen>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelactsubmotden
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelActSubMotDen filterrelactsubmotden, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_DEN IDRELACTSUBMOTDEN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_ACT_SUB_MOT_DEN t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelactsubmotden, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				RelActSubMotDen.class, query, params, "ID_REL_ACT_SUB_MOT_DEN");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelActSubMotDen table.
	 *
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelActSubMotDen>>
	 */
	@Override
	public List<JerarquiaDto<RelActSubMotDen>> findAllLikeJerarquia(RelActSubMotDen filterRelActSubMotDen,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_DEN IDRELACTSUBMOTDEN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_MOT_DEN t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_MOT_DEN");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubMotDen, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_ACT_SUB_MOT_DEN",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelActSubMotDenDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelActSubMotDen filterRelActSubMotDen, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_MOT_DEN t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_MOT_DEN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubMotDen, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_REL_ACT_SUB_MOT_DEN", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelActSubMotDen>>
	 */
	@Override
	public List<TableRowDto<RelActSubMotDen>> findAllChild(RelActSubMotDen filterRelActSubMotDen,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_MOT_DEN t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_MOT_DEN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubMotDen, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_REL_ACT_SUB_MOT_DEN", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelActSubMotDen>(this.rwMapPK, "ID_REL_ACT_SUB_MOT_DEN"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelActSubMotDen entity
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelActSubMotDen relactsubmotden) {

		StringBuilder where = new StringBuilder(RelActSubMotDenDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relactsubmotden != null && relactsubmotden.getIdRelActSubMotDen() != null) {
			where.append(" AND t1.ID_REL_ACT_SUB_MOT_DEN = ?");
			params.add(relactsubmotden.getIdRelActSubMotDen());
		}
		if (relactsubmotden != null && relactsubmotden.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relactsubmotden.getIdRelExpActSub());
		}
		if (relactsubmotden != null && relactsubmotden.getIdMotivoDenegacion() != null) {
			where.append(" AND t1.ID_MOTIVO_DENEGACION = ?");
			params.add(relactsubmotden.getIdMotivoDenegacion());
		}
		if (relactsubmotden != null && relactsubmotden.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relactsubmotden.getFechaRegistro());
		}
		if (relactsubmotden != null && relactsubmotden.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relactsubmotden.getUsuarioRegistro());
		}
		if (relactsubmotden != null && relactsubmotden.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relactsubmotden.getFechaUltmodificacion());
		}
		if (relactsubmotden != null && relactsubmotden.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(relactsubmotden.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelActSubMotDen entity
	 *
	 * @param relactsubmotden
	 *            RelActSubMotDen Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelActSubMotDen relactsubmotden, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelActSubMotDenDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relactsubmotden != null && relactsubmotden.getIdRelActSubMotDen() != null) {
			where.append(" AND t1.ID_REL_ACT_SUB_MOT_DEN = ?");
			params.add(relactsubmotden.getIdRelActSubMotDen());
		}
		if (relactsubmotden != null && relactsubmotden.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relactsubmotden.getIdRelExpActSub());
		}
		if (relactsubmotden != null && relactsubmotden.getIdMotivoDenegacion() != null) {
			where.append(" AND t1.ID_MOTIVO_DENEGACION = ?");
			params.add(relactsubmotden.getIdMotivoDenegacion());
		}
		if (relactsubmotden != null && relactsubmotden.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relactsubmotden.getFechaRegistro());
		}
		if (relactsubmotden != null && relactsubmotden.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relactsubmotden.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relactsubmotden.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relactsubmotden != null && relactsubmotden.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relactsubmotden.getFechaUltmodificacion());
		}
		if (relactsubmotden != null && relactsubmotden.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relactsubmotden.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relactsubmotden.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
