package com.ejie.ab60.dao.actuacionesSubvencionables;

import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotMin;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * RelActSubMotMinDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelActSubMotMinDaoImpl implements RelActSubMotMinDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELACTSUBMOTMIN", "IDRELEXPACTSUB",
			"IDMOTIVOMINORACION", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelActSubMotMin> rwMap = new RowMapper<RelActSubMotMin>() {
		public RelActSubMotMin mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubMotMin(resultSet.getInt("IDRELACTSUBMOTMIN"), resultSet.getInt("IDRELEXPACTSUB"),
					resultSet.getLong("IDMOTIVOMINORACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<RelActSubMotMin> rwMapfindIdsMotivosMinoraciones = new RowMapper<RelActSubMotMin>() {
		public RelActSubMotMin mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubMotMin(null, null, resultSet.getLong("IDMOTIVOMINORACION"), null, null, null, null);
		}
	};

	private RowMapper<RelActSubMotMin> rwMapPK = new RowMapper<RelActSubMotMin>() {
		public RelActSubMotMin mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubMotMin(resultSet.getInt("IDRELACTSUBMOTMIN"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelActSubMotMin>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelActSubMotMin>>() {
		public JerarquiaDto<RelActSubMotMin> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelActSubMotMin relactsubmotmin = new RelActSubMotMin(resultSet.getInt("IDRELACTSUBMOTMIN"),
					resultSet.getInt("IDRELEXPACTSUB"), resultSet.getLong("IDMOTIVOMINORACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<RelActSubMotMin> jerarquia = new JerarquiaDto<RelActSubMotMin>();
			jerarquia.setModel(relactsubmotmin);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelActSubMotMin table.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @return RelActSubMotMin
	 */
	public RelActSubMotMin add(RelActSubMotMin relactsubmotmin) {
		String query = "INSERT INTO REL_ACT_SUB_MOT_MIN (ID_REL_ACT_SUB_MOT_MIN, ID_REL_EXP_ACT_SUB, ID_MOTIVO_MINORACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6065T00.NEXTVAL,?,?,?,?)";
		this.jdbcTemplate.update(query, relactsubmotmin.getIdRelExpActSub(), relactsubmotmin.getIdMotivoMinoracion(),
				relactsubmotmin.getFechaRegistro(), relactsubmotmin.getUsuarioRegistro());
		return relactsubmotmin;
	}

	/**
	 * Updates a single row in the RelActSubMotMin table.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @return RelActSubMotMin
	 */
	public RelActSubMotMin update(RelActSubMotMin relactsubmotmin) {
		String query = "UPDATE REL_ACT_SUB_MOT_MIN SET ID_REL_EXP_ACT_SUB=?, ID_MOTIVO_MINORACION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_ACT_SUB_MOT_MIN=?";
		this.jdbcTemplate.update(query, relactsubmotmin.getIdRelExpActSub(), relactsubmotmin.getIdMotivoMinoracion(),
				relactsubmotmin.getFechaRegistro(), relactsubmotmin.getUsuarioRegistro(),
				relactsubmotmin.getFechaUltmodificacion(), relactsubmotmin.getUsuarioUltmodificacion(),
				relactsubmotmin.getIdRelActSubMotMin());
		return relactsubmotmin;
	}

	/**
	 * Finds a single row in the RelActSubMotMin table.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @return RelActSubMotMin
	 */
	@Transactional(readOnly = true)
	public RelActSubMotMin find(RelActSubMotMin relactsubmotmin) {
		String query = "SELECT t1.ID_REL_ACT_SUB_MOT_MIN IDRELACTSUBMOTMIN, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM REL_ACT_SUB_MOT_MIN t1  WHERE t1.ID_REL_ACT_SUB_MOT_MIN = ?  ";

		List<RelActSubMotMin> relactsubmotminList = this.jdbcTemplate.query(query, this.rwMap,
				relactsubmotmin.getIdRelActSubMotMin());
		return (RelActSubMotMin) DataAccessUtils.uniqueResult(relactsubmotminList);
	}

	/**
	 * Saca los id de motivos de minoracion
	 *
	 * @param idRelActSubMotMin
	 *            Integer
	 * 
	 * @return List<RelActSubMotMin>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubMotMin> findIdsMotivosMinoraciones(Integer idRelActSubMotMin,
			Integer origenMotivosMinoracion) {
		String query = "SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION FROM REL_ACT_SUB_MOT_MIN t1, MOTIVOS_MINORACION t2  WHERE t1.ID_MOTIVO_MINORACION = t2.ID_MOTIVO_MINORACION AND t1.ID_REL_EXP_ACT_SUB = ?  AND t2.ORIGEN = ?";
		List<RelActSubMotMin> relactsubmotminList = this.jdbcTemplate.query(query, this.rwMapfindIdsMotivosMinoraciones,
				idRelActSubMotMin, origenMotivosMinoracion);
		return relactsubmotminList;
	}

	/**
	 * Removes a single row in the RelActSubMotMin table.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @return
	 */
	public void remove(RelActSubMotMin relactsubmotmin, Integer origen) {
		String query = "DELETE FROM REL_ACT_SUB_MOT_MIN WHERE ID_REL_ACT_SUB_MOT_MIN IN (SELECT ID_REL_ACT_SUB_MOT_MIN FROM REL_ACT_SUB_MOT_MIN, MOTIVOS_MINORACION WHERE REL_ACT_SUB_MOT_MIN.ID_MOTIVO_MINORACION = MOTIVOS_MINORACION.ID_MOTIVO_MINORACION AND ID_REL_EXP_ACT_SUB = ? AND ORIGEN = ?)";
		this.jdbcTemplate.update(query, relactsubmotmin.getIdRelExpActSub(), origen);
	}

	/**
	 * Finds a list of rows in the RelActSubMotMin table.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelActSubMotMin>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubMotMin> findAll(RelActSubMotMin relactsubmotmin, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_ACT_SUB_MOT_MIN IDRELACTSUBMOTMIN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_ACT_SUB_MOT_MIN t1 , MOTIVOS_MINORACION t2");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relactsubmotmin);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					RelActSubMotMinDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelActSubMotMin>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelActSubMotMin table using like.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelActSubMotMin>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubMotMin> findAllLike(RelActSubMotMin relactsubmotmin, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_ACT_SUB_MOT_MIN IDRELACTSUBMOTMIN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REL_ACT_SUB_MOT_MIN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					RelActSubMotMinDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelActSubMotMin>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelActSubMotMin table.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelActSubMotMin relactsubmotmin) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_ACT_SUB_MOT_MIN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relactsubmotmin);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelActSubMotMin table using like.
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelActSubMotMin relactsubmotmin, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_ACT_SUB_MOT_MIN t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelActSubMotMin selected for rup_table
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelActSubMotMin>>
	 */
	@Override
	public List<TableRowDto<RelActSubMotMin>> reorderSelection(RelActSubMotMin relactsubmotmin,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_MIN IDRELACTSUBMOTMIN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_ACT_SUB_MOT_MIN t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				RelActSubMotMin.class, filterParamList, "ID_REL_ACT_SUB_MOT_MIN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelActSubMotMin>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelActSubMotMin
	 * @param searchParams
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelActSubMotMin>>
	 */
	@Override
	public List<TableRowDto<RelActSubMotMin>> search(RelActSubMotMin filterParams, RelActSubMotMin searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_MIN IDRELACTSUBMOTMIN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_ACT_SUB_MOT_MIN t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				RelActSubMotMin.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_REL_ACT_SUB_MOT_MIN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelActSubMotMin>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelactsubmotmin
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelActSubMotMin filterrelactsubmotmin, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_MIN IDRELACTSUBMOTMIN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REL_ACT_SUB_MOT_MIN t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelactsubmotmin, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				RelActSubMotMin.class, query, params, "ID_REL_ACT_SUB_MOT_MIN");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelActSubMotMin table.
	 *
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelActSubMotMin>>
	 */
	@Override
	public List<JerarquiaDto<RelActSubMotMin>> findAllLikeJerarquia(RelActSubMotMin filterRelActSubMotMin,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_MOT_MIN IDRELACTSUBMOTMIN,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_MOT_MIN t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_MOT_MIN");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubMotMin, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_ACT_SUB_MOT_MIN",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelActSubMotMinDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelActSubMotMin filterRelActSubMotMin, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_MOT_MIN t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_MOT_MIN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubMotMin, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_REL_ACT_SUB_MOT_MIN", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelActSubMotMin>>
	 */
	@Override
	public List<TableRowDto<RelActSubMotMin>> findAllChild(RelActSubMotMin filterRelActSubMotMin,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_MOT_MIN t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_MOT_MIN");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubMotMin, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_REL_ACT_SUB_MOT_MIN", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelActSubMotMin>(this.rwMapPK, "ID_REL_ACT_SUB_MOT_MIN"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelActSubMotMin entity
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelActSubMotMin relactsubmotmin) {

		StringBuilder where = new StringBuilder(RelActSubMotMinDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relactsubmotmin != null && relactsubmotmin.getIdRelActSubMotMin() != null) {
			where.append(" AND t1.ID_REL_ACT_SUB_MOT_MIN = ?");
			params.add(relactsubmotmin.getIdRelActSubMotMin());
		}
		if (relactsubmotmin != null && relactsubmotmin.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relactsubmotmin.getIdRelExpActSub());
		}
		if (relactsubmotmin != null && relactsubmotmin.getIdMotivoMinoracion() != null) {
			where.append(" AND t1.ID_MOTIVO_MINORACION = ?");
			params.add(relactsubmotmin.getIdMotivoMinoracion());
		}
		if (relactsubmotmin != null && relactsubmotmin.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relactsubmotmin.getFechaRegistro());
		}
		if (relactsubmotmin != null && relactsubmotmin.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relactsubmotmin.getUsuarioRegistro());
		}
		if (relactsubmotmin != null && relactsubmotmin.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relactsubmotmin.getFechaUltmodificacion());
		}
		if (relactsubmotmin != null && relactsubmotmin.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(relactsubmotmin.getUsuarioUltmodificacion());
		}
		if (relactsubmotmin != null && relactsubmotmin.getOrigen() != null) {
			where.append(" AND t1.ID_MOTIVO_MINORACION = t2.ID_MOTIVO_MINORACION AND t2.ORIGEN = ?");
			params.add(relactsubmotmin.getOrigen());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelActSubMotMin entity
	 *
	 * @param relactsubmotmin
	 *            RelActSubMotMin Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelActSubMotMin relactsubmotmin, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelActSubMotMinDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relactsubmotmin != null && relactsubmotmin.getIdRelActSubMotMin() != null) {
			where.append(" AND t1.ID_REL_ACT_SUB_MOT_MIN = ?");
			params.add(relactsubmotmin.getIdRelActSubMotMin());
		}
		if (relactsubmotmin != null && relactsubmotmin.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relactsubmotmin.getIdRelExpActSub());
		}
		if (relactsubmotmin != null && relactsubmotmin.getIdMotivoMinoracion() != null) {
			where.append(" AND t1.ID_MOTIVO_MINORACION = ?");
			params.add(relactsubmotmin.getIdMotivoMinoracion());
		}
		if (relactsubmotmin != null && relactsubmotmin.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relactsubmotmin.getFechaRegistro());
		}
		if (relactsubmotmin != null && relactsubmotmin.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relactsubmotmin.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relactsubmotmin.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relactsubmotmin != null && relactsubmotmin.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relactsubmotmin.getFechaUltmodificacion());
		}
		if (relactsubmotmin != null && relactsubmotmin.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relactsubmotmin.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relactsubmotmin.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
