package com.ejie.ab60.dao.actuacionesSubvencionables;

import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubSubact;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * RelActSubSubactDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelActSubSubactDaoImpl implements RelActSubSubactDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELACTSUBSUBACT", "IDRELEXPACTSUB", "IDACTSUB",
			"FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelActSubSubact> rwMap = new RowMapper<RelActSubSubact>() {
		public RelActSubSubact mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubSubact(resultSet.getInt("IDRELACTSUBSUBACT"), resultSet.getInt("IDRELEXPACTSUB"),
					resultSet.getInt("IDACTSUB"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<RelActSubSubact> rwMapPKidActSub = new RowMapper<RelActSubSubact>() {
		public RelActSubSubact mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelActSubSubact relActSubSubact = new RelActSubSubact();
			relActSubSubact.setIdRelActSubSubact(resultSet.getInt("IDRELACTSUBSUBACT"));
			relActSubSubact.setIdActSub(resultSet.getInt("IDACTSUB"));

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			relActSubSubact.setActSubvencionable(actSubvencionable);

			return relActSubSubact;

		}
	};

	private RowMapper<RelActSubSubact> rwMapPK = new RowMapper<RelActSubSubact>() {
		public RelActSubSubact mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelActSubSubact(resultSet.getInt("IDRELACTSUBSUBACT"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelActSubSubact>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelActSubSubact>>() {
		public JerarquiaDto<RelActSubSubact> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelActSubSubact relactsubsubact = new RelActSubSubact(resultSet.getInt("IDRELACTSUBSUBACT"),
					resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("IDACTSUB"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<RelActSubSubact> jerarquia = new JerarquiaDto<RelActSubSubact>();
			jerarquia.setModel(relactsubsubact);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelActSubSubact table.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @return RelActSubSubact
	 */
	public RelActSubSubact add(RelActSubSubact relactsubsubact) {
		String query = "INSERT INTO REL_ACT_SUB_SUBACT (ID_REL_ACT_SUB_SUBACT, ID_REL_EXP_ACT_SUB, ID_ACT_SUB, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6052T00.NEXTVAL,?,?,?,?)";
		Object getIdRelExpActSubAux = null;
		if (relactsubsubact.getActSubvencionable() != null
				&& relactsubsubact.getActSubvencionable().getIdActSub() != null) {
			getIdRelExpActSubAux = relactsubsubact.getActSubvencionable().getIdActSub();
		}

		this.jdbcTemplate.update(query, relactsubsubact.getIdRelExpActSub(), getIdRelExpActSubAux,
				relactsubsubact.getFechaRegistro(), relactsubsubact.getUsuarioRegistro());
		return relactsubsubact;
	}

	/**
	 * Updates a single row in the RelActSubSubact table.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @return RelActSubSubact
	 */
	public RelActSubSubact update(RelActSubSubact relactsubsubact) {
		String query = "UPDATE REL_ACT_SUB_SUBACT SET ID_REL_EXP_ACT_SUB=?, ID_ACT_SUB=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_REL_ACT_SUB_SUBACT=?";
		this.jdbcTemplate.update(query, relactsubsubact.getIdRelExpActSub(), relactsubsubact.getIdActSub(),
				relactsubsubact.getFechaRegistro(), relactsubsubact.getUsuarioRegistro(),
				relactsubsubact.getIdRelActSubSubact());
		return relactsubsubact;
	}

	/**
	 * Finds a single row in the RelActSubSubact table.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @return RelActSubSubact
	 */
	@Transactional(readOnly = true)
	public RelActSubSubact find(RelActSubSubact relactsubsubact) {
		String query = "SELECT t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ID_ACT_SUB IDACTSUB, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_ACT_SUB_SUBACT t1  WHERE t1.ID_REL_ACT_SUB_SUBACT = ?  ";

		List<RelActSubSubact> relactsubsubactList = this.jdbcTemplate.query(query, this.rwMap,
				relactsubsubact.getIdRelActSubSubact());
		return (RelActSubSubact) DataAccessUtils.uniqueResult(relactsubsubactList);
	}

	/**
	 * Removes a single row in the RelActSubSubact table.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @return
	 */
	public void remove(RelActSubSubact relactsubsubact) {
		String query = "DELETE FROM REL_ACT_SUB_SUBACT WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, relactsubsubact.getIdRelExpActSub());
	}

	/**
	 * Encuentra los id de las actuaciones subvencionable dado un id
	 *
	 * @param Integer
	 *            idRelacion
	 * @return relactsubsubactList
	 */
	@Transactional(readOnly = true)
	public List<RelActSubSubact> findIdActSubSubact(Integer idRelacion) {

		String query = "SELECT  t2.ORDEN ORDEN ,t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT , t1.ID_ACT_SUB IDACTSUB FROM REL_ACT_SUB_SUBACT t1 , ACT_SUBVENCIONABLE t2 WHERE t1.ID_REL_EXP_ACT_SUB=? and t1.ID_ACT_SUB = t2.ID_ACT_SUB ORDER BY t2.ORDEN";

		List<RelActSubSubact> relactsubsubactList = this.jdbcTemplate.query(query, this.rwMapPKidActSub, idRelacion);

		return relactsubsubactList;
	}

	/**
	 * Finds a list of rows in the RelActSubSubact table.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelActSubSubact>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubSubact> findAll(RelActSubSubact relactsubsubact, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_ACT_SUB IDACTSUB,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_ACT_SUB_SUBACT t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relactsubsubact);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					RelActSubSubactDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelActSubSubact>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelActSubSubact table using like.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelActSubSubact>
	 */
	@Transactional(readOnly = true)
	public List<RelActSubSubact> findAllLike(RelActSubSubact relactsubsubact, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_ACT_SUB IDACTSUB,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_ACT_SUB_SUBACT t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubsubact, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					RelActSubSubactDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelActSubSubact>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelActSubSubact table.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelActSubSubact relactsubsubact) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_ACT_SUB_SUBACT t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relactsubsubact);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelActSubSubact table using like.
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelActSubSubact relactsubsubact, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_ACT_SUB_SUBACT t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubsubact, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelActSubSubact selected for rup_table
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelActSubSubact>>
	 */
	@Override
	public List<TableRowDto<RelActSubSubact>> reorderSelection(RelActSubSubact relactsubsubact,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_ACT_SUB IDACTSUB,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_ACT_SUB_SUBACT t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relactsubsubact, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				RelActSubSubact.class, filterParamList, "ID_REL_ACT_SUB_SUBACT");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelActSubSubact>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelActSubSubact
	 * @param searchParams
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelActSubSubact>>
	 */
	@Override
	public List<TableRowDto<RelActSubSubact>> search(RelActSubSubact filterParams, RelActSubSubact searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_ACT_SUB IDACTSUB,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_ACT_SUB_SUBACT t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				RelActSubSubact.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_REL_ACT_SUB_SUBACT");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelActSubSubact>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelactsubsubact
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelActSubSubact filterrelactsubsubact, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_ACT_SUB IDACTSUB,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_ACT_SUB_SUBACT t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelactsubsubact, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				RelActSubSubact.class, query, params, "ID_REL_ACT_SUB_SUBACT");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelActSubSubact table.
	 *
	 * @param filterRelActSubSubact
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelActSubSubact>>
	 */
	@Override
	public List<JerarquiaDto<RelActSubSubact>> findAllLikeJerarquia(RelActSubSubact filterRelActSubSubact,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_ACT_SUB_SUBACT IDRELACTSUBSUBACT,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_ACT_SUB IDACTSUB,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_SUBACT t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_SUBACT");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubSubact, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_ACT_SUB_SUBACT", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelActSubSubactDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelActSubSubact
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelActSubSubact filterRelActSubSubact, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_SUBACT t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_SUBACT");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubSubact, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_ACT_SUB_SUBACT",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelActSubSubact
	 *            RelActSubSubact
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelActSubSubact>>
	 */
	@Override
	public List<TableRowDto<RelActSubSubact>> findAllChild(RelActSubSubact filterRelActSubSubact,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_ACT_SUB_SUBACT t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("REL_ACT_SUB_SUBACT");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelActSubSubact, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_REL_ACT_SUB_SUBACT", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelActSubSubact>(this.rwMapPK, "ID_REL_ACT_SUB_SUBACT"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelActSubSubact entity
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelActSubSubact relactsubsubact) {

		StringBuilder where = new StringBuilder(RelActSubSubactDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relactsubsubact != null && relactsubsubact.getIdRelActSubSubact() != null) {
			where.append(" AND t1.ID_REL_ACT_SUB_SUBACT = ?");
			params.add(relactsubsubact.getIdRelActSubSubact());
		}
		if (relactsubsubact != null && relactsubsubact.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relactsubsubact.getIdRelExpActSub());
		}
		if (relactsubsubact != null && relactsubsubact.getIdActSub() != null) {
			where.append(" AND t1.ID_ACT_SUB = ?");
			params.add(relactsubsubact.getIdActSub());
		}
		if (relactsubsubact != null && relactsubsubact.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relactsubsubact.getFechaRegistro());
		}
		if (relactsubsubact != null && relactsubsubact.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relactsubsubact.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelActSubSubact entity
	 *
	 * @param relactsubsubact
	 *            RelActSubSubact Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelActSubSubact relactsubsubact, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelActSubSubactDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relactsubsubact != null && relactsubsubact.getIdRelActSubSubact() != null) {
			where.append(" AND t1.ID_REL_ACT_SUB_SUBACT = ?");
			params.add(relactsubsubact.getIdRelActSubSubact());
		}
		if (relactsubsubact != null && relactsubsubact.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relactsubsubact.getIdRelExpActSub());
		}
		if (relactsubsubact != null && relactsubsubact.getIdActSub() != null) {
			where.append(" AND t1.ID_ACT_SUB = ?");
			params.add(relactsubsubact.getIdActSub());
		}
		if (relactsubsubact != null && relactsubsubact.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relactsubsubact.getFechaRegistro());
		}
		if (relactsubsubact != null && relactsubsubact.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relactsubsubact.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relactsubsubact.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
