package com.ejie.ab60.dao.actuacionesSubvencionables;

import java.math.BigDecimal;
import java.util.List;

import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpActSubDao  
 * 
 *  
 */

public interface RelExpActSubDao {

	/**
	 * Finds el ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub findUltimoId();

	/**
	 * Sumo todos los importes de las Relaciones hijos de un expediente sin su
	 * padre.
	 *
	 * @param idExpediente
	 *            Integer
	 * @return RelExpActSub
	 */

	RelExpActSub findRelExpActHijosPorExpediente(Integer idExpediente);

	/**
	 * Finds el siguiente al ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param idExpediente
	 *            idExpediente
	 * @return Integer
	 */
	RelExpActSub findLastId(Integer idExpediente, Integer idActSub);

	/**
	 * Finds el siguiente al ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param idExpediente
	 *            idExpediente
	 * @return Integer
	 */
	RelExpActSub findRelExpActSub(Integer idActSub, Integer idExpediente);

	/**
	 * Finds DEC.
	 *
	 * @param idExpediente
	 *            idExpediente
	 * @return Integer
	 */
	RelExpActSub findDEC(RelExpActSub relExpActSub);

	/**
	 * Inserts a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub add(RelExpActSub relexpactsub);

	/**
	 * Inserts a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub anyadirRelacion(RelExpActSub relexpactsub);

	/**
	 * Inserts a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub anyadirRelacionPadre(RelExpActSub relexpactsub);

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub update(RelExpActSub relexpactsub);

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateDEC(RelExpActSub relexpactsub);

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateDECsinImportes(RelExpActSub relexpactsub);

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateSubvencionPorcentaje(RelExpActSub relExpActSub);

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updatePTT(RelExpActSub relexpactsub);

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateOTC(RelExpActSub relexpactsub);

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateOMIC(RelExpActSub relexpactsub);

	/**
	 * sumOMIC
	 * 
	 * @param idExpediente
	 * @return
	 */
	public RelExpActSub sumOMIC(Integer idExpediente);

	/**
	 * Updates de Importe Admitido in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateImporte(RelExpActSub relexpactsub);

	/**
	 * Updates Importe Admitido y presentado in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateImportePresentadoAdmtido(RelExpActSub relexpactsub);

	/**
	 * Updates Importe Admitido y presentado in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateImporteJusPresentadoAdmtido(RelExpActSub relexpactsub);

	/**
	 * Updates Importe Admitido y presentado in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateImportePresentadoAdmtidoPadre(RelExpActSub relexpactsub);

	/**
	 * Updates de SUBVENCION_CALCULADA y PORCENTAJE in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateImporteSubvencionCalculada(RelExpActSub relexpactsub);

	/**
	 * Updates Importe Admitido y presentado in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateImportePorIdActSub(RelExpActSub relExpActSub, Integer idActSub);

	/**
	 * Updates Importe Admitido y presentado in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub updateImporteAyuntamiento(RelExpActSub relExpActSub, Integer idActSub);

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub find(RelExpActSub relexpactsub);

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub findIdActSub(Integer idRelexpactsub);

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	RelExpActSub findIdActSubPorExpedienteNotNull(Integer idExpediente, Integer idActSubPadre);

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	Integer findIdActSubAgrupacionPorExpediente(Integer idExpediente);

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param idExpedientes,
	 *            IdCriterio Integer, Integer
	 * @return RelExpActSub
	 */
	RelExpActSub findRelPorExpedientePorCriterio(Integer idExpedientes, Integer IdCriterio);

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales para
	 * la ayuda CPT
	 *
	 * @param Integer
	 *            idExpediente
	 * 
	 * @return List<RelExpActSub>
	 */
	List<RelExpActSub> findRelEXpActSubPorExpedienteCTP(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param idExpedientes,
	 *            IdCriterio Integer, Integer
	 * @return RelExpActSub
	 */
	RelExpActSub findRelPorExpedientePorCriterioPTT(Integer idExpedientes, Integer IdCriterio);

	/**
	 * Devuelve los totales de un RelExpActSub
	 *
	 * @param Integer
	 *            IdRelacion
	 *
	 * @return RelExpActSub
	 */
	RelExpActSub findTotales(Integer IdRelacion);

	/**
	 * Devuelve los totales de un RelExpActSub
	 * 
	 * @param idRelExpActSub
	 *
	 * @param Integer
	 *            IdRelacion
	 *
	 * @return RelExpActSub
	 */
	RelExpActSub findTotalesJustificacion(Integer IdRelacion, Integer idRelExpActSub);

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	RelExpActSub sumTotales(Integer idExpediente);

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	RelExpActSub sumTotalesJus(Integer idExpediente);

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	RelExpActSub sumEstudioActuacion(Integer idExpediente, Integer idActuacion);

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	RelExpActSub sumAyuntamiento(Integer idActSub, Integer idExpediente, Integer idConvocatoria);

	/**
	 * Removes a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 */
	void remove(RelExpActSub relexpactsub);

	/**
	 * Finds a List of rows in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<RelExpActSub> findAll(RelExpActSub relexpactsub, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the RelExpActSub table using like.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<RelExpActSub> findAllLike(RelExpActSub relexpactsub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Sacamos la tabla de act subencionables por expediente MET
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	List<RelExpActSub> findRelEXpActSubPorExpedienteMEC(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	List<RelExpActSub> findRelEXpActSubPorExpedienteEMET(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	List<RelExpActSub> findRelEXpActSubPorExpedientePTT(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	List<RelExpActSub> findRelEXpActSubPorExpedienteDEC(Integer idExpediente);

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	List<RelExpActSub> findRelEXpActSubPorExpedienteOMIC(Integer idExpediente);

	/**
	 * Sacamos la tabla de relaciones de act subencionables por expediente
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<RelExpActSub>
	 */
	List<RelExpActSub> findRelEXpActSubPorExpediente(Integer idExpediente);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the RelExpActSub table.
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(RelExpActSub filterRelExpActSub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the RelExpActSub table using like.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(RelExpActSub relexpactsub, Boolean startsWith);

	/**
	 * Counts rows in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return Long
	 */
	Long findAllCount(RelExpActSub relexpactsub);

	/**
	 * Reorder selection.
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpActSub>>
	 */
	List<TableRowDto<RelExpActSub>> reorderSelection(RelExpActSub filterRelExpActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param searchRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpActSub>>
	 */
	List<TableRowDto<RelExpActSub>> search(RelExpActSub filterRelExpActSub, RelExpActSub searchRelExpActSub,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical RelExpActSub table.
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelExpActSub>>
	 */
	List<JerarquiaDto<RelExpActSub>> findAllLikeJerarquia(RelExpActSub filterRelExpActSub,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(RelExpActSub filterRelExpActSub, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpActSub>>
	 */
	List<TableRowDto<RelExpActSub>> findAllChild(RelExpActSub filterRelExpActSub, JQGridRequestDto jqGridRequestDto);

	/**
	 * 
	 * @param idExpediente
	 *            idExpediente
	 * @param idConvocatoria
	 *            idConvocatoria
	 * @param idRelExpActSub
	 *            idRelExpActSub
	 * @return
	 */
	RelExpActSub findDetallePTT(Integer idExpediente, Integer idConvocatoria, Integer idRelExpActSub);

	/**
	 * sumPTT
	 * 
	 * @param idConvocatoria
	 * @param idExpediente
	 * @return
	 */
	RelExpActSub sumPTT(Integer idConvocatoria, Integer idExpediente);

	/**
	 * sumOTC
	 * 
	 * @param idRelExpActSub
	 * @return
	 */
	RelExpActSub sumOTC(Integer idRelExpActSub);

	RelExpActSub findEMCO(RelExpActSub relExpActSub);

	List<RelExpActSub> findAllLikeJustificacion(RelExpActSub filterRelFacActSubvencionables,
			JQGridRequestDto jqGridRequestDto, boolean startsWith);

	Long findAllLikeCountJustificacion(RelExpActSub relExpActSub, boolean startsWith);

	RelExpActSub saveDatosJustificacion(Integer idExpediente, RelExpActSub relExpActSub, Usuario usuario);

	RelExpActSub findJustificacion(RelExpActSub relExpActSub);

	RelExpActSub anyadirRelacionDEC(RelExpActSub relExpActSub);

	List<RelExpActSub> findExentoPorExpediente(Integer idExpediente);

	List<RelExpActSub> filterDECTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	List<RelExpActSub> filterOMICTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	List<MarcarInspeccionableAct> filterConConceptosTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	List<RelExpActSub> filterEMETTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	List<RelExpActSub> filterPTTTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	List<RelExpActSub> filterOTCTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	List<RelExpActSub> filterMECTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	List<RelExpActSub> filterJustificacionTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	List<RelExpActSub> findRelEXpActSubPorExpedienteEMCO(Integer idExpediente);

	List<RelExpActSub> importesPorExento(Integer idExpediente, Integer exento);

	void updateImportesPorExento(RelExpActSub relexpactsub);

	void updateImportesPadre(RelExpActSub relExpActSubPadre, BigDecimal presentadoTotal);

	RelExpActSub findPorIdActSubPadre(Integer idActSubPadre, Integer idExpediente);

	void updateImportesProyecto(BigDecimal presentadoTotal, Integer idExpediente);

	RelExpActSub updateEMCORelActSub(RelExpActSub relExpActSub);

	RelExpActSub sumAyuntamientoEMCO(Integer idActSubPadre, Integer idExpediente, Integer idConvocatoria);

	RelExpActSub anyadirRelacionEMCO(RelExpActSub relExpActSub);

	RelExpActSub findIdActSubPorExpedienteNotNullEMCO(Integer idExpediente, Integer idActSubPadre);

	void updateRelExpActSubEmpreEMCO(Integer idRelacion, Integer idActSubPadre, RelExpActSub relExpActSub,
			Integer idExpediente);

	RelExpActSub sumaImportesFacturasEMCO(Integer idExpediente, Integer idActSubPadre);

	void updateRelExpActSubEmprePadreEMCO(Integer idActSubPadre, BigDecimal sumaImporteEMCO, Integer idExpediente);

	Integer findRelExpActSubEmprePadreEMCO(Integer idActSubHijo);

	void updateDatosProyectoEMCO(Integer idExpediente, BigDecimal sumaImporteEMCO);

	void updateRelExpActSubPadreEMCO(Integer idRelacion, Integer idActSubHijo, Integer idExpediente,
			RelExpActSub relExpActSub);

	Integer findNuevoIdActSubHijo(Integer idRelacion);

	void updateRelExpActSubAbueloEMCO(EstudioTecnico estudioTecnico, Integer idActSubPadre);

	Boolean existeRelacionPadre(RelExpActSub relExpActSubHijoNew);

	Integer findRelExpActSubEmpreHijoEMCO(Integer idActSub);

	Integer findIdCriterio(Integer idRelacion, Integer idExpediente);

	void updateRelExpActSubAdmitidoPadreEMCO(Integer idRelacion, Integer idActSubHijo, Integer idExpediente,
			RelExpActSub relExpActSub);

	Integer existenMasFacturas(Integer idActSubHijo, Integer idExpediente);

	void removeRelExpActSubPadreEMCO(Integer idActSubHijo, Integer idExpediente);

	List<RelExpActSub> filterEMCOTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, boolean b,
			Integer idExpediente);

	List<MarcarInspeccionableAct> filterConConceptosPTTTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			boolean b);

	void updateJustOTC(RelExpActSub relExpActSub);

	RelExpActSub sumJusOTC(Integer idRelExpActSub);

	List<RelExpActSub> filterEMCOEmpreTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, boolean b,
			Integer idExpedientes);

	void eliminarImporteCalculado(Integer idExpediente);

	List<RelExpActSub> findRelEXpActSubPorExpedienteCOVIDT(Integer idExpediente, Integer idconvocatoria);

	RelExpActSub findNotasObservaciones(RelExpActSub relExpActSub);

	RelExpActSub findRelPorExpedientePorCriterioEntidadBancaria(Integer idExpedientes, Integer idActSub,
			String entidadBancaria);

	RelExpActSub updateEntidadBancaria(RelExpActSub relExpActSub);

	RelExpActSub sumImportesConceptos(Integer idExpediente);

}
