package com.ejie.ab60.dao.convocatorias;

import com.ejie.ab60.model.Idiomas;
import com.ejie.ab60.model.convocatorias.AplicacionesPresupuestarias;
import com.ejie.ab60.model.nora.T17Provincia;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * AplicacionesPresupuestariasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class AplicacionesPresupuestariasDaoImpl implements AplicacionesPresupuestariasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDAPLICACIONPRESUPUESTARIA", "IDCONVOCATORIA",
			"EJERCICIO", "AGRUPACION", "GASTOINGRESO", "SECCION", "SERVICIO", "CENTRO", "IDPROVINCIA", "CAC", "SC",
			"PROGRAMA", "PARTIDA", "LETRACONTROL", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<AplicacionesPresupuestarias> rwMap = new RowMapper<AplicacionesPresupuestarias>() {
		public AplicacionesPresupuestarias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AplicacionesPresupuestarias(resultSet.getInt("IDAPLICACIONPRESUPUESTARIA"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getString("EJERCICIO"),
					resultSet.getString("AGRUPACION"), resultSet.getString("GASTOINGRESO"),
					resultSet.getString("SECCION"), resultSet.getString("SERVICIO"), resultSet.getString("CENTRO"),

					new T17Provincia(resultSet.getString("IDPROVINCIA"),
							("".equals(resultSet.getString("IDPROVINCIA"))) ? null : resultSet.getString("DSO"),
							("".equals(resultSet.getString("IDPROVINCIA"))) ? null
									: resultSet.getString("IDAUTONOMIA")),
					resultSet.getString("CAC"), resultSet.getString("SC"), resultSet.getString("PROGRAMA"),
					resultSet.getString("PARTIDA"), resultSet.getString("LETRACONTROL"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
		}
	};

	private RowMapper<AplicacionesPresupuestarias> rwMapPK = new RowMapper<AplicacionesPresupuestarias>() {
		public AplicacionesPresupuestarias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AplicacionesPresupuestarias(resultSet.getInt("IDAPLICACIONPRESUPUESTARIA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<AplicacionesPresupuestarias>> rwMapJerarquia = new RowMapper<JerarquiaDto<AplicacionesPresupuestarias>>() {
		public JerarquiaDto<AplicacionesPresupuestarias> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			AplicacionesPresupuestarias aplicacionespresupuestarias = new AplicacionesPresupuestarias(
					resultSet.getInt("IDAPLICACIONPRESUPUESTARIA"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("EJERCICIO"), resultSet.getString("AGRUPACION"),
					resultSet.getString("GASTOINGRESO"), resultSet.getString("SECCION"),
					resultSet.getString("SERVICIO"), resultSet.getString("CENTRO"),
					new T17Provincia(resultSet.getString("IDPROVINCIA"), resultSet.getString("DSO"),
							resultSet.getString("IDAUTONOMIA")),
					resultSet.getString("CAC"), resultSet.getString("SC"), resultSet.getString("PROGRAMA"),
					resultSet.getString("PARTIDA"), resultSet.getString("LETRACONTROL"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getBigDecimal("IMPORTEDISPONIBLE"));

			JerarquiaDto<AplicacionesPresupuestarias> jerarquia = new JerarquiaDto<AplicacionesPresupuestarias>();
			jerarquia.setModel(aplicacionespresupuestarias);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the AplicacionesPresupuestarias table.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @return AplicacionesPresupuestarias
	 */
	public AplicacionesPresupuestarias add(AplicacionesPresupuestarias aplicacionespresupuestarias) {
		aplicacionespresupuestarias.setIdAplicacionPresupuestaria(
				this.jdbcTemplate.queryForObject("SELECT AB60.S_AB6095T00.NEXTVAL FROM DUAL", Integer.class));
		String query = "INSERT INTO APLICACIONES_PRESUPUESTARIAS (ID_APLICACION_PRESUPUESTARIA, ID_CONVOCATORIA, EJERCICIO, AGRUPACION, GASTO_INGRESO, SECCION, SERVICIO, CENTRO, ID_PROVINCIA, CAC, SC, PROGRAMA, PARTIDA, LETRA_CONTROL, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION, IMPORTE, IMPORTE_DISPONIBLE) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, aplicacionespresupuestarias.getIdAplicacionPresupuestaria(),
				aplicacionespresupuestarias.getIdConvocatoria(), aplicacionespresupuestarias.getEjercicio(),
				aplicacionespresupuestarias.getAgrupacion(), aplicacionespresupuestarias.getGastoIngreso(),
				aplicacionespresupuestarias.getSeccion(), aplicacionespresupuestarias.getServicio(),
				aplicacionespresupuestarias.getCentro(), aplicacionespresupuestarias.getProvincia().getId(),
				aplicacionespresupuestarias.getCac(), aplicacionespresupuestarias.getSc(),
				aplicacionespresupuestarias.getPrograma(), aplicacionespresupuestarias.getPartida(),
				aplicacionespresupuestarias.getLetraControl(), aplicacionespresupuestarias.getFechaRegistro(),
				aplicacionespresupuestarias.getUsuarioRegistro(), aplicacionespresupuestarias.getFechaUltmodificacion(),
				aplicacionespresupuestarias.getUsuarioUltmodificacion(), aplicacionespresupuestarias.getImporte(),
				aplicacionespresupuestarias.getImporte());
		return aplicacionespresupuestarias;
	}

	/**
	 * Updates a single row in the AplicacionesPresupuestarias table.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @return AplicacionesPresupuestarias
	 */
	public AplicacionesPresupuestarias update(AplicacionesPresupuestarias aplicacionespresupuestarias)
			throws Exception {

		AplicacionesPresupuestarias aplicacionespresupuestariasAux = new AplicacionesPresupuestarias();
		aplicacionespresupuestariasAux = this.find(aplicacionespresupuestarias);

		StringBuilder query = new StringBuilder();
		query.append(
				"UPDATE APLICACIONES_PRESUPUESTARIAS SET ID_CONVOCATORIA=?, EJERCICIO=?, AGRUPACION=?, GASTO_INGRESO=?, SECCION=?, SERVICIO=?, CENTRO=?, ID_PROVINCIA=?, CAC=?, SC=?, PROGRAMA=?, PARTIDA=?, LETRA_CONTROL=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, IMPORTE=? ");

		if (aplicacionespresupuestariasAux.getImporte() == null
				&& aplicacionespresupuestariasAux.getImporteDisponible() == null) {
			query.append(", IMPORTE_DISPONIBLE= " + aplicacionespresupuestarias.getImporte());
		} else if (aplicacionespresupuestariasAux.getImporte() != null
				&& aplicacionespresupuestariasAux.getImporteDisponible() != null && aplicacionespresupuestariasAux
						.getImporte().compareTo(aplicacionespresupuestariasAux.getImporteDisponible()) == 0) {
			query.append(", IMPORTE_DISPONIBLE= " + aplicacionespresupuestarias.getImporte());
		} else if ((aplicacionespresupuestariasAux.getImporte() != null
				&& aplicacionespresupuestariasAux.getImporteDisponible() != null)
				&& aplicacionespresupuestariasAux.getImporte()
						.compareTo(aplicacionespresupuestariasAux.getImporteDisponible()) != 0) {
			throw new Exception();
		}

		query.append(" WHERE ID_APLICACION_PRESUPUESTARIA=?");
		this.jdbcTemplate.update(query.toString(), aplicacionespresupuestarias.getIdConvocatoria(),
				aplicacionespresupuestarias.getEjercicio(), aplicacionespresupuestarias.getAgrupacion(),
				aplicacionespresupuestarias.getGastoIngreso(), aplicacionespresupuestarias.getSeccion(),
				aplicacionespresupuestarias.getServicio(), aplicacionespresupuestarias.getCentro(),
				aplicacionespresupuestarias.getProvincia().getId(), aplicacionespresupuestarias.getCac(),
				aplicacionespresupuestarias.getSc(), aplicacionespresupuestarias.getPrograma(),
				aplicacionespresupuestarias.getPartida(), aplicacionespresupuestarias.getLetraControl(),
				aplicacionespresupuestarias.getFechaRegistro(), aplicacionespresupuestarias.getUsuarioRegistro(),
				aplicacionespresupuestarias.getFechaUltmodificacion(),
				aplicacionespresupuestarias.getUsuarioUltmodificacion(), aplicacionespresupuestarias.getImporte(),
				aplicacionespresupuestarias.getIdAplicacionPresupuestaria());
		return aplicacionespresupuestarias;
	}

	/**
	 * Updates a single row in the AplicacionesPresupuestarias table.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @return AplicacionesPresupuestarias
	 */
	public AplicacionesPresupuestarias updateImporteDisponible(
			AplicacionesPresupuestarias aplicacionespresupuestarias) {

		StringBuilder query = new StringBuilder();
		query.append("UPDATE APLICACIONES_PRESUPUESTARIAS SET IMPORTE_DISPONIBLE=? ");

		query.append(" WHERE ID_APLICACION_PRESUPUESTARIA=?");
		this.jdbcTemplate.update(query.toString(), aplicacionespresupuestarias.getImporteDisponible(),
				aplicacionespresupuestarias.getIdAplicacionPresupuestaria());
		return aplicacionespresupuestarias;
	}

	/**
	 * Finds a single row in the AplicacionesPresupuestarias table.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @return AplicacionesPresupuestarias
	 */
	@Transactional(readOnly = true)
	public AplicacionesPresupuestarias find(AplicacionesPresupuestarias aplicacionespresupuestarias) {
		String query = "SELECT t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.EJERCICIO EJERCICIO, t1.AGRUPACION AGRUPACION, t1.GASTO_INGRESO GASTOINGRESO, t1.SECCION SECCION, t1.SERVICIO SERVICIO, t1.CENTRO CENTRO, t1.ID_PROVINCIA IDPROVINCIA, t2.DS_O DSO, t2.AUTONOMIA_ID IDAUTONOMIA, t1.CAC CAC, t1.SC SC, t1.PROGRAMA PROGRAMA, t1.PARTIDA PARTIDA, t1.LETRA_CONTROL LETRACONTROL, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.IMPORTE IMPORTE, t1.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE FROM APLICACIONES_PRESUPUESTARIAS t1 LEFT JOIN PROVINCIAS t2 ON t1.ID_PROVINCIA = REPLACE(LTRIM(REPLACE(t2.ID, '0', ' ')), ' ', '0') WHERE t1.ID_APLICACION_PRESUPUESTARIA = ?";

		List<AplicacionesPresupuestarias> aplicacionespresupuestariasList = this.jdbcTemplate.query(query, this.rwMap,
				aplicacionespresupuestarias.getIdAplicacionPresupuestaria());
		return (AplicacionesPresupuestarias) DataAccessUtils.uniqueResult(aplicacionespresupuestariasList);
	}

	/**
	 * Removes a single row in the AplicacionesPresupuestarias table.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @return
	 */
	public void remove(AplicacionesPresupuestarias aplicacionespresupuestarias) {
		String query = "DELETE FROM APLICACIONES_PRESUPUESTARIAS WHERE ID_APLICACION_PRESUPUESTARIA=?";
		this.jdbcTemplate.update(query, aplicacionespresupuestarias.getIdAplicacionPresupuestaria());
	}

	/**
	 * Finds a list of rows in the AplicacionesPresupuestarias table.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<AplicacionesPresupuestarias>
	 */
	@Transactional(readOnly = true)
	public List<AplicacionesPresupuestarias> findAll(AplicacionesPresupuestarias aplicacionespresupuestarias,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.EJERCICIO EJERCICIO,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.ID_PROVINCIA IDPROVINCIA, t2.DS_O DSO, t2.AUTONOMIA_ID IDAUTONOMIA,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.IMPORTE IMPORTE, t1.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE ");
		query.append("FROM APLICACIONES_PRESUPUESTARIAS t1 "
				+ "LEFT JOIN PROVINCIAS t2 ON t1.ID_PROVINCIA = REPLACE(LTRIM(REPLACE(t2.ID, '0', ' ')), ' ', '0')  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(aplicacionespresupuestarias);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AplicacionesPresupuestariasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AplicacionesPresupuestarias>) this.jdbcTemplate.query(query.toString(), this.rwMap,
				params.toArray());
	}

	/**
	 * Finds rows in the AplicacionesPresupuestarias table using like.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<AplicacionesPresupuestarias>
	 */
	@Transactional(readOnly = true)
	public List<AplicacionesPresupuestarias> findAllLike(AplicacionesPresupuestarias aplicacionespresupuestarias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.EJERCICIO EJERCICIO,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.ID_PROVINCIA IDPROVINCIA, t2.DS_O DSO, t2.AUTONOMIA_ID IDAUTONOMIA,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.IMPORTE IMPORTE, t1.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE ");
		query.append("FROM APLICACIONES_PRESUPUESTARIAS t1 "
				+ "LEFT JOIN PROVINCIAS t2 ON t1.ID_PROVINCIA = REPLACE(LTRIM(REPLACE(t2.ID, '0', ' ')), ' ', '0') ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(aplicacionespresupuestarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AplicacionesPresupuestariasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AplicacionesPresupuestarias>) this.jdbcTemplate.query(query.toString(), this.rwMap,
				params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the AplicacionesPresupuestarias table.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(AplicacionesPresupuestarias aplicacionespresupuestarias) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM APLICACIONES_PRESUPUESTARIAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(aplicacionespresupuestarias);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the AplicacionesPresupuestarias table using like.
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(AplicacionesPresupuestarias aplicacionespresupuestarias, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM APLICACIONES_PRESUPUESTARIAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(aplicacionespresupuestarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of AplicacionesPresupuestarias selected for
	 * rup_table
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AplicacionesPresupuestarias>>
	 */
	@Override
	public List<TableRowDto<AplicacionesPresupuestarias>> reorderSelection(
			AplicacionesPresupuestarias aplicacionespresupuestarias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.EJERCICIO EJERCICIO,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.ID_PROVINCIA IDPROVINCIA, t2.DS_O DSO, t2.AUTONOMIA_ID IDAUTONOMIA,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM APLICACIONES_PRESUPUESTARIAS t1"
				+ "LEFT JOIN PROVINCIAS t2 ON t1.ID_PROVINCIA = REPLACE(LTRIM(REPLACE(t2.ID, '0', ' ')), ' ', '0') ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(aplicacionespresupuestarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				AplicacionesPresupuestarias.class, filterParamList, "ID_APLICACION_PRESUPUESTARIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AplicacionesPresupuestarias>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            AplicacionesPresupuestarias
	 * @param searchParams
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AplicacionesPresupuestarias>>
	 */
	@Override
	public List<TableRowDto<AplicacionesPresupuestarias>> search(AplicacionesPresupuestarias filterParams,
			AplicacionesPresupuestarias searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.EJERCICIO EJERCICIO,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.ID_PROVINCIA IDPROVINCIA, t2.DS_O DSO, t2.AUTONOMIA_ID IDAUTONOMIA,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM APLICACIONES_PRESUPUESTARIAS t1, PROVINCIAS t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(" AND t1.ID_PROVINCIA=REPLACE(LTRIM(REPLACE(t2.ID, '0', ' ')), ' ', '0') ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				AplicacionesPresupuestarias.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_APLICACION_PRESUPUESTARIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AplicacionesPresupuestarias>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filteraplicacionespresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(AplicacionesPresupuestarias filteraplicacionespresupuestarias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.EJERCICIO EJERCICIO,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.ID_PROVINCIA IDPROVINCIA, t2.DS_O DSO, t2.AUTONOMIA_ID IDAUTONOMIA,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM APLICACIONES_PRESUPUESTARIAS t1, PROVINCIAS t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filteraplicacionespresupuestarias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(" AND t1.ID_PROVINCIA=REPLACE(LTRIM(REPLACE(t2.ID, '0', ' ')), ' ', '0') ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				AplicacionesPresupuestarias.class, query, params, "ID_APLICACION_PRESUPUESTARIA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical AplicacionesPresupuestarias table.
	 *
	 * @param filterAplicacionesPresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<AplicacionesPresupuestarias>>
	 */
	@Override
	public List<JerarquiaDto<AplicacionesPresupuestarias>> findAllLikeJerarquia(
			AplicacionesPresupuestarias filterAplicacionesPresupuestarias, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.EJERCICIO EJERCICIO,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.ID_PROVINCIA IDPROVINCIA,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM
		// APLICACIONES_PRESUPUESTARIAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("APLICACIONES_PRESUPUESTARIAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAplicacionesPresupuestarias, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_APLICACION_PRESUPUESTARIA",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					AplicacionesPresupuestariasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAplicacionesPresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(AplicacionesPresupuestarias filterAplicacionesPresupuestarias,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM
		// APLICACIONES_PRESUPUESTARIAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("APLICACIONES_PRESUPUESTARIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAplicacionesPresupuestarias, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_APLICACION_PRESUPUESTARIA", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAplicacionesPresupuestarias
	 *            AplicacionesPresupuestarias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<AplicacionesPresupuestarias>>
	 */
	@Override
	public List<TableRowDto<AplicacionesPresupuestarias>> findAllChild(
			AplicacionesPresupuestarias filterAplicacionesPresupuestarias, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM
		// APLICACIONES_PRESUPUESTARIAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("APLICACIONES_PRESUPUESTARIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAplicacionesPresupuestarias, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_APLICACION_PRESUPUESTARIA", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<AplicacionesPresupuestarias>(this.rwMapPK, "ID_APLICACION_PRESUPUESTARIA"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AplicacionesPresupuestarias entity
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias Bean with the criteria values to
	 *            filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(AplicacionesPresupuestarias aplicacionespresupuestarias) {

		StringBuilder where = new StringBuilder(AplicacionesPresupuestariasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (aplicacionespresupuestarias != null
				&& aplicacionespresupuestarias.getIdAplicacionPresupuestaria() != null) {
			where.append(" AND t1.ID_APLICACION_PRESUPUESTARIA = ?");
			params.add(aplicacionespresupuestarias.getIdAplicacionPresupuestaria());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(aplicacionespresupuestarias.getIdConvocatoria());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(aplicacionespresupuestarias.getEjercicio());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getAgrupacion() != null) {
			where.append(" AND t1.AGRUPACION = ?");
			params.add(aplicacionespresupuestarias.getAgrupacion());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getGastoIngreso() != null) {
			where.append(" AND t1.GASTO_INGRESO = ?");
			params.add(aplicacionespresupuestarias.getGastoIngreso());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(aplicacionespresupuestarias.getSeccion());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getServicio() != null) {
			where.append(" AND t1.SERVICIO = ?");
			params.add(aplicacionespresupuestarias.getServicio());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getCentro() != null) {
			where.append(" AND t1.CENTRO = ?");
			params.add(aplicacionespresupuestarias.getCentro());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getProvincia() != null) {
			where.append(" AND t1.ID_PROVINCIA = ?");
			params.add(aplicacionespresupuestarias.getProvincia().getId());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getCac() != null) {
			where.append(" AND t1.CAC = ?");
			params.add(aplicacionespresupuestarias.getCac());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getSc() != null) {
			where.append(" AND t1.SC = ?");
			params.add(aplicacionespresupuestarias.getSc());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getPrograma() != null) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(aplicacionespresupuestarias.getPrograma());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getPartida() != null) {
			where.append(" AND t1.PARTIDA = ?");
			params.add(aplicacionespresupuestarias.getPartida());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getLetraControl() != null) {
			where.append(" AND t1.LETRA_CONTROL = ?");
			params.add(aplicacionespresupuestarias.getLetraControl());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(aplicacionespresupuestarias.getFechaRegistro());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(aplicacionespresupuestarias.getUsuarioRegistro());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(aplicacionespresupuestarias.getFechaUltmodificacion());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(aplicacionespresupuestarias.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the AplicacionesPresupuestarias entity
	 *
	 * @param aplicacionespresupuestarias
	 *            AplicacionesPresupuestarias Bean with the criteria values to
	 *            filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(AplicacionesPresupuestarias aplicacionespresupuestarias,
			Boolean startsWith) {

		StringBuilder where = new StringBuilder(AplicacionesPresupuestariasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (aplicacionespresupuestarias != null
				&& aplicacionespresupuestarias.getIdAplicacionPresupuestaria() != null) {
			where.append(" AND t1.ID_APLICACION_PRESUPUESTARIA = ?");
			params.add(aplicacionespresupuestarias.getIdAplicacionPresupuestaria());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(aplicacionespresupuestarias.getIdConvocatoria());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(aplicacionespresupuestarias.getEjercicio());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getAgrupacion() != null) {
			where.append(" AND t1.AGRUPACION = ?");
			params.add(aplicacionespresupuestarias.getAgrupacion());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getGastoIngreso() != null) {
			where.append(" AND t1.GASTO_INGRESO = ?");
			params.add(aplicacionespresupuestarias.getGastoIngreso());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(aplicacionespresupuestarias.getSeccion());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getServicio() != null) {
			where.append(" AND t1.SERVICIO = ?");
			params.add(aplicacionespresupuestarias.getServicio());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getCentro() != null) {
			where.append(" AND t1.CENTRO = ?");
			params.add(aplicacionespresupuestarias.getCentro());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getProvincia() != null) {
			where.append(" AND t1.ID_PROVINCIA = ?");
			params.add(aplicacionespresupuestarias.getProvincia().getId());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getCac() != null) {
			where.append(" AND t1.CAC = ?");
			params.add(aplicacionespresupuestarias.getCac());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getSc() != null) {
			where.append(" AND t1.SC = ?");
			params.add(aplicacionespresupuestarias.getSc());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getPrograma() != null) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(aplicacionespresupuestarias.getPrograma());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getPartida() != null) {
			where.append(" AND t1.PARTIDA = ?");
			params.add(aplicacionespresupuestarias.getPartida());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getLetraControl() != null) {
			where.append(" AND UPPER(t1.LETRA_CONTROL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(aplicacionespresupuestarias.getLetraControl().toUpperCase() + "%");
			} else {
				params.add("%" + aplicacionespresupuestarias.getLetraControl().toUpperCase() + "%");
			}
			where.append(" AND t1.LETRA_CONTROL IS NOT NULL");
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(aplicacionespresupuestarias.getFechaRegistro());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(aplicacionespresupuestarias.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + aplicacionespresupuestarias.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(aplicacionespresupuestarias.getFechaUltmodificacion());
		}
		if (aplicacionespresupuestarias != null && aplicacionespresupuestarias.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(aplicacionespresupuestarias.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + aplicacionespresupuestarias.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
