package com.ejie.ab60.dao.convocatorias;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.ab60.service.calculoAyuda.CalculoAyudaServiceImpl;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ConvocatoriasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ConvocatoriasDaoImpl implements ConvocatoriasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCONVOCATORIA", "IDTIPOCONVOCATORIA",
			"IDPROCEDIMIENTO", "CONVOCATORIA", "FECHARESOLUCION", "IMPORTE", "PORCENTAJESUBVENCION",
			"CANTMAXSUBVENCION", "PLSQLCALCULO", "PLSQLREPARTO", "OBSERVACIONES", "IMPORTEMINIMOINVERSION",
			"FECHAORDENDIA", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION",
			"LIMITELOCAL", "TIPOSCONVIDTIPOCONV", "TIPOSCONVDESCCASTELLANO", "TIPOSCONVDESCEUSKERA",
			"TIPOSCONVFECREGISTRO", "TIPOSCONVUSUREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	private static final Logger logger = LoggerFactory.getLogger(CalculoAyudaServiceImpl.class);

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Convocatorias> rwMapConvocatorias = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getLong("IDTIPOCONVOCATORIA"),
					resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getString("CODPROCEDUREID"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getString("CONVOCATORIA"), resultSet.getDate("FECHARESOLUCION"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getBigDecimal("IMPORTEDISPONIBLE"),
					resultSet.getBigDecimal("PORCENTAJESUBVENCION"), resultSet.getBigDecimal("CANTMAXSUBVENCION"),
					resultSet.getString("PLSQLCALCULO"), resultSet.getString("PLSQLREPARTO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAORDENDIA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getBigDecimal("LIMITELOCAL"), resultSet.getInt("IDTIPOAYUDA"),
					resultSet.getInt("FASEACTIVA"), resultSet.getInt("NUMPERCON"), resultSet.getInt("NUMPERCUR"),
					resultSet.getInt("NUMBECAS"), resultSet.getInt("NUMSUPLENTES"),
					resultSet.getString("ORIGENMAQUETA"), resultSet.getBoolean("EXENTOIVA"));
		}
	};

	private RowMapper<Convocatorias> rwMapFaseActiva = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			convocatorias.setIdProcedimiento(resultSet.getInt("IDPROCEDIMIENTO"));
			convocatorias.setFaseActiva(resultSet.getInt("FASEACTIVA"));

			return convocatorias;
		}
	};

	private RowMapper<Convocatorias> rwMapFindByIdExpediente = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			return convocatorias;
		}
	};

	private RowMapper<Convocatorias> rwMap = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getLong("IDTIPOCONVOCATORIA"),
					resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getString("CONVOCATORIA"),
					resultSet.getDate("FECHARESOLUCION"), resultSet.getBigDecimal("IMPORTE"),
					resultSet.getBigDecimal("PORCENTAJESUBVENCION"), resultSet.getBigDecimal("CANTMAXSUBVENCION"),
					resultSet.getString("PLSQLCALCULO"), resultSet.getString("PLSQLREPARTO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAORDENDIA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getBigDecimal("LIMITELOCAL"), resultSet.getInt("IDTIPOAYUDA"));
		}
	};

	private RowMapper<Convocatorias> rwMapComboAyuda = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getLong("IDTIPOCONVOCATORIA"),
					resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getString("CONVOCATORIA"),
					resultSet.getDate("FECHARESOLUCION"), resultSet.getBigDecimal("IMPORTE"),
					resultSet.getBigDecimal("PORCENTAJESUBVENCION"), resultSet.getBigDecimal("CANTMAXSUBVENCION"),
					resultSet.getString("PLSQLCALCULO"), resultSet.getString("PLSQLREPARTO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAORDENDIA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getBigDecimal("LIMITELOCAL"), resultSet.getInt("IDTIPOAYUDA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"));
		}
	};

	private RowMapper<Convocatorias> rwMapConvocatoria = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getLong("IDTIPOCONVOCATORIA"),
					resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getString("CONVOCATORIA"),
					resultSet.getDate("FECHARESOLUCION"), resultSet.getBigDecimal("IMPORTE"),
					resultSet.getBigDecimal("PORCENTAJESUBVENCION"), resultSet.getBigDecimal("CANTMAXSUBVENCION"),
					resultSet.getString("PLSQLCALCULO"), resultSet.getString("PLSQLREPARTO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAORDENDIA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getBigDecimal("LIMITEAT"), resultSet.getInt("IDTIPOAYUDA"));

		}
	};

	private RowMapper<Convocatorias> rwMapCombo = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			return new Convocatorias(resultSet.getLong("IDTIPOCONVOCATORIA"),
					new TiposConvocatoria(resultSet.getLong("TIPOSCONVIDTIPOCONV"),
							resultSet.getString("TIPOSCONVDESCCASTELLANO"), resultSet.getString("TIPOSCONVDESCEUSKERA"),
							resultSet.getDate("TIPOSCONVFECREGISTRO"), resultSet.getString("TIPOSCONVUSUREGISTRO")));
		}
	};

	private RowMapper<Convocatorias> rwMapPK = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"));
		}
	};

	private RowMapper<Convocatorias> rwMapPLSQL = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getString("PLSQLCALCULO"));
		}
	};

	private RowMapper<Convocatorias> rwMapPLSQLReparto = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getInt("IDPROCEDIMIENTO"),
					resultSet.getString("PLSQLREPARTO"));
		}
	};

	private RowMapper<Convocatorias> rwMapPLSQLAnularReparto = new RowMapper<Convocatorias>() {
		public Convocatorias mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getInt("IDPROCEDIMIENTO"),
					resultSet.getString("PLSQLANULARREPARTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Convocatorias>> rwMapJerarquia = new RowMapper<JerarquiaDto<Convocatorias>>() {
		public JerarquiaDto<Convocatorias> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Convocatorias convocatorias = new Convocatorias(resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getString("CONVOCATORIA"),
					resultSet.getDate("FECHARESOLUCION"), resultSet.getBigDecimal("IMPORTE"),
					resultSet.getBigDecimal("PORCENTAJESUBVENCION"), resultSet.getBigDecimal("CANTMAXSUBVENCION"),
					resultSet.getString("PLSQLCALCULO"), resultSet.getString("PLSQLREPARTO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAORDENDIA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getBigDecimal("LIMITELOCAL"),
					new TiposConvocatoria(resultSet.getLong("TIPOSCONVIDTIPOCONV"),
							resultSet.getString("TIPOSCONVDESCCASTELLANO"), resultSet.getString("TIPOSCONVDESCEUSKERA"),
							resultSet.getDate("TIPOSCONVFECREGISTRO"), resultSet.getString("TIPOSCONVUSUREGISTRO")));

			JerarquiaDto<Convocatorias> jerarquia = new JerarquiaDto<Convocatorias>();
			jerarquia.setModel(convocatorias);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias add(Convocatorias convocatorias) {
		String query = "INSERT INTO CONVOCATORIAS (ID_CONVOCATORIA, ID_TIPO_CONVOCATORIA, ID_PROCEDIMIENTO) VALUES (AB60.S_AB6001T00.NEXTVAL,?,?)";

		this.jdbcTemplate.update(query, convocatorias.getIdTipoConvocatoria(), convocatorias.getIdProcedimiento());
		return convocatorias;
	}

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias update(Convocatorias convocatorias) {
		String query = "UPDATE CONVOCATORIAS SET ID_TIPO_CONVOCATORIA=?, FECHA_RESOLUCION=TO_DATE (?,'DD/MM/YYYY'), FECHA_ORDEN_DIA=TO_DATE (?,'DD/MM/YYYY'), IMPORTE=?, PORCENTAJE_SUBVENCION=?, CANT_MAX_SUBVENCION=?, OBSERVACIONES=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_CONVOCATORIA=?";

		this.jdbcTemplate.update(query, convocatorias.getIdTipoConvocatoria(), convocatorias.getFechaResolucionStr(),
				convocatorias.getFechaOrdenDiaStr(), convocatorias.getImporte(),
				convocatorias.getPorcentajeSubvencion(), convocatorias.getCantMaxSubvencion(),
				convocatorias.getObservaciones(), convocatorias.getFechaUltmodificacion(),
				convocatorias.getUsuarioUltmodificacion(), convocatorias.getIdConvocatoria());
		return convocatorias;
	}

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias updateFaseActiva(Convocatorias convocatorias) {
		String query = "UPDATE CONVOCATORIAS SET FASE_ACTIVA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_CONVOCATORIA=?";

		this.jdbcTemplate.update(query, convocatorias.getFaseActiva(), convocatorias.getFechaUltmodificacion(),
				convocatorias.getUsuarioUltmodificacion(), convocatorias.getIdConvocatoria());
		return convocatorias;
	}

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias updateBEC(Convocatorias convocatorias) {
		String query = "UPDATE CONVOCATORIAS SET ID_TIPO_CONVOCATORIA = ?, FECHA_RESOLUCION=TO_DATE (?,'DD/MM/YYYY'), FECHA_ORDEN_DIA=TO_DATE (?,'DD/MM/YYYY'), NUM_PER_CON = ?, NUM_PER_CUR = ?, NUM_BECAS = ?, NUM_SUPLENTES = ?, OBSERVACIONES = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_CONVOCATORIA = ?";

		this.jdbcTemplate.update(query, convocatorias.getIdTipoConvocatoria(), convocatorias.getFechaResolucionStr(),
				convocatorias.getFechaOrdenDiaStr(), convocatorias.getNumPersonasConocimientos(),
				convocatorias.getNumPersonasCurso(), convocatorias.getNumBecas(), convocatorias.getNumSuplentes(),
				convocatorias.getObservaciones(), convocatorias.getFechaUltmodificacion(),
				convocatorias.getUsuarioUltmodificacion(), convocatorias.getIdConvocatoria());
		return convocatorias;
	}

	/**
	 * Updates Importes en Convocatorias table.
	 *
	 * @param idConvocatorias
	 *            Integer
	 * @return Convocatorias
	 */
	public Convocatorias updateImportes(Convocatorias convocatorias) {
		String query = "UPDATE CONVOCATORIAS SET IMPORTE=?,IMPORTE_DISPONIBLE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_CONVOCATORIA=?";

		this.jdbcTemplate.update(query, convocatorias.getImporte(), convocatorias.getImporteDisponible(),
				convocatorias.getFechaUltmodificacion(), convocatorias.getUsuarioUltmodificacion(),
				convocatorias.getIdConvocatoria());
		return convocatorias;
	}

	/**
	 * Updates Fechas table.
	 *
	 * @param idConvocatorias
	 *            Integer
	 * @return Convocatorias
	 */
	public Convocatorias updateFechas(Convocatorias convocatorias) {
		String query = "UPDATE CONVOCATORIAS SET FECHA_RESOLUCION=TO_DATE (?,'DD/MM/YYYY'), FECHA_ORDEN_DIA=TO_DATE (?,'DD/MM/YYYY') WHERE ID_CONVOCATORIA=?";

		this.jdbcTemplate.update(query, convocatorias.getFechaResolucionStr(), convocatorias.getFechaOrdenDiaStr(),
				convocatorias.getIdConvocatoria());
		return convocatorias;
	}

	/**
	 * Updates Importe_Disponible en Convocatorias table.
	 *
	 * @param idConvocatorias
	 *            Integer
	 * @return Convocatorias
	 */
	public Convocatorias updateImporteDisponible(Convocatorias convocatorias) {
		String query = "UPDATE CONVOCATORIAS SET IMPORTE_DISPONIBLE=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_CONVOCATORIA=?";

		this.jdbcTemplate.update(query, convocatorias.getImporteDisponible(), convocatorias.getFechaUltmodificacion(),
				convocatorias.getUsuarioUltmodificacion(), convocatorias.getIdConvocatoria());
		return convocatorias;
	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias find(Convocatorias convocatorias) {
		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, T3.COD_PROCEDURE_ID CODPROCEDUREID, T3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.CONVOCATORIA CONVOCATORIA, t1.FECHA_RESOLUCION FECHARESOLUCION, t1.IMPORTE IMPORTE, t1.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE, t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION, t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION, t1.PLSQL_CALCULO PLSQLCALCULO, t1.PLSQL_REPARTO PLSQLREPARTO, t1.OBSERVACIONES OBSERVACIONES, t1.FECHA_ORDEN_DIA FECHAORDENDIA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.LIMITE_AT LIMITELOCAL, t1.NUM_PER_CON NUMPERCON, t1.NUM_PER_CUR NUMPERCUR, t1.NUM_BECAS NUMBECAS, t1.NUM_SUPLENTES NUMSUPLENTES, t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV, t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO, t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA, t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO, t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO, t1.ID_TIPO_AYUDA IDTIPOAYUDA, t1.FASE_ACTIVA FASEACTIVA, t1.ORIGEN_MAQUETA ORIGENMAQUETA, t1.EXENTO_IVA EXENTOIVA FROM CONVOCATORIAS t1 , TIPOS_CONVOCATORIA t2 , PROCEDIMIENTOS T3 WHERE t1.ID_CONVOCATORIA = ?   AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+) AND T3.ID_PROCEDIMIENTO(+) = t1.ID_PROCEDIMIENTO";

		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapConvocatorias,
				convocatorias.getIdConvocatoria());
		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias findFaseActiva(Convocatorias convocatorias) {
		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,  t1.FASE_ACTIVA FASEACTIVA FROM CONVOCATORIAS t1 WHERE t1.ID_CONVOCATORIA  = ?";

		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapFaseActiva,
				convocatorias.getIdConvocatoria());
		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias findWithProcedimiento(Integer idProcedimiento) {
		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.CONVOCATORIA CONVOCATORIA, t1.FECHA_RESOLUCION FECHARESOLUCION, t1.IMPORTE IMPORTE, t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION, t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION, t1.PLSQL_CALCULO PLSQLCALCULO, t1.PLSQL_REPARTO PLSQLREPARTO, t1.OBSERVACIONES OBSERVACIONES, t1.FECHA_ORDEN_DIA FECHAORDENDIA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.LIMITE_AT LIMITELOCAL, t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV, t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO, t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA, t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO, t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO, t1.ID_TIPO_AYUDA IDTIPOAYUDA FROM CONVOCATORIAS t1 , TIPOS_CONVOCATORIA t2  WHERE t1.ID_PROCEDIMIENTO = ?   AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+)";

		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMap, idProcedimiento);
		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * Encuentra el nombre del pl-sql de calculo de ayuda correspondiente a cada
	 * convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias findNombrePLSQL(Integer idConvocatorias) {

		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.PLSQL_CALCULO PLSQLCALCULO FROM CONVOCATORIAS t1  WHERE t1.ID_CONVOCATORIA  =?";
		logger.info("SElct de nombre de pl = " + query);
		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapPLSQL, idConvocatorias);

		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * Encuentra el nombre del pl-sql de ANULAR REPARTO de ayuda correspondiente
	 * a cada convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias findNombrePLSQLAnularReparto(Integer idConvocatoria) {

		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.PLSQL_ANULARREPARTO PLSQLANULARREPARTO FROM CONVOCATORIAS t1  WHERE t1.ID_CONVOCATORIA  =?";
		logger.info("SELECT de nombre de pl de reparto = " + query);
		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapPLSQLAnularReparto,
				idConvocatoria);

		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * Encuentra el nombre del pl-sql de REPARTO de ayuda correspondiente a cada
	 * convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias findNombrePLSQLReparto(Integer idConvocatoria) {

		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.PLSQL_REPARTO PLSQLREPARTO FROM CONVOCATORIAS t1  WHERE t1.ID_CONVOCATORIA  =?";
		logger.info("SELECT de nombre de pl de reparto = " + query);
		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapPLSQLReparto, idConvocatoria);

		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias findProc(Convocatorias convocatorias) {
		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.CONVOCATORIA CONVOCATORIA, t1.FECHA_RESOLUCION FECHARESOLUCION, t1.IMPORTE IMPORTE, t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION, t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION, t1.PLSQL_CALCULO PLSQLCALCULO, t1.PLSQL_REPARTO PLSQLREPARTO, t1.OBSERVACIONES OBSERVACIONES, t1.FECHA_ORDEN_DIA FECHAORDENDIA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.LIMITE_AT LIMITEAT, t1.ID_TIPO_AYUDA IDTIPOAYUDA FROM CONVOCATORIAS t1  WHERE t1.ID_PROCEDIMIENTO = ?";

		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapConvocatoria,
				convocatorias.getIdProcedimiento());
		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * Rellenar el combo de tipoConvocatorias
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(readOnly = true)
	public Convocatorias tipoConvo(Convocatorias convocatorias) {
		String query = "SELECT ab6001t00.IDTIPOCONVOCATORIA, ab6012t00.TIPOSCONVDESCCASTELLANO FROM ab6001t00, ab6012t00 WHERE ab6001t00.IDTIPOCONVOCATORIA = ab6012t00.TIPOSCONVIDTIPOCONV";

		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapCombo,
				convocatorias.getIdProcedimiento());
		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}

	/**
	 * 
	 * 
	 * /** Removes a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return
	 */
	public void remove(Convocatorias convocatorias) {
		String query = "DELETE FROM CONVOCATORIAS WHERE ID_CONVOCATORIA=?";
		this.jdbcTemplate.update(query, convocatorias.getIdConvocatoria());
	}

	/**
	 * Finds a list of rows in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Convocatorias>
	 */
	@Transactional(readOnly = true)
	public List<Convocatorias> findAll(Convocatorias convocatorias, JQGridRequestDto jqGridRequestDto) {

		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.CONVOCATORIA CONVOCATORIA,t1.FECHA_RESOLUCION FECHARESOLUCION,t1.IMPORTE IMPORTE,t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION,t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION,t1.PLSQL_CALCULO PLSQLCALCULO,t1.PLSQL_REPARTO PLSQLREPARTO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_ORDEN_DIA FECHAORDENDIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.LIMITE_AT LIMITELOCAL,t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV,t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA,t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO,t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO, t1.ID_TIPO_AYUDA IDTIPOAYUDA, '(' || t3.COD_PROCEDURE_ID || ') : ' || t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, '(' || t3.COD_PROCEDURE_ID ||  ') ' ||  t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA ");
		query.append("FROM CONVOCATORIAS t1 ,TIPOS_CONVOCATORIA t2, PROCEDIMIENTOS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(convocatorias);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+) AND t1.ID_PROCEDIMIENTO = t3.ID_PROCEDIMIENTO ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ConvocatoriasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Convocatorias>) this.jdbcTemplate.query(query.toString(), this.rwMapComboAyuda, params.toArray());
	}

	/**
	 * Finds rows in the Convocatorias table using like.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Convocatorias>
	 */
	@Transactional(readOnly = true)
	public List<Convocatorias> findAllLike(Convocatorias convocatorias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.CONVOCATORIA CONVOCATORIA,t1.FECHA_RESOLUCION FECHARESOLUCION,t1.IMPORTE IMPORTE,t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION,t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION,t1.PLSQL_CALCULO PLSQLCALCULO,t1.PLSQL_REPARTO PLSQLREPARTO,t1.OBSERVACIONES OBSERVACIONES,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.FECHA_ORDEN_DIA FECHAORDENDIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.LIMITE_AT LIMITELOCAL,t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV,t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA,t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO,t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO, t1.ID_TIPO_AYUDA IDTIPOAYUDA ");
		query.append("FROM CONVOCATORIAS t1 ,TIPOS_CONVOCATORIA t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(convocatorias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ConvocatoriasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Convocatorias>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Convocatorias convocatorias) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM CONVOCATORIAS t1 , TIPOS_CONVOCATORIA t2, PROCEDIMIENTOS t3  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(convocatorias);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+)  AND t1.ID_PROCEDIMIENTO = t3.ID_PROCEDIMIENTO ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Convocatorias table using like.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Convocatorias convocatorias, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM CONVOCATORIAS t1 ,TIPOS_CONVOCATORIA t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(convocatorias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Convocatorias selected for rup_table
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Convocatorias>>
	 */
	@Override
	public List<TableRowDto<Convocatorias>> reorderSelection(Convocatorias convocatorias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.CONVOCATORIA CONVOCATORIA,t1.FECHA_RESOLUCION FECHARESOLUCION,t1.IMPORTE IMPORTE,t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION,t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION,t1.PLSQL_CALCULO PLSQLCALCULO,t1.PLSQL_REPARTO PLSQLREPARTO,t1.OBSERVACIONES OBSERVACIONES,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.FECHA_ORDEN_DIA FECHAORDENDIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.LIMITE_AT LIMITELOCAL,t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV,t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA,t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO,t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO ");
		// FROM
		query.append("FROM CONVOCATORIAS t1 ,TIPOS_CONVOCATORIA t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(convocatorias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				Convocatorias.class, filterParamList, "ID_CONVOCATORIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Convocatorias>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Convocatorias
	 * @param searchParams
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Convocatorias>>
	 */
	@Override
	public List<TableRowDto<Convocatorias>> search(Convocatorias filterParams, Convocatorias searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.CONVOCATORIA CONVOCATORIA,t1.FECHA_RESOLUCION FECHARESOLUCION,t1.IMPORTE IMPORTE,t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION,t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION,t1.PLSQL_CALCULO PLSQLCALCULO,t1.PLSQL_REPARTO PLSQLREPARTO,t1.OBSERVACIONES OBSERVACIONES,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.FECHA_ORDEN_DIA FECHAORDENDIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.LIMITE_AT LIMITELOCAL,t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV,t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA,t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO,t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO ");
		// FROM
		query.append("FROM CONVOCATORIAS t1 ,TIPOS_CONVOCATORIA t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TIPO_CONVOCATORIA= t2.ID_TIPO_CONVOCATORIA(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Convocatorias.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_CONVOCATORIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Convocatorias>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterconvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Convocatorias filterconvocatorias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.CONVOCATORIA CONVOCATORIA,t1.FECHA_RESOLUCION FECHARESOLUCION,t1.IMPORTE IMPORTE,t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION,t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION,t1.PLSQL_CALCULO PLSQLCALCULO,t1.PLSQL_REPARTO PLSQLREPARTO,t1.OBSERVACIONES OBSERVACIONES,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.FECHA_ORDEN_DIA FECHAORDENDIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.LIMITE_AT LIMITELOCAL,t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV,t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA,t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO,t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO ");
		// FROM
		query.append("FROM CONVOCATORIAS t1 ,TIPOS_CONVOCATORIA t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterconvocatorias, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Convocatorias.class,
				query, params, "ID_CONVOCATORIA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Convocatorias>>
	 */
	@Override
	public List<JerarquiaDto<Convocatorias>> findAllLikeJerarquia(Convocatorias filterConvocatorias,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.CONVOCATORIA CONVOCATORIA,t1.FECHA_RESOLUCION FECHARESOLUCION,t1.IMPORTE IMPORTE,t1.PORCENTAJE_SUBVENCION PORCENTAJESUBVENCION,t1.CANT_MAX_SUBVENCION CANTMAXSUBVENCION,t1.PLSQL_CALCULO PLSQLCALCULO,t1.PLSQL_REPARTO PLSQLREPARTO,t1.OBSERVACIONES OBSERVACIONES,t1.IMPORTE_MINIMO_INVERSION IMPORTEMINIMOINVERSION,t1.FECHA_ORDEN_DIA FECHAORDENDIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.LIMITE_AT LIMITELOCAL,t2.ID_TIPO_CONVOCATORIA TIPOSCONVIDTIPOCONV,t2.DESCRIPCION_CASTELLANO TIPOSCONVDESCCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCONVDESCEUSKERA,t2.FECHA_REGISTRO TIPOSCONVFECREGISTRO,t2.USUARIO_REGISTRO TIPOSCONVUSUREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM CONVOCATORIAS t1
		// ,TIPOS_CONVOCATORIA t2 ");
		List<String> from = new ArrayList<String>();
		from.add("CONVOCATORIAS");
		from.add("TIPOS_CONVOCATORIA");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterConvocatorias, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CONVOCATORIA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ConvocatoriasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Convocatorias filterConvocatorias, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM CONVOCATORIAS t1
		// ,TIPOS_CONVOCATORIA t2 ");
		List<String> from = new ArrayList<String>();
		from.add("CONVOCATORIAS");
		from.add("TIPOS_CONVOCATORIA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterConvocatorias, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CONVOCATORIA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Convocatorias>>
	 */
	@Override
	public List<TableRowDto<Convocatorias>> findAllChild(Convocatorias filterConvocatorias,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM CONVOCATORIAS t1
		// ,TIPOS_CONVOCATORIA t2 ");
		List<String> from = new ArrayList<String>();
		from.add("CONVOCATORIAS");
		from.add("TIPOS_CONVOCATORIA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterConvocatorias, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CONVOCATORIA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Convocatorias>(this.rwMapPK, "ID_CONVOCATORIA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Convocatorias entity
	 *
	 * @param convocatorias
	 *            Convocatorias Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Convocatorias convocatorias) {

		StringBuilder where = new StringBuilder(ConvocatoriasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		// SEGURIDAD
		List<GrantedAuthority> list = new ArrayList<GrantedAuthority>(
				SecurityContextHolder.getContext().getAuthentication().getAuthorities());

		boolean esComercio = false;
		boolean esTurismo = false;
		boolean esConsumo = false;

		for (int i = 0; i < list.size(); i++) {

			if ("ROLE_AB60-IN-0001".equals(list.get(i).getAuthority())) {
				esComercio = true;
				esTurismo = true;
				esConsumo = true;
			} else if ("ROLE_AB60-IN-0002".equals(list.get(i).getAuthority())) {
				esTurismo = true;
			} else if ("ROLE_AB60-IN-0003".equals(list.get(i).getAuthority())) {
				esTurismo = true;
			} else if ("ROLE_AB60-IN-0004".equals(list.get(i).getAuthority())) {
				esComercio = true;
			} else if ("ROLE_AB60-IN-0005".equals(list.get(i).getAuthority())) {
				esComercio = true;
			} else if ("ROLE_AB60-IN-0006".equals(list.get(i).getAuthority())) {
				esConsumo = true;
			} else if ("ROLE_AB60-IN-0007".equals(list.get(i).getAuthority())) {
				esConsumo = true;
			}

		}

		if (esComercio && esTurismo && esConsumo) {
			where.append(" AND (t3.ID_DIRECCION IN (?,?,?)) ");

			params.add(Constantes.COD_DIRECCION_COMERCIO);
			params.add(Constantes.COD_DIRECCION_TURISMO);
			params.add(Constantes.COD_DIRECCION_CONSUMO);

		} else if (esComercio && esTurismo) {
			where.append(" AND (t3.ID_DIRECCION IN (?,?)) ");

			params.add(Constantes.COD_DIRECCION_COMERCIO);
			params.add(Constantes.COD_DIRECCION_TURISMO);

		} else if (esComercio || esTurismo || esConsumo) {
			where.append(" AND (t3.ID_DIRECCION = ?)");
			if (esComercio) {
				params.add(Constantes.COD_DIRECCION_COMERCIO);
			} else if (esTurismo) {
				params.add(Constantes.COD_DIRECCION_TURISMO);
			} else if (esConsumo) {
				params.add(Constantes.COD_DIRECCION_CONSUMO);
			}
		}

		if (convocatorias != null && convocatorias.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(convocatorias.getIdConvocatoria());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t2.ID_TIPO_CONVOCATORIA = ?");
			params.add(convocatorias.getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(convocatorias.getTiposConvocatoria().getDescripcionCastellano());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(convocatorias.getTiposConvocatoria().getDescripcionEuskera());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(convocatorias.getTiposConvocatoria().getFechaRegistro());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(convocatorias.getTiposConvocatoria().getUsuarioRegistro());
		}
		if (convocatorias != null && convocatorias.getIdProcedimiento() != null) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(convocatorias.getIdProcedimiento());
		}
		if (convocatorias != null && convocatorias.getConvocatoria() != null) {
			where.append(" AND t1.CONVOCATORIA = ?");
			params.add(convocatorias.getConvocatoria());
		}
		if (convocatorias != null && convocatorias.getFechaResolucion() != null) {
			where.append(" AND t1.FECHA_RESOLUCION = ?");
			params.add(convocatorias.getFechaResolucion());
		}
		if (convocatorias != null && convocatorias.getImporte() != null) {
			where.append(" AND t1.IMPORTE = ?");
			params.add(convocatorias.getImporte());
		}
		if (convocatorias != null && convocatorias.getPorcentajeSubvencion() != null) {
			where.append(" AND t1.PORCENTAJE_SUBVENCION = ?");
			params.add(convocatorias.getPorcentajeSubvencion());
		}
		if (convocatorias != null && convocatorias.getCantMaxSubvencion() != null) {
			where.append(" AND t1.CANT_MAX_SUBVENCION = ?");
			params.add(convocatorias.getCantMaxSubvencion());
		}
		if (convocatorias != null && convocatorias.getPlsqlCalculo() != null) {
			where.append(" AND t1.PLSQL_CALCULO = ?");
			params.add(convocatorias.getPlsqlCalculo());
		}
		if (convocatorias != null && convocatorias.getPlsqlReparto() != null) {
			where.append(" AND t1.PLSQL_REPARTO = ?");
			params.add(convocatorias.getPlsqlReparto());
		}
		if (convocatorias != null && convocatorias.getObservaciones() != null) {
			where.append(" AND t1.OBSERVACIONES = ?");
			params.add(convocatorias.getObservaciones());
		}
		if (convocatorias != null && convocatorias.getFechaOrdenDia() != null) {
			where.append(" AND t1.FECHA_ORDEN_DIA = ?");
			params.add(convocatorias.getFechaOrdenDia());
		}
		if (convocatorias != null && convocatorias.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(convocatorias.getFechaRegistro());
		}
		if (convocatorias != null && convocatorias.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(convocatorias.getUsuarioRegistro());
		}
		if (convocatorias != null && convocatorias.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(convocatorias.getFechaUltmodificacion());
		}
		if (convocatorias != null && convocatorias.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(convocatorias.getUsuarioUltmodificacion());
		}
		if (convocatorias != null && convocatorias.getLimiteLocal() != null) {
			where.append(" AND t1.LIMITE_AT = ?");
			params.add(convocatorias.getLimiteLocal());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Convocatorias entity
	 *
	 * @param convocatorias
	 *            Convocatorias Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Convocatorias convocatorias, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ConvocatoriasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (convocatorias != null && convocatorias.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(convocatorias.getIdConvocatoria());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t2.ID_TIPO_CONVOCATORIA = ?");
			params.add(convocatorias.getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getTiposConvocatoria().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getTiposConvocatoria().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getTiposConvocatoria().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getTiposConvocatoria().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(convocatorias.getTiposConvocatoria().getFechaRegistro());
		}
		if (convocatorias != null && convocatorias.getTiposConvocatoria() != null
				&& convocatorias.getTiposConvocatoria().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getTiposConvocatoria().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getTiposConvocatoria().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getIdProcedimiento() != null) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(convocatorias.getIdProcedimiento());
		}
		if (convocatorias != null && convocatorias.getConvocatoria() != null) {
			where.append(" AND UPPER(t1.CONVOCATORIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getConvocatoria().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getConvocatoria().toUpperCase() + "%");
			}
			where.append(" AND t1.CONVOCATORIA IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getFechaResolucion() != null) {
			where.append(" AND t1.FECHA_RESOLUCION = ?");
			params.add(convocatorias.getFechaResolucion());
		}
		if (convocatorias != null && convocatorias.getImporte() != null) {
			where.append(" AND t1.IMPORTE = ?");
			params.add(convocatorias.getImporte());
		}
		if (convocatorias != null && convocatorias.getPorcentajeSubvencion() != null) {
			where.append(" AND t1.PORCENTAJE_SUBVENCION = ?");
			params.add(convocatorias.getPorcentajeSubvencion());
		}
		if (convocatorias != null && convocatorias.getCantMaxSubvencion() != null) {
			where.append(" AND t1.CANT_MAX_SUBVENCION = ?");
			params.add(convocatorias.getCantMaxSubvencion());
		}
		if (convocatorias != null && convocatorias.getPlsqlCalculo() != null) {
			where.append(" AND UPPER(t1.PLSQL_CALCULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getPlsqlCalculo().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getPlsqlCalculo().toUpperCase() + "%");
			}
			where.append(" AND t1.PLSQL_CALCULO IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getPlsqlReparto() != null) {
			where.append(" AND UPPER(t1.PLSQL_REPARTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getPlsqlReparto().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getPlsqlReparto().toUpperCase() + "%");
			}
			where.append(" AND t1.PLSQL_REPARTO IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getObservaciones() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES IS NOT NULL");
		}

		if (convocatorias != null && convocatorias.getFechaOrdenDia() != null) {
			where.append(" AND t1.FECHA_ORDEN_DIA = ?");
			params.add(convocatorias.getFechaOrdenDia());
		}
		if (convocatorias != null && convocatorias.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(convocatorias.getFechaRegistro());
		}
		if (convocatorias != null && convocatorias.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(convocatorias.getFechaUltmodificacion());
		}
		if (convocatorias != null && convocatorias.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(convocatorias.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + convocatorias.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (convocatorias != null && convocatorias.getLimiteLocal() != null) {
			where.append(" AND t1.LIMITE_AT = ?");
			params.add(convocatorias.getLimiteLocal());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public Convocatorias findByIdExpediente(Integer idExpediente) {
		String query = "SELECT t1.ID_CONVOCATORIA IDCONVOCATORIA FROM CONVOCATORIAS t1, PROCEDIMIENTOS t2, EXPEDIENTES t3 WHERE t1.ID_PROCEDIMIENTO = t2.ID_PROCEDIMIENTO AND t2.ID_PROCEDIMIENTO = t3.ID_PROCEDIMIENTO AND t3.ID_EXPEDIENTE = ?";

		List<Convocatorias> convocatoriasList = this.jdbcTemplate.query(query, this.rwMapFindByIdExpediente,
				idExpediente);
		return (Convocatorias) DataAccessUtils.uniqueResult(convocatoriasList);
	}
}
