package com.ejie.ab60.dao.convocatorias;

import com.ejie.ab60.model.convocatorias.DatosContables;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * DatosContablesDao  
 * 
 *  
 */

public interface DatosContablesDao {

	/**
	 * Inserts a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	DatosContables add(DatosContables datoscontables);

	/**
	 * Updates a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	DatosContables update(DatosContables datoscontables);

	/**
	 * Finds a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	DatosContables find(DatosContables datoscontables);

	/**
	 * Finds a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	DatosContables findbyConvocatoria(DatosContables datoscontables);

	/**
	 * Removes a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 */
	void remove(DatosContables datoscontables);

	/**
	 * Finds a List of rows in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<DatosContables> findAll(DatosContables datoscontables, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the DatosContables table using like.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<DatosContables> findAllLike(DatosContables datoscontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(DatosContables filterDatosContables, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the DatosContables table using like.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(DatosContables datoscontables, Boolean startsWith);

	/**
	 * Counts rows in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return Long
	 */
	Long findAllCount(DatosContables datoscontables);

	/**
	 * Reorder selection.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosContables>>
	 */
	List<TableRowDto<DatosContables>> reorderSelection(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param searchDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosContables>>
	 */
	List<TableRowDto<DatosContables>> search(DatosContables filterDatosContables, DatosContables searchDatosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<DatosContables>>
	 */
	List<JerarquiaDto<DatosContables>> findAllLikeJerarquia(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(DatosContables filterDatosContables, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<DatosContables>>
	 */
	List<TableRowDto<DatosContables>> findAllChild(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto);

}
