package com.ejie.ab60.dao.convocatorias;

import com.ejie.ab60.model.convocatorias.DatosContables;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * DatosContablesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class DatosContablesDaoImpl implements DatosContablesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDDATOCONTABLE", "IDCONVOCATORIA", "INSTITUCION",
			"EJERCICIO", "SECCION", "USUARIOIKUS", "IDIOMA", "CONCEPTORESUMIDO", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<DatosContables> rwMap = new RowMapper<DatosContables>() {
		public DatosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DatosContables(resultSet.getInt("IDDATOCONTABLE"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("INSTITUCION"), resultSet.getString("EJERCICIO"),
					resultSet.getString("SECCION"), resultSet.getString("USUARIOIKUS"), resultSet.getInt("IDIOMA"),
					resultSet.getString("CONCEPTORESUMIDO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getBigDecimal("IMPORTE"),
					resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
		}
	};

	private RowMapper<DatosContables> rwMapPK = new RowMapper<DatosContables>() {
		public DatosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DatosContables(resultSet.getInt("IDDATOCONTABLE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<DatosContables>> rwMapJerarquia = new RowMapper<JerarquiaDto<DatosContables>>() {
		public JerarquiaDto<DatosContables> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			DatosContables datoscontables = new DatosContables(resultSet.getInt("IDDATOCONTABLE"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getString("INSTITUCION"),
					resultSet.getString("EJERCICIO"), resultSet.getString("SECCION"),
					resultSet.getString("USUARIOIKUS"), resultSet.getInt("IDIOMA"),
					resultSet.getString("CONCEPTORESUMIDO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getBigDecimal("IMPORTE"),
					resultSet.getBigDecimal("IMPORTEDISPONIBLE"));

			JerarquiaDto<DatosContables> jerarquia = new JerarquiaDto<DatosContables>();
			jerarquia.setModel(datoscontables);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	public DatosContables add(DatosContables datoscontables) {
		datoscontables.setIdDatoContable(
				this.jdbcTemplate.queryForObject("SELECT AB60.S_AB6094T00.NEXTVAL FROM DUAL", Integer.class));
		String query = "INSERT INTO DATOS_CONTABLES (ID_DATO_CONTABLE, ID_CONVOCATORIA, INSTITUCION, EJERCICIO, SECCION, USUARIO_IKUS, ID_IDIOMA, CONCEPTO_RESUMIDO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, datoscontables.getIdDatoContable(), datoscontables.getIdConvocatoria(),
				datoscontables.getInstitucion(), datoscontables.getEjercicio(), datoscontables.getSeccion(),
				datoscontables.getUsuarioIkus(), datoscontables.getIdIdioma(), datoscontables.getConceptoResumido(),
				datoscontables.getFechaRegistro(), datoscontables.getUsuarioRegistro());
		return datoscontables;
	}

	/**
	 * Updates a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	public DatosContables update(DatosContables datoscontables) {
		String query = "UPDATE DATOS_CONTABLES SET ID_CONVOCATORIA=?, INSTITUCION=?, EJERCICIO=?, SECCION=?, USUARIO_IKUS=?, ID_IDIOMA=?, CONCEPTO_RESUMIDO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_DATO_CONTABLE=?";
		this.jdbcTemplate.update(query, datoscontables.getIdConvocatoria(), datoscontables.getInstitucion(),
				datoscontables.getEjercicio(), datoscontables.getSeccion(), datoscontables.getUsuarioIkus(),
				datoscontables.getIdIdioma(), datoscontables.getConceptoResumido(),
				datoscontables.getFechaUltmodificacion(), datoscontables.getUsuarioUltmodificacion(),
				datoscontables.getIdDatoContable());
		return datoscontables;
	}

	/**
	 * Finds a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	@Transactional(readOnly = true)
	public DatosContables find(DatosContables datoscontables) {
		String query = "SELECT t1.ID_DATO_CONTABLE IDDATOCONTABLE, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.INSTITUCION INSTITUCION, t1.EJERCICIO EJERCICIO, t1.SECCION SECCION, t1.USUARIO_IKUS USUARIOIKUS, t1.ID_IDIOMA IDIOMA, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM DATOS_CONTABLES t1  WHERE t1.ID_DATO_CONTABLE = ?  ";

		List<DatosContables> datoscontablesList = this.jdbcTemplate.query(query, this.rwMap,
				datoscontables.getIdDatoContable());
		return (DatosContables) DataAccessUtils.uniqueResult(datoscontablesList);
	}

	/**
	 * Finds a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return DatosContables
	 */
	@Transactional(readOnly = true)
	public DatosContables findbyConvocatoria(DatosContables datoscontables) {
		String query = "SELECT t1.ID_DATO_CONTABLE IDDATOCONTABLE, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.INSTITUCION INSTITUCION, t1.EJERCICIO EJERCICIO, t1.SECCION SECCION, t1.USUARIO_IKUS USUARIOIKUS, t1.ID_IDIOMA IDIOMA, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.IMPORTE IMPORTE, t2.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE FROM DATOS_CONTABLES t1 RIGHT JOIN CONVOCATORIAS t2 ON t1.ID_CONVOCATORIA = t2.ID_CONVOCATORIA WHERE t1.ID_CONVOCATORIA = ?  ";

		List<DatosContables> datoscontablesList = this.jdbcTemplate.query(query, this.rwMap,
				datoscontables.getIdConvocatoria());
		return (DatosContables) DataAccessUtils.uniqueResult(datoscontablesList);
	}

	/**
	 * Removes a single row in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return
	 */
	public void remove(DatosContables datoscontables) {
		String query = "DELETE FROM DATOS_CONTABLES WHERE ID_DATO_CONTABLE=?";
		this.jdbcTemplate.update(query, datoscontables.getIdDatoContable());
	}

	/**
	 * Finds a list of rows in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<DatosContables>
	 */
	@Transactional(readOnly = true)
	public List<DatosContables> findAll(DatosContables datoscontables, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DATO_CONTABLE IDDATOCONTABLE,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.USUARIO_IKUS USUARIOIKUS,t1.IDIOMA IDIOMA,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM DATOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(datoscontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DatosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<DatosContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the DatosContables table using like.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<DatosContables>
	 */
	@Transactional(readOnly = true)
	public List<DatosContables> findAllLike(DatosContables datoscontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DATO_CONTABLE IDDATOCONTABLE,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.USUARIO_IKUS USUARIOIKUS,t1.IDIOMA IDIOMA,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM DATOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DatosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<DatosContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the DatosContables table.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(DatosContables datoscontables) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DATOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(datoscontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the DatosContables table using like.
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(DatosContables datoscontables, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DATOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of DatosContables selected for rup_table
	 *
	 * @param datoscontables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosContables>>
	 */
	@Override
	public List<TableRowDto<DatosContables>> reorderSelection(DatosContables datoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATO_CONTABLE IDDATOCONTABLE,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.USUARIO_IKUS USUARIOIKUS,t1.IDIOMA IDIOMA,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM DATOS_CONTABLES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				DatosContables.class, filterParamList, "ID_DATO_CONTABLE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DatosContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            DatosContables
	 * @param searchParams
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosContables>>
	 */
	@Override
	public List<TableRowDto<DatosContables>> search(DatosContables filterParams, DatosContables searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATO_CONTABLE IDDATOCONTABLE,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.USUARIO_IKUS USUARIOIKUS,t1.IDIOMA IDIOMA,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM DATOS_CONTABLES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				DatosContables.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_DATO_CONTABLE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DatosContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterdatoscontables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(DatosContables filterdatoscontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATO_CONTABLE IDDATOCONTABLE,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.USUARIO_IKUS USUARIOIKUS,t1.IDIOMA IDIOMA,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM DATOS_CONTABLES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterdatoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, DatosContables.class,
				query, params, "ID_DATO_CONTABLE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<DatosContables>>
	 */
	@Override
	public List<JerarquiaDto<DatosContables>> findAllLikeJerarquia(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATO_CONTABLE IDDATOCONTABLE,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.USUARIO_IKUS USUARIOIKUS,t1.IDIOMA IDIOMA,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_CONTABLES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_CONTABLES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDatosContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_DATO_CONTABLE", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					DatosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(DatosContables filterDatosContables, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_CONTABLES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_CONTABLES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDatosContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_DATO_CONTABLE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<DatosContables>>
	 */
	@Override
	public List<TableRowDto<DatosContables>> findAllChild(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_CONTABLES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_CONTABLES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDatosContables, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_DATO_CONTABLE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<DatosContables>(this.rwMapPK, "ID_DATO_CONTABLE"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DatosContables entity
	 *
	 * @param datoscontables
	 *            DatosContables Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(DatosContables datoscontables) {

		StringBuilder where = new StringBuilder(DatosContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (datoscontables != null && datoscontables.getIdDatoContable() != null) {
			where.append(" AND t1.ID_DATO_CONTABLE = ?");
			params.add(datoscontables.getIdDatoContable());
		}
		if (datoscontables != null && datoscontables.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(datoscontables.getIdConvocatoria());
		}
		if (datoscontables != null && datoscontables.getInstitucion() != null) {
			where.append(" AND t1.INSTITUCION = ?");
			params.add(datoscontables.getInstitucion());
		}
		if (datoscontables != null && datoscontables.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(datoscontables.getEjercicio());
		}
		if (datoscontables != null && datoscontables.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(datoscontables.getSeccion());
		}
		if (datoscontables != null && datoscontables.getUsuarioIkus() != null) {
			where.append(" AND t1.USUARIO_IKUS = ?");
			params.add(datoscontables.getUsuarioIkus());
		}
		if (datoscontables != null && datoscontables.getIdIdioma() != null) {
			where.append(" AND t1.ID_IDIOMA = ?");
			params.add(datoscontables.getIdIdioma());
		}
		if (datoscontables != null && datoscontables.getConceptoResumido() != null) {
			where.append(" AND t1.CONCEPTO_RESUMIDO = ?");
			params.add(datoscontables.getConceptoResumido());
		}
		if (datoscontables != null && datoscontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(datoscontables.getFechaRegistro());
		}
		if (datoscontables != null && datoscontables.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(datoscontables.getUsuarioRegistro());
		}
		if (datoscontables != null && datoscontables.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(datoscontables.getFechaUltmodificacion());
		}
		if (datoscontables != null && datoscontables.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(datoscontables.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DatosContables entity
	 *
	 * @param datoscontables
	 *            DatosContables Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(DatosContables datoscontables, Boolean startsWith) {

		StringBuilder where = new StringBuilder(DatosContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (datoscontables != null && datoscontables.getIdDatoContable() != null) {
			where.append(" AND t1.ID_DATO_CONTABLE = ?");
			params.add(datoscontables.getIdDatoContable());
		}
		if (datoscontables != null && datoscontables.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(datoscontables.getIdConvocatoria());
		}
		if (datoscontables != null && datoscontables.getInstitucion() != null) {
			where.append(" AND t1.INSTITUCION = ?");
			params.add(datoscontables.getInstitucion());
		}
		if (datoscontables != null && datoscontables.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(datoscontables.getEjercicio());
		}
		if (datoscontables != null && datoscontables.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(datoscontables.getSeccion());
		}
		if (datoscontables != null && datoscontables.getUsuarioIkus() != null) {
			where.append(" AND UPPER(t1.USUARIO_IKUS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datoscontables.getUsuarioIkus().toUpperCase() + "%");
			} else {
				params.add("%" + datoscontables.getUsuarioIkus().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_IKUS IS NOT NULL");
		}
		if (datoscontables != null && datoscontables.getIdIdioma() != null) {
			where.append(" AND t1.ID_IDIOMA = ?");
			params.add(datoscontables.getIdIdioma());
		}
		if (datoscontables != null && datoscontables.getConceptoResumido() != null) {
			where.append(" AND UPPER(t1.CONCEPTO_RESUMIDO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datoscontables.getConceptoResumido().toUpperCase() + "%");
			} else {
				params.add("%" + datoscontables.getConceptoResumido().toUpperCase() + "%");
			}
			where.append(" AND t1.CONCEPTO_RESUMIDO IS NOT NULL");
		}
		if (datoscontables != null && datoscontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(datoscontables.getFechaRegistro());
		}
		if (datoscontables != null && datoscontables.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datoscontables.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + datoscontables.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (datoscontables != null && datoscontables.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(datoscontables.getFechaUltmodificacion());
		}
		if (datoscontables != null && datoscontables.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datoscontables.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + datoscontables.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
