package com.ejie.ab60.dao.convocatorias;

import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

import com.ejie.ab60.model.Idiomas;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;

/**
 * IdiomasDao  
 * 
 *  
 */

public interface IdiomasDao {

	/**
	 * Inserts a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	Idiomas add(Idiomas idiomas);

	/**
	 * Updates a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	Idiomas update(Idiomas idiomas);

	/**
	 * Finds a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	Idiomas find(Idiomas idiomas);

	/**
	 * Removes a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 */
	void remove(Idiomas idiomas);

	/**
	 * Finds a List of rows in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<Idiomas> findAll(Idiomas idiomas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Idiomas table using like.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Idiomas> findAllLike(Idiomas idiomas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the Idiomas table using like.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(Idiomas idiomas, Boolean startsWith);

	/**
	 * Counts rows in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Long
	 */
	Long findAllCount(Idiomas idiomas);

	/**
	 * Reorder selection.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Idiomas>>
	 */
	List<TableRowDto<Idiomas>> reorderSelection(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param searchIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Idiomas>>
	 */
	List<TableRowDto<Idiomas>> search(Idiomas filterIdiomas, Idiomas searchIdiomas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Idiomas>>
	 */
	List<JerarquiaDto<Idiomas>> findAllLikeJerarquia(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Idiomas>>
	 */
	List<TableRowDto<Idiomas>> findAllChild(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds a list of rows in the Idiomas table.
	 *
	 * 
	 * @return List<Idiomas>
	 */
	List<Idiomas> findIdioma();

}
