package com.ejie.ab60.dao.convocatorias;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.Idiomas;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;

/**
 * IdiomasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class IdiomasDaoImpl implements IdiomasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDIDIOMA", "IDCONVOCATORIA",
			"DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Idiomas> rwMap = new RowMapper<Idiomas>() {
		public Idiomas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Idiomas(resultSet.getLong("IDIDIOMA"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<Idiomas> rwMapPK = new RowMapper<Idiomas>() {
		public Idiomas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Idiomas(resultSet.getLong("IDIDIOMA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Idiomas>> rwMapJerarquia = new RowMapper<JerarquiaDto<Idiomas>>() {
		public JerarquiaDto<Idiomas> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Idiomas idiomas = new Idiomas(resultSet.getLong("IDIDIOMA"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<Idiomas> jerarquia = new JerarquiaDto<Idiomas>();
			jerarquia.setModel(idiomas);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Finds a list of rows in the Idiomas table.
	 *
	 * 
	 * @return List<Idiomas>
	 */
	@Transactional(readOnly = true)
	public List<Idiomas> findIdioma() {

		String query = "SELECT  t1.ID_IDIOMA IDIDIOMA,t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO  FROM IDIOMAS t1 WHERE t1.ID_CONVOCATORIA IS NULL";

		return (List<Idiomas>) this.jdbcTemplate.query(query, this.rwMap);

	}

	/**
	 * Inserts a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	public Idiomas add(Idiomas idiomas) {
		String query = "INSERT INTO IDIOMAS (ID_IDIOMA, ID_CONVOCATORIA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, idiomas.getIdIdioma(), idiomas.getIdConvocatoria(),
				idiomas.getDescripcionCastellano(), idiomas.getDescripcionEuskera(), idiomas.getFechaRegistro(),
				idiomas.getUsuarioRegistro());
		return idiomas;
	}

	/**
	 * Updates a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	public Idiomas update(Idiomas idiomas) {
		String query = "UPDATE IDIOMAS SET ID_CONVOCATORIA=?, DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_IDIOMA=?";
		this.jdbcTemplate.update(query, idiomas.getIdConvocatoria(), idiomas.getDescripcionCastellano(),
				idiomas.getDescripcionEuskera(), idiomas.getFechaRegistro(), idiomas.getUsuarioRegistro(),
				idiomas.getIdIdioma());
		return idiomas;
	}

	/**
	 * Finds a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	@Transactional(readOnly = true)
	public Idiomas find(Idiomas idiomas) {
		String query = "SELECT t1.ID_IDIOMA IDIDIOMA, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM IDIOMAS t1  WHERE t1.ID_IDIOMA = ?  ";

		List<Idiomas> idiomasList = this.jdbcTemplate.query(query, this.rwMap, idiomas.getIdIdioma());
		return (Idiomas) DataAccessUtils.uniqueResult(idiomasList);
	}

	/**
	 * Removes a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return
	 */
	public void remove(Idiomas idiomas) {
		String query = "DELETE FROM IDIOMAS WHERE ID_IDIOMA=?";
		this.jdbcTemplate.update(query, idiomas.getIdIdioma());
	}

	/**
	 * Finds a list of rows in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Idiomas>
	 */
	@Transactional(readOnly = true)
	public List<Idiomas> findAll(Idiomas idiomas, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_IDIOMA IDIDIOMA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM IDIOMAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(idiomas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, IdiomasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Idiomas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Idiomas table using like.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Idiomas>
	 */
	@Transactional(readOnly = true)
	public List<Idiomas> findAllLike(Idiomas idiomas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_IDIOMA IDIDIOMA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM IDIOMAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(idiomas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, IdiomasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Idiomas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Idiomas idiomas) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM IDIOMAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(idiomas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Idiomas table using like.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Idiomas idiomas, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM IDIOMAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(idiomas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Idiomas selected for rup_table
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Idiomas>>
	 */
	@Override
	public List<TableRowDto<Idiomas>> reorderSelection(Idiomas idiomas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_IDIOMA IDIDIOMA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM IDIOMAS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(idiomas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Idiomas.class,
				filterParamList, "ID_IDIOMA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Idiomas>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Idiomas
	 * @param searchParams
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Idiomas>>
	 */
	@Override
	public List<TableRowDto<Idiomas>> search(Idiomas filterParams, Idiomas searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_IDIOMA IDIDIOMA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM IDIOMAS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Idiomas.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_IDIOMA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Idiomas>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filteridiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Idiomas filteridiomas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_IDIOMA IDIDIOMA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM IDIOMAS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filteridiomas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Idiomas.class, query,
				params, "ID_IDIOMA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Idiomas>>
	 */
	@Override
	public List<JerarquiaDto<Idiomas>> findAllLikeJerarquia(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_IDIOMA IDIDIOMA,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM IDIOMAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("IDIOMAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterIdiomas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_IDIOMA", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					IdiomasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM IDIOMAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("IDIOMAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterIdiomas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_IDIOMA", "ID_PADRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Idiomas>>
	 */
	@Override
	public List<TableRowDto<Idiomas>> findAllChild(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM IDIOMAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("IDIOMAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterIdiomas, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_IDIOMA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Idiomas>(this.rwMapPK, "ID_IDIOMA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Idiomas entity
	 *
	 * @param idiomas
	 *            Idiomas Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Idiomas idiomas) {

		StringBuilder where = new StringBuilder(IdiomasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (idiomas != null && idiomas.getIdIdioma() != null) {
			where.append(" AND t1.ID_IDIOMA = ?");
			params.add(idiomas.getIdIdioma());
		}
		if (idiomas != null && idiomas.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(idiomas.getIdConvocatoria());
		}
		if (idiomas != null && idiomas.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(idiomas.getDescripcionCastellano());
		}
		if (idiomas != null && idiomas.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(idiomas.getDescripcionEuskera());
		}
		if (idiomas != null && idiomas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(idiomas.getFechaRegistro());
		}
		if (idiomas != null && idiomas.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(idiomas.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Idiomas entity
	 *
	 * @param idiomas
	 *            Idiomas Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Idiomas idiomas, Boolean startsWith) {

		StringBuilder where = new StringBuilder(IdiomasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (idiomas != null && idiomas.getIdIdioma() != null) {
			where.append(" AND t1.ID_IDIOMA = ?");
			params.add(idiomas.getIdIdioma());
		}
		if (idiomas != null && idiomas.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(idiomas.getIdConvocatoria());
		}
		if (idiomas != null && idiomas.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(idiomas.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + idiomas.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (idiomas != null && idiomas.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(idiomas.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + idiomas.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (idiomas != null && idiomas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(idiomas.getFechaRegistro());
		}
		if (idiomas != null && idiomas.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(idiomas.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + idiomas.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
