package com.ejie.ab60.dao.convocatorias;

import com.ejie.ab60.model.convocatorias.ReferenciasIntervencion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * ReferenciasIntervencionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ReferenciasIntervencionDaoImpl implements ReferenciasIntervencionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDREFERENCIAINTERVENCION", "IDAPLICACIONPRESU",
			"EJERCICIO", "ANYOORIGEN", "NUMERO", "DISPONIBLE", "OBLIGACION", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ReferenciasIntervencion> rwMap = new RowMapper<ReferenciasIntervencion>() {
		public ReferenciasIntervencion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ReferenciasIntervencion(resultSet.getInt("IDREFERENCIAINTERVENCION"),
					resultSet.getInt("IDAPLICACIONPRESU"), resultSet.getString("EJERCICIO"),
					resultSet.getString("ANYOORIGEN"), resultSet.getString("NUMERO"), resultSet.getString("DISPONIBLE"),
					resultSet.getString("OBLIGACION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<ReferenciasIntervencion> rwMapPK = new RowMapper<ReferenciasIntervencion>() {
		public ReferenciasIntervencion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ReferenciasIntervencion(resultSet.getInt("IDREFERENCIAINTERVENCION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ReferenciasIntervencion>> rwMapJerarquia = new RowMapper<JerarquiaDto<ReferenciasIntervencion>>() {
		public JerarquiaDto<ReferenciasIntervencion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ReferenciasIntervencion referenciasintervencion = new ReferenciasIntervencion(
					resultSet.getInt("IDREFERENCIAINTERVENCION"), resultSet.getInt("IDAPLICACIONPRESU"),
					resultSet.getString("EJERCICIO"), resultSet.getString("ANYOORIGEN"), resultSet.getString("NUMERO"),
					resultSet.getString("DISPONIBLE"), resultSet.getString("OBLIGACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<ReferenciasIntervencion> jerarquia = new JerarquiaDto<ReferenciasIntervencion>();
			jerarquia.setModel(referenciasintervencion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @return ReferenciasIntervencion
	 */
	public ReferenciasIntervencion add(ReferenciasIntervencion referenciasintervencion) {
		referenciasintervencion.setIdReferenciaIntervencion(
				this.jdbcTemplate.queryForObject("SELECT AB60.S_AB6096T00.NEXTVAL FROM DUAL", Integer.class));
		String query = "INSERT INTO REFERENCIAS_INTERVENCION (ID_REFERENCIA_INTERVENCION, ID_APLICACION_PRESUPUESTARIA, EJERCICIO, ANYO_ORIGEN, NUMERO, DISPONIBLE, OBLIGACION, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, referenciasintervencion.getIdReferenciaIntervencion(),
				referenciasintervencion.getIdAplicacionPresupuestaria(), referenciasintervencion.getEjercicio(),
				referenciasintervencion.getAnyoOrigen(), referenciasintervencion.getNumero(),
				referenciasintervencion.getDisponible(), referenciasintervencion.getObligacion(),
				referenciasintervencion.getFechaRegistro(), referenciasintervencion.getUsuarioRegistro());
		return referenciasintervencion;
	}

	/**
	 * Updates a single row in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @return ReferenciasIntervencion
	 */
	public ReferenciasIntervencion update(ReferenciasIntervencion referenciasintervencion) {
		String query = "UPDATE REFERENCIAS_INTERVENCION SET ID_APLICACION_PRESUPUESTARIA=?, EJERCICIO=?, ANYO_ORIGEN=?, NUMERO=?, DISPONIBLE=?, OBLIGACION=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REFERENCIA_INTERVENCION=?";
		this.jdbcTemplate.update(query, referenciasintervencion.getIdAplicacionPresupuestaria(),
				referenciasintervencion.getEjercicio(), referenciasintervencion.getAnyoOrigen(),
				referenciasintervencion.getNumero(), referenciasintervencion.getDisponible(),
				referenciasintervencion.getObligacion(), referenciasintervencion.getFechaUltmodificacion(),
				referenciasintervencion.getUsuarioUltmodificacion(),
				referenciasintervencion.getIdReferenciaIntervencion());
		return referenciasintervencion;
	}

	/**
	 * Finds a single row in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @return ReferenciasIntervencion
	 */
	@Transactional(readOnly = true)
	public ReferenciasIntervencion find(ReferenciasIntervencion referenciasintervencion) {
		String query = "SELECT t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.EJERCICIO EJERCICIO, t1.ANYO_ORIGEN ANYOORIGEN, t1.NUMERO NUMERO, t1.DISPONIBLE DISPONIBLE, t1.OBLIGACION OBLIGACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM REFERENCIAS_INTERVENCION t1  WHERE t1.ID_REFERENCIA_INTERVENCION = ?  ";

		List<ReferenciasIntervencion> referenciasintervencionList = this.jdbcTemplate.query(query, this.rwMap,
				referenciasintervencion.getIdReferenciaIntervencion());
		return (ReferenciasIntervencion) DataAccessUtils.uniqueResult(referenciasintervencionList);
	}

	/**
	 * Finds a single row in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @return ReferenciasIntervencion
	 */
	@Transactional(readOnly = true)
	public ReferenciasIntervencion findByAplicPresu(ReferenciasIntervencion referenciasintervencion) {
		String query = "SELECT t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION, t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESU, t1.EJERCICIO EJERCICIO, t1.ANYO_ORIGEN ANYOORIGEN, t1.NUMERO NUMERO, t1.DISPONIBLE DISPONIBLE, t1.OBLIGACION OBLIGACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM REFERENCIAS_INTERVENCION t1  WHERE t1.ID_APLICACION_PRESUPUESTARIA = ?  ";

		List<ReferenciasIntervencion> referenciasintervencionList = this.jdbcTemplate.query(query, this.rwMap,
				referenciasintervencion.getIdAplicacionPresupuestaria());
		return (ReferenciasIntervencion) DataAccessUtils.uniqueResult(referenciasintervencionList);
	}

	/**
	 * Removes a single row in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @return
	 */
	public void remove(ReferenciasIntervencion referenciasintervencion) {
		String query = "DELETE FROM REFERENCIAS_INTERVENCION WHERE ID_REFERENCIA_INTERVENCION=?";
		this.jdbcTemplate.update(query, referenciasintervencion.getIdReferenciaIntervencion());
	}

	/**
	 * Removes a single row in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @return
	 */
	public void removeByAplicacionPresu(ReferenciasIntervencion referenciasintervencion) {
		String query = "DELETE FROM REFERENCIAS_INTERVENCION WHERE ID_APLICACION_PRESUPUESTARIA=?";
		this.jdbcTemplate.update(query, referenciasintervencion.getIdAplicacionPresupuestaria());
	}

	/**
	 * Finds a list of rows in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ReferenciasIntervencion>
	 */
	@Transactional(readOnly = true)
	public List<ReferenciasIntervencion> findAll(ReferenciasIntervencion referenciasintervencion,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.EJERCICIO EJERCICIO,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.OBLIGACION OBLIGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REFERENCIAS_INTERVENCION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(referenciasintervencion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ReferenciasIntervencionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ReferenciasIntervencion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the ReferenciasIntervencion table using like.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ReferenciasIntervencion>
	 */
	@Transactional(readOnly = true)
	public List<ReferenciasIntervencion> findAllLike(ReferenciasIntervencion referenciasintervencion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.EJERCICIO EJERCICIO,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.OBLIGACION OBLIGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM REFERENCIAS_INTERVENCION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(referenciasintervencion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ReferenciasIntervencionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ReferenciasIntervencion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ReferenciasIntervencion table.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ReferenciasIntervencion referenciasintervencion) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REFERENCIAS_INTERVENCION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(referenciasintervencion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ReferenciasIntervencion table using like.
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ReferenciasIntervencion referenciasintervencion, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REFERENCIAS_INTERVENCION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(referenciasintervencion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ReferenciasIntervencion selected for rup_table
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ReferenciasIntervencion>>
	 */
	@Override
	public List<TableRowDto<ReferenciasIntervencion>> reorderSelection(ReferenciasIntervencion referenciasintervencion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.EJERCICIO EJERCICIO,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.OBLIGACION OBLIGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REFERENCIAS_INTERVENCION t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(referenciasintervencion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ReferenciasIntervencion.class, filterParamList, "ID_REFERENCIA_INTERVENCION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ReferenciasIntervencion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ReferenciasIntervencion
	 * @param searchParams
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ReferenciasIntervencion>>
	 */
	@Override
	public List<TableRowDto<ReferenciasIntervencion>> search(ReferenciasIntervencion filterParams,
			ReferenciasIntervencion searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.EJERCICIO EJERCICIO,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.OBLIGACION OBLIGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REFERENCIAS_INTERVENCION t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ReferenciasIntervencion.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_REFERENCIA_INTERVENCION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ReferenciasIntervencion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterreferenciasintervencion
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ReferenciasIntervencion filterreferenciasintervencion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.EJERCICIO EJERCICIO,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.OBLIGACION OBLIGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM REFERENCIAS_INTERVENCION t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterreferenciasintervencion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				ReferenciasIntervencion.class, query, params, "ID_REFERENCIA_INTERVENCION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ReferenciasIntervencion table.
	 *
	 * @param filterReferenciasIntervencion
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ReferenciasIntervencion>>
	 */
	@Override
	public List<JerarquiaDto<ReferenciasIntervencion>> findAllLikeJerarquia(
			ReferenciasIntervencion filterReferenciasIntervencion, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION,t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.EJERCICIO EJERCICIO,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.OBLIGACION OBLIGACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REFERENCIAS_INTERVENCION
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REFERENCIAS_INTERVENCION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterReferenciasIntervencion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REFERENCIA_INTERVENCION",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ReferenciasIntervencionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterReferenciasIntervencion
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ReferenciasIntervencion filterReferenciasIntervencion,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REFERENCIAS_INTERVENCION
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REFERENCIAS_INTERVENCION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterReferenciasIntervencion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_REFERENCIA_INTERVENCION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterReferenciasIntervencion
	 *            ReferenciasIntervencion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ReferenciasIntervencion>>
	 */
	@Override
	public List<TableRowDto<ReferenciasIntervencion>> findAllChild(
			ReferenciasIntervencion filterReferenciasIntervencion, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REFERENCIAS_INTERVENCION
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REFERENCIAS_INTERVENCION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterReferenciasIntervencion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_REFERENCIA_INTERVENCION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ReferenciasIntervencion>(this.rwMapPK, "ID_REFERENCIA_INTERVENCION"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ReferenciasIntervencion entity
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion Bean with the criteria values to
	 *            filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ReferenciasIntervencion referenciasintervencion) {

		StringBuilder where = new StringBuilder(ReferenciasIntervencionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (referenciasintervencion != null && referenciasintervencion.getIdReferenciaIntervencion() != null) {
			where.append(" AND t1.ID_REFERENCIA_INTERVENCION = ?");
			params.add(referenciasintervencion.getIdReferenciaIntervencion());
		}
		if (referenciasintervencion != null && referenciasintervencion.getIdAplicacionPresupuestaria() != null) {
			where.append(" AND t1.ID_APLICACION_PRESUPUESTARIA = ?");
			params.add(referenciasintervencion.getIdAplicacionPresupuestaria());
		}
		if (referenciasintervencion != null && referenciasintervencion.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(referenciasintervencion.getEjercicio());
		}
		if (referenciasintervencion != null && referenciasintervencion.getAnyoOrigen() != null) {
			where.append(" AND t1.ANYO_ORIGEN = ?");
			params.add(referenciasintervencion.getAnyoOrigen());
		}
		if (referenciasintervencion != null && referenciasintervencion.getNumero() != null) {
			where.append(" AND t1.NUMERO = ?");
			params.add(referenciasintervencion.getNumero());
		}
		if (referenciasintervencion != null && referenciasintervencion.getDisponible() != null) {
			where.append(" AND t1.DISPONIBLE = ?");
			params.add(referenciasintervencion.getDisponible());
		}
		if (referenciasintervencion != null && referenciasintervencion.getObligacion() != null) {
			where.append(" AND t1.OBLIGACION = ?");
			params.add(referenciasintervencion.getObligacion());
		}
		if (referenciasintervencion != null && referenciasintervencion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(referenciasintervencion.getFechaRegistro());
		}
		if (referenciasintervencion != null && referenciasintervencion.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(referenciasintervencion.getUsuarioRegistro());
		}
		if (referenciasintervencion != null && referenciasintervencion.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(referenciasintervencion.getFechaUltmodificacion());
		}
		if (referenciasintervencion != null && referenciasintervencion.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(referenciasintervencion.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ReferenciasIntervencion entity
	 *
	 * @param referenciasintervencion
	 *            ReferenciasIntervencion Bean with the criteria values to
	 *            filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ReferenciasIntervencion referenciasintervencion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ReferenciasIntervencionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (referenciasintervencion != null && referenciasintervencion.getIdReferenciaIntervencion() != null) {
			where.append(" AND t1.ID_REFERENCIA_INTERVENCION = ?");
			params.add(referenciasintervencion.getIdReferenciaIntervencion());
		}
		if (referenciasintervencion != null && referenciasintervencion.getIdAplicacionPresupuestaria() != null) {
			where.append(" AND t1.ID_APLICACION_PRESUPUESTARIA = ?");
			params.add(referenciasintervencion.getIdAplicacionPresupuestaria());
		}
		if (referenciasintervencion != null && referenciasintervencion.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(referenciasintervencion.getEjercicio());
		}
		if (referenciasintervencion != null && referenciasintervencion.getAnyoOrigen() != null) {
			where.append(" AND t1.ANYO_ORIGEN = ?");
			params.add(referenciasintervencion.getAnyoOrigen());
		}
		if (referenciasintervencion != null && referenciasintervencion.getNumero() != null) {
			where.append(" AND t1.NUMERO = ?");
			params.add(referenciasintervencion.getNumero());
		}
		if (referenciasintervencion != null && referenciasintervencion.getDisponible() != null) {
			where.append(" AND t1.DISPONIBLE = ?");
			params.add(referenciasintervencion.getDisponible());
		}
		if (referenciasintervencion != null && referenciasintervencion.getObligacion() != null) {
			where.append(" AND t1.OBLIGACION = ?");
			params.add(referenciasintervencion.getObligacion());
		}
		if (referenciasintervencion != null && referenciasintervencion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(referenciasintervencion.getFechaRegistro());
		}
		if (referenciasintervencion != null && referenciasintervencion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(referenciasintervencion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + referenciasintervencion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (referenciasintervencion != null && referenciasintervencion.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(referenciasintervencion.getFechaUltmodificacion());
		}
		if (referenciasintervencion != null && referenciasintervencion.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(referenciasintervencion.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + referenciasintervencion.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
