package com.ejie.ab60.dao.convocatorias;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.convocatorias.TiposAyuda;

/**
 * TiposAyudaDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposAyudaDaoImpl implements TiposAyudaDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOAYUDA", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposAyuda> rwMap = new RowMapper<TiposAyuda>() {
		public TiposAyuda mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposAyuda(resultSet.getLong("IDTIPOAYUDA"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<TiposAyuda> rwMapPK = new RowMapper<TiposAyuda>() {
		public TiposAyuda mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposAyuda(resultSet.getLong("IDTIPOAYUDA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposAyuda>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposAyuda>>() {
		public JerarquiaDto<TiposAyuda> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposAyuda tiposayuda = new TiposAyuda(resultSet.getLong("IDTIPOAYUDA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<TiposAyuda> jerarquia = new JerarquiaDto<TiposAyuda>();
			jerarquia.setModel(tiposayuda);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	private RowMapper<TiposAyuda> rwMapPLSQL = new RowMapper<TiposAyuda>() {
		public TiposAyuda mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposAyuda(resultSet.getLong("IDTIPOAYUDA"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getString("PLSQCOPCONVOCATORIA"));
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposAyuda table.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @return TiposAyuda
	 */
	public TiposAyuda add(TiposAyuda tiposayuda) {
		String query = "INSERT INTO TIPOS_AYUDA (ID_TIPO_AYUDA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, tiposayuda.getIdTipoAyuda(), tiposayuda.getDescripcionCastellano(),
				tiposayuda.getDescripcionEuskera(), tiposayuda.getFechaRegistro(), tiposayuda.getUsuarioRegistro());
		return tiposayuda;
	}

	/**
	 * Updates a single row in the TiposAyuda table.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @return TiposAyuda
	 */
	public TiposAyuda update(TiposAyuda tiposayuda) {
		String query = "UPDATE TIPOS_AYUDA SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_TIPO_AYUDA=?";
		this.jdbcTemplate.update(query, tiposayuda.getDescripcionCastellano(), tiposayuda.getDescripcionEuskera(),
				tiposayuda.getFechaRegistro(), tiposayuda.getUsuarioRegistro(), tiposayuda.getIdTipoAyuda());
		return tiposayuda;
	}

	/**
	 * Finds a single row in the TiposAyuda table.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @return TiposAyuda
	 */
	@Transactional(readOnly = true)
	public TiposAyuda find(TiposAyuda tiposayuda) {
		String query = "SELECT t1.ID_TIPO_AYUDA IDTIPOAYUDA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_AYUDA t1  WHERE t1.ID_TIPO_AYUDA = ?  ";

		List<TiposAyuda> tiposayudaList = this.jdbcTemplate.query(query, this.rwMap, tiposayuda.getIdTipoAyuda());
		return (TiposAyuda) DataAccessUtils.uniqueResult(tiposayudaList);
	}

	/**
	 * Finds a single row in the TiposAyuda table.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @return TiposAyuda
	 */
	@Transactional(readOnly = true)
	public TiposAyuda findPLSQL(TiposAyuda tiposayuda) {
		String query = "SELECT t1.ID_TIPO_AYUDA IDTIPOAYUDA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.PLSQL_COPIA_CONVOCATORIA PLSQCOPCONVOCATORIA FROM TIPOS_AYUDA t1  WHERE t1.ID_TIPO_AYUDA = ?  ";

		List<TiposAyuda> tiposayudaList = this.jdbcTemplate.query(query, this.rwMapPLSQL, tiposayuda.getIdTipoAyuda());
		return (TiposAyuda) DataAccessUtils.uniqueResult(tiposayudaList);
	}

	/**
	 * Removes a single row in the TiposAyuda table.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @return
	 */
	public void remove(TiposAyuda tiposayuda) {
		String query = "DELETE FROM TIPOS_AYUDA WHERE ID_TIPO_AYUDA=?";
		this.jdbcTemplate.update(query, tiposayuda.getIdTipoAyuda());
	}

	/**
	 * Finds a list of rows in the TiposAyuda table.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposAyuda>
	 */
	@Transactional(readOnly = true)
	public List<TiposAyuda> findAll(TiposAyuda tiposayuda, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_AYUDA IDTIPOAYUDA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_AYUDA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposayuda);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, TiposAyudaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposAyuda>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposAyuda table using like.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposAyuda>
	 */
	@Transactional(readOnly = true)
	public List<TiposAyuda> findAllLike(TiposAyuda tiposayuda, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_AYUDA IDTIPOAYUDA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_AYUDA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposayuda, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, TiposAyudaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposAyuda>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposAyuda table.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposAyuda tiposayuda) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_AYUDA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposayuda);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposAyuda table using like.
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposAyuda tiposayuda, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_AYUDA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposayuda, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposAyuda selected for rup_table
	 *
	 * @param tiposayuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposAyuda>>
	 */
	@Override
	public List<TableRowDto<TiposAyuda>> reorderSelection(TiposAyuda tiposayuda, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_AYUDA IDTIPOAYUDA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_AYUDA t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposayuda, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, TiposAyuda.class,
				filterParamList, "ID_TIPO_AYUDA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposAyuda>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposAyuda
	 * @param searchParams
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposAyuda>>
	 */
	@Override
	public List<TableRowDto<TiposAyuda>> search(TiposAyuda filterParams, TiposAyuda searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_AYUDA IDTIPOAYUDA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_AYUDA t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, TiposAyuda.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_TIPO_AYUDA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposAyuda>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertiposayuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposAyuda filtertiposayuda, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_AYUDA IDTIPOAYUDA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_AYUDA t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertiposayuda, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, TiposAyuda.class,
				query, params, "ID_TIPO_AYUDA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposAyuda table.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposAyuda>>
	 */
	@Override
	public List<JerarquiaDto<TiposAyuda>> findAllLikeJerarquia(TiposAyuda filterTiposAyuda,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_AYUDA IDTIPOAYUDA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_AYUDA t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_AYUDA");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposAyuda, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_AYUDA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposAyudaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposAyuda filterTiposAyuda, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_AYUDA t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_AYUDA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposAyuda, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_AYUDA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposAyuda>>
	 */
	@Override
	public List<TableRowDto<TiposAyuda>> findAllChild(TiposAyuda filterTiposAyuda, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_AYUDA t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_AYUDA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposAyuda, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_TIPO_AYUDA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposAyuda>(this.rwMapPK, "ID_TIPO_AYUDA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposAyuda entity
	 *
	 * @param tiposayuda
	 *            TiposAyuda Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposAyuda tiposayuda) {

		StringBuilder where = new StringBuilder(TiposAyudaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposayuda != null && tiposayuda.getIdTipoAyuda() != null) {
			where.append(" AND t1.ID_TIPO_AYUDA = ?");
			params.add(tiposayuda.getIdTipoAyuda());
		}
		if (tiposayuda != null && tiposayuda.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposayuda.getDescripcionCastellano());
		}
		if (tiposayuda != null && tiposayuda.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposayuda.getDescripcionEuskera());
		}
		if (tiposayuda != null && tiposayuda.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposayuda.getFechaRegistro());
		}
		if (tiposayuda != null && tiposayuda.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposayuda.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposAyuda entity
	 *
	 * @param tiposayuda
	 *            TiposAyuda Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposAyuda tiposayuda, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposAyudaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposayuda != null && tiposayuda.getIdTipoAyuda() != null) {
			where.append(" AND t1.ID_TIPO_AYUDA = ?");
			params.add(tiposayuda.getIdTipoAyuda());
		}
		if (tiposayuda != null && tiposayuda.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposayuda.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tiposayuda.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tiposayuda != null && tiposayuda.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposayuda.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tiposayuda.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tiposayuda != null && tiposayuda.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposayuda.getFechaRegistro());
		}
		if (tiposayuda != null && tiposayuda.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposayuda.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tiposayuda.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
