package com.ejie.ab60.dao.convocatorias;

import java.util.List;

import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposConvocatoriaDao  
 * 
 *  
 */

public interface TiposConvocatoriaDao {

	/**
	 * Inserts a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	TiposConvocatoria add(TiposConvocatoria tiposconvocatoria);

	/**
	 * Updates a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	TiposConvocatoria update(TiposConvocatoria tiposconvocatoria);

	/**
	 * Finds a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	TiposConvocatoria find(TiposConvocatoria tiposconvocatoria);

	/**
	 * Finds a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	TiposConvocatoria findNoConcursal(TiposConvocatoria tiposconvocatoria);

	/**
	 * Removes a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 */
	void remove(TiposConvocatoria tiposconvocatoria);

	/**
	 * Finds a List of rows in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<TiposConvocatoria> findAll(TiposConvocatoria tiposconvocatoria, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the TiposConvocatoria table using like.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<TiposConvocatoria> findAllLike(TiposConvocatoria tiposconvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(TiposConvocatoria filterTiposConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Counts rows in the TiposConvocatoria table using like.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(TiposConvocatoria tiposconvocatoria, Boolean startsWith);

	/**
	 * Counts rows in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return Long
	 */
	Long findAllCount(TiposConvocatoria tiposconvocatoria);

	/**
	 * Reorder selection.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposConvocatoria>>
	 */
	List<TableRowDto<TiposConvocatoria>> reorderSelection(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param searchTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposConvocatoria>>
	 */
	List<TableRowDto<TiposConvocatoria>> search(TiposConvocatoria filterTiposConvocatoria,
			TiposConvocatoria searchTiposConvocatoria, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposConvocatoria>>
	 */
	List<JerarquiaDto<TiposConvocatoria>> findAllLikeJerarquia(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(TiposConvocatoria filterTiposConvocatoria, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposConvocatoria>>
	 */
	List<TableRowDto<TiposConvocatoria>> findAllChild(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto);

}
