package com.ejie.ab60.dao.convocatorias;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposConvocatoriaDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposConvocatoriaDaoImpl implements TiposConvocatoriaDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOCONVOCATORIA", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposConvocatoria> rwMap = new RowMapper<TiposConvocatoria>() {
		public TiposConvocatoria mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposConvocatoria(resultSet.getLong("IDTIPOCONVOCATORIA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<TiposConvocatoria> rwMapPK = new RowMapper<TiposConvocatoria>() {
		public TiposConvocatoria mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposConvocatoria(resultSet.getLong("IDTIPOCONVOCATORIA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposConvocatoria>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposConvocatoria>>() {
		public JerarquiaDto<TiposConvocatoria> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposConvocatoria tiposconvocatoria = new TiposConvocatoria(resultSet.getLong("IDTIPOCONVOCATORIA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<TiposConvocatoria> jerarquia = new JerarquiaDto<TiposConvocatoria>();
			jerarquia.setModel(tiposconvocatoria);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	public TiposConvocatoria add(TiposConvocatoria tiposconvocatoria) {
		String query = "INSERT INTO TIPOS_CONVOCATORIA (ID_TIPO_CONVOCATORIA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, tiposconvocatoria.getIdTipoConvocatoria(),
				tiposconvocatoria.getDescripcionCastellano(), tiposconvocatoria.getDescripcionEuskera(),
				tiposconvocatoria.getFechaRegistro(), tiposconvocatoria.getUsuarioRegistro());
		return tiposconvocatoria;
	}

	/**
	 * Updates a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	public TiposConvocatoria update(TiposConvocatoria tiposconvocatoria) {
		String query = "UPDATE TIPOS_CONVOCATORIA SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_TIPO_CONVOCATORIA=?";
		this.jdbcTemplate.update(query, tiposconvocatoria.getDescripcionCastellano(),
				tiposconvocatoria.getDescripcionEuskera(), tiposconvocatoria.getFechaRegistro(),
				tiposconvocatoria.getUsuarioRegistro(), tiposconvocatoria.getIdTipoConvocatoria());
		return tiposconvocatoria;
	}

	/**
	 * Finds a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	@Transactional(readOnly = true)
	public TiposConvocatoria find(TiposConvocatoria tiposconvocatoria) {
		String query = "SELECT t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_CONVOCATORIA t1  WHERE t1.ID_TIPO_CONVOCATORIA = ?  ";

		List<TiposConvocatoria> tiposconvocatoriaList = this.jdbcTemplate.query(query, this.rwMap,
				tiposconvocatoria.getIdTipoConvocatoria());
		return (TiposConvocatoria) DataAccessUtils.uniqueResult(tiposconvocatoriaList);
	}

	/**
	 * Finds a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	@Transactional(readOnly = true)
	public TiposConvocatoria findNoConcursal(TiposConvocatoria tiposconvocatoria) {
		String query = "SELECT t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_CONVOCATORIA t1  WHERE t1.ID_TIPO_CONVOCATORIA = ?  ";

		List<TiposConvocatoria> tiposconvocatoriaList = this.jdbcTemplate.query(query, this.rwMap,
				tiposconvocatoria.getIdTipoConvocatoria());
		return (TiposConvocatoria) DataAccessUtils.uniqueResult(tiposconvocatoriaList);
	}

	/**
	 * Removes a single row in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return
	 */
	public void remove(TiposConvocatoria tiposconvocatoria) {
		String query = "DELETE FROM TIPOS_CONVOCATORIA WHERE ID_TIPO_CONVOCATORIA=?";
		this.jdbcTemplate.update(query, tiposconvocatoria.getIdTipoConvocatoria());
	}

	/**
	 * Finds a list of rows in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposConvocatoria>
	 */
	@Transactional(readOnly = true)
	public List<TiposConvocatoria> findAll(TiposConvocatoria tiposconvocatoria, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_CONVOCATORIA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposconvocatoria);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposConvocatoriaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposConvocatoria>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposConvocatoria table using like.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposConvocatoria>
	 */
	@Transactional(readOnly = true)
	public List<TiposConvocatoria> findAllLike(TiposConvocatoria tiposconvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_CONVOCATORIA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposConvocatoriaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposConvocatoria>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposConvocatoria table.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposConvocatoria tiposconvocatoria) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_CONVOCATORIA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposconvocatoria);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposConvocatoria table using like.
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposConvocatoria tiposconvocatoria, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_CONVOCATORIA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposConvocatoria selected for rup_table
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposConvocatoria>>
	 */
	@Override
	public List<TableRowDto<TiposConvocatoria>> reorderSelection(TiposConvocatoria tiposconvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_CONVOCATORIA t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				TiposConvocatoria.class, filterParamList, "ID_TIPO_CONVOCATORIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposConvocatoria>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposConvocatoria
	 * @param searchParams
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposConvocatoria>>
	 */
	@Override
	public List<TableRowDto<TiposConvocatoria>> search(TiposConvocatoria filterParams, TiposConvocatoria searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_CONVOCATORIA t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				TiposConvocatoria.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_TIPO_CONVOCATORIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposConvocatoria>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertiposconvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposConvocatoria filtertiposconvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_CONVOCATORIA t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertiposconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				TiposConvocatoria.class, query, params, "ID_TIPO_CONVOCATORIA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposConvocatoria>>
	 */
	@Override
	public List<JerarquiaDto<TiposConvocatoria>> findAllLikeJerarquia(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_CONVOCATORIA IDTIPOCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_CONVOCATORIA t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_CONVOCATORIA");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposConvocatoria, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_CONVOCATORIA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposConvocatoriaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_CONVOCATORIA t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_CONVOCATORIA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposConvocatoria, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_CONVOCATORIA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposConvocatoria>>
	 */
	@Override
	public List<TableRowDto<TiposConvocatoria>> findAllChild(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_CONVOCATORIA t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_CONVOCATORIA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposConvocatoria, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_TIPO_CONVOCATORIA", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposConvocatoria>(this.rwMapPK, "ID_TIPO_CONVOCATORIA"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposConvocatoria entity
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposConvocatoria tiposconvocatoria) {

		StringBuilder where = new StringBuilder(TiposConvocatoriaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposconvocatoria != null && tiposconvocatoria.getIdTipoConvocatoria() != null) {
			where.append(" AND t1.ID_TIPO_CONVOCATORIA = ?");
			params.add(tiposconvocatoria.getIdTipoConvocatoria());
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposconvocatoria.getDescripcionCastellano());
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposconvocatoria.getDescripcionEuskera());
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposconvocatoria.getFechaRegistro());
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposconvocatoria.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposConvocatoria entity
	 *
	 * @param tiposconvocatoria
	 *            TiposConvocatoria Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposConvocatoria tiposconvocatoria, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposConvocatoriaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposconvocatoria != null && tiposconvocatoria.getIdTipoConvocatoria() != null) {
			where.append(" AND t1.ID_TIPO_CONVOCATORIA = ?");
			params.add(tiposconvocatoria.getIdTipoConvocatoria());
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposconvocatoria.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tiposconvocatoria.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposconvocatoria.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tiposconvocatoria.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposconvocatoria.getFechaRegistro());
		}
		if (tiposconvocatoria != null && tiposconvocatoria.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposconvocatoria.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tiposconvocatoria.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
