package com.ejie.ab60.dao.criteriosPuntuacion;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.ab60.model.criteriosPuntuacion.TiposCriterio;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * CriteriosPuntuacionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class CriteriosPuntuacionDaoImpl implements CriteriosPuntuacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCRITERIO", "CRIPUNCASTELLANO", "CRIPUNEUSKERA",
			"VALORMINIMO", "VALORMAXIMO", "INCREMENTOPORCENTAJE", "OBSERVACIONES", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "TIPOSCRITERIOIDTIPOCRITERIO",
			"TIPOSCRITERIODESCRIPCIONCASTELLANO", "TIPOSCRITERIODESCRIPCIONEUSKERA", "TIPOSCRITERIOFECHAREGISTRO",
			"TIPOSCRITERIOUSUARIOREGISTRO", "CONVOCATORIASIDCONVOCATORIA", "CONVOCATORIASIDPROCEDIMIENTO",
			"CONVOCATORIASCONVOCATORIA", "CONVOCATORIASFECHARESOLUCION", "CONVOCATORIASIMPORTE",
			"CONVOCATORIASPORCENTAJESUBVENCION", "CONVOCATORIASCANTMAXSUBVENCION", "CONVOCATORIASPLSQLCALCULO",
			"CONVOCATORIASPLSQLREPARTO", "CONVOCATORIASOBSERVACIONES", "CONVOCATORIASIMPORTEMINIMOINVERSION",
			"CONVOCATORIASFECHAORDENDIA", "CONVOCATORIASFECHAREGISTRO", "CONVOCATORIASUSUARIOREGISTRO",
			"CONVOCATORIASFECHAULTMODIFICACION", "CONVOCATORIASUSUARIOULTMODIFICACION", "CONVOCATORIASLIMITELOCAL",
			"CONVOCATORIASIDTIPOCONVOCATORIA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<CriteriosPuntuacion> rwMap = new RowMapper<CriteriosPuntuacion>() {
		public CriteriosPuntuacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new CriteriosPuntuacion(resultSet.getInt("IDCRITERIO"), resultSet.getString("CRIPUNCASTELLANO"),
					resultSet.getString("CRIPUNEUSKERA"), resultSet.getBigDecimal("VALORMINIMO"),
					resultSet.getBigDecimal("VALORMAXIMO"), resultSet.getBigDecimal("INCREMENTOPORCENTAJE"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new TiposCriterio(resultSet.getLong("TiposCriterioIDTIPOCRITERIO"),
							resultSet.getString("TiposCriterioDESCRIPCIONCASTELLANO"),
							resultSet.getString("TiposCriterioDESCRIPCIONEUSKERA"),
							resultSet.getDate("TiposCriterioFECHAREGISTRO"),
							resultSet.getString("TiposCriterioUSUARIOREGISTRO")),
					new Convocatorias(resultSet.getInt("ConvocatoriasIDCONVOCATORIA"),
							resultSet.getInt("ConvocatoriasIDPROCEDIMIENTO"),
							resultSet.getString("ConvocatoriasCONVOCATORIA"),
							resultSet.getDate("ConvocatoriasFECHARESOLUCION"),
							resultSet.getBigDecimal("ConvocatoriasIMPORTE"),
							resultSet.getBigDecimal("ConvocatoriasPORCENTAJESUBVENCION"),
							resultSet.getBigDecimal("ConvocatoriasCANTMAXSUBVENCION"),
							resultSet.getString("ConvocatoriasPLSQLCALCULO"),
							resultSet.getString("ConvocatoriasPLSQLREPARTO"),
							resultSet.getString("ConvocatoriasOBSERVACIONES"),
							resultSet.getDate("ConvocatoriasFECHAORDENDIA"),
							resultSet.getDate("ConvocatoriasFECHAREGISTRO"),
							resultSet.getString("ConvocatoriasUSUARIOREGISTRO"),
							resultSet.getDate("ConvocatoriasFECHAULTMODIFICACION"),
							resultSet.getString("ConvocatoriasUSUARIOULTMODIFICACION"),
							resultSet.getBigDecimal("ConvocatoriasLIMITELOCAL"),
							new TiposConvocatoria(resultSet.getLong("ConvocatoriasIDTIPOCONVOCATORIA"), null, null,
									null, null, null)));
		}
	};

	private RowMapper<CriteriosPuntuacion> rwMapTextoCriterio = new RowMapper<CriteriosPuntuacion>() {
		public CriteriosPuntuacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new CriteriosPuntuacion(resultSet.getInt("IDCRITERIO"), resultSet.getString("CRIPUNCASTELLANO"),
					resultSet.getString("CRIPUNEUSKERA"),
					new TiposCriterio(resultSet.getLong("TiposCriterioIDTIPOCRITERIO")),
					new Convocatorias(resultSet.getInt("ConvocatoriasIDCONVOCATORIA")));
		}
	};

	private RowMapper<CriteriosPuntuacion> rwMapPK = new RowMapper<CriteriosPuntuacion>() {
		public CriteriosPuntuacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new CriteriosPuntuacion(resultSet.getInt("IDCRITERIO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<CriteriosPuntuacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<CriteriosPuntuacion>>() {
		public JerarquiaDto<CriteriosPuntuacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			CriteriosPuntuacion criteriospuntuacion = new CriteriosPuntuacion(resultSet.getInt("IDCRITERIO"),
					resultSet.getString("CRIPUNCASTELLANO"), resultSet.getString("CRIPUNEUSKERA"),
					resultSet.getBigDecimal("VALORMINIMO"), resultSet.getBigDecimal("VALORMAXIMO"),
					resultSet.getBigDecimal("INCREMENTOPORCENTAJE"), resultSet.getString("OBSERVACIONES"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new TiposCriterio(resultSet.getLong("TiposCriterioIDTIPOCRITERIO"),
							resultSet.getString("TiposCriterioDESCRIPCIONCASTELLANO"),
							resultSet.getString("TiposCriterioDESCRIPCIONEUSKERA"),
							resultSet.getDate("TiposCriterioFECHAREGISTRO"),
							resultSet.getString("TiposCriterioUSUARIOREGISTRO")),
					new Convocatorias(resultSet.getInt("ConvocatoriasIDCONVOCATORIA"),
							resultSet.getInt("ConvocatoriasIDPROCEDIMIENTO"),
							resultSet.getString("ConvocatoriasCONVOCATORIA"),
							resultSet.getDate("ConvocatoriasFECHARESOLUCION"),
							resultSet.getBigDecimal("ConvocatoriasIMPORTE"),
							resultSet.getBigDecimal("ConvocatoriasPORCENTAJESUBVENCION"),
							resultSet.getBigDecimal("ConvocatoriasCANTMAXSUBVENCION"),
							resultSet.getString("ConvocatoriasPLSQLCALCULO"),
							resultSet.getString("ConvocatoriasPLSQLREPARTO"),
							resultSet.getString("ConvocatoriasOBSERVACIONES"),
							resultSet.getDate("ConvocatoriasFECHAORDENDIA"),
							resultSet.getDate("ConvocatoriasFECHAREGISTRO"),
							resultSet.getString("ConvocatoriasUSUARIOREGISTRO"),
							resultSet.getDate("ConvocatoriasFECHAULTMODIFICACION"),
							resultSet.getString("ConvocatoriasUSUARIOULTMODIFICACION"),
							resultSet.getBigDecimal("ConvocatoriasLIMITELOCAL"),
							new TiposConvocatoria(resultSet.getLong("ConvocatoriasIDTIPOCONVOCATORIA"), null, null,
									null, null, null)));

			JerarquiaDto<CriteriosPuntuacion> jerarquia = new JerarquiaDto<CriteriosPuntuacion>();
			jerarquia.setModel(criteriospuntuacion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	public CriteriosPuntuacion add(CriteriosPuntuacion criteriospuntuacion) {
		String query = "INSERT INTO CRITERIOS_PUNTUACION (ID_CRITERIO, ID_TIPO_CRITERIO, ID_CONVOCATORIA, CRI_PUN_CASTELLANO, CRI_PUN_EUSKERA, VALOR_MINIMO, VALOR_MAXIMO, INCREMENTO_PORCENTAJE, OBSERVACIONES, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)";
		Object getTiposCriterioIdTipoCriterioAux = null;
		if (criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getIdTipoCriterio() != null) {
			getTiposCriterioIdTipoCriterioAux = criteriospuntuacion.getTiposCriterio().getIdTipoCriterio();
		}
		Object getConvocatoriasIdConvocatoriaAux = null;
		if (criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getIdConvocatoria() != null) {
			getConvocatoriasIdConvocatoriaAux = criteriospuntuacion.getConvocatorias().getIdConvocatoria();
		}
		this.jdbcTemplate.update(query, criteriospuntuacion.getIdCriterio(), getTiposCriterioIdTipoCriterioAux,
				getConvocatoriasIdConvocatoriaAux, criteriospuntuacion.getCriPunCastellano(),
				criteriospuntuacion.getCriPunEuskera(), criteriospuntuacion.getValorMinimo(),
				criteriospuntuacion.getValorMaximo(), criteriospuntuacion.getIncrementoPorcentaje(),
				criteriospuntuacion.getObservaciones(), criteriospuntuacion.getFechaRegistro(),
				criteriospuntuacion.getUsuarioRegistro(), criteriospuntuacion.getFechaUltmodificacion(),
				criteriospuntuacion.getUsuarioUltmodificacion());
		return criteriospuntuacion;
	}

	/**
	 * Updates a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	public CriteriosPuntuacion update(CriteriosPuntuacion criteriospuntuacion) {
		String query = "UPDATE CRITERIOS_PUNTUACION SET ID_TIPO_CRITERIO=?, ID_CONVOCATORIA=?, CRI_PUN_CASTELLANO=?, CRI_PUN_EUSKERA=?, VALOR_MINIMO=?, VALOR_MAXIMO=?, INCREMENTO_PORCENTAJE=?, OBSERVACIONES=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_CRITERIO=?";
		Object getTiposCriterioIdTipoCriterioAux = null;
		if (criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getIdTipoCriterio() != null) {
			getTiposCriterioIdTipoCriterioAux = criteriospuntuacion.getTiposCriterio().getIdTipoCriterio();
		}
		Object getConvocatoriasIdConvocatoriaAux = null;
		if (criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getIdConvocatoria() != null) {
			getConvocatoriasIdConvocatoriaAux = criteriospuntuacion.getConvocatorias().getIdConvocatoria();
		}
		this.jdbcTemplate.update(query, getTiposCriterioIdTipoCriterioAux, getConvocatoriasIdConvocatoriaAux,
				criteriospuntuacion.getCriPunCastellano(), criteriospuntuacion.getCriPunEuskera(),
				criteriospuntuacion.getValorMinimo(), criteriospuntuacion.getValorMaximo(),
				criteriospuntuacion.getIncrementoPorcentaje(), criteriospuntuacion.getObservaciones(),
				criteriospuntuacion.getFechaRegistro(), criteriospuntuacion.getUsuarioRegistro(),
				criteriospuntuacion.getFechaUltmodificacion(), criteriospuntuacion.getUsuarioUltmodificacion(),
				criteriospuntuacion.getIdCriterio());
		return criteriospuntuacion;
	}

	/**
	 * Finds a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	@Transactional(readOnly = true)
	public CriteriosPuntuacion find(CriteriosPuntuacion criteriospuntuacion) {
		String query = "SELECT t1.ID_CRITERIO IDCRITERIO, t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO, t1.CRI_PUN_EUSKERA CRIPUNEUSKERA, t1.VALOR_MINIMO VALORMINIMO, t1.VALOR_MAXIMO VALORMAXIMO, t1.INCREMENTO_PORCENTAJE INCREMENTOPORCENTAJE, t1.OBSERVACIONES OBSERVACIONES, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO, t2.DESCRIPCION_CASTELLANO TIPOSCRITERIODESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA TIPOSCRITERIODESCRIPCIONEUSKERA, t2.FECHA_REGISTRO TIPOSCRITERIOFECHAREGISTRO, t2.USUARIO_REGISTRO TIPOSCRITERIOUSUARIOREGISTRO, t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA, t3.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO, t3.CONVOCATORIA CONVOCATORIASCONVOCATORIA, t3.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION, t3.IMPORTE CONVOCATORIASIMPORTE, t3.PORCENTAJE_SUBVENCION CONVOCATORIASPORCENTAJESUBVENCION, t3.CANT_MAX_SUBVENCION CONVOCATORIASCANTMAXSUBVENCION, t3.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO, t3.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO, t3.OBSERVACIONES CONVOCATORIASOBSERVACIONES, t3.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA, t3.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO, t3.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO, t3.FECHA_ULTMODIFICACION CONVOCATORIASFECHAULTMODIFICACION, t3.USUARIO_ULTMODIFICACION CONVOCATORIASUSUARIOULTMODIFICACION, t3.LIMITE_AT CONVOCATORIASLIMITELOCAL, t3.ID_TIPO_CONVOCATORIA CONVOCATORIASIDTIPOCONVOCATORIA FROM CRITERIOS_PUNTUACION t1 , TIPOS_CRITERIO t2 , CONVOCATORIAS t3  WHERE t1.ID_CRITERIO = ?   AND t1.ID_TIPO_CRITERIO= t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA= t3.ID_CONVOCATORIA(+)";

		List<CriteriosPuntuacion> criteriospuntuacionList = this.jdbcTemplate.query(query, this.rwMap,
				criteriospuntuacion.getIdCriterio());
		return (CriteriosPuntuacion) DataAccessUtils.uniqueResult(criteriospuntuacionList);
	}

	/**
	 * Texto de criterios de puntuacion CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	@Transactional(readOnly = true)
	public List<CriteriosPuntuacion> findTextoCriterio(Integer idconvocatoria) {

		String query = "SELECT t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO ,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA , t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO , t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 WHERE t1.ID_TIPO_CRITERIO = t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA   = t3.ID_CONVOCATORIA(+) and t1.ID_CONVOCATORIA=?";

		List<CriteriosPuntuacion> criteriospuntuacionList = this.jdbcTemplate.query(query, this.rwMapTextoCriterio,
				idconvocatoria);

		// return (CriteriosPuntuacion)
		// DataAccessUtils.uniqueResult(criteriospuntuacionList);

		return criteriospuntuacionList;
	}

	/**
	 * Texto de criterios de puntuacion CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	@Transactional(readOnly = true)
	public List<CriteriosPuntuacion> findTextoCriterioBEC(Integer idconvocatoria) {

		String query = "SELECT t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO ,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA , t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO , t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 WHERE t1.ID_TIPO_CRITERIO = t2.ID_TIPO_CRITERIO AND t1.ID_CONVOCATORIA   = t3.ID_CONVOCATORIA and t1.ID_CONVOCATORIA=?";

		List<CriteriosPuntuacion> criteriospuntuacionList = this.jdbcTemplate.query(query, this.rwMapTextoCriterio,
				idconvocatoria);

		// return (CriteriosPuntuacion)
		// DataAccessUtils.uniqueResult(criteriospuntuacionList);

		return criteriospuntuacionList;
	}

	/**
	 * Removes a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @return
	 */
	public void remove(CriteriosPuntuacion criteriospuntuacion) {
		String query = "DELETE FROM CRITERIOS_PUNTUACION WHERE ID_CRITERIO=?";
		this.jdbcTemplate.update(query, criteriospuntuacion.getIdCriterio());
	}

	/**
	 * Finds a list of rows in the CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<CriteriosPuntuacion>
	 */
	@Transactional(readOnly = true)
	public List<CriteriosPuntuacion> findAll(CriteriosPuntuacion criteriospuntuacion,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA,t1.VALOR_MINIMO VALORMINIMO,t1.VALOR_MAXIMO VALORMAXIMO,t1.INCREMENTO_PORCENTAJE INCREMENTOPORCENTAJE,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO,t2.DESCRIPCION_CASTELLANO TIPOSCRITERIODESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCRITERIODESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSCRITERIOFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSCRITERIOUSUARIOREGISTRO,t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t3.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t3.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t3.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t3.IMPORTE CONVOCATORIASIMPORTE,t3.PORCENTAJE_SUBVENCION CONVOCATORIASPORCENTAJESUBVENCION,t3.CANT_MAX_SUBVENCION CONVOCATORIASCANTMAXSUBVENCION,t3.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t3.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t3.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t3.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t3.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t3.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CONVOCATORIASFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CONVOCATORIASUSUARIOULTMODIFICACION,t3.LIMITE_AT CONVOCATORIASLIMITELOCAL,t3.ID_TIPO_CONVOCATORIA CONVOCATORIASIDTIPOCONVOCATORIA ");
		query.append("FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(criteriospuntuacion);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CRITERIO= t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA= t3.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CriteriosPuntuacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<CriteriosPuntuacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the CriteriosPuntuacion table using like.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<CriteriosPuntuacion>
	 */
	@Transactional(readOnly = true)
	public List<CriteriosPuntuacion> findAllLike(CriteriosPuntuacion criteriospuntuacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA,t1.VALOR_MINIMO VALORMINIMO,t1.VALOR_MAXIMO VALORMAXIMO,t1.INCREMENTO_PORCENTAJE INCREMENTOPORCENTAJE,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO,t2.DESCRIPCION_CASTELLANO TIPOSCRITERIODESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCRITERIODESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSCRITERIOFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSCRITERIOUSUARIOREGISTRO,t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t3.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t3.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t3.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t3.IMPORTE CONVOCATORIASIMPORTE,t3.PORCENTAJE_SUBVENCION CONVOCATORIASPORCENTAJESUBVENCION,t3.CANT_MAX_SUBVENCION CONVOCATORIASCANTMAXSUBVENCION,t3.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t3.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t3.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t3.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t3.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t3.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CONVOCATORIASFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CONVOCATORIASUSUARIOULTMODIFICACION,t3.LIMITE_AT CONVOCATORIASLIMITELOCAL,t3.ID_TIPO_CONVOCATORIA CONVOCATORIASIDTIPOCONVOCATORIA ");
		query.append("FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(criteriospuntuacion, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CRITERIO= t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA= t3.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CriteriosPuntuacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<CriteriosPuntuacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the CriteriosPuntuacion table.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(CriteriosPuntuacion criteriospuntuacion) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM CRITERIOS_PUNTUACION t1 , TIPOS_CRITERIO t2 , CONVOCATORIAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(criteriospuntuacion);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CRITERIO= t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA= t3.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the CriteriosPuntuacion table using like.
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(CriteriosPuntuacion criteriospuntuacion, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(criteriospuntuacion, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CRITERIO= t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA= t3.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of CriteriosPuntuacion selected for rup_table
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<CriteriosPuntuacion>>
	 */
	@Override
	public List<TableRowDto<CriteriosPuntuacion>> reorderSelection(CriteriosPuntuacion criteriospuntuacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA,t1.VALOR_MINIMO VALORMINIMO,t1.VALOR_MAXIMO VALORMAXIMO,t1.INCREMENTO_PORCENTAJE INCREMENTOPORCENTAJE,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO,t2.DESCRIPCION_CASTELLANO TIPOSCRITERIODESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCRITERIODESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSCRITERIOFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSCRITERIOUSUARIOREGISTRO,t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t3.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t3.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t3.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t3.IMPORTE CONVOCATORIASIMPORTE,t3.PORCENTAJE_SUBVENCION CONVOCATORIASPORCENTAJESUBVENCION,t3.CANT_MAX_SUBVENCION CONVOCATORIASCANTMAXSUBVENCION,t3.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t3.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t3.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t3.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t3.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t3.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CONVOCATORIASFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CONVOCATORIASUSUARIOULTMODIFICACION,t3.LIMITE_AT CONVOCATORIASLIMITELOCAL,t3.ID_TIPO_CONVOCATORIA CONVOCATORIASIDTIPOCONVOCATORIA ");
		// FROM
		query.append("FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(criteriospuntuacion, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CRITERIO= t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA= t3.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				CriteriosPuntuacion.class, filterParamList, "ID_CRITERIO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<CriteriosPuntuacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            CriteriosPuntuacion
	 * @param searchParams
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<CriteriosPuntuacion>>
	 */
	@Override
	public List<TableRowDto<CriteriosPuntuacion>> search(CriteriosPuntuacion filterParams,
			CriteriosPuntuacion searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA,t1.VALOR_MINIMO VALORMINIMO,t1.VALOR_MAXIMO VALORMAXIMO,t1.INCREMENTO_PORCENTAJE INCREMENTOPORCENTAJE,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO,t2.DESCRIPCION_CASTELLANO TIPOSCRITERIODESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCRITERIODESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSCRITERIOFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSCRITERIOUSUARIOREGISTRO,t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t3.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t3.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t3.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t3.IMPORTE CONVOCATORIASIMPORTE,t3.PORCENTAJE_SUBVENCION CONVOCATORIASPORCENTAJESUBVENCION,t3.CANT_MAX_SUBVENCION CONVOCATORIASCANTMAXSUBVENCION,t3.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t3.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t3.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t3.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t3.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t3.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CONVOCATORIASFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CONVOCATORIASUSUARIOULTMODIFICACION,t3.LIMITE_AT CONVOCATORIASLIMITELOCAL,t3.ID_TIPO_CONVOCATORIA CONVOCATORIASIDTIPOCONVOCATORIA ");
		// FROM
		query.append("FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_CRITERIO= t2.ID_TIPO_CRITERIO(+) AND t1.ID_CONVOCATORIA= t3.ID_CONVOCATORIA(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				CriteriosPuntuacion.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_CRITERIO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<CriteriosPuntuacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtercriteriospuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(CriteriosPuntuacion filtercriteriospuntuacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA,t1.VALOR_MINIMO VALORMINIMO,t1.VALOR_MAXIMO VALORMAXIMO,t1.INCREMENTO_PORCENTAJE INCREMENTOPORCENTAJE,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO,t2.DESCRIPCION_CASTELLANO TIPOSCRITERIODESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCRITERIODESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSCRITERIOFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSCRITERIOUSUARIOREGISTRO,t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t3.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t3.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t3.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t3.IMPORTE CONVOCATORIASIMPORTE,t3.PORCENTAJE_SUBVENCION CONVOCATORIASPORCENTAJESUBVENCION,t3.CANT_MAX_SUBVENCION CONVOCATORIASCANTMAXSUBVENCION,t3.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t3.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t3.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t3.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t3.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t3.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CONVOCATORIASFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CONVOCATORIASUSUARIOULTMODIFICACION,t3.LIMITE_AT CONVOCATORIASLIMITELOCAL,t3.ID_TIPO_CONVOCATORIA CONVOCATORIASIDTIPOCONVOCATORIA ");
		// FROM
		query.append("FROM CRITERIOS_PUNTUACION t1 ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtercriteriospuntuacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				CriteriosPuntuacion.class, query, params, "ID_CRITERIO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical CriteriosPuntuacion table.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<CriteriosPuntuacion>>
	 */
	@Override
	public List<JerarquiaDto<CriteriosPuntuacion>> findAllLikeJerarquia(CriteriosPuntuacion filterCriteriosPuntuacion,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CRITERIO IDCRITERIO,t1.CRI_PUN_CASTELLANO CRIPUNCASTELLANO,t1.CRI_PUN_EUSKERA CRIPUNEUSKERA,t1.VALOR_MINIMO VALORMINIMO,t1.VALOR_MAXIMO VALORMAXIMO,t1.INCREMENTO_PORCENTAJE INCREMENTOPORCENTAJE,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO TIPOSCRITERIOIDTIPOCRITERIO,t2.DESCRIPCION_CASTELLANO TIPOSCRITERIODESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA TIPOSCRITERIODESCRIPCIONEUSKERA,t2.FECHA_REGISTRO TIPOSCRITERIOFECHAREGISTRO,t2.USUARIO_REGISTRO TIPOSCRITERIOUSUARIOREGISTRO,t3.ID_CONVOCATORIA CONVOCATORIASIDCONVOCATORIA,t3.ID_PROCEDIMIENTO CONVOCATORIASIDPROCEDIMIENTO,t3.CONVOCATORIA CONVOCATORIASCONVOCATORIA,t3.FECHA_RESOLUCION CONVOCATORIASFECHARESOLUCION,t3.IMPORTE CONVOCATORIASIMPORTE,t3.PORCENTAJE_SUBVENCION CONVOCATORIASPORCENTAJESUBVENCION,t3.CANT_MAX_SUBVENCION CONVOCATORIASCANTMAXSUBVENCION,t3.PLSQL_CALCULO CONVOCATORIASPLSQLCALCULO,t3.PLSQL_REPARTO CONVOCATORIASPLSQLREPARTO,t3.OBSERVACIONES CONVOCATORIASOBSERVACIONES,t3.FECHA_ORDEN_DIA CONVOCATORIASFECHAORDENDIA,t3.FECHA_REGISTRO CONVOCATORIASFECHAREGISTRO,t3.USUARIO_REGISTRO CONVOCATORIASUSUARIOREGISTRO,t3.FECHA_ULTMODIFICACION CONVOCATORIASFECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION CONVOCATORIASUSUARIOULTMODIFICACION,t3.LIMITE_AT CONVOCATORIASLIMITELOCAL,t3.ID_TIPO_CONVOCATORIA CONVOCATORIASIDTIPOCONVOCATORIA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM CRITERIOS_PUNTUACION t1
		// ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("CRITERIOS_PUNTUACION");
		from.add("TIPOS_CRITERIO");
		from.add("CONVOCATORIAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCriteriosPuntuacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CRITERIO", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					CriteriosPuntuacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(CriteriosPuntuacion filterCriteriosPuntuacion,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM CRITERIOS_PUNTUACION t1
		// ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("CRITERIOS_PUNTUACION");
		from.add("TIPOS_CRITERIO");
		from.add("CONVOCATORIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCriteriosPuntuacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CRITERIO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<CriteriosPuntuacion>>
	 */
	@Override
	public List<TableRowDto<CriteriosPuntuacion>> findAllChild(CriteriosPuntuacion filterCriteriosPuntuacion,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM CRITERIOS_PUNTUACION t1
		// ,TIPOS_CRITERIO t2 ,CONVOCATORIAS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("CRITERIOS_PUNTUACION");
		from.add("TIPOS_CRITERIO");
		from.add("CONVOCATORIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCriteriosPuntuacion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CRITERIO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<CriteriosPuntuacion>(this.rwMapPK, "ID_CRITERIO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the CriteriosPuntuacion entity
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(CriteriosPuntuacion criteriospuntuacion) {

		StringBuilder where = new StringBuilder(CriteriosPuntuacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (criteriospuntuacion != null && criteriospuntuacion.getIdCriterio() != null) {
			where.append(" AND t1.ID_CRITERIO = ?");
			params.add(criteriospuntuacion.getIdCriterio());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getIdTipoCriterio() != null) {
			where.append(" AND t2.ID_TIPO_CRITERIO = ?");
			params.add(criteriospuntuacion.getTiposCriterio().getIdTipoCriterio());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(criteriospuntuacion.getTiposCriterio().getDescripcionCastellano());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(criteriospuntuacion.getTiposCriterio().getDescripcionEuskera());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(criteriospuntuacion.getTiposCriterio().getFechaRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(criteriospuntuacion.getTiposCriterio().getUsuarioRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t3.ID_CONVOCATORIA = ?");
			params.add(criteriospuntuacion.getConvocatorias().getIdConvocatoria());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getTiposConvocatoria() != null
				&& criteriospuntuacion.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t3.ID_TIPO_CONVOCATORIA = ?");
			params.add(criteriospuntuacion.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getIdProcedimiento() != null) {
			where.append(" AND t3.ID_PROCEDIMIENTO = ?");
			params.add(criteriospuntuacion.getConvocatorias().getIdProcedimiento());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getConvocatoria() != null) {
			where.append(" AND t3.CONVOCATORIA = ?");
			params.add(criteriospuntuacion.getConvocatorias().getConvocatoria());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaResolucion() != null) {
			where.append(" AND t3.FECHA_RESOLUCION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaResolucion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getImporte() != null) {
			where.append(" AND t3.IMPORTE = ?");
			params.add(criteriospuntuacion.getConvocatorias().getImporte());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getPorcentajeSubvencion() != null) {
			where.append(" AND t3.PORCENTAJE_SUBVENCION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getPorcentajeSubvencion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getCantMaxSubvencion() != null) {
			where.append(" AND t3.CANT_MAX_SUBVENCION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getCantMaxSubvencion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getPlsqlCalculo() != null) {
			where.append(" AND t3.PLSQL_CALCULO = ?");
			params.add(criteriospuntuacion.getConvocatorias().getPlsqlCalculo());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getPlsqlReparto() != null) {
			where.append(" AND t3.PLSQL_REPARTO = ?");
			params.add(criteriospuntuacion.getConvocatorias().getPlsqlReparto());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getObservaciones() != null) {
			where.append(" AND t3.OBSERVACIONES = ?");
			params.add(criteriospuntuacion.getConvocatorias().getObservaciones());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaOrdenDia() != null) {
			where.append(" AND t3.FECHA_ORDEN_DIA = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaOrdenDia());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(criteriospuntuacion.getConvocatorias().getUsuarioRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaUltmodificacion() != null) {
			where.append(" AND t3.FECHA_ULTMODIFICACION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaUltmodificacion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getUsuarioUltmodificacion() != null) {
			where.append(" AND t3.USUARIO_ULTMODIFICACION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getUsuarioUltmodificacion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getLimiteLocal() != null) {
			where.append(" AND t3.LIMITE_AT = ?");
			params.add(criteriospuntuacion.getConvocatorias().getLimiteLocal());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getCriPunCastellano() != null) {
			where.append(" AND t1.CRI_PUN_CASTELLANO = ?");
			params.add(criteriospuntuacion.getCriPunCastellano());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getCriPunEuskera() != null) {
			where.append(" AND t1.CRI_PUN_EUSKERA = ?");
			params.add(criteriospuntuacion.getCriPunEuskera());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getValorMinimo() != null) {
			where.append(" AND t1.VALOR_MINIMO = ?");
			params.add(criteriospuntuacion.getValorMinimo());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getValorMaximo() != null) {
			where.append(" AND t1.VALOR_MAXIMO = ?");
			params.add(criteriospuntuacion.getValorMaximo());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getIncrementoPorcentaje() != null) {
			where.append(" AND t1.INCREMENTO_PORCENTAJE = ?");
			params.add(criteriospuntuacion.getIncrementoPorcentaje());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getObservaciones() != null) {
			where.append(" AND t1.OBSERVACIONES = ?");
			params.add(criteriospuntuacion.getObservaciones());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(criteriospuntuacion.getFechaRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(criteriospuntuacion.getUsuarioRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(criteriospuntuacion.getFechaUltmodificacion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(criteriospuntuacion.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the CriteriosPuntuacion entity
	 *
	 * @param criteriospuntuacion
	 *            CriteriosPuntuacion Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(CriteriosPuntuacion criteriospuntuacion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(CriteriosPuntuacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (criteriospuntuacion != null && criteriospuntuacion.getIdCriterio() != null) {
			where.append(" AND t1.ID_CRITERIO = ?");
			params.add(criteriospuntuacion.getIdCriterio());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getIdTipoCriterio() != null) {
			where.append(" AND t2.ID_TIPO_CRITERIO = ?");
			params.add(criteriospuntuacion.getTiposCriterio().getIdTipoCriterio());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getTiposCriterio().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getTiposCriterio().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getTiposCriterio().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getTiposCriterio().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(criteriospuntuacion.getTiposCriterio().getFechaRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getTiposCriterio() != null
				&& criteriospuntuacion.getTiposCriterio().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getTiposCriterio().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getTiposCriterio().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t3.ID_CONVOCATORIA = ?");
			params.add(criteriospuntuacion.getConvocatorias().getIdConvocatoria());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getTiposConvocatoria() != null
				&& criteriospuntuacion.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t3.ID_TIPO_CONVOCATORIA = ?");
			params.add(criteriospuntuacion.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getIdProcedimiento() != null) {
			where.append(" AND t3.ID_PROCEDIMIENTO = ?");
			params.add(criteriospuntuacion.getConvocatorias().getIdProcedimiento());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getConvocatoria() != null) {
			where.append(" AND UPPER(t3.CONVOCATORIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getConvocatorias().getConvocatoria().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getConvocatorias().getConvocatoria().toUpperCase() + "%");
			}
			where.append(" AND t3.CONVOCATORIA IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaResolucion() != null) {
			where.append(" AND t3.FECHA_RESOLUCION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaResolucion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getImporte() != null) {
			where.append(" AND t3.IMPORTE = ?");
			params.add(criteriospuntuacion.getConvocatorias().getImporte());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getPorcentajeSubvencion() != null) {
			where.append(" AND t3.PORCENTAJE_SUBVENCION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getPorcentajeSubvencion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getCantMaxSubvencion() != null) {
			where.append(" AND t3.CANT_MAX_SUBVENCION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getCantMaxSubvencion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getPlsqlCalculo() != null) {
			where.append(" AND UPPER(t3.PLSQL_CALCULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getConvocatorias().getPlsqlCalculo().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getConvocatorias().getPlsqlCalculo().toUpperCase() + "%");
			}
			where.append(" AND t3.PLSQL_CALCULO IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getPlsqlReparto() != null) {
			where.append(" AND UPPER(t3.PLSQL_REPARTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getConvocatorias().getPlsqlReparto().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getConvocatorias().getPlsqlReparto().toUpperCase() + "%");
			}
			where.append(" AND t3.PLSQL_REPARTO IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getObservaciones() != null) {
			where.append(" AND UPPER(t3.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getConvocatorias().getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getConvocatorias().getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t3.OBSERVACIONES IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaOrdenDia() != null) {
			where.append(" AND t3.FECHA_ORDEN_DIA = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaOrdenDia());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getConvocatorias().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getConvocatorias().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getFechaUltmodificacion() != null) {
			where.append(" AND t3.FECHA_ULTMODIFICACION = ?");
			params.add(criteriospuntuacion.getConvocatorias().getFechaUltmodificacion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t3.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getConvocatorias().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add(
						"%" + criteriospuntuacion.getConvocatorias().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getConvocatorias() != null
				&& criteriospuntuacion.getConvocatorias().getLimiteLocal() != null) {
			where.append(" AND t3.LIMITE_AT = ?");
			params.add(criteriospuntuacion.getConvocatorias().getLimiteLocal());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getCriPunCastellano() != null) {
			where.append(" AND UPPER(t1.CRI_PUN_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getCriPunCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getCriPunCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.CRI_PUN_CASTELLANO IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getCriPunEuskera() != null) {
			where.append(" AND UPPER(t1.CRI_PUN_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getCriPunEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getCriPunEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.CRI_PUN_EUSKERA IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getValorMinimo() != null) {
			where.append(" AND t1.VALOR_MINIMO = ?");
			params.add(criteriospuntuacion.getValorMinimo());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getValorMaximo() != null) {
			where.append(" AND t1.VALOR_MAXIMO = ?");
			params.add(criteriospuntuacion.getValorMaximo());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getIncrementoPorcentaje() != null) {
			where.append(" AND t1.INCREMENTO_PORCENTAJE = ?");
			params.add(criteriospuntuacion.getIncrementoPorcentaje());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getObservaciones() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(criteriospuntuacion.getFechaRegistro());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(criteriospuntuacion.getFechaUltmodificacion());
		}
		if (criteriospuntuacion != null && criteriospuntuacion.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(criteriospuntuacion.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + criteriospuntuacion.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
