package com.ejie.ab60.dao.criteriosPuntuacion;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.ab60.model.criteriosPuntuacion.RelExpCriPun;
import com.ejie.ab60.model.criteriosPuntuacion.TiposCriterio;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpCriPunDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelExpCriPunDaoImpl implements RelExpCriPunDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELEXPCRIPUN", "IDEXPEDIENTE",
			"PUNTUACIONTEORICA", "PUNTUACIONADMITIDA", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION", "CRITERIOSPUNTUACIONIDCRITERIO", "CRIPUNCASTELLANO", "CRIPUNEUSKERA",
			"CRITERIOSPUNTUACIONVALORMINIMO", "CRITERIOSPUNTUACIONVALORMAXIMO",
			"CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE", "CRITERIOSPUNTUACIONOBSERVACIONES",
			"CRITERIOSPUNTUACIONFECHAREGISTRO", "CRITERIOSPUNTUACIONUSUARIOREGISTRO",
			"CRITERIOSPUNTUACIONFECHAULTMODIFICACION", "CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION",
			"CRITERIOSPUNTUACIONIDTIPOCRITERIO", "CRITERIOSPUNTUACIONIDCONVOCATORIA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelExpCriPun> rwMap = new RowMapper<RelExpCriPun>() {
		public RelExpCriPun mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpCriPun(resultSet.getInt("IDRELEXPCRIPUN"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getBigDecimal("PUNTUACIONTEORICA"), resultSet.getBigDecimal("PUNTUACIONADMITIDA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new CriteriosPuntuacion(resultSet.getInt("CriteriosPuntuacionIDCRITERIO"),
							resultSet.getString("CriteriosPuntuacionCRIPUNCASTELLANO"),
							resultSet.getString("CriteriosPuntuacionCRIPUNEUSKERA"),
							resultSet.getBigDecimal("CriteriosPuntuacionVALORMINIMO"),
							resultSet.getBigDecimal("CriteriosPuntuacionVALORMAXIMO"),
							resultSet.getBigDecimal("CriteriosPuntuacionINCREMENTOPORCENTAJE"),
							resultSet.getString("CriteriosPuntuacionOBSERVACIONES"),
							resultSet.getDate("CriteriosPuntuacionFECHAREGISTRO"),
							resultSet.getString("CriteriosPuntuacionUSUARIOREGISTRO"),
							resultSet.getDate("CriteriosPuntuacionFECHAULTMODIFICACION"),
							resultSet.getString("CriteriosPuntuacionUSUARIOULTMODIFICACION"),
							new TiposCriterio(resultSet.getLong("CriteriosPuntuacionIDTIPOCRITERIO"), null, null, null,
									null, null),
							new Convocatorias(resultSet.getInt("CriteriosPuntuacionIDCONVOCATORIA"))));
		}
	};

	private RowMapper<RelExpCriPun> rwMapIdsCriterio = new RowMapper<RelExpCriPun>() {
		public RelExpCriPun mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpCriPun(resultSet.getInt("IDRELEXPCRIPUN"), resultSet.getInt("IDEXPEDIENTE"),
					new CriteriosPuntuacion(resultSet.getInt("CriteriosPuntuacionIDCRITERIO")));
		}
	};

	private RowMapper<RelExpCriPun> rwMapPuntTeorica = new RowMapper<RelExpCriPun>() {
		public RelExpCriPun mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpCriPun relExpCriPun = new RelExpCriPun();
			relExpCriPun.setIdRelExpCriPun(resultSet.getInt("IDRELEXPCRIPUN"));
			relExpCriPun.setPuntuacionTeorica(resultSet.getBigDecimal("PUNTUACIONTEORICA"));
			return relExpCriPun;
		}
	};

	private RowMapper<RelExpCriPun> rwMapDescCriterio = new RowMapper<RelExpCriPun>() {
		public RelExpCriPun mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpCriPun relExpCriPun = new RelExpCriPun();
			relExpCriPun.setIdRelExpCriPun(resultSet.getInt("IDRELEXPCRIPUN"));
			relExpCriPun.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpCriPun.setPuntuacionTeorica(resultSet.getBigDecimal("PUNTUACIONTEORICA"));
			if (resultSet.wasNull()) {
				relExpCriPun.setPuntuacionTeorica(null);
			}
			relExpCriPun.setPuntuacionAdmitida(resultSet.getBigDecimal("PUNTUACIONADMITIDA"));
			if (resultSet.wasNull()) {
				relExpCriPun.setPuntuacionAdmitida(null);
			}
			CriteriosPuntuacion criteriosPuntuacion = new CriteriosPuntuacion();
			criteriosPuntuacion.setIdCriterio(resultSet.getInt("IDCRITERIO"));
			criteriosPuntuacion.setCriPunCastellano(resultSet.getString("CRIPUNCASTELLANO"));
			criteriosPuntuacion.setCriPunEuskera(resultSet.getString("CRIPUNEUSKERA"));
			criteriosPuntuacion.setValorMinimo(resultSet.getBigDecimal("VALORMINIMO"));
			criteriosPuntuacion.setValorMaximo(resultSet.getBigDecimal("VALORMAXIMO"));
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			criteriosPuntuacion.setConvocatorias(convocatorias);
			relExpCriPun.setCriteriosPuntuacion(criteriosPuntuacion);

			return relExpCriPun;
		}
	};

	private RowMapper<RelExpCriPun> rwMapPK = new RowMapper<RelExpCriPun>() {
		public RelExpCriPun mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpCriPun(resultSet.getInt("IDRELEXPCRIPUN"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelExpCriPun>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelExpCriPun>>() {
		public JerarquiaDto<RelExpCriPun> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpCriPun relexpcripun = new RelExpCriPun(resultSet.getInt("IDRELEXPCRIPUN"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getBigDecimal("PUNTUACIONTEORICA"),
					resultSet.getBigDecimal("PUNTUACIONADMITIDA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new CriteriosPuntuacion(resultSet.getInt("CriteriosPuntuacionIDCRITERIO"),
							resultSet.getString("CriteriosPuntuacionCRIPUNCASTELLANO"),
							resultSet.getString("CriteriosPuntuacionCRIPUNEUSKERA"),
							resultSet.getBigDecimal("CriteriosPuntuacionVALORMINIMO"),
							resultSet.getBigDecimal("CriteriosPuntuacionVALORMAXIMO"),
							resultSet.getBigDecimal("CriteriosPuntuacionINCREMENTOPORCENTAJE"),
							resultSet.getString("CriteriosPuntuacionOBSERVACIONES"),
							resultSet.getDate("CriteriosPuntuacionFECHAREGISTRO"),
							resultSet.getString("CriteriosPuntuacionUSUARIOREGISTRO"),
							resultSet.getDate("CriteriosPuntuacionFECHAULTMODIFICACION"),
							resultSet.getString("CriteriosPuntuacionUSUARIOULTMODIFICACION"),
							new TiposCriterio(resultSet.getLong("CriteriosPuntuacionIDTIPOCRITERIO"), null, null, null,
									null, null),
							new Convocatorias(resultSet.getInt("CriteriosPuntuacionIDCONVOCATORIA"))));

			JerarquiaDto<RelExpCriPun> jerarquia = new JerarquiaDto<RelExpCriPun>();
			jerarquia.setModel(relexpcripun);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	public RelExpCriPun add(RelExpCriPun relexpcripun) {
		String query = "INSERT INTO REL_EXP_CRI_PUN (ID_REL_EXP_CRI_PUN, ID_CRITERIO, ID_EXPEDIENTE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB60.S_AB6009T00.NEXTVAL,?,?,?,?)";
		Object getCriteriosPuntuacionIdCriterioAux = null;
		if (relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getIdCriterio() != null) {
			getCriteriosPuntuacionIdCriterioAux = relexpcripun.getCriteriosPuntuacion().getIdCriterio();
		}
		this.jdbcTemplate.update(query, getCriteriosPuntuacionIdCriterioAux, relexpcripun.getIdExpediente(),
				relexpcripun.getFechaRegistro(), relexpcripun.getUsuarioRegistro());
		return relexpcripun;
	}

	/**
	 * Updates a single row in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	public RelExpCriPun update(RelExpCriPun relexpcripun) {
		String query = "UPDATE REL_EXP_CRI_PUN SET  PUNTUACION_ADMITIDA=?,  FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_EXP_CRI_PUN=?";

		this.jdbcTemplate.update(query, relexpcripun.getPuntuacionAdmitida(), relexpcripun.getFechaUltmodificacion(),
				relexpcripun.getUsuarioUltmodificacion(), relexpcripun.getIdRelExpCriPun());
		return relexpcripun;
	}

	/**
	 * Updates a single row in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	public RelExpCriPun updatePuntuacionAdmitida(RelExpCriPun relexpcripun) {
		String query = "UPDATE REL_EXP_CRI_PUN SET PUNTUACION_ADMITIDA = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_EXPEDIENTE = ? AND ID_REL_EXP_CRI_PUN = ?";

		this.jdbcTemplate.update(query, relexpcripun.getPuntuacionTeorica(), relexpcripun.getFechaUltmodificacion(),
				relexpcripun.getUsuarioUltmodificacion(), relexpcripun.getIdExpediente(),
				relexpcripun.getIdRelExpCriPun());
		return relexpcripun;
	}

	/**
	 * Finds a single row in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	@Transactional(readOnly = true)
	public RelExpCriPun find(RelExpCriPun relexpcripun) {
		String query = "SELECT t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.PUNTUACION_TEORICA PUNTUACIONTEORICA, t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO, t2.CRI_PUN_CASTELLANO CRITERIOSPUNTUACIONCRIPUNCASTELLANO, t2.CRI_PUN_EUSKERA CRITERIOSPUNTUACIONCRIPUNEUSKERA, t2.VALOR_MINIMO CRITERIOSPUNTUACIONVALORMINIMO, t2.VALOR_MAXIMO CRITERIOSPUNTUACIONVALORMAXIMO, t2.INCREMENTO_PORCENTAJE CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE, t2.OBSERVACIONES CRITERIOSPUNTUACIONOBSERVACIONES, t2.FECHA_REGISTRO CRITERIOSPUNTUACIONFECHAREGISTRO, t2.USUARIO_REGISTRO CRITERIOSPUNTUACIONUSUARIOREGISTRO, t2.FECHA_ULTMODIFICACION CRITERIOSPUNTUACIONFECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION, t2.ID_TIPO_CRITERIO CRITERIOSPUNTUACIONIDTIPOCRITERIO, t2.ID_CONVOCATORIA CRITERIOSPUNTUACIONIDCONVOCATORIA FROM REL_EXP_CRI_PUN t1 , CRITERIOS_PUNTUACION t2  WHERE t1.ID_REL_EXP_CRI_PUN = ?   AND t1.ID_CRITERIO= t2.ID_CRITERIO(+)";

		List<RelExpCriPun> relexpcripunList = this.jdbcTemplate.query(query, this.rwMap,
				relexpcripun.getIdRelExpCriPun());
		return (RelExpCriPun) DataAccessUtils.uniqueResult(relexpcripunList);
	}

	/**
	 * Finds a single row in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	@Transactional(readOnly = true)
	public RelExpCriPun findPuntTeorica(RelExpCriPun relexpcripun) {
		String query = "SELECT ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN, PUNTUACION_TEORICA PUNTUACIONTEORICA FROM REL_EXP_CRI_PUN  WHERE ID_REL_EXP_CRI_PUN = ?";

		List<RelExpCriPun> relexpcripunList = this.jdbcTemplate.query(query, this.rwMapPuntTeorica,
				relexpcripun.getIdRelExpCriPun());
		return (RelExpCriPun) DataAccessUtils.uniqueResult(relexpcripunList);
	}

	/**
	 * Removes a single row in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @return
	 */
	public void remove(RelExpCriPun relexpcripun) {
		String query = "DELETE FROM REL_EXP_CRI_PUN WHERE ID_REL_EXP_CRI_PUN=?";
		this.jdbcTemplate.update(query, relexpcripun.getIdRelExpCriPun());
	}

	/**
	 * Removes a single row in the RelExpCriPun table.
	 *
	 * @param Integer
	 *            IdExpediente
	 * @return
	 */
	public void removeCriteriosPorExpediente(Integer IdExpediente) {
		String query = "DELETE FROM REL_EXP_CRI_PUN WHERE ID_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, IdExpediente);
	}

	/**
	 * Finds a list of rows in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpCriPun>
	 */
	@Transactional(readOnly = true)
	public List<RelExpCriPun> findAll(RelExpCriPun relexpcripun, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_TEORICA PUNTUACIONTEORICA,t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO,t2.CRI_PUN_CASTELLANO CRITERIOSPUNTUACIONCRIPUNCASTELLANO,t2.CRI_PUN_EUSKERA CRITERIOSPUNTUACIONCRIPUNEUSKERA,t2.VALOR_MINIMO CRITERIOSPUNTUACIONVALORMINIMO,t2.VALOR_MAXIMO CRITERIOSPUNTUACIONVALORMAXIMO,t2.INCREMENTO_PORCENTAJE CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE,t2.OBSERVACIONES CRITERIOSPUNTUACIONOBSERVACIONES,t2.FECHA_REGISTRO CRITERIOSPUNTUACIONFECHAREGISTRO,t2.USUARIO_REGISTRO CRITERIOSPUNTUACIONUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CRITERIOSPUNTUACIONFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO CRITERIOSPUNTUACIONIDTIPOCRITERIO,t2.ID_CONVOCATORIA CRITERIOSPUNTUACIONIDCONVOCATORIA ");
		query.append("FROM REL_EXP_CRI_PUN t1 ,CRITERIOS_PUNTUACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpcripun);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CRITERIO= t2.ID_CRITERIO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpCriPunDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpCriPun>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * 
	 * Lista de id de criterios de puntuacion de la RelExpCriPun table
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<RelExpCriPun>
	 */
	@Transactional(readOnly = true)
	public List<RelExpCriPun> findIdsCriterio(Integer idExpediente) {

		String query = "SELECT t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN, t1.ID_EXPEDIENTE IDEXPEDIENTE, t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO FROM REL_EXP_CRI_PUN t1, CRITERIOS_PUNTUACION t2 WHERE t1.ID_EXPEDIENTE = ? AND t1.ID_CRITERIO = t2.ID_CRITERIO";

		List<RelExpCriPun> relExpCriPunList = this.jdbcTemplate.query(query, this.rwMapIdsCriterio, idExpediente);

		// return (CriteriosPuntuacion)
		// DataAccessUtils.uniqueResult(criteriospuntuacionList);

		return relExpCriPunList;
	}

	/**
	 * 
	 * Lista de id de criterios de puntuacion de la RelExpCriPun table
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<RelExpCriPun>
	 */
	@Transactional(readOnly = true)
	public List<RelExpCriPun> findDescCriterio(Integer idExpediente, Integer idConvocatoria) {

		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN, t1.ID_EXPEDIENTE IDEXPEDIENTE, t2.ID_CRITERIO IDCRITERIO, t2.ID_CONVOCATORIA IDCONVOCATORIA, t1.PUNTUACION_TEORICA PUNTUACIONTEORICA, t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA, t2.CRI_PUN_CASTELLANO CRIPUNCASTELLANO, t2.CRI_PUN_EUSKERA CRIPUNEUSKERA, t2.VALOR_MINIMO VALORMINIMO, t2.VALOR_MAXIMO VALORMAXIMO FROM REL_EXP_CRI_PUN t1, CRITERIOS_PUNTUACION t2 WHERE t1.ID_CRITERIO = t2.ID_CRITERIO AND t1.ID_EXPEDIENTE = ? AND t2.ID_CONVOCATORIA = ? AND t2.ID_CRITERIO_PADRE IS NULL");

		Locale locale = LocaleContextHolder.getLocale();

		if (locale.toString().equals(Constantes.CASTELLANO)) {
			query.append(" ORDER BY CRIPUNCASTELLANO");
		} else if (locale.toString().equals(Constantes.EUSKERA)) {
			query.append(" ORDER BY CRIPUNEUSKERA");
		}

		List<RelExpCriPun> relExpCriPunList = this.jdbcTemplate.query(query.toString(), this.rwMapDescCriterio,
				idExpediente, idConvocatoria);

		return relExpCriPunList;
	}

	/**
	 * Finds rows in the RelExpCriPun table using like.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpCriPun>
	 */
	@Transactional(readOnly = true)
	public List<RelExpCriPun> findAllLike(RelExpCriPun relexpcripun, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_TEORICA PUNTUACIONTEORICA,t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO,t2.CRI_PUN_CASTELLANO CRITERIOSPUNTUACIONCRIPUNCASTELLANO,t2.CRI_PUN_EUSKERA CRITERIOSPUNTUACIONCRIPUNEUSKERA,t2.VALOR_MINIMO CRITERIOSPUNTUACIONVALORMINIMO,t2.VALOR_MAXIMO CRITERIOSPUNTUACIONVALORMAXIMO,t2.INCREMENTO_PORCENTAJE CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE,t2.OBSERVACIONES CRITERIOSPUNTUACIONOBSERVACIONES,t2.FECHA_REGISTRO CRITERIOSPUNTUACIONFECHAREGISTRO,t2.USUARIO_REGISTRO CRITERIOSPUNTUACIONUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CRITERIOSPUNTUACIONFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO CRITERIOSPUNTUACIONIDTIPOCRITERIO,t2.ID_CONVOCATORIA CRITERIOSPUNTUACIONIDCONVOCATORIA ");
		query.append("FROM REL_EXP_CRI_PUN t1 ,CRITERIOS_PUNTUACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpcripun, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CRITERIO= t2.ID_CRITERIO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpCriPunDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpCriPun>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelExpCriPun table.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelExpCriPun relexpcripun) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_CRI_PUN t1 , CRITERIOS_PUNTUACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpcripun);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CRITERIO= t2.ID_CRITERIO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelExpCriPun table using like.
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelExpCriPun relexpcripun, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_CRI_PUN t1 ,CRITERIOS_PUNTUACION t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpcripun, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CRITERIO= t2.ID_CRITERIO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelExpCriPun selected for rup_table
	 *
	 * @param relexpcripun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpCriPun>>
	 */
	@Override
	public List<TableRowDto<RelExpCriPun>> reorderSelection(RelExpCriPun relexpcripun,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_TEORICA PUNTUACIONTEORICA,t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO,t2.CRI_PUN_CASTELLANO CRITERIOSPUNTUACIONCRIPUNCASTELLANO,t2.CRI_PUN_EUSKERA CRITERIOSPUNTUACIONCRIPUNEUSKERA,t2.VALOR_MINIMO CRITERIOSPUNTUACIONVALORMINIMO,t2.VALOR_MAXIMO CRITERIOSPUNTUACIONVALORMAXIMO,t2.INCREMENTO_PORCENTAJE CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE,t2.OBSERVACIONES CRITERIOSPUNTUACIONOBSERVACIONES,t2.FECHA_REGISTRO CRITERIOSPUNTUACIONFECHAREGISTRO,t2.USUARIO_REGISTRO CRITERIOSPUNTUACIONUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CRITERIOSPUNTUACIONFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO CRITERIOSPUNTUACIONIDTIPOCRITERIO,t2.ID_CONVOCATORIA CRITERIOSPUNTUACIONIDCONVOCATORIA ");
		// FROM
		query.append("FROM REL_EXP_CRI_PUN t1 ,CRITERIOS_PUNTUACION t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpcripun, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CRITERIO= t2.ID_CRITERIO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelExpCriPun.class,
				filterParamList, "ID_REL_EXP_CRI_PUN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpCriPun>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelExpCriPun
	 * @param searchParams
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpCriPun>>
	 */
	@Override
	public List<TableRowDto<RelExpCriPun>> search(RelExpCriPun filterParams, RelExpCriPun searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_TEORICA PUNTUACIONTEORICA,t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO,t2.CRI_PUN_CASTELLANO CRITERIOSPUNTUACIONCRIPUNCASTELLANO,t2.CRI_PUN_EUSKERA CRITERIOSPUNTUACIONCRIPUNEUSKERA,t2.VALOR_MINIMO CRITERIOSPUNTUACIONVALORMINIMO,t2.VALOR_MAXIMO CRITERIOSPUNTUACIONVALORMAXIMO,t2.INCREMENTO_PORCENTAJE CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE,t2.OBSERVACIONES CRITERIOSPUNTUACIONOBSERVACIONES,t2.FECHA_REGISTRO CRITERIOSPUNTUACIONFECHAREGISTRO,t2.USUARIO_REGISTRO CRITERIOSPUNTUACIONUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CRITERIOSPUNTUACIONFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO CRITERIOSPUNTUACIONIDTIPOCRITERIO,t2.ID_CONVOCATORIA CRITERIOSPUNTUACIONIDCONVOCATORIA ");
		// FROM
		query.append("FROM REL_EXP_CRI_PUN t1 ,CRITERIOS_PUNTUACION t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CRITERIO= t2.ID_CRITERIO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelExpCriPun.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_EXP_CRI_PUN");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpCriPun>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelexpcripun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelExpCriPun filterrelexpcripun, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_TEORICA PUNTUACIONTEORICA,t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO,t2.CRI_PUN_CASTELLANO CRITERIOSPUNTUACIONCRIPUNCASTELLANO,t2.CRI_PUN_EUSKERA CRITERIOSPUNTUACIONCRIPUNEUSKERA,t2.VALOR_MINIMO CRITERIOSPUNTUACIONVALORMINIMO,t2.VALOR_MAXIMO CRITERIOSPUNTUACIONVALORMAXIMO,t2.INCREMENTO_PORCENTAJE CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE,t2.OBSERVACIONES CRITERIOSPUNTUACIONOBSERVACIONES,t2.FECHA_REGISTRO CRITERIOSPUNTUACIONFECHAREGISTRO,t2.USUARIO_REGISTRO CRITERIOSPUNTUACIONUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CRITERIOSPUNTUACIONFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO CRITERIOSPUNTUACIONIDTIPOCRITERIO,t2.ID_CONVOCATORIA CRITERIOSPUNTUACIONIDCONVOCATORIA ");
		// FROM
		query.append("FROM REL_EXP_CRI_PUN t1 ,CRITERIOS_PUNTUACION t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelexpcripun, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelExpCriPun.class,
				query, params, "ID_REL_EXP_CRI_PUN");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelExpCriPun table.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelExpCriPun>>
	 */
	@Override
	public List<JerarquiaDto<RelExpCriPun>> findAllLikeJerarquia(RelExpCriPun filterRelExpCriPun,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_CRI_PUN IDRELEXPCRIPUN,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.PUNTUACION_TEORICA PUNTUACIONTEORICA,t1.PUNTUACION_ADMITIDA PUNTUACIONADMITIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_CRITERIO CRITERIOSPUNTUACIONIDCRITERIO,t2.CRI_PUN_CASTELLANO CRITERIOSPUNTUACIONCRIPUNCASTELLANO,t2.CRI_PUN_EUSKERA CRITERIOSPUNTUACIONCRIPUNEUSKERA,t2.VALOR_MINIMO CRITERIOSPUNTUACIONVALORMINIMO,t2.VALOR_MAXIMO CRITERIOSPUNTUACIONVALORMAXIMO,t2.INCREMENTO_PORCENTAJE CRITERIOSPUNTUACIONINCREMENTOPORCENTAJE,t2.OBSERVACIONES CRITERIOSPUNTUACIONOBSERVACIONES,t2.FECHA_REGISTRO CRITERIOSPUNTUACIONFECHAREGISTRO,t2.USUARIO_REGISTRO CRITERIOSPUNTUACIONUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION CRITERIOSPUNTUACIONFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION CRITERIOSPUNTUACIONUSUARIOULTMODIFICACION,t2.ID_TIPO_CRITERIO CRITERIOSPUNTUACIONIDTIPOCRITERIO,t2.ID_CONVOCATORIA CRITERIOSPUNTUACIONIDCONVOCATORIA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_CRI_PUN t1
		// ,CRITERIOS_PUNTUACION t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_CRI_PUN");
		from.add("CRITERIOS_PUNTUACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpCriPun, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_EXP_CRI_PUN", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelExpCriPunDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelExpCriPun filterRelExpCriPun, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_CRI_PUN t1
		// ,CRITERIOS_PUNTUACION t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_CRI_PUN");
		from.add("CRITERIOS_PUNTUACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpCriPun, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_EXP_CRI_PUN",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpCriPun>>
	 */
	@Override
	public List<TableRowDto<RelExpCriPun>> findAllChild(RelExpCriPun filterRelExpCriPun,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_CRI_PUN t1
		// ,CRITERIOS_PUNTUACION t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_CRI_PUN");
		from.add("CRITERIOS_PUNTUACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpCriPun, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_EXP_CRI_PUN",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelExpCriPun>(this.rwMapPK, "ID_REL_EXP_CRI_PUN"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpCriPun entity
	 *
	 * @param relexpcripun
	 *            RelExpCriPun Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelExpCriPun relexpcripun) {

		StringBuilder where = new StringBuilder(RelExpCriPunDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpcripun != null && relexpcripun.getIdRelExpCriPun() != null) {
			where.append(" AND t1.ID_REL_EXP_CRI_PUN = ?");
			params.add(relexpcripun.getIdRelExpCriPun());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getIdCriterio() != null) {
			where.append(" AND t2.ID_CRITERIO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getIdCriterio());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getTiposCriterio() != null
				&& relexpcripun.getCriteriosPuntuacion().getTiposCriterio().getIdTipoCriterio() != null) {
			where.append(" AND t2.ID_TIPO_CRITERIO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getTiposCriterio().getIdTipoCriterio());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getConvocatorias() != null
				&& relexpcripun.getCriteriosPuntuacion().getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getConvocatorias().getIdConvocatoria());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getCriPunCastellano() != null) {
			where.append(" AND t2.CRI_PUN_CASTELLANO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getCriPunCastellano());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getCriPunEuskera() != null) {
			where.append(" AND t2.CRI_PUN_EUSKERA = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getCriPunEuskera());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getValorMinimo() != null) {
			where.append(" AND t2.VALOR_MINIMO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getValorMinimo());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getValorMaximo() != null) {
			where.append(" AND t2.VALOR_MAXIMO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getValorMaximo());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getIncrementoPorcentaje() != null) {
			where.append(" AND t2.INCREMENTO_PORCENTAJE = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getIncrementoPorcentaje());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getObservaciones() != null) {
			where.append(" AND t2.OBSERVACIONES = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getObservaciones());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getFechaRegistro());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getUsuarioRegistro());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getFechaUltmodificacion());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getUsuarioUltmodificacion());
		}
		if (relexpcripun != null && relexpcripun.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpcripun.getIdExpediente());
		}
		if (relexpcripun != null && relexpcripun.getPuntuacionTeorica() != null) {
			where.append(" AND t1.PUNTUACION_TEORICA = ?");
			params.add(relexpcripun.getPuntuacionTeorica());
		}
		if (relexpcripun != null && relexpcripun.getPuntuacionAdmitida() != null) {
			where.append(" AND t1.PUNTUACION_ADMITIDA = ?");
			params.add(relexpcripun.getPuntuacionAdmitida());
		}
		if (relexpcripun != null && relexpcripun.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpcripun.getFechaRegistro());
		}
		if (relexpcripun != null && relexpcripun.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relexpcripun.getUsuarioRegistro());
		}
		if (relexpcripun != null && relexpcripun.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relexpcripun.getFechaUltmodificacion());
		}
		if (relexpcripun != null && relexpcripun.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(relexpcripun.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpCriPun entity
	 *
	 * @param relexpcripun
	 *            RelExpCriPun Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelExpCriPun relexpcripun, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelExpCriPunDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpcripun != null && relexpcripun.getIdRelExpCriPun() != null) {
			where.append(" AND t1.ID_REL_EXP_CRI_PUN = ?");
			params.add(relexpcripun.getIdRelExpCriPun());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getIdCriterio() != null) {
			where.append(" AND t2.ID_CRITERIO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getIdCriterio());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getTiposCriterio() != null
				&& relexpcripun.getCriteriosPuntuacion().getTiposCriterio().getIdTipoCriterio() != null) {
			where.append(" AND t2.ID_TIPO_CRITERIO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getTiposCriterio().getIdTipoCriterio());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getConvocatorias() != null
				&& relexpcripun.getCriteriosPuntuacion().getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getConvocatorias().getIdConvocatoria());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getCriPunCastellano() != null) {
			where.append(" AND UPPER(t2.CRI_PUN_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpcripun.getCriteriosPuntuacion().getCriPunCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + relexpcripun.getCriteriosPuntuacion().getCriPunCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.CRI_PUN_CASTELLANO IS NOT NULL");
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getCriPunEuskera() != null) {
			where.append(" AND UPPER(t2.CRI_PUN_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpcripun.getCriteriosPuntuacion().getCriPunEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + relexpcripun.getCriteriosPuntuacion().getCriPunEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.CRI_PUN_EUSKERA IS NOT NULL");
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getValorMinimo() != null) {
			where.append(" AND t2.VALOR_MINIMO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getValorMinimo());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getValorMaximo() != null) {
			where.append(" AND t2.VALOR_MAXIMO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getValorMaximo());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getIncrementoPorcentaje() != null) {
			where.append(" AND t2.INCREMENTO_PORCENTAJE = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getIncrementoPorcentaje());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getObservaciones() != null) {
			where.append(" AND UPPER(t2.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpcripun.getCriteriosPuntuacion().getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + relexpcripun.getCriteriosPuntuacion().getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t2.OBSERVACIONES IS NOT NULL");
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getFechaRegistro());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpcripun.getCriteriosPuntuacion().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpcripun.getCriteriosPuntuacion().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(relexpcripun.getCriteriosPuntuacion().getFechaUltmodificacion());
		}
		if (relexpcripun != null && relexpcripun.getCriteriosPuntuacion() != null
				&& relexpcripun.getCriteriosPuntuacion().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpcripun.getCriteriosPuntuacion().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relexpcripun.getCriteriosPuntuacion().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (relexpcripun != null && relexpcripun.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpcripun.getIdExpediente());
		}
		if (relexpcripun != null && relexpcripun.getPuntuacionTeorica() != null) {
			where.append(" AND t1.PUNTUACION_TEORICA = ?");
			params.add(relexpcripun.getPuntuacionTeorica());
		}
		if (relexpcripun != null && relexpcripun.getPuntuacionAdmitida() != null) {
			where.append(" AND t1.PUNTUACION_ADMITIDA = ?");
			params.add(relexpcripun.getPuntuacionAdmitida());
		}
		if (relexpcripun != null && relexpcripun.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpcripun.getFechaRegistro());
		}
		if (relexpcripun != null && relexpcripun.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpcripun.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpcripun.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relexpcripun != null && relexpcripun.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(relexpcripun.getFechaUltmodificacion());
		}
		if (relexpcripun != null && relexpcripun.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpcripun.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relexpcripun.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
