package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * ConceptosDao  
 * 
 *  
 */

public interface ConceptosDao {

	/**
	 * Inserts a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos add(Conceptos conceptos);

	/**
	 * Updates a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos update(Conceptos conceptos);

	/**
	 * Updates a Importe admitido row in the Conceptos table
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos updateImporte(Conceptos conceptos);

	/**
	 * 
	 * Update el importe Admitido de null a cero
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos updateImporteAdmitidoDeNullACero(Conceptos conceptos);

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos find(Conceptos conceptos);

	/**
	 * Sumatorio de importe admitido de la tabla de conceptos, por expediente y
	 * relacion subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return conceptos
	 */
	Conceptos findConceptosPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion);

	/**
	 * Finds a List of rows in the Conceptos table.
	 *
	 * @param Integer
	 *            idExpediente
	 * @return Conceptos
	 */
	Conceptos findConceptosPorExpediente(Integer idExpediente);

	/**
	 * Sumatorio de importe admitido de la tabla de conceptos por relacion
	 * subvencionable
	 *
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return conceptos
	 */
	Conceptos findSumConceptosPorRelExpActSub(Integer idRelacion);

	/**
	 * Finds a List of rows in the Conceptos table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List
	 */
	List<Conceptos> findConceptosPorRelExpActSub(Integer idRelExpActSub);

	/**
	 * Removes a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 */
	void remove(Conceptos conceptos);

	/**
	 * Finds a List of rows in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<Conceptos> findAll(Conceptos conceptos, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Conceptos table using like.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<Conceptos> findAllLike(Conceptos conceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the Conceptos table using like.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(Conceptos conceptos, Boolean startsWith);

	/**
	 * Counts rows in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Long
	 */
	Long findAllCount(Conceptos conceptos);

	/**
	 * Reorder selection.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Conceptos>>
	 */
	List<TableRowDto<Conceptos>> reorderSelection(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param searchConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Conceptos>>
	 */
	List<TableRowDto<Conceptos>> search(Conceptos filterConceptos, Conceptos searchConceptos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Conceptos>>
	 */
	List<JerarquiaDto<Conceptos>> findAllLikeJerarquia(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Conceptos>>
	 */
	List<TableRowDto<Conceptos>> findAllChild(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto);

	/**
	 * removeByIdRelExpActSub
	 * 
	 * @param idRelExpActSub
	 */
	void removeByIdRelExpActSub(Integer idRelExpActSub);

	int findCountByRelExpActSub(Integer idRelacion);

}
