package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.estudioTecnico.TiposGasto;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;

/**
 * ConceptosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ConceptosDaoImpl implements ConceptosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCONCEPTO", "IDRELEXPACTSUB", "IDTIPOGASTO",
			"CONCEPTO", "IMPORTEPRESENTADO", "IMPORTEADMITIDO", "IMPORTEJUSPRESENTADO", "IMPORTEJUSADMITIDO",
			"FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "INSPECCIONABLE",
			"OBSERVACIONESCASTELLANO", "OBSERVACIONESEUSKERA", "IMPORTESINIVA", "IVA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Conceptos> rwMap = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Conceptos concepto = new Conceptos();
			concepto.setIdConcepto(resultSet.getInt("IDCONCEPTO"));
			concepto.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			concepto.setIdTipoGasto(resultSet.getLong("IDTIPOGASTO"));
			concepto.setConcepto(resultSet.getString("CONCEPTO"));
			concepto.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			concepto.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			concepto.setImporteJusPresentado(resultSet.getBigDecimal("IMPORTEJUSPRESENTADO"));
			concepto.setImporteJusAdmitido(resultSet.getBigDecimal("IMPORTEJUSADMITIDO"));
			concepto.setFechaRegistro(resultSet.getDate("FECHAREGISTRO"));
			concepto.setUsuarioRegistro(resultSet.getString("USUARIOREGISTRO"));
			concepto.setFechaUltmodificacion(resultSet.getDate("FECHAULTMODIFICACION"));
			concepto.setUsuarioUltmodificacion(resultSet.getString("USUARIOULTMODIFICACION"));
			concepto.setInspeccionable(resultSet.getInt("INSPECCIONABLE"));
			concepto.setObservacionesCastellano(resultSet.getString("OBSERVACIONESCASTELLANO"));
			concepto.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEUSKERA"));

			concepto.setImporteSinIva(resultSet.getBigDecimal("IMPORTESINIVA"));
			concepto.setImporteIva(resultSet.getBigDecimal("IVA"));

			return concepto;
		}
	};

	private RowMapper<Conceptos> rwMap2 = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Conceptos(resultSet.getInt("IDCONCEPTO"), resultSet.getLong("IDTIPOGASTO"),
					resultSet.getString("CONCEPTO"), resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getBigDecimal("IMPORTEJUSPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEJUSADMITIDO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getInt("INSPECCIONABLE"),
					resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getString("OBSERVACIONESEUSKERA"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));
		}
	};

	private RowMapper<Conceptos> rwMapSumConceptosPorRelExpActSub = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Conceptos(resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"));
		}
	};

	private RowMapper<Conceptos> rwMapConceptosPorRelExpActSub = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Conceptos conceptos = new Conceptos();

			conceptos.setIdConcepto(resultSet.getInt("IDCONCEPTO"));
			conceptos.setIdRelExpActSub(resultSet.getInt("RELEXPACTSUBIDRELEXPACTSUB"));
			conceptos.setConcepto(resultSet.getString("CONCEPTO"));
			conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			conceptos.setImporteSinIva(resultSet.getBigDecimal("IMPORTESINIVA"));
			conceptos.setImporteIva(resultSet.getBigDecimal("IVA"));

			TiposGasto tiposGasto = new TiposGasto();

			tiposGasto.setIdTipoGasto(resultSet.getLong("IDTIPOGASTO"));
			tiposGasto.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			tiposGasto.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			conceptos.setTiposGasto(tiposGasto);

			return conceptos;
		}
	};

	private RowMapper<Conceptos> rwMapConceptosPorExpedientePorRelacion = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Conceptos(resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getBigDecimal("IMPORTESINIVA"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB")));
		}
	};

	// private RowMapper<Conceptos> rwMapConceptosPorExpediente = new
	// RowMapper<Conceptos>() {
	// public Conceptos mapRow(ResultSet resultSet, int rowNum) throws
	// SQLException {
	// return new Conceptos(resultSet.getBigDecimal("IMPORTEPRESENTADO"),
	// resultSet.getBigDecimal("IMPORTEADMITIDO"),
	// new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
	// resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
	// new ActSubvencionable(resultSet.getInt("ActSubvencionableIDACTSUB"),
	// resultSet.getString("DESCRIPCIONCASTELLANO"),
	// resultSet.getString("DESCRIPCIONEUSKERA"))));
	// }
	// };
	private RowMapper<Conceptos> rwMapConceptosPorExpediente = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Conceptos(resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDEXPEDIENTE")));
		}
	};

	private RowMapper<Conceptos> rwMapPK = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Conceptos(resultSet.getInt("IDCONCEPTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Conceptos>> rwMapJerarquia = new RowMapper<JerarquiaDto<Conceptos>>() {
		public JerarquiaDto<Conceptos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Conceptos conceptos = new Conceptos(resultSet.getInt("IDCONCEPTO"), resultSet.getInt("IDRELEXPACTSUB"),
					resultSet.getLong("IDTIPOGASTO"), resultSet.getString("CONCEPTO"),
					resultSet.getBigDecimal("IMPORTEPRESENTADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getBigDecimal("IMPORTEJUSPRESENTADO"), resultSet.getBigDecimal("IMPORTEJUSADMITIDO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getInt("INSPECCIONABLE"), resultSet.getString("OBSERVACIONESCASTELLANO"),
					resultSet.getString("OBSERVACIONESEUSKERA"));

			JerarquiaDto<Conceptos> jerarquia = new JerarquiaDto<Conceptos>();
			jerarquia.setModel(conceptos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Conceptos>> rwMapJerarquia2 = new RowMapper<JerarquiaDto<Conceptos>>() {
		public JerarquiaDto<Conceptos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Conceptos conceptos = new Conceptos(resultSet.getInt("IDCONCEPTO"), resultSet.getLong("IDTIPOGASTO"),
					resultSet.getString("CONCEPTO"), resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getBigDecimal("IMPORTEJUSPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEJUSADMITIDO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getInt("INSPECCIONABLE"),
					resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getString("OBSERVACIONESEUSKERA"),
					new RelExpActSub(resultSet.getInt("RelExpActSubIDRELEXPACTSUB"),
							resultSet.getInt("RelExpActSubIDEXPEDIENTE"),
							resultSet.getDate("RelExpActSubFECHAREGISTRO"),
							resultSet.getString("RelExpActSubUSUARIOREGISTRO"),
							new ActSubvencionable(resultSet.getInt("RelExpActSubIDACTSUB"), null, null, null, null,
									null, null, null, null, null, null),
							resultSet.getInt("RelExpActSubIDACTSUB")));

			JerarquiaDto<Conceptos> jerarquia = new JerarquiaDto<Conceptos>();
			jerarquia.setModel(conceptos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	public Conceptos add(Conceptos conceptos) {
		String query = "INSERT INTO CONCEPTOS (ID_CONCEPTO, ID_REL_EXP_ACT_SUB, ID_TIPO_GASTO, CONCEPTO, IMPORTE_PRESENTADO, IMPORTE_ADMITIDO, INSPECCIONABLE, OBSERVACIONES_CASTELLANO, OBSERVACIONES_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO, IMPORTE_SIN_IVA, IVA) VALUES (AB60.S_AB6019T00.NEXTVAL,?,?,?,?,?,?,?,?,?,?,?,?)";

		Object getRelExpActSubIdRelExpActSubAux = null;
		if (conceptos.getRelExpActSub() != null && conceptos.getRelExpActSub().getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = conceptos.getRelExpActSub().getIdRelExpActSub();
		}

		Object getConcepto = null;
		if (!conceptos.getConcepto().equals("")) {
			getConcepto = conceptos.getConcepto();
		}

		this.jdbcTemplate.update(query, getRelExpActSubIdRelExpActSubAux, conceptos.getIdTipoGasto(), getConcepto,
				conceptos.getImportePresentado(), conceptos.getImporteAdmitido(), conceptos.getInspeccionable(),
				conceptos.getObservacionesCastellano(), conceptos.getObservacionesEuskera(),
				conceptos.getFechaRegistro(), conceptos.getUsuarioRegistro(), conceptos.getImporteSinIva(),
				conceptos.getImporteIva());
		return conceptos;
	}

	/**
	 * Updates a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	public Conceptos update(Conceptos conceptos) {
		String query = "UPDATE CONCEPTOS SET ID_REL_EXP_ACT_SUB=?, ID_TIPO_GASTO=?, CONCEPTO=?, IMPORTE_PRESENTADO=?, IMPORTE_ADMITIDO=?, INSPECCIONABLE=?, OBSERVACIONES_CASTELLANO=?, OBSERVACIONES_EUSKERA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, IMPORTE_SIN_IVA=?, IVA=? WHERE ID_CONCEPTO=?";
		Object getRelExpActSubIdRelExpActSubAux = null;
		if (conceptos.getIdRelExpActSub() != null) {
			getRelExpActSubIdRelExpActSubAux = conceptos.getIdRelExpActSub();
		}

		if (conceptos.getIdTipoGasto() != null && 0 == conceptos.getIdTipoGasto()) {
			conceptos.setIdTipoGasto(null);
		}
		this.jdbcTemplate.update(query, getRelExpActSubIdRelExpActSubAux, conceptos.getIdTipoGasto(),
				conceptos.getConcepto(), conceptos.getImportePresentado(), conceptos.getImporteAdmitido(),
				conceptos.getInspeccionable(), conceptos.getObservacionesCastellano(),
				conceptos.getObservacionesEuskera(), conceptos.getFechaUltmodificacion(),
				conceptos.getUsuarioUltmodificacion(), conceptos.getImporteSinIva(), conceptos.getImporteIva(),
				conceptos.getIdConcepto());
		return conceptos;
	}

	/**
	 * Updates IMPORTE_ADMITIDO por Importe_Presentado
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	public Conceptos updateImporte(Conceptos conceptos) {
		String query = "UPDATE CONCEPTOS SET  IMPORTE_ADMITIDO =?, FECHA_ULTMODIFICACION  =?, USUARIO_ULTMODIFICACION=? WHERE ID_CONCEPTO =?";

		this.jdbcTemplate.update(query, conceptos.getImportePresentado(), conceptos.getFechaUltmodificacion(),
				conceptos.getUsuarioUltmodificacion(), conceptos.getIdConcepto());
		return conceptos;
	}

	/**
	 * 
	 * Update el importe Admitido de null a cero
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	public Conceptos updateImporteAdmitidoDeNullACero(Conceptos conceptos) {
		String query = "UPDATE CONCEPTOS SET  IMPORTE_ADMITIDO =?, FECHA_ULTMODIFICACION  =?, USUARIO_ULTMODIFICACION=? WHERE ID_CONCEPTO =?";

		this.jdbcTemplate.update(query, conceptos.getImporteAdmitido(), conceptos.getFechaUltmodificacion(),
				conceptos.getUsuarioUltmodificacion(), conceptos.getIdConcepto());
		return conceptos;
	}

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	@Transactional(readOnly = true)
	public Conceptos find(Conceptos conceptos) {
		String query = "SELECT t1.ID_CONCEPTO IDCONCEPTO, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ID_TIPO_GASTO IDTIPOGASTO, t1.CONCEPTO CONCEPTO, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO, t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.INSPECCIONABLE INSPECCIONABLE, t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t1.IMPORTE_SIN_IVA IMPORTESINIVA, t1.IVA IVA FROM CONCEPTOS t1  WHERE t1.ID_CONCEPTO = ?  ";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(query, this.rwMap, conceptos.getIdConcepto());
		return (Conceptos) DataAccessUtils.uniqueResult(conceptosList);
	}

	/**
	 * Finds a List of rows in the Conceptos table
	 *
	 * @param Integer
	 *            idRelacion
	 * @return conceptosList
	 */
	@Transactional(readOnly = true)
	public Conceptos findSumConceptosPorRelExpActSub(Integer idRelacion) {

		String query = "SELECT SUM(t2.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(t2.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB t1, CONCEPTOS t2 WHERE t1.ID_REL_EXP_ACT_SUB = t2.ID_REL_EXP_ACT_SUB AND t1.ID_REL_EXP_ACT_SUB   = ?";
		List<Conceptos> conceptosList = this.jdbcTemplate.query(query, this.rwMapSumConceptosPorRelExpActSub,
				idRelacion);

		return DataAccessUtils.uniqueResult(conceptosList);
	}

	/**
	 * Sumatorio de importe admitido de la tabla de conceptos, por relacion
	 * subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return conceptosList
	 */
	@Transactional(readOnly = true)
	public Conceptos findConceptosPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion) {

		String query = "SELECT SUM(t2.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(t2.IMPORTE_ADMITIDO) IMPORTEADMITIDO, SUM(t2.IMPORTE_SIN_IVA) IMPORTESINIVA, t1.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB  FROM REL_EXP_ACT_SUB t1, CONCEPTOS t2, ACT_SUBVENCIONABLE t3 WHERE t1.ID_REL_EXP_ACT_SUB = t2.ID_REL_EXP_ACT_SUB AND t1.ID_ACT_SUB = t3.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? AND  t1.ID_REL_EXP_ACT_SUB =? GROUP BY t1.ID_REL_EXP_ACT_SUB";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(query, this.rwMapConceptosPorExpedientePorRelacion,
				idExpediente, idRelacion);
		return DataAccessUtils.uniqueResult(conceptosList);

	}

	/**
	 * Finds a List of rows in the Conceptos table
	 *
	 * @param Integer
	 *            idExpediente
	 * @return conceptosList
	 */
	@Transactional(readOnly = true)
	public Conceptos findConceptosPorExpediente(Integer idExpediente) {

		String query = "SELECT SUM(t1.IMPORTE_PRESENTADO) IMPORTEPRESENTADO,  SUM(t1.IMPORTE_ADMITIDO) IMPORTEADMITIDO, t1.ID_EXPEDIENTE RELEXPACTSUBIDEXPEDIENTE FROM  REL_EXP_ACT_SUB t1 WHERE  t1.ID_EXPEDIENTE = ? GROUP BY  t1.ID_EXPEDIENTE";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(query, this.rwMapConceptosPorExpediente, idExpediente);

		return (Conceptos) DataAccessUtils.uniqueResult(conceptosList);
	}

	/**
	 * Finds a List of rows in the Conceptos table
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return conceptosList
	 */
	@Transactional(readOnly = true)
	public List<Conceptos> findConceptosPorRelExpActSub(Integer idRelExpActSub) {

		String query = "SELECT t1.ID_CONCEPTO IDCONCEPTO, t1.ID_TIPO_GASTO IDTIPOGASTO, t1.CONCEPTO CONCEPTO, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.IMPORTE_SIN_IVA IMPORTESINIVA, t1.IVA IVA, t2.ID_REL_EXP_ACT_SUB RELEXPACTSUBIDRELEXPACTSUB, t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM CONCEPTOS t1, REL_EXP_ACT_SUB t2, TIPOS_GASTO t3 WHERE t1.ID_REL_EXP_ACT_SUB = ? AND t1.ID_REL_EXP_ACT_SUB= t2.ID_REL_EXP_ACT_SUB AND t1.ID_TIPO_GASTO = t3.ID_TIPO_GASTO(+)";
		List<Conceptos> conceptosList = this.jdbcTemplate.query(query, this.rwMapConceptosPorRelExpActSub,
				idRelExpActSub);

		return conceptosList;
	}

	/**
	 * Removes a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return
	 */
	public void remove(Conceptos conceptos) {
		String query = "DELETE FROM CONCEPTOS WHERE ID_CONCEPTO=?";
		this.jdbcTemplate.update(query, conceptos.getIdConcepto());
	}

	/**
	 * removeByIdRelExpActSub
	 * 
	 * @param idRelExpActSub
	 */
	@Override
	public void removeByIdRelExpActSub(Integer idRelExpActSub) {
		String query = "DELETE FROM CONCEPTOS WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Conceptos>
	 */
	@Transactional(readOnly = true)
	public List<Conceptos> findAll(Conceptos conceptos, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONCEPTO IDCONCEPTO,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_TIPO_GASTO IDTIPOGASTO,t1.CONCEPTO CONCEPTO,t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO,t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.INSPECCIONABLE INSPECCIONABLE,t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO,t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		query.append("FROM CONCEPTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(conceptos);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ConceptosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Conceptos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Conceptos table using like.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Conceptos>
	 */
	@Transactional(readOnly = true)
	public List<Conceptos> findAllLike(Conceptos conceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CONCEPTO IDCONCEPTO,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_TIPO_GASTO IDTIPOGASTO,t1.CONCEPTO CONCEPTO,t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO,t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.INSPECCIONABLE INSPECCIONABLE,t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO,t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		query.append("FROM CONCEPTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(conceptos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ConceptosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Conceptos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Conceptos conceptos) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM CONCEPTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(conceptos);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Conceptos table using like.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Conceptos conceptos, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM CONCEPTOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(conceptos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public int findCountByRelExpActSub(Integer idRelacion) {
		String query = "SELECT COUNT(1) FROM CONCEPTOS t1 WHERE t1.ID_REL_EXP_ACT_SUB = ?";

		return this.jdbcTemplate.queryForInt(query, idRelacion);
	}

	/**
	 * Reorder the data list of Conceptos selected for rup_table
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Conceptos>>
	 */
	@Override
	public List<TableRowDto<Conceptos>> reorderSelection(Conceptos conceptos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONCEPTO IDCONCEPTO,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_TIPO_GASTO IDTIPOGASTO,t1.CONCEPTO CONCEPTO,t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO,t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.INSPECCIONABLE INSPECCIONABLE,t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO,t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		query.append("FROM CONCEPTOS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(conceptos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Conceptos.class,
				filterParamList, "ID_CONCEPTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Conceptos>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Conceptos
	 * @param searchParams
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Conceptos>>
	 */
	@Override
	public List<TableRowDto<Conceptos>> search(Conceptos filterParams, Conceptos searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONCEPTO IDCONCEPTO,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_TIPO_GASTO IDTIPOGASTO,t1.CONCEPTO CONCEPTO,t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO,t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.INSPECCIONABLE INSPECCIONABLE,t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO,t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		query.append("FROM CONCEPTOS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Conceptos.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_CONCEPTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Conceptos>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterconceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Conceptos filterconceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONCEPTO IDCONCEPTO,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_TIPO_GASTO IDTIPOGASTO,t1.CONCEPTO CONCEPTO,t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO,t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.INSPECCIONABLE INSPECCIONABLE,t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO,t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		query.append("FROM CONCEPTOS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterconceptos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Conceptos.class,
				query, params, "ID_CONCEPTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Conceptos>>
	 */
	@Override
	public List<JerarquiaDto<Conceptos>> findAllLikeJerarquia(Conceptos filterConceptos,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CONCEPTO IDCONCEPTO,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_TIPO_GASTO IDTIPOGASTO,t1.CONCEPTO CONCEPTO,t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,t1.IMPORTE_ADMITIDO IMPORTEADMITIDO,t1.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO,t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.INSPECCIONABLE INSPECCIONABLE,t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO,t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM CONCEPTOS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CONCEPTOS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterConceptos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CONCEPTO", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ConceptosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM CONCEPTOS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CONCEPTOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterConceptos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CONCEPTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Conceptos>>
	 */
	@Override
	public List<TableRowDto<Conceptos>> findAllChild(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM CONCEPTOS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CONCEPTOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterConceptos, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CONCEPTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Conceptos>(this.rwMapPK, "ID_CONCEPTO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Conceptos entity
	 *
	 * @param conceptos
	 *            Conceptos Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Conceptos conceptos) {

		StringBuilder where = new StringBuilder(ConceptosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (conceptos != null && conceptos.getIdConcepto() != null) {
			where.append(" AND t1.ID_CONCEPTO = ?");
			params.add(conceptos.getIdConcepto());
		}
		if (conceptos != null && conceptos.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(conceptos.getIdRelExpActSub());
		}
		if (conceptos != null && conceptos.getIdTipoGasto() != null) {
			where.append(" AND t1.ID_TIPO_GASTO = ?");
			params.add(conceptos.getIdTipoGasto());
		}
		if (conceptos != null && conceptos.getConcepto() != null) {
			where.append(" AND t1.CONCEPTO = ?");
			params.add(conceptos.getConcepto());
		}
		if (conceptos != null && conceptos.getImportePresentado() != null) {
			where.append(" AND t1.IMPORTE_PRESENTADO = ?");
			params.add(conceptos.getImportePresentado());
		}
		if (conceptos != null && conceptos.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(conceptos.getImporteAdmitido());
		}
		if (conceptos != null && conceptos.getImporteJusPresentado() != null) {
			where.append(" AND t1.IMPORTE_JUS_PRESENTADO = ?");
			params.add(conceptos.getImporteJusPresentado());
		}
		if (conceptos != null && conceptos.getImporteJusAdmitido() != null) {
			where.append(" AND t1.IMPORTE_JUS_ADMITIDO = ?");
			params.add(conceptos.getImporteJusAdmitido());
		}
		if (conceptos != null && conceptos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(conceptos.getFechaRegistro());
		}
		if (conceptos != null && conceptos.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(conceptos.getUsuarioRegistro());
		}
		if (conceptos != null && conceptos.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(conceptos.getFechaUltmodificacion());
		}
		if (conceptos != null && conceptos.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(conceptos.getUsuarioUltmodificacion());
		}
		if (conceptos != null && conceptos.getInspeccionable() != null) {
			where.append(" AND t1.INSPECCIONABLE = ?");
			params.add(conceptos.getInspeccionable());
		}
		if (conceptos != null && conceptos.getObservacionesCastellano() != null) {
			where.append(" AND t1.OBSERVACIONES_CASTELLANO = ?");
			params.add(conceptos.getObservacionesCastellano());
		}
		if (conceptos != null && conceptos.getObservacionesEuskera() != null) {
			where.append(" AND t1.OBSERVACIONES_EUSKERA = ?");
			params.add(conceptos.getObservacionesEuskera());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Conceptos entity
	 *
	 * @param conceptos
	 *            Conceptos Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Conceptos conceptos, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ConceptosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (conceptos != null && conceptos.getIdConcepto() != null) {
			where.append(" AND t1.ID_CONCEPTO = ?");
			params.add(conceptos.getIdConcepto());
		}
		if (conceptos != null && conceptos.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(conceptos.getIdRelExpActSub());
		}
		if (conceptos != null && conceptos.getIdTipoGasto() != null) {
			where.append(" AND t1.ID_TIPO_GASTO = ?");
			params.add(conceptos.getIdTipoGasto());
		}
		if (conceptos != null && conceptos.getConcepto() != null) {
			where.append(" AND UPPER(t1.CONCEPTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(conceptos.getConcepto().toUpperCase() + "%");
			} else {
				params.add("%" + conceptos.getConcepto().toUpperCase() + "%");
			}
			where.append(" AND t1.CONCEPTO IS NOT NULL");
		}
		if (conceptos != null && conceptos.getImportePresentado() != null) {
			where.append(" AND t1.IMPORTE_PRESENTADO = ?");
			params.add(conceptos.getImportePresentado());
		}
		if (conceptos != null && conceptos.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(conceptos.getImporteAdmitido());
		}
		if (conceptos != null && conceptos.getImporteJusPresentado() != null) {
			where.append(" AND t1.IMPORTE_JUS_PRESENTADO = ?");
			params.add(conceptos.getImporteJusPresentado());
		}
		if (conceptos != null && conceptos.getImporteJusAdmitido() != null) {
			where.append(" AND t1.IMPORTE_JUS_ADMITIDO = ?");
			params.add(conceptos.getImporteJusAdmitido());
		}
		if (conceptos != null && conceptos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(conceptos.getFechaRegistro());
		}
		if (conceptos != null && conceptos.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(conceptos.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + conceptos.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (conceptos != null && conceptos.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(conceptos.getFechaUltmodificacion());
		}
		if (conceptos != null && conceptos.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(conceptos.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + conceptos.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (conceptos != null && conceptos.getInspeccionable() != null) {
			where.append(" AND t1.INSPECCIONABLE = ?");
			params.add(conceptos.getInspeccionable());
		}
		if (conceptos != null && conceptos.getObservacionesCastellano() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(conceptos.getObservacionesCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + conceptos.getObservacionesCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES_CASTELLANO IS NOT NULL");
		}
		if (conceptos != null && conceptos.getObservacionesEuskera() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(conceptos.getObservacionesEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + conceptos.getObservacionesEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES_EUSKERA IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
