package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.DatosTerOmic;

/**
 * DatosTerOmicDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class DatosTerOmicDaoImpl implements DatosTerOmicDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDDATOSOMIC", "IDEXPEDIENTE", "TIPOENTIDAD",
			"IDPOBLACION", "IDHORARIO", "MANCOMUNADA", "NUEVACREACION", "NUMERORECLAMACIONES", "NUMEROCONSULTAS",
			"INSPECCIONCONSUMO", "INFFOREDU", "SISTEMAARBITRAL", "NUMEROINSPECCIONES", "NUMEROINSPECTORES",
			"NUMEROSECTORES", "COSTESERVICIO", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<DatosTerOmic> rwMap = new RowMapper<DatosTerOmic>() {
		public DatosTerOmic mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DatosTerOmic(resultSet.getInt("IDDATOSOMIC"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getInt("TIPOENTIDAD"), resultSet.getInt("IDPOBLACION"), resultSet.getLong("IDHORARIO"),
					resultSet.getInt("MANCOMUNADA"), resultSet.getInt("NUEVACREACION"),
					resultSet.getLong("NUMERORECLAMACIONES"), resultSet.getLong("NUMEROCONSULTAS"),
					resultSet.getInt("INSPECCIONCONSUMO"), resultSet.getInt("INFFOREDU"),
					resultSet.getInt("SISTEMAARBITRAL"), resultSet.getLong("NUMEROINSPECCIONES"),
					resultSet.getLong("NUMEROINSPECTORES"), resultSet.getLong("NUMEROSECTORES"),
					resultSet.getBigDecimal("COSTESERVICIO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<DatosTerOmic> rwMapPK = new RowMapper<DatosTerOmic>() {
		public DatosTerOmic mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DatosTerOmic(resultSet.getInt("IDDATOSOMIC"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<DatosTerOmic>> rwMapJerarquia = new RowMapper<JerarquiaDto<DatosTerOmic>>() {
		public JerarquiaDto<DatosTerOmic> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			DatosTerOmic datosteromic = new DatosTerOmic(resultSet.getInt("IDDATOSOMIC"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getInt("TIPOENTIDAD"), resultSet.getInt("IDPOBLACION"),
					resultSet.getLong("IDHORARIO"), resultSet.getInt("MANCOMUNADA"), resultSet.getInt("NUEVACREACION"),
					resultSet.getLong("NUMERORECLAMACIONES"), resultSet.getLong("NUMEROCONSULTAS"),
					resultSet.getInt("INSPECCIONCONSUMO"), resultSet.getInt("INFFOREDU"),
					resultSet.getInt("SISTEMAARBITRAL"), resultSet.getLong("NUMEROINSPECCIONES"),
					resultSet.getLong("NUMEROINSPECTORES"), resultSet.getLong("NUMEROSECTORES"),
					resultSet.getBigDecimal("COSTESERVICIO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<DatosTerOmic> jerarquia = new JerarquiaDto<DatosTerOmic>();
			jerarquia.setModel(datosteromic);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @return DatosTerOmic
	 */
	public DatosTerOmic add(DatosTerOmic datosteromic) {
		datosteromic.setIdDatosOmic(
				this.jdbcTemplate.queryForObject("SELECT AB60.S_AB6085T00.NEXTVAL FROM DUAL", Integer.class));
		String query = "INSERT INTO DATOS_OMIC (ID_DATOS_OMIC, ID_EXPEDIENTE, TIPO_ENTIDAD, ID_POBLACION, ID_HORARIO, MANCOMUNADA, NUEVA_CREACION, NUMERO_RECLAMACIONES, NUMERO_CONSULTAS, INSPECCION_CONSUMO, INF_FOR_EDU, SISTEMA_ARBITRAL, NUMERO_INSPECCIONES, NUMERO_INSPECTORES, NUMERO_SECTORES, COSTE_SERVICIO, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, datosteromic.getIdDatosOmic(), datosteromic.getIdExpediente(),
				datosteromic.getTipoEntidad(), datosteromic.getIdPoblacion(), datosteromic.getIdHorario(),
				datosteromic.getMancomunada(), datosteromic.getNuevaCreacion(), datosteromic.getNumeroReclamaciones(),
				datosteromic.getNumeroConsultas(), datosteromic.getInspeccionConsumo(), datosteromic.getInfForEdu(),
				datosteromic.getSistemaArbitral(), datosteromic.getNumeroInspecciones(),
				datosteromic.getNumeroInspectores(), datosteromic.getNumeroSectores(), datosteromic.getCosteServicio(),
				datosteromic.getFechaRegistro(), datosteromic.getUsuarioRegistro(),
				datosteromic.getFechaUltmodificacion(), datosteromic.getUsuarioUltmodificacion());
		return datosteromic;
	}

	/**
	 * Updates a single row in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @return DatosTerOmic
	 */
	public DatosTerOmic update(DatosTerOmic datosteromic) {
		String query = "UPDATE DATOS_OMIC SET ID_EXPEDIENTE=?, TIPO_ENTIDAD=?, ID_POBLACION=?, ID_HORARIO=?, MANCOMUNADA=?, NUEVA_CREACION=?, NUMERO_RECLAMACIONES=?, NUMERO_CONSULTAS=?, INSPECCION_CONSUMO=?, INF_FOR_EDU=?, SISTEMA_ARBITRAL=?, NUMERO_INSPECCIONES=?, NUMERO_INSPECTORES=?, NUMERO_SECTORES=?, COSTE_SERVICIO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_DATOS_OMIC=?";
		this.jdbcTemplate.update(query, datosteromic.getIdExpediente(), datosteromic.getTipoEntidad(),
				datosteromic.getIdPoblacion(), datosteromic.getIdHorario(), datosteromic.getMancomunada(),
				datosteromic.getNuevaCreacion(), datosteromic.getNumeroReclamaciones(),
				datosteromic.getNumeroConsultas(), datosteromic.getInspeccionConsumo(), datosteromic.getInfForEdu(),
				datosteromic.getSistemaArbitral(), datosteromic.getNumeroInspecciones(),
				datosteromic.getNumeroInspectores(), datosteromic.getNumeroSectores(), datosteromic.getCosteServicio(),
				datosteromic.getFechaRegistro(), datosteromic.getUsuarioRegistro(),
				datosteromic.getFechaUltmodificacion(), datosteromic.getUsuarioUltmodificacion(),
				datosteromic.getIdDatosOmic());
		return datosteromic;
	}

	/**
	 * Updates a single row in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @return DatosTerOmic
	 */
	public DatosTerOmic updateByExpediente(DatosTerOmic datosteromic) {
		String query = "UPDATE DATOS_OMIC SET ID_POBLACION=?, ID_HORARIO=?, NUMERO_RECLAMACIONES=?, NUMERO_CONSULTAS=?, NUMERO_INSPECCIONES=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, datosteromic.getIdPoblacion(), datosteromic.getIdHorario(),
				datosteromic.getNumeroReclamaciones(), datosteromic.getNumeroConsultas(),
				datosteromic.getNumeroInspecciones(), datosteromic.getFechaUltmodificacion(),
				datosteromic.getUsuarioUltmodificacion(), datosteromic.getIdExpediente());
		return datosteromic;
	}

	/**
	 * Finds a single row in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @return DatosTerOmic
	 */
	@Transactional(readOnly = true)
	public DatosTerOmic find(DatosTerOmic datosteromic) {
		String query = "SELECT t1.ID_DATOS_OMIC IDDATOSOMIC, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.TIPO_ENTIDAD TIPOENTIDAD, t1.ID_POBLACION IDPOBLACION, t1.ID_HORARIO IDHORARIO, t1.MANCOMUNADA MANCOMUNADA, t1.NUEVA_CREACION NUEVACREACION, t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES, t1.NUMERO_CONSULTAS NUMEROCONSULTAS, t1.INSPECCION_CONSUMO INSPECCIONCONSUMO, t1.INF_FOR_EDU INFFOREDU, t1.SISTEMA_ARBITRAL SISTEMAARBITRAL, t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES, t1.NUMERO_INSPECTORES NUMEROINSPECTORES, t1.NUMERO_SECTORES NUMEROSECTORES, t1.COSTE_SERVICIO COSTESERVICIO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM DATOS_OMIC t1  WHERE t1.ID_DATOS_OMIC = ?  ";

		List<DatosTerOmic> datosteromicList = this.jdbcTemplate.query(query, this.rwMap, datosteromic.getIdDatosOmic());
		return (DatosTerOmic) DataAccessUtils.uniqueResult(datosteromicList);
	}

	/**
	 * Finds a single row in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @return DatosTerOmic
	 */
	@Transactional(readOnly = true)
	public DatosTerOmic findByExpediente(DatosTerOmic datosteromic) {
		String query = "SELECT t1.ID_DATOS_OMIC IDDATOSOMIC, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.TIPO_ENTIDAD TIPOENTIDAD, t1.ID_POBLACION IDPOBLACION, t1.ID_HORARIO IDHORARIO, t1.MANCOMUNADA MANCOMUNADA, t1.NUEVA_CREACION NUEVACREACION, t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES, t1.NUMERO_CONSULTAS NUMEROCONSULTAS, t1.INSPECCION_CONSUMO INSPECCIONCONSUMO, t1.INF_FOR_EDU INFFOREDU, t1.SISTEMA_ARBITRAL SISTEMAARBITRAL, t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES, t1.NUMERO_INSPECTORES NUMEROINSPECTORES, t1.NUMERO_SECTORES NUMEROSECTORES, t1.COSTE_SERVICIO COSTESERVICIO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM DATOS_OMIC t1  WHERE t1.ID_EXPEDIENTE = ?  ";

		List<DatosTerOmic> datosteromicList = this.jdbcTemplate.query(query, this.rwMap,
				datosteromic.getIdExpediente());
		return (DatosTerOmic) DataAccessUtils.uniqueResult(datosteromicList);
	}

	/**
	 * Removes a single row in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @return
	 */
	public void remove(DatosTerOmic datosteromic) {
		String query = "DELETE FROM DATOS_OMIC WHERE ID_DATOS_OMIC=?";
		this.jdbcTemplate.update(query, datosteromic.getIdDatosOmic());
	}

	/**
	 * Finds a list of rows in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<DatosTerOmic>
	 */
	@Transactional(readOnly = true)
	public List<DatosTerOmic> findAll(DatosTerOmic datosteromic, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DATOS_OMIC IDDATOSOMIC,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_ENTIDAD TIPOENTIDAD,t1.ID_POBLACION IDPOBLACION,t1.ID_HORARIO IDHORARIO,t1.MANCOMUNADA MANCOMUNADA,t1.NUEVA_CREACION NUEVACREACION,t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES,t1.NUMERO_CONSULTAS NUMEROCONSULTAS,t1.INSPECCION_CONSUMO INSPECCIONCONSUMO,t1.INF_FOR_EDU INFFOREDU,t1.SISTEMA_ARBITRAL SISTEMAARBITRAL,t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES,t1.NUMERO_INSPECTORES NUMEROINSPECTORES,t1.NUMERO_SECTORES NUMEROSECTORES,t1.COSTE_SERVICIO COSTESERVICIO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM DATOS_OMIC t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(datosteromic);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, DatosTerOmicDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<DatosTerOmic>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the DatosTerOmic table using like.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<DatosTerOmic>
	 */
	@Transactional(readOnly = true)
	public List<DatosTerOmic> findAllLike(DatosTerOmic datosteromic, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DATOS_OMIC IDDATOSOMIC,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_ENTIDAD TIPOENTIDAD,t1.ID_POBLACION IDPOBLACION,t1.ID_HORARIO IDHORARIO,t1.MANCOMUNADA MANCOMUNADA,t1.NUEVA_CREACION NUEVACREACION,t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES,t1.NUMERO_CONSULTAS NUMEROCONSULTAS,t1.INSPECCION_CONSUMO INSPECCIONCONSUMO,t1.INF_FOR_EDU INFFOREDU,t1.SISTEMA_ARBITRAL SISTEMAARBITRAL,t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES,t1.NUMERO_INSPECTORES NUMEROINSPECTORES,t1.NUMERO_SECTORES NUMEROSECTORES,t1.COSTE_SERVICIO COSTESERVICIO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM DATOS_OMIC t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datosteromic, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, DatosTerOmicDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<DatosTerOmic>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the DatosTerOmic table.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(DatosTerOmic datosteromic) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DATOS_OMIC t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(datosteromic);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the DatosTerOmic table using like.
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(DatosTerOmic datosteromic, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DATOS_OMIC t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datosteromic, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of DatosTerOmic selected for rup_table
	 *
	 * @param datosteromic
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosTerOmic>>
	 */
	@Override
	public List<TableRowDto<DatosTerOmic>> reorderSelection(DatosTerOmic datosteromic,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATOS_OMIC IDDATOSOMIC,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_ENTIDAD TIPOENTIDAD,t1.ID_POBLACION IDPOBLACION,t1.ID_HORARIO IDHORARIO,t1.MANCOMUNADA MANCOMUNADA,t1.NUEVA_CREACION NUEVACREACION,t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES,t1.NUMERO_CONSULTAS NUMEROCONSULTAS,t1.INSPECCION_CONSUMO INSPECCIONCONSUMO,t1.INF_FOR_EDU INFFOREDU,t1.SISTEMA_ARBITRAL SISTEMAARBITRAL,t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES,t1.NUMERO_INSPECTORES NUMEROINSPECTORES,t1.NUMERO_SECTORES NUMEROSECTORES,t1.COSTE_SERVICIO COSTESERVICIO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM DATOS_OMIC t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datosteromic, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, DatosTerOmic.class,
				filterParamList, "ID_DATOS_OMIC");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DatosTerOmic>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            DatosTerOmic
	 * @param searchParams
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosTerOmic>>
	 */
	@Override
	public List<TableRowDto<DatosTerOmic>> search(DatosTerOmic filterParams, DatosTerOmic searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATOS_OMIC IDDATOSOMIC,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_ENTIDAD TIPOENTIDAD,t1.ID_POBLACION IDPOBLACION,t1.ID_HORARIO IDHORARIO,t1.MANCOMUNADA MANCOMUNADA,t1.NUEVA_CREACION NUEVACREACION,t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES,t1.NUMERO_CONSULTAS NUMEROCONSULTAS,t1.INSPECCION_CONSUMO INSPECCIONCONSUMO,t1.INF_FOR_EDU INFFOREDU,t1.SISTEMA_ARBITRAL SISTEMAARBITRAL,t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES,t1.NUMERO_INSPECTORES NUMEROINSPECTORES,t1.NUMERO_SECTORES NUMEROSECTORES,t1.COSTE_SERVICIO COSTESERVICIO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM DATOS_OMIC t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, DatosTerOmic.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_DATOS_OMIC");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DatosTerOmic>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterdatosteromic
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(DatosTerOmic filterdatosteromic, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATOS_OMIC IDDATOSOMIC,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_ENTIDAD TIPOENTIDAD,t1.ID_POBLACION IDPOBLACION,t1.ID_HORARIO IDHORARIO,t1.MANCOMUNADA MANCOMUNADA,t1.NUEVA_CREACION NUEVACREACION,t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES,t1.NUMERO_CONSULTAS NUMEROCONSULTAS,t1.INSPECCION_CONSUMO INSPECCIONCONSUMO,t1.INF_FOR_EDU INFFOREDU,t1.SISTEMA_ARBITRAL SISTEMAARBITRAL,t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES,t1.NUMERO_INSPECTORES NUMEROINSPECTORES,t1.NUMERO_SECTORES NUMEROSECTORES,t1.COSTE_SERVICIO COSTESERVICIO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM DATOS_OMIC t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterdatosteromic, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, DatosTerOmic.class,
				query, params, "ID_DATOS_OMIC");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical DatosTerOmic table.
	 *
	 * @param filterDatosTerOmic
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<DatosTerOmic>>
	 */
	@Override
	public List<JerarquiaDto<DatosTerOmic>> findAllLikeJerarquia(DatosTerOmic filterDatosTerOmic,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DATOS_OMIC IDDATOSOMIC,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_ENTIDAD TIPOENTIDAD,t1.ID_POBLACION IDPOBLACION,t1.ID_HORARIO IDHORARIO,t1.MANCOMUNADA MANCOMUNADA,t1.NUEVA_CREACION NUEVACREACION,t1.NUMERO_RECLAMACIONES NUMERORECLAMACIONES,t1.NUMERO_CONSULTAS NUMEROCONSULTAS,t1.INSPECCION_CONSUMO INSPECCIONCONSUMO,t1.INF_FOR_EDU INFFOREDU,t1.SISTEMA_ARBITRAL SISTEMAARBITRAL,t1.NUMERO_INSPECCIONES NUMEROINSPECCIONES,t1.NUMERO_INSPECTORES NUMEROINSPECTORES,t1.NUMERO_SECTORES NUMEROSECTORES,t1.COSTE_SERVICIO COSTESERVICIO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_OMIC t1 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_OMIC");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDatosTerOmic, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_DATOS_OMIC", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					DatosTerOmicDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterDatosTerOmic
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(DatosTerOmic filterDatosTerOmic, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_OMIC t1 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_OMIC");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDatosTerOmic, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_DATOS_OMIC",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterDatosTerOmic
	 *            DatosTerOmic
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<DatosTerOmic>>
	 */
	@Override
	public List<TableRowDto<DatosTerOmic>> findAllChild(DatosTerOmic filterDatosTerOmic,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_OMIC t1 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_OMIC");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDatosTerOmic, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_DATOS_OMIC",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<DatosTerOmic>(this.rwMapPK, "ID_DATOS_OMIC"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DatosTerOmic entity
	 *
	 * @param datosteromic
	 *            DatosTerOmic Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(DatosTerOmic datosteromic) {

		StringBuilder where = new StringBuilder(DatosTerOmicDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (datosteromic != null && datosteromic.getIdDatosOmic() != null) {
			where.append(" AND t1.ID_DATOS_OMIC = ?");
			params.add(datosteromic.getIdDatosOmic());
		}
		if (datosteromic != null && datosteromic.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(datosteromic.getIdExpediente());
		}
		if (datosteromic != null && datosteromic.getTipoEntidad() != null) {
			where.append(" AND t1.TIPO_ENTIDAD = ?");
			params.add(datosteromic.getTipoEntidad());
		}
		if (datosteromic != null && datosteromic.getIdPoblacion() != null) {
			where.append(" AND t1.ID_POBLACION = ?");
			params.add(datosteromic.getIdPoblacion());
		}
		if (datosteromic != null && datosteromic.getIdHorario() != null) {
			where.append(" AND t1.ID_HORARIO = ?");
			params.add(datosteromic.getIdHorario());
		}
		if (datosteromic != null && datosteromic.getMancomunada() != null) {
			where.append(" AND t1.MANCOMUNADA = ?");
			params.add(datosteromic.getMancomunada());
		}
		if (datosteromic != null && datosteromic.getNuevaCreacion() != null) {
			where.append(" AND t1.NUEVA_CREACION = ?");
			params.add(datosteromic.getNuevaCreacion());
		}
		if (datosteromic != null && datosteromic.getNumeroReclamaciones() != null) {
			where.append(" AND t1.NUMERO_RECLAMACIONES = ?");
			params.add(datosteromic.getNumeroReclamaciones());
		}
		if (datosteromic != null && datosteromic.getNumeroConsultas() != null) {
			where.append(" AND t1.NUMERO_CONSULTAS = ?");
			params.add(datosteromic.getNumeroConsultas());
		}
		if (datosteromic != null && datosteromic.getInspeccionConsumo() != null) {
			where.append(" AND t1.INSPECCION_CONSUMO = ?");
			params.add(datosteromic.getInspeccionConsumo());
		}
		if (datosteromic != null && datosteromic.getInfForEdu() != null) {
			where.append(" AND t1.INF_FOR_EDU = ?");
			params.add(datosteromic.getInfForEdu());
		}
		if (datosteromic != null && datosteromic.getSistemaArbitral() != null) {
			where.append(" AND t1.SISTEMA_ARBITRAL = ?");
			params.add(datosteromic.getSistemaArbitral());
		}
		if (datosteromic != null && datosteromic.getNumeroInspecciones() != null) {
			where.append(" AND t1.NUMERO_INSPECCIONES = ?");
			params.add(datosteromic.getNumeroInspecciones());
		}
		if (datosteromic != null && datosteromic.getNumeroInspectores() != null) {
			where.append(" AND t1.NUMERO_INSPECTORES = ?");
			params.add(datosteromic.getNumeroInspectores());
		}
		if (datosteromic != null && datosteromic.getNumeroSectores() != null) {
			where.append(" AND t1.NUMERO_SECTORES = ?");
			params.add(datosteromic.getNumeroSectores());
		}
		if (datosteromic != null && datosteromic.getCosteServicio() != null) {
			where.append(" AND t1.COSTE_SERVICIO = ?");
			params.add(datosteromic.getCosteServicio());
		}
		if (datosteromic != null && datosteromic.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(datosteromic.getFechaRegistro());
		}
		if (datosteromic != null && datosteromic.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(datosteromic.getUsuarioRegistro());
		}
		if (datosteromic != null && datosteromic.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(datosteromic.getFechaUltmodificacion());
		}
		if (datosteromic != null && datosteromic.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(datosteromic.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DatosTerOmic entity
	 *
	 * @param datosteromic
	 *            DatosTerOmic Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(DatosTerOmic datosteromic, Boolean startsWith) {

		StringBuilder where = new StringBuilder(DatosTerOmicDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (datosteromic != null && datosteromic.getIdDatosOmic() != null) {
			where.append(" AND t1.ID_DATOS_OMIC = ?");
			params.add(datosteromic.getIdDatosOmic());
		}
		if (datosteromic != null && datosteromic.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(datosteromic.getIdExpediente());
		}
		if (datosteromic != null && datosteromic.getTipoEntidad() != null) {
			where.append(" AND t1.TIPO_ENTIDAD = ?");
			params.add(datosteromic.getTipoEntidad());
		}
		if (datosteromic != null && datosteromic.getIdPoblacion() != null) {
			where.append(" AND t1.ID_POBLACION = ?");
			params.add(datosteromic.getIdPoblacion());
		}
		if (datosteromic != null && datosteromic.getIdHorario() != null) {
			where.append(" AND t1.ID_HORARIO = ?");
			params.add(datosteromic.getIdHorario());
		}
		if (datosteromic != null && datosteromic.getMancomunada() != null) {
			where.append(" AND t1.MANCOMUNADA = ?");
			params.add(datosteromic.getMancomunada());
		}
		if (datosteromic != null && datosteromic.getNuevaCreacion() != null) {
			where.append(" AND t1.NUEVA_CREACION = ?");
			params.add(datosteromic.getNuevaCreacion());
		}
		if (datosteromic != null && datosteromic.getNumeroReclamaciones() != null) {
			where.append(" AND t1.NUMERO_RECLAMACIONES = ?");
			params.add(datosteromic.getNumeroReclamaciones());
		}
		if (datosteromic != null && datosteromic.getNumeroConsultas() != null) {
			where.append(" AND t1.NUMERO_CONSULTAS = ?");
			params.add(datosteromic.getNumeroConsultas());
		}
		if (datosteromic != null && datosteromic.getInspeccionConsumo() != null) {
			where.append(" AND t1.INSPECCION_CONSUMO = ?");
			params.add(datosteromic.getInspeccionConsumo());
		}
		if (datosteromic != null && datosteromic.getInfForEdu() != null) {
			where.append(" AND t1.INF_FOR_EDU = ?");
			params.add(datosteromic.getInfForEdu());
		}
		if (datosteromic != null && datosteromic.getSistemaArbitral() != null) {
			where.append(" AND t1.SISTEMA_ARBITRAL = ?");
			params.add(datosteromic.getSistemaArbitral());
		}
		if (datosteromic != null && datosteromic.getNumeroInspecciones() != null) {
			where.append(" AND t1.NUMERO_INSPECCIONES = ?");
			params.add(datosteromic.getNumeroInspecciones());
		}
		if (datosteromic != null && datosteromic.getNumeroInspectores() != null) {
			where.append(" AND t1.NUMERO_INSPECTORES = ?");
			params.add(datosteromic.getNumeroInspectores());
		}
		if (datosteromic != null && datosteromic.getNumeroSectores() != null) {
			where.append(" AND t1.NUMERO_SECTORES = ?");
			params.add(datosteromic.getNumeroSectores());
		}
		if (datosteromic != null && datosteromic.getCosteServicio() != null) {
			where.append(" AND t1.COSTE_SERVICIO = ?");
			params.add(datosteromic.getCosteServicio());
		}
		if (datosteromic != null && datosteromic.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(datosteromic.getFechaRegistro());
		}
		if (datosteromic != null && datosteromic.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosteromic.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + datosteromic.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (datosteromic != null && datosteromic.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(datosteromic.getFechaUltmodificacion());
		}
		if (datosteromic != null && datosteromic.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosteromic.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + datosteromic.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
