package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.estudioTecnico.ErroresCalculo;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * ErroresCalculoDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ErroresCalculoDaoImpl implements ErroresCalculoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCODIGOERROR", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO", "TIPOERROR", "IDACTSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ErroresCalculo> rwMap = new RowMapper<ErroresCalculo>() {
		public ErroresCalculo mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ErroresCalculo erroresCalculo = new ErroresCalculo();
			erroresCalculo.setIdCodigoerror(resultSet.getInt("IDCODIGOERROR"));
			erroresCalculo.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			erroresCalculo.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			erroresCalculo.setFechaRegistro(resultSet.getDate("FECHAREGISTRO"));
			erroresCalculo.setUsuarioRegistro(resultSet.getString("USUARIOREGISTRO"));
			erroresCalculo.setTipoError(resultSet.getInt("TIPOERROR"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			erroresCalculo.setActSubvencionable(actSubvencionable);

			return erroresCalculo;
		}
	};

	private RowMapper<ErroresCalculo> rwMapPK = new RowMapper<ErroresCalculo>() {
		public ErroresCalculo mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ErroresCalculo(resultSet.getInt("IDCODIGOERROR"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ErroresCalculo>> rwMapJerarquia = new RowMapper<JerarquiaDto<ErroresCalculo>>() {
		public JerarquiaDto<ErroresCalculo> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ErroresCalculo erroresCalculo = new ErroresCalculo();
			erroresCalculo.setIdCodigoerror(resultSet.getInt("IDCODIGOERROR"));
			erroresCalculo.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			erroresCalculo.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			erroresCalculo.setFechaRegistro(resultSet.getDate("FECHAREGISTRO"));
			erroresCalculo.setUsuarioRegistro(resultSet.getString("USUARIOREGISTRO"));
			erroresCalculo.setTipoError(resultSet.getInt("TIPOERROR"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			erroresCalculo.setActSubvencionable(actSubvencionable);

			JerarquiaDto<ErroresCalculo> jerarquia = new JerarquiaDto<ErroresCalculo>();
			jerarquia.setModel(erroresCalculo);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the ErroresCalculo table.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @return ErroresCalculo
	 */
	public ErroresCalculo add(ErroresCalculo errorescalculo) {
		String query = "INSERT INTO ERRORES_CALCULO (ID_CODIGOERROR, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO, TIPO_ERROR, ID_ACT_SUB) VALUES (?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, errorescalculo.getIdCodigoerror(), errorescalculo.getDescripcionCastellano(),
				errorescalculo.getDescripcionEuskera(), errorescalculo.getFechaRegistro(),
				errorescalculo.getUsuarioRegistro(), errorescalculo.getTipoError(),
				errorescalculo.getActSubvencionable().getIdActSub());
		return errorescalculo;
	}

	/**
	 * Updates a single row in the ErroresCalculo table.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @return ErroresCalculo
	 */
	public ErroresCalculo update(ErroresCalculo errorescalculo) {
		String query = "UPDATE ERRORES_CALCULO SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, TIPO_ERROR=?, ID_ACT_SUB WHERE ID_CODIGOERROR=?";
		this.jdbcTemplate.update(query, errorescalculo.getDescripcionCastellano(),
				errorescalculo.getDescripcionEuskera(), errorescalculo.getFechaRegistro(),
				errorescalculo.getUsuarioRegistro(), errorescalculo.getTipoError(), errorescalculo.getIdCodigoerror(),
				errorescalculo.getActSubvencionable().getIdActSub());
		return errorescalculo;
	}

	/**
	 * Finds a single row in the ErroresCalculo table.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @return ErroresCalculo
	 */
	@Transactional(readOnly = true)
	public ErroresCalculo find(ErroresCalculo errorescalculo) {
		String query = "SELECT t1.ID_CODIGOERROR IDCODIGOERROR, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.TIPO_ERROR TIPOERROR, t1.ID_ACT_SUB IDACTSUB FROM ERRORES_CALCULO t1  WHERE t1.ID_CODIGOERROR = ?";

		List<ErroresCalculo> errorescalculoList = this.jdbcTemplate.query(query, this.rwMap,
				errorescalculo.getIdCodigoerror());
		return (ErroresCalculo) DataAccessUtils.uniqueResult(errorescalculoList);
	}

	/**
	 * Removes a single row in the ErroresCalculo table.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @return
	 */
	public void remove(ErroresCalculo errorescalculo) {
		String query = "DELETE FROM ERRORES_CALCULO WHERE ID_CODIGOERROR=?";
		this.jdbcTemplate.update(query, errorescalculo.getIdCodigoerror());
	}

	/**
	 * Finds a list of rows in the ErroresCalculo table.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ErroresCalculo>
	 */
	@Transactional(readOnly = true)
	public List<ErroresCalculo> findAll(ErroresCalculo errorescalculo, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CODIGOERROR IDCODIGOERROR,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.TIPO_ERROR TIPOERROR, t1.ID_ACT_SUB IDACTSUB ");
		query.append("FROM ERRORES_CALCULO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(errorescalculo);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ErroresCalculoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ErroresCalculo>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the ErroresCalculo table using like.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ErroresCalculo>
	 */
	@Transactional(readOnly = true)
	public List<ErroresCalculo> findAllLike(ErroresCalculo errorescalculo, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CODIGOERROR IDCODIGOERROR,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.TIPO_ERROR TIPOERROR,t1.ID_ACT_SUB IDACTSUB ");
		query.append("FROM ERRORES_CALCULO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(errorescalculo, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ErroresCalculoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ErroresCalculo>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the ErroresCalculo table.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ErroresCalculo errorescalculo) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ERRORES_CALCULO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(errorescalculo);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the ErroresCalculo table using like.
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ErroresCalculo errorescalculo, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM ERRORES_CALCULO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(errorescalculo, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of ErroresCalculo selected for rup_table
	 *
	 * @param errorescalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ErroresCalculo>>
	 */
	@Override
	public List<TableRowDto<ErroresCalculo>> reorderSelection(ErroresCalculo errorescalculo,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CODIGOERROR IDCODIGOERROR,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.TIPO_ERROR TIPOERROR,t1.ID_ACT_SUB IDACTSUB ");
		// FROM
		query.append("FROM ERRORES_CALCULO t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(errorescalculo, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				ErroresCalculo.class, filterParamList, "ID_CODIGOERROR");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ErroresCalculo>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            ErroresCalculo
	 * @param searchParams
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ErroresCalculo>>
	 */
	@Override
	public List<TableRowDto<ErroresCalculo>> search(ErroresCalculo filterParams, ErroresCalculo searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CODIGOERROR IDCODIGOERROR,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.TIPO_ERROR TIPOERROR,t1.ID_ACT_SUB IDACTSUB ");
		// FROM
		query.append("FROM ERRORES_CALCULO t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				ErroresCalculo.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_CODIGOERROR");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ErroresCalculo>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtererrorescalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ErroresCalculo filtererrorescalculo, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CODIGOERROR IDCODIGOERROR,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.TIPO_ERROR TIPOERROR,t1.ID_ACT_SUB IDACTSUB ");
		// FROM
		query.append("FROM ERRORES_CALCULO t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtererrorescalculo, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, ErroresCalculo.class,
				query, params, "ID_CODIGOERROR");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical ErroresCalculo table.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<ErroresCalculo>>
	 */
	@Override
	public List<JerarquiaDto<ErroresCalculo>> findAllLikeJerarquia(ErroresCalculo filterErroresCalculo,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CODIGOERROR IDCODIGOERROR,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.TIPO_ERROR TIPOERROR,t1.ID_ACT_SUB IDACTSUB ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM ERRORES_CALCULO t1 ");
		List<String> from = new ArrayList<String>();
		from.add("ERRORES_CALCULO");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterErroresCalculo, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_CODIGOERROR", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ErroresCalculoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(ErroresCalculo filterErroresCalculo, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM ERRORES_CALCULO t1 ");
		List<String> from = new ArrayList<String>();
		from.add("ERRORES_CALCULO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterErroresCalculo, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CODIGOERROR",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<ErroresCalculo>>
	 */
	@Override
	public List<TableRowDto<ErroresCalculo>> findAllChild(ErroresCalculo filterErroresCalculo,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM ERRORES_CALCULO t1 ");
		List<String> from = new ArrayList<String>();
		from.add("ERRORES_CALCULO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterErroresCalculo, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CODIGOERROR",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ErroresCalculo>(this.rwMapPK, "ID_CODIGOERROR"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ErroresCalculo entity
	 *
	 * @param errorescalculo
	 *            ErroresCalculo Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ErroresCalculo errorescalculo) {

		StringBuilder where = new StringBuilder(ErroresCalculoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (errorescalculo != null && errorescalculo.getIdCodigoerror() != null) {
			where.append(" AND t1.ID_CODIGOERROR = ?");
			params.add(errorescalculo.getIdCodigoerror());
		}
		if (errorescalculo != null && errorescalculo.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(errorescalculo.getDescripcionCastellano());
		}
		if (errorescalculo != null && errorescalculo.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(errorescalculo.getDescripcionEuskera());
		}
		if (errorescalculo != null && errorescalculo.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(errorescalculo.getFechaRegistro());
		}
		if (errorescalculo != null && errorescalculo.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(errorescalculo.getUsuarioRegistro());
		}
		if (errorescalculo != null && errorescalculo.getTipoError() != null) {
			where.append(" AND t1.TIPO_ERROR = ?");
			params.add(errorescalculo.getTipoError());
		}
		if (errorescalculo != null && errorescalculo.getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t1.ID_ACT_SUB = ?");
			params.add(errorescalculo.getActSubvencionable().getIdActSub());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the ErroresCalculo entity
	 *
	 * @param errorescalculo
	 *            ErroresCalculo Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ErroresCalculo errorescalculo, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ErroresCalculoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (errorescalculo != null && errorescalculo.getIdCodigoerror() != null) {
			where.append(" AND t1.ID_CODIGOERROR = ?");
			params.add(errorescalculo.getIdCodigoerror());
		}
		if (errorescalculo != null && errorescalculo.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(errorescalculo.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + errorescalculo.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (errorescalculo != null && errorescalculo.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(errorescalculo.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + errorescalculo.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (errorescalculo != null && errorescalculo.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(errorescalculo.getFechaRegistro());
		}
		if (errorescalculo != null && errorescalculo.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(errorescalculo.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + errorescalculo.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (errorescalculo != null && errorescalculo.getTipoError() != null) {
			where.append(" AND t1.TIPO_ERROR = ?");
			params.add(errorescalculo.getTipoError());
		}
		if (errorescalculo != null && errorescalculo.getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t1.ID_ACT_SUB = ?");
			params.add(errorescalculo.getActSubvencionable().getIdActSub());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
