package com.ejie.ab60.dao.estudioTecnico;

import java.util.List;

import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.expedientes.MarcarInspeccionable;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * EstudioTecnicoDao  
 * 
 *  
 */

public interface EstudioTecnicoDao {

	/**
	 * Inserts a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico add(EstudioTecnico datosproyecto);

	/**
	 * Updates a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico update(EstudioTecnico datosproyecto);

	/**
	 * Update importes de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateImporte(EstudioTecnico datosproyecto);

	/**
	 * Update importeAdmitido de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateImporteAdmitidoPresentadodeNullaCero(EstudioTecnico datosproyecto);

	/**
	 * Update SUBVENCION_RESUELTA de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateSubvencionResuelta(EstudioTecnico datosproyecto);

	/**
	 * Update SUBVENCION_RESUELTA de Estudio de tecnico DE AYUDAS CONCURSALES
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param idProcedimiento
	 *            Integer
	 * 
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateSubvencionResueltaConcursal(EstudioTecnico datosproyecto, Integer idProcedimiento);

	/**
	 * Update Habilitar subvencion resuelta de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateHabilitar(EstudioTecnico datosproyecto);

	/**
	 * Cambiar valor al campo expedienteValidado si validamos expediente.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateExpedienteValidado(EstudioTecnico datosproyecto);

	/**
	 * Update importeAdmitido de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateImporteAdmitido(EstudioTecnico datosproyecto);

	/**
	 * Finds a single row in the EstudioTecnico table. PARA CTP
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico findCTP(EstudioTecnico datosproyecto);

	/**
	 * Finds a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico find(EstudioTecnico datosproyecto);

	/**
	 * Select de todos los importes de Estudio de tecnico
	 *
	 * @param idExpediente
	 *            Integer
	 * @return EstudioTecnico
	 */
	EstudioTecnico refescarImportes(Integer idExpediente);

	/**
	 * Finds datos de ayuda de la EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico findDatosProyecto(EstudioTecnico datosproyecto);

	/**
	 * Devolvemos una lista de expedientes valiaddaos filtrado por convocatoria
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @return List<Expedientes>
	 */
	List<EstudioTecnico> findListExpedientesValidados(Integer idConvocatoria);

	/**
	 * Recogemos SUBVENCION_RESUELTA, restando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */

	EstudioTecnico calcularSubvencionResuelta(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Recogemos SUBVENCION_RESUELTA, restando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6006T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */

	EstudioTecnico calcularSubvencionResueltaPorAccionSubencionable(Integer idExpediente);

	/**
	 * Recogemos el tipo_importe para saber si el importe disponible esta en la
	 * AB6006T00 o en la AB6001T00
	 * 
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */

	EstudioTecnico findTipoImporte(Integer idConvocatoria);

	/**
	 * retornamos SUBVENCION_RESUELTA, sumando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	EstudioTecnico retonarSubvencionResuelta(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Buscar SUBVENCION_RESUELTA de la tabla EstudioTecnico
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */

	EstudioTecnico findSubvencionResuelta(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Devuelve los totales de un expediente
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return EstudioTecnico
	 */
	EstudioTecnico findTotales(Integer IdExpediente);

	/**
	 * Removes a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 */
	void remove(EstudioTecnico datosproyecto);

	/**
	 * Finds a List of rows in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<EstudioTecnico> findAll(EstudioTecnico datosproyecto, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the EstudioTecnico table using like.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<EstudioTecnico> findAllLike(EstudioTecnico datosproyecto, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the EstudioTecnico table using like.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(EstudioTecnico datosproyecto, Boolean startsWith);

	/**
	 * Counts rows in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return Long
	 */
	Long findAllCount(EstudioTecnico datosproyecto);

	/**
	 * Reorder selection.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	List<TableRowDto<EstudioTecnico>> reorderSelection(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param searchEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	List<TableRowDto<EstudioTecnico>> search(EstudioTecnico filterEstudioTecnico, EstudioTecnico searchEstudioTecnico,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<EstudioTecnico>>
	 */
	List<JerarquiaDto<EstudioTecnico>> findAllLikeJerarquia(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	List<TableRowDto<EstudioTecnico>> findAllChild(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * retornamos SUBVENCION_RESUELTA, sumando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6006T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @return EstudioTecnico
	 */
	EstudioTecnico retornarSubvencionResueltaPorAccionSubencionable(Integer idExpediente);

	EstudioTecnico obtenerImporteDisponiblePorAccionSubencionable(Integer idExpediente);

	void updateExepto(Integer idExpediente, Integer exeptoHidden);

	EstudioTecnico findImporteProyecto(Integer idExpediente);

	void updateImporteJusOTC(EstudioTecnico estudioTecnico);

}
