package com.ejie.ab60.dao.estudioTecnico;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.RelExpIns;
import com.ejie.ab60.model.CTP.AsociacionesSectoriales;
import com.ejie.ab60.model.CTP.Proyectos;
import com.ejie.ab60.model.CTP.Solicitantes;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.estudioTecnico.MotivosDesestimacion;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;
import com.ejie.ab60.model.estudioTecnico.TiposResultado;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * EstudioTecnicoDaoImpl  
 * 
 * 
 */
@Repository
@Transactional
public class EstudioTecnicoDaoImpl implements EstudioTecnicoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPROYECTOEXPEDIENTE", "IDEXPEDIENTE",
			"IMPORTEPRESENTADO", "IMPORTEADMITIDO", "SUBVENCIONCALCULADA", "SUBVENCIONJUSTIFICADA", "IMPORTERECURSO",
			"SUBVENCIONRESUELTA", "FECHAINFORME", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION", "IDTECNICORESPONSABLE", "NOMBRETECNICORESPONSABLE", "FECREGTECNICORESPONSABLE",
			"USUREGTECNICORESPONSABLE", "IDTIPOSRESULTADO", "TIPOSRESULTADODESCASTELLANO", "TIPOSRESULTADODESEUSKERA",
			"TIPOSRESULTADOFECHAREGISTRO", "TIPOSRESULTADOUSUARIOREGISTRO", "IDMOTIVOSDESESTIMACION",
			"DESMOTIVOCASTELLANO", "DESMOTIVOEUSKERA", "MOTIVOSDESESTIMACIONFECREG", "MOTIVOSDESESTIMACIONUSUREG",
			"IMPORTEFINAL", "IMPORTEDISPONIBLE", "DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "IDSOLICITANTE",
			"DCASTELLANO", "DEUSKERA", "CRIPUNCASTELLANO", "CRIPUNEUSKERA", "IDASOCIACION", "IDCRITERIO",
			"CARGARSOLSUB" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */

	private RowMapper<EstudioTecnico> rwMap = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getInt("IDPROYECTOEXPEDIENTE"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getInt("EXPEDIENTEVALIDADO"), resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getBigDecimal("SUBVENCIONCALCULADA"),
					resultSet.getBigDecimal("SUBVENCIONJUSTIFICADA"), resultSet.getBigDecimal("IMPORTERECURSO"),
					resultSet.getBigDecimal("SUBVENCIONRESUELTA"), resultSet.getString("OBSERVACIONESCASTELLANO"),
					resultSet.getString("OBSERVACIONESEUSKERA"), resultSet.getDate("FECHAINFORME"),
					resultSet.getBigDecimal("IMPORTEDISPONIBLE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),

					new MotivosDesestimacion(resultSet.getLong("IDMOTIVOSDESESTIMACION"),
							resultSet.getString("DESMOTIVOCASTELLANO"), resultSet.getString("DESMOTIVOEUSKERA"),
							resultSet.getDate("MOTIVOSDESESTIMACIONFECREG"),
							resultSet.getString("MOTIVOSDESESTIMACIONUSUREG")),
					new TecnicosResponsables(resultSet.getInt("IDTECNICORESPONSABLE"),
							resultSet.getString("NOMBRETECNICORESPONSABLE"),
							resultSet.getDate("FECREGTECNICORESPONSABLE"),
							resultSet.getString("USUREGTECNICORESPONSABLE")),
					new TiposResultado(resultSet.getLong("IDTIPOSRESULTADO"),
							resultSet.getString("TIPOSRESULTADODESCASTELLANO"),
							resultSet.getString("TIPOSRESULTADODESEUSKERA"),
							resultSet.getDate("TIPOSRESULTADOFECHAREGISTRO"),
							resultSet.getString("TIPOSRESULTADOUSUARIOREGISTRO"))

			);

		}
	};

	private RowMapper<EstudioTecnico> rwMapFindEstudio = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			EstudioTecnico estudioTecnico = new EstudioTecnico();
			estudioTecnico.setIdProyectoExpediente(resultSet.getInt("IDPROYECTOEXPEDIENTE"));
			estudioTecnico.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			estudioTecnico.setExpedienteValidado(resultSet.getInt("EXPEDIENTEVALIDADO"));
			estudioTecnico.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			estudioTecnico.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			estudioTecnico.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			estudioTecnico.setSubvencionJustificada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			estudioTecnico.setImporteRecurso(resultSet.getBigDecimal("IMPORTERECURSO"));
			estudioTecnico.setSubvencionResuelta(resultSet.getBigDecimal("SUBVENCIONRESUELTA"));
			estudioTecnico.setObservacionesCastellano(resultSet.getString("OBSERVACIONESCASTELLANO"));
			estudioTecnico.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEUSKERA"));
			estudioTecnico.setFechaInforme(resultSet.getDate("FECHAINFORME"));
			estudioTecnico.setImporteDisponible(resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
			estudioTecnico.setCargarSolSub(resultSet.getInt("CARGARSOLSUB"));

			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVOSDESESTIMACION"));
			motivosDesestimacion.setDescripcionCastellano(resultSet.getString("DESMOTIVOCASTELLANO"));
			motivosDesestimacion.setDescripcionEuskera(resultSet.getString("DESMOTIVOEUSKERA"));

			estudioTecnico.setMotivosDesestimacion(motivosDesestimacion);

			TecnicosResponsables tecnicosResponsables = new TecnicosResponsables();
			tecnicosResponsables.setIdTecnicoResponsable(resultSet.getInt("IDTECNICORESPONSABLE"));
			tecnicosResponsables.setNombreTecnico(resultSet.getString("NOMBRETECNICORESPONSABLE"));

			estudioTecnico.setTecnicosResponsables(tecnicosResponsables);

			TiposResultado tiposResultado = new TiposResultado();
			tiposResultado.setIdResultado(resultSet.getLong("IDTIPOSRESULTADO"));
			tiposResultado.setDescripcionCastellano(resultSet.getString("TIPOSRESULTADODESCASTELLANO"));
			tiposResultado.setDescripcionEuskera(resultSet.getString("TIPOSRESULTADODESEUSKERA"));

			estudioTecnico.setTiposResultado(tiposResultado);

			RelExpIns relExpIns = new RelExpIns();
			relExpIns.setIdInspeccion(resultSet.getInt("IDINSPECCION"));
			estudioTecnico.setRelExpIns(relExpIns);

			return estudioTecnico;

		}
	};

	private RowMapper<EstudioTecnico> rwMapCTP = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			EstudioTecnico estudioTecnico = new EstudioTecnico();
			estudioTecnico.setIdProyectoExpediente(resultSet.getInt("IDPROYECTOEXPEDIENTE"));
			estudioTecnico.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			estudioTecnico.setExpedienteValidado(resultSet.getInt("EXPEDIENTEVALIDADO"));
			estudioTecnico.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			estudioTecnico.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			estudioTecnico.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			estudioTecnico.setSubvencionJustificada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			estudioTecnico.setImporteRecurso(resultSet.getBigDecimal("IMPORTERECURSO"));
			estudioTecnico.setSubvencionResuelta(resultSet.getBigDecimal("SUBVENCIONRESUELTA"));
			estudioTecnico.setObservacionesCastellano(resultSet.getString("OBSERVACIONESCASTELLANO"));
			estudioTecnico.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEUSKERA"));
			estudioTecnico.setFechaInforme(resultSet.getDate("FECHAINFORME"));
			estudioTecnico.setImporteDisponible(resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
			estudioTecnico.setCargarSolSub(resultSet.getInt("CARGARSOLSUB"));

			MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
			motivosDesestimacion.setIdMotivoDesestimacion(resultSet.getLong("IDMOTIVOSDESESTIMACION"));
			motivosDesestimacion.setDescripcionCastellano(resultSet.getString("DESMOTIVOCASTELLANO"));
			motivosDesestimacion.setDescripcionEuskera(resultSet.getString("DESMOTIVOEUSKERA"));

			estudioTecnico.setMotivosDesestimacion(motivosDesestimacion);

			TecnicosResponsables tecnicosResponsables = new TecnicosResponsables();
			tecnicosResponsables.setIdTecnicoResponsable(resultSet.getInt("IDTECNICORESPONSABLE"));
			tecnicosResponsables.setNombreTecnico(resultSet.getString("NOMBRETECNICORESPONSABLE"));

			estudioTecnico.setTecnicosResponsables(tecnicosResponsables);

			TiposResultado tiposResultado = new TiposResultado();
			tiposResultado.setIdResultado(resultSet.getLong("IDTIPOSRESULTADO"));
			tiposResultado.setDescripcionCastellano(resultSet.getString("TIPOSRESULTADODESCASTELLANO"));
			tiposResultado.setDescripcionEuskera(resultSet.getString("TIPOSRESULTADODESEUSKERA"));

			estudioTecnico.setTiposResultado(tiposResultado);

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));

			estudioTecnico.setActSubvencionable(actSubvencionable);

			Solicitantes solicitantes = new Solicitantes();
			solicitantes.setIdSolicitante(resultSet.getLong("IDSOLICITANTE"));
			solicitantes.setDescripcionCastellano(resultSet.getString("DCASTELLANO"));
			solicitantes.setDescripcionEuskera(resultSet.getString("DEUSKERA"));
			AsociacionesSectoriales asociacionesSectoriales = new AsociacionesSectoriales();
			asociacionesSectoriales.setIdAsociacion(resultSet.getLong("IDASOCIACION"));
			Proyectos proyectos = new Proyectos();
			proyectos.setSolicitantes(solicitantes);
			proyectos.setAsociacionesSectoriales(asociacionesSectoriales);

			estudioTecnico.setProyectos(proyectos);

			CriteriosPuntuacion criteriosPuntuacion = new CriteriosPuntuacion();
			criteriosPuntuacion.setIdCriterio(resultSet.getInt("IDCRITERIO"));
			criteriosPuntuacion.setCriPunCastellano(resultSet.getString("CRIPUNCASTELLANO"));
			criteriosPuntuacion.setCriPunEuskera(resultSet.getString("CRIPUNEUSKERA"));

			estudioTecnico.setCriteriosPuntuacion(criteriosPuntuacion);

			RelExpIns relExpIns = new RelExpIns();
			relExpIns.setIdInspeccion(resultSet.getInt("IDINSPECCION"));

			estudioTecnico.setRelExpIns(relExpIns);

			return estudioTecnico;
		}
	};

	private RowMapper<EstudioTecnico> rwMapDatosProyecto = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getInt("IDRESULTADO"), resultSet.getInt("IDMOTIVODESESTIMACION"),
					resultSet.getInt("IDTECNICORESPONSABLE"), resultSet.getDate("FECHAINFORME"),
					resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
		}
	};

	private RowMapper<EstudioTecnico> rwMapListaExpedientes = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getInt("IDEXPEDIENTE"), resultSet.getInt("EXPEDIENTEVALIDADO"),
					resultSet.getBigDecimal("SUBVENCIONRESUELTA"));
		}
	};

	private RowMapper<EstudioTecnico> rwMapTotales = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			EstudioTecnico estudioTecnico = new EstudioTecnico();
			estudioTecnico.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			estudioTecnico.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			estudioTecnico.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			estudioTecnico.setSubvencionResuelta(resultSet.getBigDecimal("SUBVENCIONRESUELTA"));
			return estudioTecnico;
		}
	};

	private RowMapper<EstudioTecnico> rwMapTodoslosImportes = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getBigDecimal("SUBVENCIONCALCULADA"),
					resultSet.getBigDecimal("SUBVENCIONRESUELTA"));
		}
	};

	private RowMapper<EstudioTecnico> rwMapImportePresentado = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
		}
	};

	private RowMapper<EstudioTecnico> rwMapSubvencion = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getBigDecimal("IMPORTEFINAL"),
					resultSet.getBigDecimal("IMPORTEDISPONIBLE"), resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
		}
	};

	private RowMapper<EstudioTecnico> rwMapSubvencionPorAccionSubencionable = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			EstudioTecnico estudioTecnico = new EstudioTecnico();
			estudioTecnico.setImporteFinal(resultSet.getBigDecimal("IMPORTEFINAL"));
			estudioTecnico.setImporteDisponible(resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
			estudioTecnico.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			estudioTecnico.setImporteFinalConvocatoria(resultSet.getBigDecimal("IMPORTEFINALCONVOCATORIAS"));
			ActSubvencionable actSubencionable = new ActSubvencionable();
			actSubencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			estudioTecnico.setActSubvencionable(actSubencionable);

			return estudioTecnico;
		}
	};

	private RowMapper<EstudioTecnico> rwMapImporteFinal = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getBigDecimal("IMPORTEFINAL"));
		}
	};

	private RowMapper<EstudioTecnico> rwMapImporteDisponible = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			EstudioTecnico estudioTecnico = new EstudioTecnico();
			estudioTecnico.setImporteDisponible(resultSet.getBigDecimal("IMPORTEDISPONIBLE"));
			return estudioTecnico;
		}
	};

	private RowMapper<EstudioTecnico> rwMapImporteFinalActSubvencionable = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			EstudioTecnico estudioTecnico = new EstudioTecnico();
			estudioTecnico.setImporteFinal(resultSet.getBigDecimal("IMPORTEFINAL"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			estudioTecnico.setActSubvencionable(actSubvencionable);
			return estudioTecnico;
		}
	};
	private RowMapper<EstudioTecnico> rwMapTipoImporte = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			EstudioTecnico estudioTecnico = new EstudioTecnico();
			estudioTecnico.setTipoImporte(resultSet.getInt("TIPOIMPORTE"));

			return estudioTecnico;
		}
	};
	private RowMapper<EstudioTecnico> rwMapPK = new RowMapper<EstudioTecnico>() {
		public EstudioTecnico mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstudioTecnico(resultSet.getInt("IDPROYECTOEXPEDIENTE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<EstudioTecnico>> rwMapJerarquia = new RowMapper<JerarquiaDto<EstudioTecnico>>() {
		public JerarquiaDto<EstudioTecnico> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			EstudioTecnico datosproyecto = new EstudioTecnico(resultSet.getInt("IDPROYECTOEXPEDIENTE"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getInt("EXPEDIENTEVALIDADO"),
					resultSet.getBigDecimal("IMPORTEPRESENTADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getBigDecimal("SUBVENCIONCALCULADA"), resultSet.getBigDecimal("SUBVENCIONJUSTIFICADA"),
					resultSet.getBigDecimal("IMPORTERECURSO"), resultSet.getBigDecimal("SUBVENCIONRESUELTA"),
					resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getString("OBSERVACIONESEUSKERA"),
					resultSet.getDate("FECHAINFORME"), resultSet.getBigDecimal("IMPORTEDISPONIBLE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new MotivosDesestimacion(resultSet.getLong("IDMOTIVOSDESESTIMACION"),
							resultSet.getString("DESMOTIVOCASTELLANO"), resultSet.getString("DESMOTIVOEUSKERA"),
							resultSet.getDate("MOTIVOSDESESTIMACIONFECREG"),
							resultSet.getString("MOTIVOSDESESTIMACIONUSUREG")),
					new TecnicosResponsables(resultSet.getInt("IDTECNICORESPONSABLE"),
							resultSet.getString("NOMBRETECNICORESPONSABLE"),
							resultSet.getDate("FECREGTECNICORESPONSABLE"),
							resultSet.getString("USUREGTECNICORESPONSABLE")),
					new TiposResultado(resultSet.getLong("IDTIPOSRESULTADO"),
							resultSet.getString("TIPOSRESULTADODESCASTELLANO"),
							resultSet.getString("TIPOSRESULTADODESEUSKERA"),
							resultSet.getDate("TIPOSRESULTADOFECHAREGISTRO"),
							resultSet.getString("TIPOSRESULTADOUSUARIOREGISTRO")));

			JerarquiaDto<EstudioTecnico> jerarquia = new JerarquiaDto<EstudioTecnico>();
			jerarquia.setModel(datosproyecto);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico add(EstudioTecnico datosproyecto) {
		String query = "INSERT INTO DATOS_PROYECTO (ID_PROYECTO_EXPEDIENTE, " + "ID_EXPEDIENTE, "
				+ "IMPORTE_PRESENTADO, " + "IMPORTE_ADMITIDO, " + "SUBVENCION_CALCULADA, " + "SUBVNECION_JUSTIFICADA, "
				+ "IMPORTE_RECURSO, " + "SUBVENCION_RESUELTA, " + "FECHA_INFORME, " + "ID_TECNICO_RESPONSABLE, "
				+ "ID_RESULTADO, " + "ID_MOTIVO_DESESTIMACION, " + "FECHA_REGISTRO, " + "USUARIO_REGISTRO, "
				+ "FECHA_ULTMODIFICACION, " + "USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		Object getTecnicosResponsablesIdTecnicoResponsableAux = null;
		if (datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable() != null) {
			getTecnicosResponsablesIdTecnicoResponsableAux = datosproyecto.getTecnicosResponsables()
					.getIdTecnicoResponsable();
		}

		Object getTiposResultadoAux = null;
		if (datosproyecto.getTiposResultado() != null && datosproyecto.getTiposResultado().getIdResultado() != null) {
			getTiposResultadoAux = datosproyecto.getTiposResultado().getIdResultado();
		}

		Object getMotivosDesestimacionAux = null;
		if (datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getIdMotivoDesestimacion() != null) {
			getTiposResultadoAux = datosproyecto.getMotivosDesestimacion().getIdMotivoDesestimacion();
		}

		this.jdbcTemplate.update(query, datosproyecto.getIdProyectoExpediente(), datosproyecto.getIdExpediente(),
				datosproyecto.getImportePresentado(), datosproyecto.getImporteAdmitido(),
				datosproyecto.getSubvencionCalculada(), datosproyecto.getSubvencionJustificada(),
				datosproyecto.getImporteRecurso(), datosproyecto.getSubvencionResuelta(),
				datosproyecto.getFechaInforme(), getTecnicosResponsablesIdTecnicoResponsableAux, getTiposResultadoAux,
				getMotivosDesestimacionAux, datosproyecto.getFechaRegistro(), datosproyecto.getUsuarioRegistro(),
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion());
		return datosproyecto;
	}

	/**
	 * Updates a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico update(EstudioTecnico datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET  " + "ID_EXPEDIENTE=?, " + "IMPORTE_PRESENTADO=?, "
				+ "IMPORTE_ADMITIDO=?, " + "SUBVENCION_CALCULADA=?, " + "SUBVENCION_JUSTIFICADA=?, "
				+ "IMPORTE_RECURSO=?, " + "SUBVENCION_RESUELTA=?, " + "OBSERVACIONES_CASTELLANO=?, "
				+ "OBSERVACIONES_EUSKERA=?, " + "FECHA_INFORME=TO_DATE (?,'DD/MM/YYYY'), "
				+ "ID_TECNICO_RESPONSABLE=?, " + "ID_RESULTADO=?, " + "ID_MOTIVO_DESESTIMACION=?, "
				+ "FECHA_ULTMODIFICACION=?, " + "USUARIO_ULTMODIFICACION=?, " + "CARGAR_SOL_SUB=? "
				+ "WHERE ID_PROYECTO_EXPEDIENTE=?";

		Object getTecnicosResponsablesIdTecnicoResponsableAux = null;
		if (datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable() != null) {
			getTecnicosResponsablesIdTecnicoResponsableAux = datosproyecto.getTecnicosResponsables()
					.getIdTecnicoResponsable();
		}

		Object getTiposResultadoAux = null;
		if (datosproyecto.getTiposResultado() != null && datosproyecto.getTiposResultado().getIdResultado() != null) {
			getTiposResultadoAux = datosproyecto.getTiposResultado().getIdResultado();
		}

		Object getMotivosDesestimacionAux = null;
		if (datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getIdMotivoDesestimacion() != null) {
			getMotivosDesestimacionAux = datosproyecto.getMotivosDesestimacion().getIdMotivoDesestimacion();
		}

		this.jdbcTemplate.update(query, datosproyecto.getIdExpediente(), datosproyecto.getImportePresentado(),
				datosproyecto.getImporteAdmitido(), datosproyecto.getSubvencionCalculada(),
				datosproyecto.getSubvencionJustificada(), datosproyecto.getImporteRecurso(),
				datosproyecto.getSubvencionResuelta(), datosproyecto.getObservacionesCastellano(),
				datosproyecto.getObservacionesEuskera(), datosproyecto.getFechaInformeStr(),
				getTecnicosResponsablesIdTecnicoResponsableAux, getTiposResultadoAux, getMotivosDesestimacionAux,
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion(),
				datosproyecto.getCargarSolSub(), datosproyecto.getIdProyectoExpediente());
		return datosproyecto;
	}

	/**
	 * Update importes de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateImporte(EstudioTecnico datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET IMPORTE_PRESENTADO= ?, IMPORTE_ADMITIDO= ?, SUBVENCION_RESUELTA =? , SUBVENCION_CALCULADA = ?, FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, datosproyecto.getImportePresentado(), datosproyecto.getImporteAdmitido(),
				datosproyecto.getSubvencionResuelta(), datosproyecto.getSubvencionCalculada(),
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion(),
				datosproyecto.getIdExpediente());
		return datosproyecto;
	}

	/**
	 * Update SUBVENCION_RESUELTA de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * 
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateSubvencionResuelta(EstudioTecnico datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET SUBVENCION_RESUELTA =? ,ID_RESULTADO=?, ID_MOTIVO_DESESTIMACION=? , EXPEDIENTE_VALIDADO = ?, CARGAR_SOL_SUB  = ? ,FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, datosproyecto.getSubvencionResuelta(), datosproyecto.getIdResultado(),
				datosproyecto.getIdMotivoDesestimacion(), datosproyecto.getExpedienteValidado(),
				datosproyecto.getCargarSolSub(), datosproyecto.getFechaUltmodificacion(),
				datosproyecto.getUsuarioUltmodificacion(), datosproyecto.getIdExpediente());
		return datosproyecto;
	}

	/**
	 * Update SUBVENCION_RESUELTA de Estudio de tecnico DE AYUDAS CONCURSALES
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * 
	 * @param idProcedimiento
	 *            Integer
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateSubvencionResueltaConcursal(EstudioTecnico datosproyecto, Integer idProcedimiento) {

		String query = "UPDATE DATOS_PROYECTO SET SUBVENCION_RESUELTA= NULL, FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE   IN (SELECT ID_EXPEDIENTE FROM EXPEDIENTES WHERE ID_PROCEDIMIENTO = ? )";

		this.jdbcTemplate.update(query, datosproyecto.getFechaUltmodificacion(),
				datosproyecto.getUsuarioUltmodificacion(), idProcedimiento);
		return datosproyecto;
	}

	/**
	 * Update Habilitar subvencion resuelta de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateHabilitar(EstudioTecnico datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET SUBVENCION_RESUELTA =? , EXPEDIENTE_VALIDADO = ? ,FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, datosproyecto.getSubvencionResuelta(), datosproyecto.getExpedienteValidado(),
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion(),
				datosproyecto.getIdExpediente());
		return datosproyecto;
	}

	/**
	 * Cambiar valor al campo expedienteValidado si validamos expediente.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateExpedienteValidado(EstudioTecnico datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET  EXPEDIENTE_VALIDADO = ?, CARGAR_SOL_SUB = ? ,FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, datosproyecto.getExpedienteValidado(), datosproyecto.getCargarSolSub(),
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion(),
				datosproyecto.getIdExpediente());
		return datosproyecto;
	}

	/**
	 * Select de todos los importes de Estudio de tecnico
	 *
	 * @param idExpediente
	 *            Integer
	 * @return EstudioTecnico
	 */
	public EstudioTecnico refescarImportes(Integer idExpediente) {
		String query = "SELECT t2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO,t2.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,t2.SUBVENCION_RESUELTA SUBVENCIONRESUELTA  FROM DATOS_PROYECTO t2 WHERE t2.ID_EXPEDIENTE = ?";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapTodoslosImportes,
				idExpediente);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	/**
	 * Update importeAdmitido de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateImporteAdmitido(EstudioTecnico datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET IMPORTE_ADMITIDO= ?, SUBVENCION_CALCULADA = ?, SUBVENCION_RESUELTA= ?,FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";
		this.jdbcTemplate.update(query, datosproyecto.getImporteAdmitido(), datosproyecto.getSubvencionCalculada(),
				datosproyecto.getSubvencionResuelta(), datosproyecto.getFechaUltmodificacion(),
				datosproyecto.getUsuarioUltmodificacion(), datosproyecto.getIdExpediente());
		return datosproyecto;
	}

	/**
	 * Update importeAdmitido de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateImporteAdmitidoPresentadodeNullaCero(EstudioTecnico datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET IMPORTE_PRESENTADO = ? , IMPORTE_ADMITIDO= ?, FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, datosproyecto.getImportePresentado(), datosproyecto.getImporteAdmitido(),
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion(),
				datosproyecto.getIdExpediente());

		return datosproyecto;
	}

	/**
	 * Finds a single row in the EstudioTecnico table. PARA CTP
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico findCTP(EstudioTecnico datosproyecto) {
		List<Object> params = new ArrayList<Object>();
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE, "
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE, " + "t1.EXPEDIENTE_VALIDADO EXPEDIENTEVALIDADO,"
				+ "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, " + "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, "
				+ "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, " + "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA, "
				+ "t1.IMPORTE_RECURSO IMPORTERECURSO, " + "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, "
				+ "t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, "
				+ "t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, " + "t1.FECHA_INFORME FECHAINFORME, "
				+ "t1.CARGAR_SOL_SUB CARGARSOLSUB, "

				+ "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE, " + "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE, "

				+ "t3.ID_RESULTADO IDTIPOSRESULTADO, " + "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "

				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "

				+ "t5.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE, " + "t6.ID_SOLICITANTE IDSOLICITANTE, "
				+ "t6.ID_ASOCIACION IDASOCIACION, " + "t10.DESCRIPCION_CASTELLANO DCASTELLANO, "
				+ "t10.DESCRIPCION_EUSKERA DEUSKERA, " + "t7.ID_CRITERIO IDCRITERIO, "
				+ "t7.CRI_PUN_CASTELLANO CRIPUNCASTELLANO, " + "t7.CRI_PUN_EUSKERA CRIPUNEUSKERA, "
				+ "t8.ID_ACT_SUB ActSubvencionableIDACTSUB, " + "t8.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, "
				+ "t8.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA,  " + "t8.ORDEN ORDEN, "
				+ "t11.ID_INSPECCION IDINSPECCION "
				+ " FROM DATOS_PROYECTO t1 , TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4 , CONVOCATORIAS t5 , PROYECTOS t6 , CRITERIOS_PUNTUACION t7 , ACT_SUBVENCIONABLE t8 , REL_EXP_ACT_SUB t9 , SOLICITANTES t10, REL_EXP_INS t11 "
				+ "WHERE 1=1 ");

		if (datosproyecto.getIdExpediente() != null && datosproyecto.getIdExpediente() != 0) {
			query.append(" AND t1.ID_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdExpediente());
		}

		if (datosproyecto.getIdConvocatoria() != null && datosproyecto.getIdConvocatoria() != 0) {
			query.append(" AND t5.ID_CONVOCATORIA = ? ");
			params.add(datosproyecto.getIdConvocatoria());
		}

		if (datosproyecto.getIdProyectoExpediente() != null && datosproyecto.getIdProyectoExpediente() != 0) {
			query.append(" AND t1.ID_PROYECTO_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdProyectoExpediente());
		}
		query.append("AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
				+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+) "
				+ "AND t6.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t7.ID_ACT_SUB = t8.ID_ACT_SUB AND t8.ID_ACT_SUB = t9.ID_ACT_SUB AND t9.ID_EXPEDIENTE= t1.ID_EXPEDIENTE AND t10.ID_SOLICITANTE = t6.ID_SOLICITANTE AND t1.ID_EXPEDIENTE = t11.ID_EXPEDIENTE(+) AND t11.TIPO_INSPECCION(+) = ? ORDER BY t8.ORDEN");

		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query.toString(), this.rwMapCTP,
				datosproyecto.getIdExpediente(), datosproyecto.getIdConvocatoria(),
				Constantes.ORIGEN_INSPECCION_ESTUDIO_TECNICO);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	/**
	 * Finds a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico find(EstudioTecnico datosproyecto) {
		List<Object> params = new ArrayList<Object>();
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE, "
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE, " + "t1.EXPEDIENTE_VALIDADO EXPEDIENTEVALIDADO,"
				+ "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, " + "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, "
				+ "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, " + "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA, "
				+ "t1.IMPORTE_RECURSO IMPORTERECURSO, " + "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, "
				+ "t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, "
				+ "t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, " + "t1.FECHA_INFORME FECHAINFORME, "
				+ "t1.CARGAR_SOL_SUB CARGARSOLSUB, " + "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE, "
				+ "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE, " + "t3.ID_RESULTADO IDTIPOSRESULTADO, "
				+ "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "
				+ "t5.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE , t6.ID_INSPECCION IDINSPECCION "
				+ "FROM DATOS_PROYECTO t1 , TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4 , CONVOCATORIAS t5 , REL_EXP_INS t6 "
				+ "WHERE 1=1 ");

		if (datosproyecto.getIdExpediente() != null && datosproyecto.getIdExpediente() != 0) {
			query.append(" AND t1.ID_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdExpediente());
		}

		if (datosproyecto.getIdConvocatoria() != null && datosproyecto.getIdConvocatoria() != 0) {
			query.append(" AND t5.ID_CONVOCATORIA = ? ");
			params.add(datosproyecto.getIdConvocatoria());
		}

		if (datosproyecto.getIdProyectoExpediente() != null && datosproyecto.getIdProyectoExpediente() != 0) {
			query.append(" AND t1.ID_PROYECTO_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdProyectoExpediente());
		}
		query.append("AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
				+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+) AND t1.ID_EXPEDIENTE = t6.ID_EXPEDIENTE(+) AND t6.TIPO_INSPECCION(+) = ?");

		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query.toString(), this.rwMapFindEstudio,
				datosproyecto.getIdExpediente(), datosproyecto.getIdConvocatoria(),
				Constantes.ORIGEN_INSPECCION_ESTUDIO_TECNICO);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	/**
	 * Finds datos de ayuda de la EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico findDatosProyecto(EstudioTecnico datosproyecto) {
		String query = "SELECT  t1.FECHA_INFORME FECHAINFORME, t1.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE, t1.ID_RESULTADO  IDRESULTADO, t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA FROM DATOS_PROYECTO t1 WHERE ID_EXPEDIENTE = ?";

		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query.toString(), this.rwMapDatosProyecto,
				datosproyecto.getIdExpediente());
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);

	}

	/**
	 * Devolvemos una lista de expedientes valiaddaos filtrado por convocatoria
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @return List<Expedientes>
	 */
	@Transactional(readOnly = true)
	public List<EstudioTecnico> findListExpedientesValidados(Integer idConvocatoria) {
		String query = "SELECT  t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.EXPEDIENTE_VALIDADO EXPEDIENTEVALIDADO , t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA FROM  DATOS_PROYECTO t1, EXPEDIENTES   t4, CONVOCATORIAS t3 WHERE  t3.ID_CONVOCATORIA = ? and t4.ID_PROCEDIMIENTO =t3.ID_PROCEDIMIENTO and t1.ID_EXPEDIENTE = t4.ID_EXPEDIENTE";
		List<EstudioTecnico> expedientesList = this.jdbcTemplate.query(query, this.rwMapListaExpedientes,
				idConvocatoria);
		return expedientesList;

	}

	/**
	 * Devuelve los totales de un expediente
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico findTotales(Integer idExpediente) {

		String query = "SELECT t2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO, t2.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,t2.SUBVENCION_RESUELTA SUBVENCIONRESUELTA FROM DATOS_PROYECTO t2 WHERE t2.ID_EXPEDIENTE = ?";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapTotales, idExpediente);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);

	}

	/**
	 * Buscar SUBVENCION_RESUELTA de la tabla EstudioTecnico
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico findSubvencionResuelta(Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE = ?";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapTodoslosImportes,
				idExpediente);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	/**
	 * retornamos SUBVENCION_RESUELTA, sumando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico retonarSubvencionResuelta(Integer idExpediente, Integer idConvocatoria) {

		String query = "SELECT SUM (t1.IMPORTE_DISPONIBLE + t2.SUBVENCION_RESUELTA) AS IMPORTEFINAL  FROM CONVOCATORIAS t1 , DATOS_PROYECTO t2, EXPEDIENTES t3 WHERE t3.ID_PROCEDIMIENTO = t1.ID_PROCEDIMIENTO AND t2.ID_EXPEDIENTE = ? AND t1.ID_CONVOCATORIA =? AND t3.ID_EXPEDIENTE = t2.ID_EXPEDIENTE";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapImporteFinal, idExpediente,
				idConvocatoria);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);

	}

	/**
	 * Recogemos SUBVENCION_RESUELTA, restando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico calcularSubvencionResuelta(Integer idExpediente, Integer idConvocatoria) {

		String query = "SELECT decode(t1.IMPORTE_DISPONIBLE - t2.SUBVENCION_CALCULADA , null,0,t1.IMPORTE_DISPONIBLE - t2.SUBVENCION_CALCULADA) AS IMPORTEFINAL,t1.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE , t2.SUBVENCION_CALCULADA SUBVENCIONCALCULADA  FROM  CONVOCATORIAS t1 , DATOS_PROYECTO t2,  EXPEDIENTES t3 WHERE t3.ID_PROCEDIMIENTO=t1.ID_PROCEDIMIENTO AND t2.ID_EXPEDIENTE = ? AND  t1.ID_CONVOCATORIA =? AND t3.ID_EXPEDIENTE = t2.ID_EXPEDIENTE";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapSubvencion, idExpediente,
				idConvocatoria);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);

	}

	/**
	 * Recogemos SUBVENCION_RESUELTA, restando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6006T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * 
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico calcularSubvencionResueltaPorAccionSubencionable(Integer idExpediente) {

		String query = "SELECT DECODE(t2.IMPORTE_DISPONIBLE - t3.SUBVENCION_CALCULADA , NULL,t2.IMPORTE_DISPONIBLE,t2.IMPORTE_DISPONIBLE - t3.SUBVENCION_CALCULADA) AS IMPORTEFINAL, DECODE(t4.IMPORTE_DISPONIBLE - t3.SUBVENCION_CALCULADA , NULL,t4.IMPORTE_DISPONIBLE,t4.IMPORTE_DISPONIBLE - t3.SUBVENCION_CALCULADA) AS IMPORTEFINALCONVOCATORIAS, t2.IMPORTE_DISPONIBLE IMPORTEDISPONIBLE, t3.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t1.ID_ACT_SUB IDACTSUB FROM REL_EXP_ACT_SUB t1 , ACT_SUBVENCIONABLE t2, DATOS_PROYECTO t3, CONVOCATORIAS t4, EXPEDIENTES t5 WHERE t1.ID_ACT_SUB =t2.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? AND t2.IMPORTE_DISPONIBLE IS NOT NULL AND t1.ID_EXPEDIENTE = t3.ID_EXPEDIENTE and T5.ID_EXPEDIENTE = T1.ID_EXPEDIENTE AND T5.ID_PROCEDIMIENTO = T4.ID_PROCEDIMIENTO";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query,
				this.rwMapSubvencionPorAccionSubencionable, idExpediente);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);

	}

	/**
	 * Obtenemos el Importe Disponible
	 * 
	 * @param Integer
	 *            IdExpediente
	 * 
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico obtenerImporteDisponiblePorAccionSubencionable(Integer idExpediente) {

		String query = "SELECT SUM(T2.IMPORTE_DISPONIBLE) IMPORTEDISPONIBLE FROM REL_EXP_ACT_SUB T1, ACT_SUBVENCIONABLE T2 WHERE T1.ID_ACT_SUB = T2.ID_ACT_SUB AND T1.ID_EXPEDIENTE = ? AND T2.IMPORTE_DISPONIBLE IS NOT NULL";
		List<EstudioTecnico> estudioTecnicoList = this.jdbcTemplate.query(query, this.rwMapImporteDisponible,
				idExpediente);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(estudioTecnicoList);

	}

	/**
	 * Recogemos el tipo_importe para saber si el importe disponible esta en la
	 * AB6006T00 o en la AB6001T00
	 * 
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico findTipoImporte(Integer IdConvocatoria) {
		String query = "SELECT TIPO_IMPORTE TIPOIMPORTE FROM CONVOCATORIAS WHERE ID_CONVOCATORIA = ?";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapTipoImporte, IdConvocatoria);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);

	}

	/**
	 * Removes a single row in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return
	 */
	public void remove(EstudioTecnico datosproyecto) {
		String query = "DELETE FROM DATOS_PROYECTO WHERE ID_PROYECTO_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, datosproyecto.getIdProyectoExpediente());
	}

	/**
	 * Finds a list of rows in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<EstudioTecnico>
	 */
	@Transactional(readOnly = true)
	public List<EstudioTecnico> findAll(EstudioTecnico datosproyecto, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder("SELECT  t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE, "
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE, " + "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, "
				+ "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, " + "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, "
				+ "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA, " + "t1.IMPORTE_RECURSO IMPORTERECURSO, "
				+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, " + "t1.FECHA_INFORME FECHAINFORME, "
				+ "t1.FECHA_REGISTRO FECHAREGISTRO, " + "t1.USUARIO_REGISTRO USUARIOREGISTRO, "
				+ "t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, "
				+ "t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,"
				+ "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE, " + "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE, "
				+ "t2.FECHA_REGISTRO FECREGTECNICORESPONSABLE, " + "t2.USUARIO_REGISTRO USUREGTECNICORESPONSABLE, "
				+ "t3.ID_RESULTADO IDTIPOSRESULTADO, " + "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
				+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
				+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "
				+ "t4.FECHA_REGISTRO MOTIVOSDESESTIMACIONFECREG, " + "t4.USUARIO_REGISTRO MOTIVOSDESESTIMACIONUSUREG ");
		query.append(
				"FROM DATOS_PROYECTO t1 , TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(datosproyecto);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
						+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+)");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EstudioTecnicoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EstudioTecnico>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the EstudioTecnico table using like.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<EstudioTecnico>
	 */
	@Transactional(readOnly = true)
	public List<EstudioTecnico> findAllLike(EstudioTecnico datosproyecto, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT  t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE,"
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE," + "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,"
				+ "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO," + "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,"
				+ "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA," + "t1.IMPORTE_RECURSO IMPORTERECURSO,"
				+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA," + "t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, "
				+ "t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, " + "t1.FECHA_INFORME FECHAINFORME,"
				+ "t1.FECHA_REGISTRO FECHAREGISTRO," + "t1.USUARIO_REGISTRO USUARIOREGISTRO,"
				+ "t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,"
				+ "t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,"
				+ "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE," + "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE,"
				+ "t2.FECHA_REGISTRO FECREGTECNICORESPONSABLE," + "t2.USUARIO_REGISTRO USUREGTECNICORESPONSABLE, "
				+ "t3.ID_RESULTADO IDTIPOSRESULTADO, " + "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
				+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
				+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "
				+ "t4.FECHA_REGISTRO MOTIVOSDESESTIMACIONFECREG, " + "t4.USUARIO_REGISTRO MOTIVOSDESESTIMACIONUSUREG ");
		query.append(
				"FROM DATOS_PROYECTO t1 , TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datosproyecto, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
						+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+)");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EstudioTecnicoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EstudioTecnico>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the EstudioTecnico table.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(EstudioTecnico datosproyecto) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM DATOS_PROYECTO t1 , TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(datosproyecto);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
						+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+)");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the EstudioTecnico table using like.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(EstudioTecnico datosproyecto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM DATOS_PROYECTO t1 ,TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datosproyecto, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
						+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+)");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of EstudioTecnico selected for rup_table
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	@Override
	public List<TableRowDto<EstudioTecnico>> reorderSelection(EstudioTecnico datosproyecto,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE,"
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE," + "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,"
				+ "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO," + "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,"
				+ "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA," + "t1.IMPORTE_RECURSO IMPORTERECURSO,"
				+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA," + "t1.FECHA_INFORME FECHAINFORME,"
				+ "t1.FECHA_REGISTRO FECHAREGISTRO," + "t1.USUARIO_REGISTRO USUARIOREGISTRO,"
				+ "t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,"
				+ "t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,"
				+ "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE," + "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE,"
				+ "t2.FECHA_REGISTRO FECREGTECNICORESPONSABLE," + "t2.USUARIO_REGISTRO USUREGTECNICORESPONSABLE , "
				+ "t3.ID_RESULTADO IDTIPOSRESULTADO, " + "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
				+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
				+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "
				+ "t4.FECHA_REGISTRO MOTIVOSDESESTIMACIONFECREG, " + "t4.USUARIO_REGISTRO MOTIVOSDESESTIMACIONUSUREG ");
		// FROM
		query.append("FROM DATOS_PROYECTO t1 ,TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(datosproyecto, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
						+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+)");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				EstudioTecnico.class, filterParamList, "ID_PROYECTO_EXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EstudioTecnico>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            EstudioTecnico
	 * @param searchParams
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	@Override
	public List<TableRowDto<EstudioTecnico>> search(EstudioTecnico filterParams, EstudioTecnico searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE,"
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE," + "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,"
				+ "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO," + "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,"
				+ "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA," + "t1.IMPORTE_RECURSO IMPORTERECURSO,"
				+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA," + "t1.FECHA_INFORME FECHAINFORME,"
				+ "t1.FECHA_REGISTRO FECHAREGISTRO," + "t1.USUARIO_REGISTRO USUARIOREGISTRO,"
				+ "t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,"
				+ "t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,"
				+ "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE," + "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE,"
				+ "t2.FECHA_REGISTRO FECREGTECNICORESPONSABLE," + "t2.USUARIO_REGISTRO USUREGTECNICORESPONSABLE, "
				+ "t3.ID_RESULTADO IDTIPOSRESULTADO, " + "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
				+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
				+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "
				+ "t4.FECHA_REGISTRO MOTIVOSDESESTIMACIONFECREG, " + "t4.USUARIO_REGISTRO MOTIVOSDESESTIMACIONUSUREG ");
		// FROM
		query.append("FROM DATOS_PROYECTO t1 ,TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TECNICO_RESPONSABLE= t2.ID_TECNICO_RESPONSABLE(+) "
						+ "AND t1.ID_RESULTADO= t3.ID_RESULTADO(+) AND t1.ID_MOTIVO_DESESTIMACION= t4.ID_MOTIVO_DESESTIMACION(+)");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				EstudioTecnico.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_PROYECTO_EXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EstudioTecnico>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterdatosproyecto
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(EstudioTecnico filterdatosproyecto, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE,"
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE," + "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,"
				+ "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO," + "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,"
				+ "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA," + "t1.IMPORTE_RECURSO IMPORTERECURSO,"
				+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA," + "t1.FECHA_INFORME FECHAINFORME,"
				+ "t1.FECHA_REGISTRO FECHAREGISTRO," + "t1.USUARIO_REGISTRO USUARIOREGISTRO,"
				+ "t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,"
				+ "t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,"
				+ "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE," + "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE,"
				+ "t2.FECHA_REGISTRO FECREGTECNICORESPONSABLE," + "t2.USUARIO_REGISTRO USUREGTECNICORESPONSABLE, "
				+ "t3.ID_RESULTADO IDTIPOSRESULTADO, " + "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
				+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
				+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "
				+ "t4.FECHA_REGISTRO MOTIVOSDESESTIMACIONFECREG, " + "t4.USUARIO_REGISTRO MOTIVOSDESESTIMACIONUSUREG ");
		// FROM
		query.append("FROM DATOS_PROYECTO t1 ,TECNICOS_RESPONSABLES t2, TIPOS_RESULTADO t3, MOTIVOS_DESESTIMACION t4 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterdatosproyecto, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, EstudioTecnico.class,
				query, params, "ID_PROYECTO_EXPEDIENTE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<EstudioTecnico>>
	 */
	@Override
	public List<JerarquiaDto<EstudioTecnico>> findAllLikeJerarquia(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE,"
				+ "t1.ID_EXPEDIENTE IDEXPEDIENTE," + "t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO,"
				+ "t1.IMPORTE_ADMITIDO IMPORTEADMITIDO," + "t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,"
				+ "t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA," + "t1.IMPORTE_RECURSO IMPORTERECURSO,"
				+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA," + "t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, "
				+ "t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, " + "t1.FECHA_INFORME FECHAINFORME,"
				+ "t1.FECHA_REGISTRO FECHAREGISTRO," + "t1.USUARIO_REGISTRO USUARIOREGISTRO,"
				+ "t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,"
				+ "t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,"
				+ "t2.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE," + "t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE,"
				+ "t2.FECHA_REGISTRO FECREGTECNICORESPONSABLE," + "t2.USUARIO_REGISTRO USUREGTECNICORESPONSABLE, "
				+ "t3.ID_RESULTADO IDTIPOSRESULTADO, " + "t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
				+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
				+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
				+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
				+ "t4.ID_MOTIVO_DESESTIMACION IDMOTIVOSDESESTIMACION, "
				+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, " + "t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA, "
				+ "t4.FECHA_REGISTRO MOTIVOSDESESTIMACIONFECREG, " + "t4.USUARIO_REGISTRO MOTIVOSDESESTIMACIONUSUREG ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_PROYECTO t1
		// ,TECNICOS_RESPONSABLES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_PROYECTO");
		from.add("TECNICOS_RESPONSABLES");
		from.add("TIPOS_RESULTADO");
		from.add("MOTIVOS_DESESTIMACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEstudioTecnico, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PROYECTO_EXPEDIENTE",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					EstudioTecnicoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_PROYECTO t1
		// ,TECNICOS_RESPONSABLES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_PROYECTO");
		from.add("TECNICOS_RESPONSABLES");
		from.add("TIPOS_RESULTADO");
		from.add("MOTIVOS_DESESTIMACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEstudioTecnico, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_PROYECTO_EXPEDIENTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	@Override
	public List<TableRowDto<EstudioTecnico>> findAllChild(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM DATOS_PROYECTO t1
		// ,TECNICOS_RESPONSABLES t2 ");
		List<String> from = new ArrayList<String>();
		from.add("DATOS_PROYECTO");
		from.add("TECNICOS_RESPONSABLES");
		from.add("TIPOS_RESULTADO");
		from.add("MOTIVOS_DESESTIMACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterEstudioTecnico, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_PROYECTO_EXPEDIENTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<EstudioTecnico>(this.rwMapPK, "ID_PROYECTO_EXPEDIENTE"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the EstudioTecnico entity
	 *
	 * @param datosproyecto
	 *            EstudioTecnico Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(EstudioTecnico datosproyecto) {

		StringBuilder where = new StringBuilder(EstudioTecnicoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (datosproyecto != null && datosproyecto.getIdProyectoExpediente() != null) {
			where.append(" AND t1.ID_PROYECTO_EXPEDIENTE = ?");
			params.add(datosproyecto.getIdProyectoExpediente());
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable() != null) {
			where.append(" AND t2.ID_TECNICO_RESPONSABLE = ?");
			params.add(datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable());
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getNombreTecnico() != null) {
			where.append(" AND t2.NOMBRE_TECNICO = ?");
			params.add(datosproyecto.getTecnicosResponsables().getNombreTecnico());
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(datosproyecto.getTecnicosResponsables().getFechaRegistro());
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(datosproyecto.getTecnicosResponsables().getUsuarioRegistro());
		}
		if (datosproyecto != null && datosproyecto.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(datosproyecto.getIdExpediente());
		}
		if (datosproyecto != null && datosproyecto.getImportePresentado() != null) {
			where.append(" AND t1.IMPORTE_PRESENTADO = ?");
			params.add(datosproyecto.getImportePresentado());
		}
		if (datosproyecto != null && datosproyecto.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(datosproyecto.getImporteAdmitido());
		}
		if (datosproyecto != null && datosproyecto.getSubvencionCalculada() != null) {
			where.append(" AND t1.SUBVENCION_CALCULADA = ?");
			params.add(datosproyecto.getSubvencionCalculada());
		}
		if (datosproyecto != null && datosproyecto.getSubvencionJustificada() != null) {
			where.append(" AND t1.SUBVENCION_JUSTIFICADA = ?");
			params.add(datosproyecto.getSubvencionJustificada());
		}
		if (datosproyecto != null && datosproyecto.getImporteRecurso() != null) {
			where.append(" AND t1.IMPORTE_RECURSO = ?");
			params.add(datosproyecto.getImporteRecurso());
		}
		if (datosproyecto != null && datosproyecto.getSubvencionResuelta() != null) {
			where.append(" AND t1.SUBVENCION_RESUELTA = ?");
			params.add(datosproyecto.getSubvencionResuelta());
		}
		if (datosproyecto != null && datosproyecto.getFechaInforme() != null) {
			where.append(" AND t1.FECHA_INFORME = ?");
			params.add(datosproyecto.getFechaInforme());
		}
		if (datosproyecto != null && datosproyecto.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(datosproyecto.getFechaRegistro());
		}
		if (datosproyecto != null && datosproyecto.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(datosproyecto.getUsuarioRegistro());
		}
		if (datosproyecto != null && datosproyecto.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(datosproyecto.getFechaUltmodificacion());
		}
		if (datosproyecto != null && datosproyecto.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(datosproyecto.getUsuarioUltmodificacion());
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getIdResultado() != null) {
			where.append(" AND t3.ID_RESULTADO = ?");
			params.add(datosproyecto.getTiposResultado().getIdResultado());
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getDescripcionCastellano() != null) {
			where.append(" AND t3.DESCRIPCION_CASTELLANO = ?");
			params.add(datosproyecto.getTiposResultado().getDescripcionCastellano());
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getDescripcionEuskera() != null) {
			where.append(" AND t3.DESCRIPCION_EUSKERA = ?");
			params.add(datosproyecto.getTiposResultado().getDescripcionEuskera());
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(datosproyecto.getTiposResultado().getUsuarioRegistro());
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getIdMotivoDesestimacion() != null) {
			where.append(" AND t4.ID_MOTIVO_DESESTIMACION = ?");
			params.add(datosproyecto.getMotivosDesestimacion().getIdMotivoDesestimacion());
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getDescripcionCastellano() != null) {
			where.append(" AND t4.DESCRIPCION_CASTELLANO = ?");
			params.add(datosproyecto.getMotivosDesestimacion().getDescripcionCastellano());
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getDescripcionEuskera() != null) {
			where.append(" AND t4.DESCRIPCION_EUSKERA = ?");
			params.add(datosproyecto.getMotivosDesestimacion().getDescripcionEuskera());
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getUsuarioRegistro() != null) {
			where.append(" AND t4.USUARIO_REGISTRO = ?");
			params.add(datosproyecto.getMotivosDesestimacion().getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the EstudioTecnico entity
	 *
	 * @param datosproyecto
	 *            EstudioTecnico Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(EstudioTecnico datosproyecto, Boolean startsWith) {

		StringBuilder where = new StringBuilder(EstudioTecnicoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (datosproyecto != null && datosproyecto.getIdProyectoExpediente() != null) {
			where.append(" AND t1.ID_PROYECTO_EXPEDIENTE = ?");
			params.add(datosproyecto.getIdProyectoExpediente());
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable() != null) {
			where.append(" AND t2.ID_TECNICO_RESPONSABLE = ?");
			params.add(datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable());
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getNombreTecnico() != null) {
			where.append(" AND UPPER(t2.NOMBRE_TECNICO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getTecnicosResponsables().getNombreTecnico().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getTecnicosResponsables().getNombreTecnico().toUpperCase() + "%");
			}
			where.append(" AND t2.NOMBRE_TECNICO IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(datosproyecto.getTecnicosResponsables().getFechaRegistro());
		}
		if (datosproyecto != null && datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getTecnicosResponsables().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getTecnicosResponsables().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(datosproyecto.getIdExpediente());
		}
		if (datosproyecto != null && datosproyecto.getImportePresentado() != null) {
			where.append(" AND t1.IMPORTE_PRESENTADO = ?");
			params.add(datosproyecto.getImportePresentado());
		}
		if (datosproyecto != null && datosproyecto.getImporteAdmitido() != null) {
			where.append(" AND t1.IMPORTE_ADMITIDO = ?");
			params.add(datosproyecto.getImporteAdmitido());
		}
		if (datosproyecto != null && datosproyecto.getSubvencionCalculada() != null) {
			where.append(" AND t1.SUBVENCION_CALCULADA = ?");
			params.add(datosproyecto.getSubvencionCalculada());
		}
		if (datosproyecto != null && datosproyecto.getSubvencionJustificada() != null) {
			where.append(" AND t1.SUBVENCION_JUSTIFICADA = ?");
			params.add(datosproyecto.getSubvencionJustificada());
		}
		if (datosproyecto != null && datosproyecto.getImporteRecurso() != null) {
			where.append(" AND t1.IMPORTE_RECURSO = ?");
			params.add(datosproyecto.getImporteRecurso());
		}
		if (datosproyecto != null && datosproyecto.getSubvencionResuelta() != null) {
			where.append(" AND t1.SUBVENCION_RESUELTA = ?");
			params.add(datosproyecto.getSubvencionResuelta());
		}
		if (datosproyecto != null && datosproyecto.getFechaInforme() != null) {
			where.append(" AND t1.FECHA_INFORME = ?");
			params.add(datosproyecto.getFechaInforme());
		}
		if (datosproyecto != null && datosproyecto.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(datosproyecto.getFechaRegistro());
		}
		if (datosproyecto != null && datosproyecto.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(datosproyecto.getFechaUltmodificacion());
		}
		if (datosproyecto != null && datosproyecto.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getIdResultado() != null) {
			where.append(" AND t3.ID_RESULTADO = ?");
			params.add(datosproyecto.getTiposResultado().getIdResultado());
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getTiposResultado().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getTiposResultado().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getTiposResultado().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getTiposResultado().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(datosproyecto.getTiposResultado().getFechaRegistro());
		}
		if (datosproyecto != null && datosproyecto.getTiposResultado() != null
				&& datosproyecto.getTiposResultado().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getTiposResultado().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getTiposResultado().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getIdMotivoDesestimacion() != null) {
			where.append(" AND t4.ID_MOTIVO_DESESTIMACION = ?");
			params.add(datosproyecto.getTiposResultado().getIdResultado());
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t4.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getMotivosDesestimacion().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add(
						"%" + datosproyecto.getMotivosDesestimacion().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t4.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t4.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getMotivosDesestimacion().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getMotivosDesestimacion().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t4.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getFechaRegistro() != null) {
			where.append(" AND t4.FECHA_REGISTRO = ?");
			params.add(datosproyecto.getMotivosDesestimacion().getFechaRegistro());
		}
		if (datosproyecto != null && datosproyecto.getMotivosDesestimacion() != null
				&& datosproyecto.getMotivosDesestimacion().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t4.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(datosproyecto.getMotivosDesestimacion().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + datosproyecto.getMotivosDesestimacion().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t4.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	/**
	 * retornamos SUBVENCION_RESUELTA, sumando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6006T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @return EstudioTecnico
	 */
	public EstudioTecnico retornarSubvencionResueltaPorAccionSubencionable(Integer idExpediente) {
		String query = "SELECT T2.IMPORTE_DISPONIBLE + t3.SUBVENCION_RESUELTA AS IMPORTEFINAL, t2.ID_ACT_SUB IDACTSUB FROM REL_EXP_ACT_SUB t1 , ACT_SUBVENCIONABLE T2, DATOS_PROYECTO t3, CONVOCATORIAS t4, EXPEDIENTES t5 WHERE t1.ID_ACT_SUB        =t2.ID_ACT_SUB AND t1.ID_EXPEDIENTE       = ? AND t2.IMPORTE_DISPONIBLE IS NOT NULL AND t1.ID_EXPEDIENTE       = t3.ID_EXPEDIENTE AND T5.ID_EXPEDIENTE       = T1.ID_EXPEDIENTE AND T5.ID_PROCEDIMIENTO    = T4.ID_PROCEDIMIENTO";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapImporteFinalActSubvencionable,
				idExpediente);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	@Override
	public void updateExepto(Integer idExpediente, Integer exeptoHidden) {
		String query = "UPDATE REL_MUN_ASO_COM SET EXENTOIVA= ? WHERE ID_EXPEDIENTE= ?";
		this.jdbcTemplate.update(query, exeptoHidden, idExpediente);

	}

	@Override
	public EstudioTecnico findImporteProyecto(Integer idExpediente) {
		String query = "SELECT IMPORTE_PRESENTADO IMPORTEPRESENTADO FROM DATOS_PROYECTO WHERE ID_EXPEDIENTE = ?";
		List<EstudioTecnico> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapImportePresentado,
				idExpediente);
		return (EstudioTecnico) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	@Override
	public void updateImporteJusOTC(EstudioTecnico estudioTecnico) {
		String query = "UPDATE DATOS_PROYECTO SET IMPORTE_JUS_ADMITIDO= ?, FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, estudioTecnico.getImporteAdmitido(), estudioTecnico.getFechaUltmodificacion(),
				estudioTecnico.getUsuarioUltmodificacion(), estudioTecnico.getIdExpediente());
	}
}
