package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.Horarios;

/**
 * HorariosDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class HorariosDaoImpl implements HorariosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDHORARIO", "IDCONVOCATORIA",
			"DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Horarios> rwMap = new RowMapper<Horarios>() {
		public Horarios mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Horarios(resultSet.getLong("IDHORARIO"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<Horarios> rwMapPK = new RowMapper<Horarios>() {
		public Horarios mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Horarios(resultSet.getLong("IDHORARIO"));
		}
	};

	private RowMapper<Integer> rwMapRelPobHor = new RowMapper<Integer>() {
		public Integer mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return resultSet.getInt("IDHORARIO");
		}
	};
	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Horarios>> rwMapJerarquia = new RowMapper<JerarquiaDto<Horarios>>() {
		public JerarquiaDto<Horarios> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Horarios horarios = new Horarios(resultSet.getLong("IDHORARIO"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<Horarios> jerarquia = new JerarquiaDto<Horarios>();
			jerarquia.setModel(horarios);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return Horarios
	 */
	public Horarios add(Horarios horarios) {
		String query = "INSERT INTO HORARIOS (ID_HORARIO, ID_CONVOCATORIA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, horarios.getIdHorario(), horarios.getIdConvocatoria(),
				horarios.getDescripcionCastellano(), horarios.getDescripcionEuskera(), horarios.getFechaRegistro(),
				horarios.getUsuarioRegistro());
		return horarios;
	}

	/**
	 * Updates a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return Horarios
	 */
	public Horarios update(Horarios horarios) {
		String query = "UPDATE HORARIOS SET ID_CONVOCATORIA=?, DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_HORARIO=?";
		this.jdbcTemplate.update(query, horarios.getIdConvocatoria(), horarios.getDescripcionCastellano(),
				horarios.getDescripcionEuskera(), horarios.getFechaRegistro(), horarios.getUsuarioRegistro(),
				horarios.getIdHorario());
		return horarios;
	}

	/**
	 * Finds a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return Horarios
	 */
	@Transactional(readOnly = true)
	public Horarios find(Horarios horarios) {
		String query = "SELECT t1.ID_HORARIO IDHORARIO, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM HORARIOS t1  WHERE t1.ID_HORARIO = ?  ";

		List<Horarios> horariosList = this.jdbcTemplate.query(query, this.rwMap, horarios.getIdHorario());
		return (Horarios) DataAccessUtils.uniqueResult(horariosList);
	}

	/**
	 * Removes a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return
	 */
	public void remove(Horarios horarios) {
		String query = "DELETE FROM HORARIOS WHERE ID_HORARIO=?";
		this.jdbcTemplate.update(query, horarios.getIdHorario());
	}

	/**
	 * Finds a list of rows in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Horarios>
	 */
	@Transactional(readOnly = true)
	public List<Horarios> findAll(Horarios horarios, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_HORARIO IDHORARIO,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM HORARIOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(horarios);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, HorariosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Horarios>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds a list of rows in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Horarios>
	 */
	@Transactional(readOnly = true)
	public List<Horarios> findByPoblacion(Integer idPoblacion, Integer idConvocatoria) {
		List<Integer> idsHorarios = this.jdbcTemplate.query(
				"SELECT ID_HORARIO IDHORARIO FROM REL_POB_HOR WHERE ID_POBLACION = " + idPoblacion,
				this.rwMapRelPobHor);

		if (idsHorarios != null && !idsHorarios.isEmpty()) {
			String query = "SELECT  t1.ID_HORARIO IDHORARIO,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO FROM HORARIOS t1"
					+ " WHERE ID_HORARIO IN (";

			String where = "";
			for (Integer id : idsHorarios) {
				where = where + "'" + id + "',";
			}
			if (where.endsWith(",")) {
				where = where.substring(0, where.length() - 1);
			}
			query = query + where + ") AND ID_CONVOCATORIA = " + idConvocatoria;

			return (List<Horarios>) this.jdbcTemplate.query(query, this.rwMap);
		} else {
			return new ArrayList<Horarios>();
		}

	}

	/**
	 * Finds rows in the Horarios table using like.
	 *
	 * @param horarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Horarios>
	 */
	@Transactional(readOnly = true)
	public List<Horarios> findAllLike(Horarios horarios, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_HORARIO IDHORARIO,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM HORARIOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(horarios, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, HorariosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Horarios>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Horarios horarios) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM HORARIOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(horarios);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Horarios table using like.
	 *
	 * @param horarios
	 *            Horarios
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Horarios horarios, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM HORARIOS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(horarios, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Horarios selected for rup_table
	 *
	 * @param horarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Horarios>>
	 */
	@Override
	public List<TableRowDto<Horarios>> reorderSelection(Horarios horarios, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HORARIO IDHORARIO,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM HORARIOS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(horarios, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Horarios.class,
				filterParamList, "ID_HORARIO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Horarios>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Horarios
	 * @param searchParams
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Horarios>>
	 */
	@Override
	public List<TableRowDto<Horarios>> search(Horarios filterParams, Horarios searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HORARIO IDHORARIO,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM HORARIOS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Horarios.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_HORARIO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Horarios>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterhorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Horarios filterhorarios, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HORARIO IDHORARIO,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM HORARIOS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterhorarios, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Horarios.class,
				query, params, "ID_HORARIO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Horarios table.
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Horarios>>
	 */
	@Override
	public List<JerarquiaDto<Horarios>> findAllLikeJerarquia(Horarios filterHorarios,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HORARIO IDHORARIO,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM HORARIOS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("HORARIOS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterHorarios, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_HORARIO", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					HorariosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Horarios filterHorarios, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM HORARIOS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("HORARIOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterHorarios, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_HORARIO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Horarios>>
	 */
	@Override
	public List<TableRowDto<Horarios>> findAllChild(Horarios filterHorarios, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM HORARIOS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("HORARIOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterHorarios, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_HORARIO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Horarios>(this.rwMapPK, "ID_HORARIO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Horarios entity
	 *
	 * @param horarios
	 *            Horarios Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Horarios horarios) {

		StringBuilder where = new StringBuilder(HorariosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (horarios != null && horarios.getIdHorario() != null) {
			where.append(" AND t1.ID_HORARIO = ?");
			params.add(horarios.getIdHorario());
		}
		if (horarios != null && horarios.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(horarios.getIdConvocatoria());
		}
		if (horarios != null && horarios.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(horarios.getDescripcionCastellano());
		}
		if (horarios != null && horarios.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(horarios.getDescripcionEuskera());
		}
		if (horarios != null && horarios.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(horarios.getFechaRegistro());
		}
		if (horarios != null && horarios.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(horarios.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Horarios entity
	 *
	 * @param horarios
	 *            Horarios Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Horarios horarios, Boolean startsWith) {

		StringBuilder where = new StringBuilder(HorariosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (horarios != null && horarios.getIdHorario() != null) {
			where.append(" AND t1.ID_HORARIO = ?");
			params.add(horarios.getIdHorario());
		}
		if (horarios != null && horarios.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(horarios.getIdConvocatoria());
		}
		if (horarios != null && horarios.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(horarios.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + horarios.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (horarios != null && horarios.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(horarios.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + horarios.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (horarios != null && horarios.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(horarios.getFechaRegistro());
		}
		if (horarios != null && horarios.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(horarios.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + horarios.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
