package com.ejie.ab60.dao.estudioTecnico;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * MotivosDenegacionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class MotivosDenegacionDaoImpl implements MotivosDenegacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMOTIVODENEGACION", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "ORIGEN", "IDCONVOCATORIA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<MotivosDenegacion> rwMap = new RowMapper<MotivosDenegacion>() {
		public MotivosDenegacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			MotivosDenegacion motivosDenegacion = new MotivosDenegacion();

			motivosDenegacion.setIdMotivoDenegacion(resultSet.getLong("IDMOTIVODENEGACION"));
			motivosDenegacion.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			motivosDenegacion.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			motivosDenegacion.setOrigen(resultSet.getInt("ORIGEN"));
			Convocatorias convocatoria = new Convocatorias(resultSet.getInt("IDCONVOCATORIA"));
			motivosDenegacion.setConvocatoria(convocatoria);

			return motivosDenegacion;
		}
	};

	private RowMapper<MotivosDenegacion> rwMapCombo = new RowMapper<MotivosDenegacion>() {
		public MotivosDenegacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			MotivosDenegacion motivosDenegacion = new MotivosDenegacion();

			motivosDenegacion.setIdMotivoDenegacion(resultSet.getLong("IDMOTIVODENEGACION"));
			motivosDenegacion.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			motivosDenegacion.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			return motivosDenegacion;
		}
	};

	private RowMapper<MotivosDenegacion> rwMapPK = new RowMapper<MotivosDenegacion>() {
		public MotivosDenegacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosDenegacion(resultSet.getLong("IDMOTIVODENEGACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<MotivosDenegacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<MotivosDenegacion>>() {
		public JerarquiaDto<MotivosDenegacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MotivosDenegacion motivosdenegacion = new MotivosDenegacion(resultSet.getLong("IDMOTIVODENEGACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<MotivosDenegacion> jerarquia = new JerarquiaDto<MotivosDenegacion>();
			jerarquia.setModel(motivosdenegacion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the MotivosDenegacion table.
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @return MotivosDenegacion
	 */
	public MotivosDenegacion add(MotivosDenegacion motivosdenegacion) {
		String query = "INSERT INTO MOTIVOS_DENEGACION (ID_MOTIVO_DENEGACION, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, ORIGEN, ID_CONVOCATORIA, BAJA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?)";
		motivosdenegacion
				.setIdMotivoDenegacion(this.jdbcTemplate.queryForLong("SELECT AB60.S_AB6020T00.NEXTVAL FROM DUAL"));
		this.jdbcTemplate.update(query, motivosdenegacion.getIdMotivoDenegacion(),
				motivosdenegacion.getDescripcionCastellano(), motivosdenegacion.getDescripcionEuskera(),
				motivosdenegacion.getOrigen(), motivosdenegacion.getConvocatoria().getIdConvocatoria(),
				Constantes.NO_BAJA, motivosdenegacion.getFechaRegistro(), motivosdenegacion.getUsuarioRegistro());
		return motivosdenegacion;
	}

	/**
	 * Updates a single row in the MotivosDenegacion table.
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @return MotivosDenegacion
	 */
	public MotivosDenegacion update(MotivosDenegacion motivosdenegacion) {
		String query = "UPDATE MOTIVOS_DENEGACION SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, ORIGEN=?, ID_CONVOCATORIA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_MOTIVO_DENEGACION=?";
		this.jdbcTemplate.update(query, motivosdenegacion.getDescripcionCastellano(),
				motivosdenegacion.getDescripcionEuskera(), motivosdenegacion.getOrigen(),
				motivosdenegacion.getConvocatoria().getIdConvocatoria(), motivosdenegacion.getFechaUltModificacion(),
				motivosdenegacion.getUsuarioUltModificacion(), motivosdenegacion.getIdMotivoDenegacion());
		return motivosdenegacion;
	}

	/**
	 * Lista de motivos de dengacion
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public List<MotivosDenegacion> findDenegacionActSubvencionable(Integer idConvocatoria, Integer origen,
			Integer idRelExpActSub) {

		StringBuilder query = new StringBuilder();
		List<Object> params = new ArrayList<Object>();

		query.append(
				"SELECT t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_DENEGACION t1");
		query.append(" WHERE ID_CONVOCATORIA = ?");
		params.add(idConvocatoria);
		query.append(" AND ORIGEN = ?");
		params.add(origen);
		query.append(" AND (BAJA = ? OR BAJA IS NULL)");
		params.add(Constantes.NO_BAJA);

		query.append(" UNION");

		query.append(
				" SELECT  t20.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION, t20.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t20.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_DENEGACION t20, REL_ACT_SUB_MOT_DEN t1");
		query.append(" WHERE t20.ID_MOTIVO_DENEGACION = t1.ID_MOTIVO_DENEGACION");
		query.append(" AND t20.ORIGEN = ?");
		params.add(origen);
		query.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
		params.add(idRelExpActSub);

		return this.jdbcTemplate.query(query.toString(), this.rwMapCombo, params.toArray());

	}

	@Override
	public List<MotivosDenegacion> findDenegacionFacturas(Integer idConvocatoria, Integer origen, Integer idFactura) {

		StringBuilder query = new StringBuilder();
		List<Object> params = new ArrayList<Object>();

		query.append(
				"SELECT t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_DENEGACION t1");
		query.append(" WHERE ID_CONVOCATORIA = ?");
		params.add(idConvocatoria);
		query.append(" AND ORIGEN = ?");
		params.add(origen);
		query.append(" AND (BAJA = ? OR BAJA IS NULL)");
		params.add(Constantes.NO_BAJA);

		query.append(" UNION");

		query.append(
				" SELECT  t20.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION, t20.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t20.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_DENEGACION t20, REL_FAC_MOT_DEN t1");
		query.append(" WHERE t20.ID_MOTIVO_DENEGACION = t1.ID_MOTIVO_DENEGACION");
		query.append(" AND t20.ORIGEN = ?");
		params.add(origen);
		query.append(" AND t1.ID_FACTURA = ?");
		params.add(idFactura);

		return this.jdbcTemplate.query(query.toString(), this.rwMapCombo, params.toArray());

	}

	/**
	 * Finds a single row in the MotivosDenegacion table.
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @return MotivosDenegacion
	 */
	@Transactional(readOnly = true)
	public MotivosDenegacion find(MotivosDenegacion motivosdenegacion) {
		String query = "SELECT t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ORIGEN ORIGEN, t1.ID_CONVOCATORIA IDCONVOCATORIA FROM MOTIVOS_DENEGACION t1  WHERE t1.ID_MOTIVO_DENEGACION = ?  ";

		List<MotivosDenegacion> motivosdenegacionList = this.jdbcTemplate.query(query, this.rwMap,
				motivosdenegacion.getIdMotivoDenegacion());
		return (MotivosDenegacion) DataAccessUtils.uniqueResult(motivosdenegacionList);
	}

	/**
	 * Baja lógica
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion *
	 * 
	 */
	public void remove(MotivosDenegacion motivosDenegacion) {
		String query = "UPDATE MOTIVOS_DENEGACION SET BAJA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_MOTIVO_DENEGACION = ?";

		this.jdbcTemplate.update(query, motivosDenegacion.getBaja(), motivosDenegacion.getFechaUltModificacion(),
				motivosDenegacion.getUsuarioUltModificacion(), motivosDenegacion.getIdMotivoDenegacion());
	}

	/**
	 * Finds a list of rows in the MotivosDenegacion table.
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<MotivosDenegacion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosDenegacion> findAll(MotivosDenegacion motivosdenegacion, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.ORIGEN AS ORIGEN, t1.ID_CONVOCATORIA IDCONVOCATORIA");
		query.append(" FROM MOTIVOS_DENEGACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosdenegacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosDenegacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosDenegacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the MotivosDenegacion table using like.
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<MotivosDenegacion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosDenegacion> findAllLike(MotivosDenegacion motivosdenegacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ORIGEN AS ORIGEN ");
		query.append("FROM MOTIVOS_DENEGACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosdenegacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosDenegacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosDenegacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the MotivosDenegacion table.
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(MotivosDenegacion motivosdenegacion) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_DENEGACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosdenegacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the MotivosDenegacion table using like.
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(MotivosDenegacion motivosdenegacion, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_DENEGACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosdenegacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of MotivosDenegacion selected for rup_table
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosDenegacion>>
	 */
	@Override
	public List<TableRowDto<MotivosDenegacion>> reorderSelection(MotivosDenegacion motivosdenegacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_DENEGACION t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosdenegacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				MotivosDenegacion.class, filterParamList, "ID_MOTIVO_DENEGACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosDenegacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            MotivosDenegacion
	 * @param searchParams
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosDenegacion>>
	 */
	@Override
	public List<TableRowDto<MotivosDenegacion>> search(MotivosDenegacion filterParams, MotivosDenegacion searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_DENEGACION t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				MotivosDenegacion.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_MOTIVO_DENEGACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosDenegacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtermotivosdenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(MotivosDenegacion filtermotivosdenegacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_DENEGACION t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtermotivosdenegacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				MotivosDenegacion.class, query, params, "ID_MOTIVO_DENEGACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical MotivosDenegacion table.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<MotivosDenegacion>>
	 */
	@Override
	public List<JerarquiaDto<MotivosDenegacion>> findAllLikeJerarquia(MotivosDenegacion filterMotivosDenegacion,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DENEGACION IDMOTIVODENEGACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ORIGEN AS ORIGEN ");
		// FROM
		query.append("FROM MOTIVOS_DENEGACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(filterMotivosDenegacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_DENEGACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		// Map<String, ?> mapaWhere =
		// this.getWhereLikeMap(filterMotivosDenegacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MOTIVO_DENEGACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					MotivosDenegacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(MotivosDenegacion filterMotivosDenegacion,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_DENEGACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_DENEGACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosDenegacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_MOTIVO_DENEGACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<MotivosDenegacion>>
	 */
	@Override
	public List<TableRowDto<MotivosDenegacion>> findAllChild(MotivosDenegacion filterMotivosDenegacion,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_DENEGACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_DENEGACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosDenegacion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_MOTIVO_DENEGACION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<MotivosDenegacion>(this.rwMapPK, "ID_MOTIVO_DENEGACION"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosDenegacion entity
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(MotivosDenegacion motivosdenegacion) {

		StringBuilder where = new StringBuilder(MotivosDenegacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();
		if (motivosdenegacion != null && motivosdenegacion.getConvocatoria().getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(motivosdenegacion.getConvocatoria().getIdConvocatoria());
		}
		if (motivosdenegacion != null && motivosdenegacion.getBaja() != null
				&& motivosdenegacion.getBaja() == Constantes.BAJA) {
			where.append(" AND t1.BAJA = ?");
			params.add(motivosdenegacion.getBaja());
		} else if (motivosdenegacion != null && motivosdenegacion.getBaja() != null
				&& motivosdenegacion.getBaja() == Constantes.NO_BAJA) {
			where.append(" AND (t1.BAJA = ? OR t1.BAJA IS NULL)");
			params.add(motivosdenegacion.getBaja());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosDenegacion entity
	 *
	 * @param motivosdenegacion
	 *            MotivosDenegacion Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(MotivosDenegacion motivosdenegacion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(MotivosDenegacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();
		if (motivosdenegacion != null && motivosdenegacion.getConvocatoria().getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(motivosdenegacion.getConvocatoria().getIdConvocatoria());
		}
		if (motivosdenegacion != null && motivosdenegacion.getIdMotivoDenegacion() != null) {
			where.append(" AND t1.ID_MOTIVO_DENEGACION = ?");
			params.add(motivosdenegacion.getIdMotivoDenegacion());
		}
		if (motivosdenegacion != null && motivosdenegacion.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosdenegacion.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + motivosdenegacion.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (motivosdenegacion != null && motivosdenegacion.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosdenegacion.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + motivosdenegacion.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (motivosdenegacion != null && motivosdenegacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(motivosdenegacion.getFechaRegistro());
		}
		if (motivosdenegacion != null && motivosdenegacion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosdenegacion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + motivosdenegacion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

}
