package com.ejie.ab60.dao.estudioTecnico;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.MotivosDesestimacion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * MotivosDesestimacionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class MotivosDesestimacionDaoImpl implements MotivosDesestimacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMOTIVODESESTIMACION", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<MotivosDesestimacion> rwMap = new RowMapper<MotivosDesestimacion>() {
		public MotivosDesestimacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<MotivosDesestimacion> rwMapMotivo = new RowMapper<MotivosDesestimacion>() {
		public MotivosDesestimacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"));
		}
	};
	private RowMapper<MotivosDesestimacion> rwMapPK = new RowMapper<MotivosDesestimacion>() {
		public MotivosDesestimacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosDesestimacion(resultSet.getLong("IDMOTIVODESESTIMACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<MotivosDesestimacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<MotivosDesestimacion>>() {
		public JerarquiaDto<MotivosDesestimacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MotivosDesestimacion motivosdesestimacion = new MotivosDesestimacion(
					resultSet.getLong("IDMOTIVODESESTIMACION"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<MotivosDesestimacion> jerarquia = new JerarquiaDto<MotivosDesestimacion>();
			jerarquia.setModel(motivosdesestimacion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the MotivosDesestimacion table.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @return MotivosDesestimacion
	 */
	public MotivosDesestimacion add(MotivosDesestimacion motivosdesestimacion) {
		String query = "INSERT INTO MOTIVOS_DESESTIMACION (ID_MOTIVO_DESESTIMACION, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, motivosdesestimacion.getIdMotivoDesestimacion(),
				motivosdesestimacion.getDescripcionCastellano(), motivosdesestimacion.getDescripcionEuskera(),
				motivosdesestimacion.getFechaRegistro(), motivosdesestimacion.getUsuarioRegistro());
		return motivosdesestimacion;
	}

	/**
	 * Updates a single row in the MotivosDesestimacion table.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @return MotivosDesestimacion
	 */
	public MotivosDesestimacion update(MotivosDesestimacion motivosdesestimacion) {
		String query = "UPDATE MOTIVOS_DESESTIMACION SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_MOTIVO_DESESTIMACION=?";
		this.jdbcTemplate.update(query, motivosdesestimacion.getDescripcionCastellano(),
				motivosdesestimacion.getDescripcionEuskera(), motivosdesestimacion.getFechaRegistro(),
				motivosdesestimacion.getUsuarioRegistro(), motivosdesestimacion.getIdMotivoDesestimacion());
		return motivosdesestimacion;
	}

	/**
	 * Finds a single row in the MotivosDesestimacion table.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @return MotivosDesestimacion
	 */
	@Transactional(readOnly = true)
	public MotivosDesestimacion find(MotivosDesestimacion motivosdesestimacion) {
		String query = "SELECT t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM MOTIVOS_DESESTIMACION t1  WHERE t1.ID_MOTIVO_DESESTIMACION = ?  ";

		List<MotivosDesestimacion> motivosdesestimacionList = this.jdbcTemplate.query(query, this.rwMap,
				motivosdesestimacion.getIdMotivoDesestimacion());
		return (MotivosDesestimacion) DataAccessUtils.uniqueResult(motivosdesestimacionList);
	}

	/**
	 * Removes a single row in the MotivosDesestimacion table.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @return
	 */
	public void remove(MotivosDesestimacion motivosdesestimacion) {
		String query = "DELETE FROM MOTIVOS_DESESTIMACION WHERE ID_MOTIVO_DESESTIMACION=?";
		this.jdbcTemplate.update(query, motivosdesestimacion.getIdMotivoDesestimacion());
	}

	/**
	 * Finds a list of rows in the MotivosDesestimacion table.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<MotivosDesestimacion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosDesestimacion> findAll(MotivosDesestimacion motivosdesestimacion,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM MOTIVOS_DESESTIMACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosdesestimacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosDesestimacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosDesestimacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the MotivosDesestimacion table using like.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<MotivosDesestimacion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosDesestimacion> findAllLike(MotivosDesestimacion motivosdesestimacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM MOTIVOS_DESESTIMACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosdesestimacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosDesestimacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosDesestimacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the MotivosDesestimacion table.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(MotivosDesestimacion motivosdesestimacion) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_DESESTIMACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosdesestimacion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the MotivosDesestimacion table using like.
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(MotivosDesestimacion motivosdesestimacion, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_DESESTIMACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosdesestimacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Finds a list of rows in the Motivos table.
	 *
	 * 
	 * @return List<MotivosDesestimacion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosDesestimacion> findMotivo() {
		String query = "SELECT t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM MOTIVOS_DESESTIMACION t1";
		return (List<MotivosDesestimacion>) this.jdbcTemplate.query(query, this.rwMapMotivo);

	}

	/**
	 * Reorder the data list of MotivosDesestimacion selected for rup_table
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosDesestimacion>>
	 */
	@Override
	public List<TableRowDto<MotivosDesestimacion>> reorderSelection(MotivosDesestimacion motivosdesestimacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_DESESTIMACION t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosdesestimacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				MotivosDesestimacion.class, filterParamList, "ID_MOTIVO_DESESTIMACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosDesestimacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            MotivosDesestimacion
	 * @param searchParams
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosDesestimacion>>
	 */
	@Override
	public List<TableRowDto<MotivosDesestimacion>> search(MotivosDesestimacion filterParams,
			MotivosDesestimacion searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_DESESTIMACION t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				MotivosDesestimacion.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_MOTIVO_DESESTIMACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosDesestimacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtermotivosdesestimacion
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(MotivosDesestimacion filtermotivosdesestimacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_DESESTIMACION t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtermotivosdesestimacion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				MotivosDesestimacion.class, query, params, "ID_MOTIVO_DESESTIMACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical MotivosDesestimacion table.
	 *
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<MotivosDesestimacion>>
	 */
	@Override
	public List<JerarquiaDto<MotivosDesestimacion>> findAllLikeJerarquia(
			MotivosDesestimacion filterMotivosDesestimacion, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_DESESTIMACION IDMOTIVODESESTIMACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_DESESTIMACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_DESESTIMACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosDesestimacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MOTIVO_DESESTIMACION",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					MotivosDesestimacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(MotivosDesestimacion filterMotivosDesestimacion,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_DESESTIMACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_DESESTIMACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosDesestimacion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_MOTIVO_DESESTIMACION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<MotivosDesestimacion>>
	 */
	@Override
	public List<TableRowDto<MotivosDesestimacion>> findAllChild(MotivosDesestimacion filterMotivosDesestimacion,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_DESESTIMACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_DESESTIMACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosDesestimacion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_MOTIVO_DESESTIMACION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<MotivosDesestimacion>(this.rwMapPK, "ID_MOTIVO_DESESTIMACION"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosDesestimacion entity
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(MotivosDesestimacion motivosdesestimacion) {

		StringBuilder where = new StringBuilder(MotivosDesestimacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (motivosdesestimacion != null && motivosdesestimacion.getIdMotivoDesestimacion() != null) {
			where.append(" AND t1.ID_MOTIVO_DESESTIMACION = ?");
			params.add(motivosdesestimacion.getIdMotivoDesestimacion());
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(motivosdesestimacion.getDescripcionCastellano());
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(motivosdesestimacion.getDescripcionEuskera());
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(motivosdesestimacion.getFechaRegistro());
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(motivosdesestimacion.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosDesestimacion entity
	 *
	 * @param motivosdesestimacion
	 *            MotivosDesestimacion Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(MotivosDesestimacion motivosdesestimacion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(MotivosDesestimacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (motivosdesestimacion != null && motivosdesestimacion.getIdMotivoDesestimacion() != null) {
			where.append(" AND t1.ID_MOTIVO_DESESTIMACION = ?");
			params.add(motivosdesestimacion.getIdMotivoDesestimacion());
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosdesestimacion.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + motivosdesestimacion.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosdesestimacion.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + motivosdesestimacion.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(motivosdesestimacion.getFechaRegistro());
		}
		if (motivosdesestimacion != null && motivosdesestimacion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosdesestimacion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + motivosdesestimacion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

}
