package com.ejie.ab60.dao.estudioTecnico;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.estudioTecnico.MotivosMinoracion;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * MotivosMinoracionDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class MotivosMinoracionDaoImpl implements MotivosMinoracionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMOTIVOMINORACION", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "ORIGEN", "IDCONVOCATORIA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<MotivosMinoracion> rwMap = new RowMapper<MotivosMinoracion>() {
		public MotivosMinoracion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			MotivosMinoracion motivosMinoracion = new MotivosMinoracion();

			motivosMinoracion.setIdMotivoMinoracion(resultSet.getLong("IDMOTIVOMINORACION"));
			motivosMinoracion.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			motivosMinoracion.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			motivosMinoracion.setOrigen(resultSet.getInt("ORIGEN"));
			Convocatorias convocatoria = new Convocatorias(resultSet.getInt("IDCONVOCATORIA"));
			motivosMinoracion.setConvocatoria(convocatoria);

			return motivosMinoracion;
		}
	};

	private RowMapper<MotivosMinoracion> rwMapCombo = new RowMapper<MotivosMinoracion>() {
		public MotivosMinoracion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			MotivosMinoracion motivosMinoracion = new MotivosMinoracion();

			motivosMinoracion.setIdMotivoMinoracion(resultSet.getLong("IDMOTIVOMINORACION"));
			motivosMinoracion.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			motivosMinoracion.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			return motivosMinoracion;
		}
	};

	private RowMapper<MotivosMinoracion> rwMapPK = new RowMapper<MotivosMinoracion>() {
		public MotivosMinoracion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosMinoracion(resultSet.getLong("IDMOTIVOMINORACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<MotivosMinoracion>> rwMapJerarquia = new RowMapper<JerarquiaDto<MotivosMinoracion>>() {
		public JerarquiaDto<MotivosMinoracion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MotivosMinoracion motivosminoracion = new MotivosMinoracion(resultSet.getLong("IDMOTIVOMINORACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<MotivosMinoracion> jerarquia = new JerarquiaDto<MotivosMinoracion>();
			jerarquia.setModel(motivosminoracion);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the MotivosMinoracion table.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @return MotivosMinoracion
	 */
	public MotivosMinoracion add(MotivosMinoracion motivosminoracion) {
		String query = "INSERT INTO MOTIVOS_MINORACION (ID_MOTIVO_MINORACION, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, ORIGEN, ID_CONVOCATORIA, BAJA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?)";
		motivosminoracion
				.setIdMotivoMinoracion(this.jdbcTemplate.queryForLong("SELECT AB60.S_AB6025T00.NEXTVAL FROM DUAL"));
		this.jdbcTemplate.update(query, motivosminoracion.getIdMotivoMinoracion(),
				motivosminoracion.getDescripcionCastellano(), motivosminoracion.getDescripcionEuskera(),
				motivosminoracion.getOrigen(), motivosminoracion.getConvocatoria().getIdConvocatoria(),
				Constantes.NO_BAJA, motivosminoracion.getFechaRegistro(), motivosminoracion.getUsuarioRegistro());
		return motivosminoracion;
	}

	/**
	 * Updates a single row in the MotivosMinoracion table.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @return MotivosMinoracion
	 */
	public MotivosMinoracion update(MotivosMinoracion motivosminoracion) {
		String query = "UPDATE MOTIVOS_MINORACION SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?,ORIGEN = ?, ID_CONVOCATORIA=?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_MOTIVO_MINORACION=?";
		this.jdbcTemplate.update(query, motivosminoracion.getDescripcionCastellano(),
				motivosminoracion.getDescripcionEuskera(), motivosminoracion.getOrigen(),
				motivosminoracion.getConvocatoria().getIdConvocatoria(), motivosminoracion.getFechaUltModificacion(),
				motivosminoracion.getUsuarioUltModificacion(), motivosminoracion.getIdMotivoMinoracion());
		return motivosminoracion;
	}

	/**
	 * Finds a single row in the MotivosMinoracion table.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @return MotivosMinoracion
	 */
	@Transactional(readOnly = true)
	public MotivosMinoracion find(MotivosMinoracion motivosminoracion) {
		String query = "SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ORIGEN ORIGEN, t1.ID_CONVOCATORIA IDCONVOCATORIA FROM MOTIVOS_MINORACION t1  WHERE t1.ID_MOTIVO_MINORACION = ?  ";

		List<MotivosMinoracion> motivosminoracionList = this.jdbcTemplate.query(query, this.rwMap,
				motivosminoracion.getIdMotivoMinoracion());
		return (MotivosMinoracion) DataAccessUtils.uniqueResult(motivosminoracionList);
	}

	/**
	 * Removes a single row in the MotivosMinoracion table.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @return
	 */
	public void remove(MotivosMinoracion motivosminoracion) {
		String query = "UPDATE MOTIVOS_MINORACION SET BAJA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_MOTIVO_MINORACION = ?";
		this.jdbcTemplate.update(query, motivosminoracion.getBaja(), motivosminoracion.getFechaUltModificacion(),
				motivosminoracion.getUsuarioUltModificacion(), motivosminoracion.getIdMotivoMinoracion());

	}

	/**
	 * Finds a list of rows in the MotivosMinoracion table.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<MotivosMinoracion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosMinoracion> findAll(MotivosMinoracion motivosminoracion, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ORIGEN AS ORIGEN, t1.ID_CONVOCATORIA IDCONVOCATORIA ");
		query.append("FROM MOTIVOS_MINORACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosminoracion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosMinoracionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosMinoracion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the MotivosMinoracion table using like.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<MotivosMinoracion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosMinoracion> findAllLike(MotivosMinoracion motivosminoracion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ORIGEN ORIGEN, t1.ID_CONVOCATORIA IDCONVOCATORIA ");
		query.append("FROM MOTIVOS_MINORACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosminoracion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosMinoracionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosMinoracion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the MotivosMinoracion table.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(MotivosMinoracion motivosminoracion) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_MINORACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosminoracion);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the MotivosMinoracion table using like.
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(MotivosMinoracion motivosminoracion, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_MINORACION t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosminoracion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Finds a list of rows in the Motivos de minoracion table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param origen
	 *            Integer
	 * @param idRelExpActSub
	 *            Integer
	 * 
	 * @return List<MotivosMinoracion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosMinoracion> findMinoracionActSubvencionable(Integer idConvocatoria, Integer origen,
			Integer idRelExpActSub) {

		StringBuilder query = new StringBuilder();
		List<Object> params = new ArrayList<Object>();

		query.append(
				"SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_MINORACION t1");
		query.append(" WHERE ID_CONVOCATORIA = ?");
		params.add(idConvocatoria);
		query.append(" AND ORIGEN = ?");
		params.add(origen);
		query.append(" AND (BAJA = ? OR BAJA IS NULL)");
		params.add(Constantes.NO_BAJA);

		query.append(" UNION");

		query.append(
				" SELECT  t25.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t25.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t25.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_MINORACION t25, REL_ACT_SUB_MOT_MIN t1");
		query.append(" WHERE t25.ID_MOTIVO_MINORACION = t1.ID_MOTIVO_MINORACION");
		query.append(" AND t25.ORIGEN = ?");
		params.add(origen);
		query.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
		params.add(idRelExpActSub);

		return this.jdbcTemplate.query(query.toString(), this.rwMapCombo, params.toArray());

	}

	/**
	 * Finds a list of rows in the Motivos de minoracion table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param origen
	 *            Integer
	 * @param idFactura
	 *            Integer
	 * 
	 * @return List<MotivosMinoracion>
	 */
	@Transactional(readOnly = true)
	public List<MotivosMinoracion> findMinoracionFacturas(Integer idConvocatoria, Integer origen, Integer idFactura) {

		StringBuilder query = new StringBuilder();
		List<Object> params = new ArrayList<Object>();

		query.append(
				"SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_MINORACION t1");
		query.append(" WHERE ID_CONVOCATORIA = ?");
		params.add(idConvocatoria);
		query.append(" AND ORIGEN = ?");
		params.add(origen);
		query.append(" AND (BAJA = ? OR BAJA IS NULL)");
		params.add(Constantes.NO_BAJA);

		query.append(" UNION");

		query.append(
				" SELECT  t25.ID_MOTIVO_MINORACION IDMOTIVOMINORACION, t25.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t25.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA");
		query.append(" FROM MOTIVOS_MINORACION t25, REL_FAC_MOT_MIN t1");
		query.append(" WHERE t25.ID_MOTIVO_MINORACION = t1.ID_MOTIVO_MINORACION");
		query.append(" AND t25.ORIGEN = ?");
		params.add(origen);
		query.append(" AND t1.ID_FACTURA = ?");
		params.add(idFactura);

		return this.jdbcTemplate.query(query.toString(), this.rwMapCombo, params.toArray());

	}

	/**
	 * Reorder the data list of MotivosMinoracion selected for rup_table
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosMinoracion>>
	 */
	@Override
	public List<TableRowDto<MotivosMinoracion>> reorderSelection(MotivosMinoracion motivosminoracion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_MINORACION t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosminoracion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				MotivosMinoracion.class, filterParamList, "ID_MOTIVO_MINORACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosMinoracion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            MotivosMinoracion
	 * @param searchParams
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosMinoracion>>
	 */
	@Override
	public List<TableRowDto<MotivosMinoracion>> search(MotivosMinoracion filterParams, MotivosMinoracion searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_MINORACION t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA = idConvocatoria ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				MotivosMinoracion.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_MOTIVO_MINORACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosMinoracion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtermotivosminoracion
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(MotivosMinoracion filtermotivosminoracion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_MINORACION t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtermotivosminoracion, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				MotivosMinoracion.class, query, params, "ID_MOTIVO_MINORACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical MotivosMinoracion table.
	 *
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<MotivosMinoracion>>
	 */
	@Override
	public List<JerarquiaDto<MotivosMinoracion>> findAllLikeJerarquia(MotivosMinoracion filterMotivosMinoracion,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_MINORACION IDMOTIVOMINORACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_MINORACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_MINORACION");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosMinoracion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MOTIVO_MINORACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					MotivosMinoracionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(MotivosMinoracion filterMotivosMinoracion,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_MINORACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_MINORACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosMinoracion, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_MOTIVO_MINORACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<MotivosMinoracion>>
	 */
	@Override
	public List<TableRowDto<MotivosMinoracion>> findAllChild(MotivosMinoracion filterMotivosMinoracion,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_MINORACION t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_MINORACION");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosMinoracion, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_MOTIVO_MINORACION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<MotivosMinoracion>(this.rwMapPK, "ID_MOTIVO_MINORACION"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosMinoracion entity
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(MotivosMinoracion motivosminoracion) {

		StringBuilder where = new StringBuilder(MotivosMinoracionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();
		if (motivosminoracion != null && motivosminoracion.getConvocatoria() != null
				&& motivosminoracion.getConvocatoria().getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(motivosminoracion.getConvocatoria().getIdConvocatoria());
		}

		if (motivosminoracion != null && motivosminoracion.getBusqConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(motivosminoracion.getBusqConvocatoria());
		}

		if (motivosminoracion != null && motivosminoracion.getIdMotivoMinoracion() != null) {
			where.append(" AND t1.ID_MOTIVO_MINORACION = ?");
			params.add(motivosminoracion.getIdMotivoMinoracion());
		}
		if (motivosminoracion != null && motivosminoracion.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(motivosminoracion.getDescripcionCastellano());
		}
		if (motivosminoracion != null && motivosminoracion.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(motivosminoracion.getDescripcionEuskera());
		}
		if (motivosminoracion != null && motivosminoracion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(motivosminoracion.getFechaRegistro());
		}
		if (motivosminoracion != null && motivosminoracion.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(motivosminoracion.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosMinoracion entity
	 *
	 * @param motivosminoracion
	 *            MotivosMinoracion Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(MotivosMinoracion motivosminoracion, Boolean startsWith) {

		StringBuilder where = new StringBuilder(MotivosMinoracionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (motivosminoracion != null && motivosminoracion.getConvocatoria().getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(motivosminoracion.getConvocatoria().getIdConvocatoria());
		}
		if (motivosminoracion != null && motivosminoracion.getIdMotivoMinoracion() != null) {
			where.append(" AND t1.ID_MOTIVO_MINORACION = ?");
			params.add(motivosminoracion.getIdMotivoMinoracion());
		}
		if (motivosminoracion != null && motivosminoracion.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosminoracion.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + motivosminoracion.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (motivosminoracion != null && motivosminoracion.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosminoracion.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + motivosminoracion.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (motivosminoracion != null && motivosminoracion.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(motivosminoracion.getFechaRegistro());
		}
		if (motivosminoracion != null && motivosminoracion.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosminoracion.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + motivosminoracion.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		where.append(" AND (t1.BAJA = ? OR t1.BAJA IS NULL)");
		params.add(Constantes.NO_BAJA);

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
