package com.ejie.ab60.dao.estudioTecnico;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.OtrasAyudas;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * OtrasAyudasDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class OtrasAyudasDaoImpl implements OtrasAyudasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDOTRAAYUDA", "IDEXPEDIENTE", "ANYOSOLICITUD",
			"INSTITUCION", "PROGRAMA", "TIPOAYUDA", "ACTIVIDAD", "IMPORTESOLICITADO", "AYUDACONCEDIDA", "FECHAREGISTRO",
			"USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<OtrasAyudas> rwMap = new RowMapper<OtrasAyudas>() {
		public OtrasAyudas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new OtrasAyudas(resultSet.getInt("IDOTRAAYUDA"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getLong("ANYOSOLICITUD"), resultSet.getString("INSTITUCION"),
					resultSet.getString("PROGRAMA"), resultSet.getString("TIPOAYUDA"), resultSet.getString("ACTIVIDAD"),
					resultSet.getBigDecimal("IMPORTESOLICITADO"), resultSet.getBigDecimal("AYUDACONCEDIDA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<OtrasAyudas> rwMapPK = new RowMapper<OtrasAyudas>() {
		public OtrasAyudas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new OtrasAyudas(resultSet.getInt("IDOTRAAYUDA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<OtrasAyudas>> rwMapJerarquia = new RowMapper<JerarquiaDto<OtrasAyudas>>() {
		public JerarquiaDto<OtrasAyudas> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			OtrasAyudas otrasayudas = new OtrasAyudas(resultSet.getInt("IDOTRAAYUDA"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getLong("ANYOSOLICITUD"), resultSet.getString("INSTITUCION"),
					resultSet.getString("PROGRAMA"), resultSet.getString("TIPOAYUDA"), resultSet.getString("ACTIVIDAD"),
					resultSet.getBigDecimal("IMPORTESOLICITADO"), resultSet.getBigDecimal("AYUDACONCEDIDA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<OtrasAyudas> jerarquia = new JerarquiaDto<OtrasAyudas>();
			jerarquia.setModel(otrasayudas);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the OtrasAyudas table.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @return OtrasAyudas
	 */
	public OtrasAyudas add(OtrasAyudas otrasayudas) {
		String query = "INSERT INTO OTRAS_AYUDAS (ID_OTRA_AYUDA, ID_EXPEDIENTE, ANYO_SOLICITUD, INSTITUCION, PROGRAMA, TIPO_AYUDA, ACTIVIDAD, IMPORTE_SOLICITADO, AYUDA_CONCEDIDA, FECHA_REGISTRO, USUARIO_REGISTRO, ID_TIPO_OTRA_AYUDA) VALUES (S_AB6008T00.NEXTVAL,?,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, otrasayudas.getIdExpediente(), otrasayudas.getAnyoSolicitud(),
				otrasayudas.getInstitucion(), otrasayudas.getPrograma(), otrasayudas.getTipoAyuda(),
				otrasayudas.getActividad(), otrasayudas.getImporteSolicitado(), otrasayudas.getAyudaConcedida(),
				otrasayudas.getFechaRegistro(), otrasayudas.getUsuarioRegistro(), otrasayudas.getIdTipoOtraAyuda());
		return otrasayudas;
	}

	/**
	 * Updates a single row in the OtrasAyudas table.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @return OtrasAyudas
	 */
	public OtrasAyudas update(OtrasAyudas otrasayudas) {
		String query = "UPDATE OTRAS_AYUDAS SET ID_EXPEDIENTE=?, ANYO_SOLICITUD=?, INSTITUCION=?, PROGRAMA=?, TIPO_AYUDA=?, ACTIVIDAD=?, IMPORTE_SOLICITADO=?, AYUDA_CONCEDIDA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION = ? WHERE ID_OTRA_AYUDA=?";
		this.jdbcTemplate.update(query, otrasayudas.getIdExpediente(), otrasayudas.getAnyoSolicitud(),
				otrasayudas.getInstitucion(), otrasayudas.getPrograma(), otrasayudas.getTipoAyuda(),
				otrasayudas.getActividad(), otrasayudas.getImporteSolicitado(), otrasayudas.getAyudaConcedida(),
				otrasayudas.getFechaUltmodificacion(), otrasayudas.getUsuarioUltmodificacion(),
				otrasayudas.getIdOtraAyuda());
		return otrasayudas;
	}

	/**
	 * Finds a single row in the OtrasAyudas table.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @return OtrasAyudas
	 */
	@Transactional(readOnly = true)
	public OtrasAyudas find(OtrasAyudas otrasayudas) {
		String query = "SELECT t1.ID_OTRA_AYUDA IDOTRAAYUDA, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ANYO_SOLICITUD ANYOSOLICITUD, t1.INSTITUCION INSTITUCION, t1.PROGRAMA PROGRAMA, t1.TIPO_AYUDA TIPOAYUDA, t1.ACTIVIDAD ACTIVIDAD, t1.IMPORTE_SOLICITADO IMPORTESOLICITADO, t1.AYUDA_CONCEDIDA AYUDACONCEDIDA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM OTRAS_AYUDAS t1  WHERE t1.ID_OTRA_AYUDA = ?  ";

		List<OtrasAyudas> otrasayudasList = this.jdbcTemplate.query(query, this.rwMap, otrasayudas.getIdOtraAyuda());
		return (OtrasAyudas) DataAccessUtils.uniqueResult(otrasayudasList);
	}

	/**
	 * Removes a single row in the OtrasAyudas table.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @return
	 */
	public void remove(OtrasAyudas otrasayudas) {
		String query = "DELETE FROM OTRAS_AYUDAS WHERE ID_OTRA_AYUDA=?";
		this.jdbcTemplate.update(query, otrasayudas.getIdOtraAyuda());
	}

	/**
	 * Finds a list of rows in the OtrasAyudas table.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<OtrasAyudas>
	 */
	@Transactional(readOnly = true)
	public List<OtrasAyudas> findAll(OtrasAyudas otrasayudas, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_OTRA_AYUDA IDOTRAAYUDA,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ANYO_SOLICITUD ANYOSOLICITUD,t1.INSTITUCION INSTITUCION,t1.PROGRAMA PROGRAMA,t1.TIPO_AYUDA TIPOAYUDA,t1.ACTIVIDAD ACTIVIDAD,t1.IMPORTE_SOLICITADO IMPORTESOLICITADO,t1.AYUDA_CONCEDIDA AYUDACONCEDIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM OTRAS_AYUDAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(otrasayudas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, OtrasAyudasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<OtrasAyudas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the OtrasAyudas table using like.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<OtrasAyudas>
	 */
	@Transactional(readOnly = true)
	public List<OtrasAyudas> findAllLike(OtrasAyudas otrasayudas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_OTRA_AYUDA IDOTRAAYUDA,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ANYO_SOLICITUD ANYOSOLICITUD,t1.INSTITUCION INSTITUCION,t1.PROGRAMA PROGRAMA,t1.TIPO_AYUDA TIPOAYUDA,t1.ACTIVIDAD ACTIVIDAD,t1.IMPORTE_SOLICITADO IMPORTESOLICITADO,t1.AYUDA_CONCEDIDA AYUDACONCEDIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM OTRAS_AYUDAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(otrasayudas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, OtrasAyudasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<OtrasAyudas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the OtrasAyudas table.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(OtrasAyudas otrasayudas) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM OTRAS_AYUDAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(otrasayudas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the OtrasAyudas table using like.
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(OtrasAyudas otrasayudas, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM OTRAS_AYUDAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(otrasayudas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of OtrasAyudas selected for rup_table
	 *
	 * @param otrasayudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<OtrasAyudas>>
	 */
	@Override
	public List<TableRowDto<OtrasAyudas>> reorderSelection(OtrasAyudas otrasayudas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OTRA_AYUDA IDOTRAAYUDA,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ANYO_SOLICITUD ANYOSOLICITUD,t1.INSTITUCION INSTITUCION,t1.PROGRAMA PROGRAMA,t1.TIPO_AYUDA TIPOAYUDA,t1.ACTIVIDAD ACTIVIDAD,t1.IMPORTE_SOLICITADO IMPORTESOLICITADO,t1.AYUDA_CONCEDIDA AYUDACONCEDIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM OTRAS_AYUDAS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(otrasayudas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, OtrasAyudas.class,
				filterParamList, "ID_OTRA_AYUDA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<OtrasAyudas>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            OtrasAyudas
	 * @param searchParams
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<OtrasAyudas>>
	 */
	@Override
	public List<TableRowDto<OtrasAyudas>> search(OtrasAyudas filterParams, OtrasAyudas searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OTRA_AYUDA IDOTRAAYUDA,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ANYO_SOLICITUD ANYOSOLICITUD,t1.INSTITUCION INSTITUCION,t1.PROGRAMA PROGRAMA,t1.TIPO_AYUDA TIPOAYUDA,t1.ACTIVIDAD ACTIVIDAD,t1.IMPORTE_SOLICITADO IMPORTESOLICITADO,t1.AYUDA_CONCEDIDA AYUDACONCEDIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM OTRAS_AYUDAS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, OtrasAyudas.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_OTRA_AYUDA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<OtrasAyudas>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterotrasayudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(OtrasAyudas filterotrasayudas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OTRA_AYUDA IDOTRAAYUDA,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ANYO_SOLICITUD ANYOSOLICITUD,t1.INSTITUCION INSTITUCION,t1.PROGRAMA PROGRAMA,t1.TIPO_AYUDA TIPOAYUDA,t1.ACTIVIDAD ACTIVIDAD,t1.IMPORTE_SOLICITADO IMPORTESOLICITADO,t1.AYUDA_CONCEDIDA AYUDACONCEDIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM OTRAS_AYUDAS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterotrasayudas, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, OtrasAyudas.class,
				query, params, "ID_OTRA_AYUDA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical OtrasAyudas table.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<OtrasAyudas>>
	 */
	@Override
	public List<JerarquiaDto<OtrasAyudas>> findAllLikeJerarquia(OtrasAyudas filterOtrasAyudas,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_OTRA_AYUDA IDOTRAAYUDA,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ANYO_SOLICITUD ANYOSOLICITUD,t1.INSTITUCION INSTITUCION,t1.PROGRAMA PROGRAMA,t1.TIPO_AYUDA TIPOAYUDA,t1.ACTIVIDAD ACTIVIDAD,t1.IMPORTE_SOLICITADO IMPORTESOLICITADO,t1.AYUDA_CONCEDIDA AYUDACONCEDIDA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM OTRAS_AYUDAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("OTRAS_AYUDAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOtrasAyudas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_OTRA_AYUDA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					OtrasAyudasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(OtrasAyudas filterOtrasAyudas, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM OTRAS_AYUDAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("OTRAS_AYUDAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOtrasAyudas, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_OTRA_AYUDA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<OtrasAyudas>>
	 */
	@Override
	public List<TableRowDto<OtrasAyudas>> findAllChild(OtrasAyudas filterOtrasAyudas,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM OTRAS_AYUDAS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("OTRAS_AYUDAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterOtrasAyudas, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_OTRA_AYUDA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<OtrasAyudas>(this.rwMapPK, "ID_OTRA_AYUDA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the OtrasAyudas entity
	 *
	 * @param otrasayudas
	 *            OtrasAyudas Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(OtrasAyudas otrasayudas) {

		StringBuilder where = new StringBuilder(OtrasAyudasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (otrasayudas != null && otrasayudas.getIdOtraAyuda() != null) {
			where.append(" AND t1.ID_OTRA_AYUDA = ?");
			params.add(otrasayudas.getIdOtraAyuda());
		}
		if (otrasayudas != null && otrasayudas.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(otrasayudas.getIdExpediente());
		}
		if (otrasayudas != null && otrasayudas.getAnyoSolicitud() != null) {
			where.append(" AND t1.ANYO_SOLICITUD = ?");
			params.add(otrasayudas.getAnyoSolicitud());
		}
		if (otrasayudas != null && otrasayudas.getInstitucion() != null) {
			where.append(" AND t1.INSTITUCION = ?");
			params.add(otrasayudas.getInstitucion());
		}
		if (otrasayudas != null && otrasayudas.getPrograma() != null) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(otrasayudas.getPrograma());
		}
		if (otrasayudas != null && otrasayudas.getTipoAyuda() != null) {
			where.append(" AND t1.TIPO_AYUDA = ?");
			params.add(otrasayudas.getTipoAyuda());
		}
		if (otrasayudas != null && otrasayudas.getActividad() != null) {
			where.append(" AND t1.ACTIVIDAD = ?");
			params.add(otrasayudas.getActividad());
		}
		if (otrasayudas != null && otrasayudas.getImporteSolicitado() != null) {
			where.append(" AND t1.IMPORTE_SOLICITADO = ?");
			params.add(otrasayudas.getImporteSolicitado());
		}
		if (otrasayudas != null && otrasayudas.getAyudaConcedida() != null) {
			where.append(" AND t1.AYUDA_CONCEDIDA = ?");
			params.add(otrasayudas.getAyudaConcedida());
		}
		if (otrasayudas != null && otrasayudas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(otrasayudas.getFechaRegistro());
		}
		if (otrasayudas != null && otrasayudas.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(otrasayudas.getUsuarioRegistro());
		}
		if (otrasayudas != null && otrasayudas.getIdTipoOtraAyuda() != null) {
			where.append(" AND t1.ID_TIPO_OTRA_AYUDA = ?");
			params.add(otrasayudas.getIdTipoOtraAyuda());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the OtrasAyudas entity
	 *
	 * @param otrasayudas
	 *            OtrasAyudas Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(OtrasAyudas otrasayudas, Boolean startsWith) {

		StringBuilder where = new StringBuilder(OtrasAyudasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (otrasayudas != null && otrasayudas.getIdOtraAyuda() != null) {
			where.append(" AND t1.ID_OTRA_AYUDA = ?");
			params.add(otrasayudas.getIdOtraAyuda());
		}
		if (otrasayudas != null && otrasayudas.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(otrasayudas.getIdExpediente());
		}
		if (otrasayudas != null && otrasayudas.getAnyoSolicitud() != null) {
			where.append(" AND t1.ANYO_SOLICITUD = ?");
			params.add(otrasayudas.getAnyoSolicitud());
		}
		if (otrasayudas != null && otrasayudas.getInstitucion() != null) {
			where.append(" AND UPPER(t1.INSTITUCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrasayudas.getInstitucion().toUpperCase() + "%");
			} else {
				params.add("%" + otrasayudas.getInstitucion().toUpperCase() + "%");
			}
			where.append(" AND t1.INSTITUCION IS NOT NULL");
		}
		if (otrasayudas != null && otrasayudas.getPrograma() != null) {
			where.append(" AND UPPER(t1.PROGRAMA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrasayudas.getPrograma().toUpperCase() + "%");
			} else {
				params.add("%" + otrasayudas.getPrograma().toUpperCase() + "%");
			}
			where.append(" AND t1.PROGRAMA IS NOT NULL");
		}
		if (otrasayudas != null && otrasayudas.getTipoAyuda() != null) {
			where.append(" AND UPPER(t1.TIPO_AYUDA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrasayudas.getTipoAyuda().toUpperCase() + "%");
			} else {
				params.add("%" + otrasayudas.getTipoAyuda().toUpperCase() + "%");
			}
			where.append(" AND t1.TIPO_AYUDA IS NOT NULL");
		}
		if (otrasayudas != null && otrasayudas.getActividad() != null) {
			where.append(" AND UPPER(t1.ACTIVIDAD) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrasayudas.getActividad().toUpperCase() + "%");
			} else {
				params.add("%" + otrasayudas.getActividad().toUpperCase() + "%");
			}
			where.append(" AND t1.ACTIVIDAD IS NOT NULL");
		}
		if (otrasayudas != null && otrasayudas.getImporteSolicitado() != null) {
			where.append(" AND t1.IMPORTE_SOLICITADO = ?");
			params.add(otrasayudas.getImporteSolicitado());
		}
		if (otrasayudas != null && otrasayudas.getAyudaConcedida() != null) {
			where.append(" AND t1.AYUDA_CONCEDIDA = ?");
			params.add(otrasayudas.getAyudaConcedida());
		}
		if (otrasayudas != null && otrasayudas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(otrasayudas.getFechaRegistro());
		}
		if (otrasayudas != null && otrasayudas.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(otrasayudas.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + otrasayudas.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (otrasayudas != null && otrasayudas.getIdTipoOtraAyuda() != null) {
			where.append(" AND t1.ID_TIPO_OTRA_AYUDA = ?");
			params.add(otrasayudas.getIdTipoOtraAyuda());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
