package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.Poblaciones;

/**
 * PoblacionesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PoblacionesDaoImpl implements PoblacionesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPOBLACION", "IDCONVOCATORIA",
			"DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Poblaciones> rwMap = new RowMapper<Poblaciones>() {
		public Poblaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Poblaciones(resultSet.getInt("IDPOBLACION"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<Poblaciones> rwMapPK = new RowMapper<Poblaciones>() {
		public Poblaciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Poblaciones(resultSet.getInt("IDPOBLACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Poblaciones>> rwMapJerarquia = new RowMapper<JerarquiaDto<Poblaciones>>() {
		public JerarquiaDto<Poblaciones> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Poblaciones poblaciones = new Poblaciones(resultSet.getInt("IDPOBLACION"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<Poblaciones> jerarquia = new JerarquiaDto<Poblaciones>();
			jerarquia.setModel(poblaciones);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Poblaciones table.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @return Poblaciones
	 */
	public Poblaciones add(Poblaciones poblaciones) {
		String query = "INSERT INTO POBLACIONES (ID_POBLACION, ID_CONVOCATORIA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, poblaciones.getIdPoblacion(), poblaciones.getIdConvocatoria(),
				poblaciones.getDescripcionCastellano(), poblaciones.getDescripcionEuskera(),
				poblaciones.getFechaRegistro(), poblaciones.getUsuarioRegistro());
		return poblaciones;
	}

	/**
	 * Updates a single row in the Poblaciones table.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @return Poblaciones
	 */
	public Poblaciones update(Poblaciones poblaciones) {
		String query = "UPDATE POBLACIONES SET ID_CONVOCATORIA=?, DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_POBLACION=?";
		this.jdbcTemplate.update(query, poblaciones.getIdConvocatoria(), poblaciones.getDescripcionCastellano(),
				poblaciones.getDescripcionEuskera(), poblaciones.getFechaRegistro(), poblaciones.getUsuarioRegistro(),
				poblaciones.getIdPoblacion());
		return poblaciones;
	}

	/**
	 * Finds a single row in the Poblaciones table.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @return Poblaciones
	 */
	@Transactional(readOnly = true)
	public Poblaciones find(Poblaciones poblaciones) {
		String query = "SELECT t1.ID_POBLACION IDPOBLACION, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM POBLACIONES t1  WHERE t1.ID_POBLACION = ?  ";

		List<Poblaciones> poblacionesList = this.jdbcTemplate.query(query, this.rwMap, poblaciones.getIdPoblacion());
		return (Poblaciones) DataAccessUtils.uniqueResult(poblacionesList);
	}

	/**
	 * Removes a single row in the Poblaciones table.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @return
	 */
	public void remove(Poblaciones poblaciones) {
		String query = "DELETE FROM POBLACIONES WHERE ID_POBLACION=?";
		this.jdbcTemplate.update(query, poblaciones.getIdPoblacion());
	}

	/**
	 * Finds a list of rows in the Poblaciones table.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Poblaciones>
	 */
	@Transactional(readOnly = true)
	public List<Poblaciones> findAll(Poblaciones poblaciones, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_POBLACION IDPOBLACION,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM POBLACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(poblaciones);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, PoblacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Poblaciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds a list of rows in the Poblaciones table.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Poblaciones>
	 */
	@Transactional(readOnly = true)
	public List<Poblaciones> findByConvocatoria(Integer idConvocatoria) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_POBLACION IDPOBLACION,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM POBLACIONES t1 ");
		query.append("WHERE ID_CONVOCATORIA =? ");
		query.append("Order by t1.ID_POBLACION");

		return (List<Poblaciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, idConvocatoria);
	}

	/**
	 * Finds rows in the Poblaciones table using like.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Poblaciones>
	 */
	@Transactional(readOnly = true)
	public List<Poblaciones> findAllLike(Poblaciones poblaciones, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_POBLACION IDPOBLACION,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM POBLACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(poblaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, PoblacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Poblaciones>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Poblaciones table.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Poblaciones poblaciones) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM POBLACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(poblaciones);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Poblaciones table using like.
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Poblaciones poblaciones, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM POBLACIONES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(poblaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Poblaciones selected for rup_table
	 *
	 * @param poblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Poblaciones>>
	 */
	@Override
	public List<TableRowDto<Poblaciones>> reorderSelection(Poblaciones poblaciones, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_POBLACION IDPOBLACION,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM POBLACIONES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(poblaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Poblaciones.class,
				filterParamList, "ID_POBLACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Poblaciones>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Poblaciones
	 * @param searchParams
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Poblaciones>>
	 */
	@Override
	public List<TableRowDto<Poblaciones>> search(Poblaciones filterParams, Poblaciones searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_POBLACION IDPOBLACION,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM POBLACIONES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Poblaciones.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_POBLACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Poblaciones>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterpoblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Poblaciones filterpoblaciones, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_POBLACION IDPOBLACION,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM POBLACIONES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterpoblaciones, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Poblaciones.class,
				query, params, "ID_POBLACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Poblaciones table.
	 *
	 * @param filterPoblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Poblaciones>>
	 */
	@Override
	public List<JerarquiaDto<Poblaciones>> findAllLikeJerarquia(Poblaciones filterPoblaciones,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_POBLACION IDPOBLACION,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM POBLACIONES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("POBLACIONES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPoblaciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_POBLACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					PoblacionesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPoblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Poblaciones filterPoblaciones, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM POBLACIONES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("POBLACIONES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPoblaciones, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_POBLACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPoblaciones
	 *            Poblaciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Poblaciones>>
	 */
	@Override
	public List<TableRowDto<Poblaciones>> findAllChild(Poblaciones filterPoblaciones,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM POBLACIONES t1 ");
		List<String> from = new ArrayList<String>();
		from.add("POBLACIONES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPoblaciones, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_POBLACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Poblaciones>(this.rwMapPK, "ID_POBLACION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Poblaciones entity
	 *
	 * @param poblaciones
	 *            Poblaciones Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Poblaciones poblaciones) {

		StringBuilder where = new StringBuilder(PoblacionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (poblaciones != null && poblaciones.getIdPoblacion() != null) {
			where.append(" AND t1.ID_POBLACION = ?");
			params.add(poblaciones.getIdPoblacion());
		}
		if (poblaciones != null && poblaciones.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(poblaciones.getIdConvocatoria());
		}
		if (poblaciones != null && poblaciones.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(poblaciones.getDescripcionCastellano());
		}
		if (poblaciones != null && poblaciones.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(poblaciones.getDescripcionEuskera());
		}
		if (poblaciones != null && poblaciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(poblaciones.getFechaRegistro());
		}
		if (poblaciones != null && poblaciones.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(poblaciones.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Poblaciones entity
	 *
	 * @param poblaciones
	 *            Poblaciones Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Poblaciones poblaciones, Boolean startsWith) {

		StringBuilder where = new StringBuilder(PoblacionesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (poblaciones != null && poblaciones.getIdPoblacion() != null) {
			where.append(" AND t1.ID_POBLACION = ?");
			params.add(poblaciones.getIdPoblacion());
		}
		if (poblaciones != null && poblaciones.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(poblaciones.getIdConvocatoria());
		}
		if (poblaciones != null && poblaciones.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(poblaciones.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + poblaciones.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (poblaciones != null && poblaciones.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(poblaciones.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + poblaciones.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (poblaciones != null && poblaciones.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(poblaciones.getFechaRegistro());
		}
		if (poblaciones != null && poblaciones.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(poblaciones.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + poblaciones.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
