package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.estudioTecnico.ErroresCalculo;
import com.ejie.ab60.model.estudioTecnico.RelExpErrCal;
import com.ejie.ab60.model.plantillas.CamposPlantilla;

/**
 * RelExpErrCalDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelExpErrCalDaoImpl implements RelExpErrCalDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELEXPERRCAL", "IDEXPEDIENTE", "IDCODIGOERROR",
			"FASE", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelExpErrCal> rwMap = new RowMapper<RelExpErrCal>() {
		public RelExpErrCal mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpErrCal(resultSet.getInt("IDRELEXPERRCAL"), resultSet.getInt("IDEXPEDIENTE"),
					new ErroresCalculo(resultSet.getInt("IDCODIGOERROR")), resultSet.getInt("FASE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<RelExpErrCal> rwMapLimites = new RowMapper<RelExpErrCal>() {
		public RelExpErrCal mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpErrCal relExpErrCal = new RelExpErrCal();
			ErroresCalculo erroresCalculo = new ErroresCalculo();
			erroresCalculo.setIdCodigoerror(resultSet.getInt("IDCODIGOERROR"));
			erroresCalculo.setDescripcionCastellano(resultSet.getString("DESCCASTELLANO"));
			erroresCalculo.setDescripcionEuskera(resultSet.getString("DESCEUSKERA"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));
			erroresCalculo.setActSubvencionable(actSubvencionable);
			relExpErrCal.setErroresCalculo(erroresCalculo);
			return relExpErrCal;
		}

	};

	private RowMapper<RelExpErrCal> rwMapPK = new RowMapper<RelExpErrCal>() {
		public RelExpErrCal mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpErrCal(resultSet.getInt("IDRELEXPERRCAL"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelExpErrCal>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelExpErrCal>>() {
		public JerarquiaDto<RelExpErrCal> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpErrCal relexperrcal = new RelExpErrCal(resultSet.getInt("IDRELEXPERRCAL"),
					resultSet.getInt("IDEXPEDIENTE"), new ErroresCalculo(resultSet.getInt("IDCODIGOERROR")),
					resultSet.getInt("FASE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<RelExpErrCal> jerarquia = new JerarquiaDto<RelExpErrCal>();
			jerarquia.setModel(relexperrcal);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelExpErrCal table.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @return RelExpErrCal
	 */
	public RelExpErrCal add(RelExpErrCal relexperrcal) {
		String query = "INSERT INTO REL_EXP_ERR_CAL (ID_REL_EXP_ERR_CAL, ID_EXPEDIENTE, ID_CODIGOERROR, FASE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, relexperrcal.getIdRelExpErrCal(), relexperrcal.getIdExpediente(),
				relexperrcal.getErroresCalculo().getIdCodigoerror(), relexperrcal.getFase(),
				relexperrcal.getFechaRegistro(), relexperrcal.getUsuarioRegistro());
		return relexperrcal;
	}

	/**
	 * Updates a single row in the RelExpErrCal table.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @return RelExpErrCal
	 */
	public RelExpErrCal update(RelExpErrCal relexperrcal) {
		String query = "UPDATE REL_EXP_ERR_CAL SET ID_EXPEDIENTE=?, ID_CODIGOERROR=?, FASE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_REL_EXP_ERR_CAL=?";
		this.jdbcTemplate.update(query, relexperrcal.getIdExpediente(),
				relexperrcal.getErroresCalculo().getIdCodigoerror(), relexperrcal.getFase(),
				relexperrcal.getFechaRegistro(), relexperrcal.getUsuarioRegistro(), relexperrcal.getIdRelExpErrCal());
		return relexperrcal;
	}

	/**
	 * Finds a single row in the RelExpErrCal table.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @return RelExpErrCal
	 */
	@Transactional(readOnly = true)
	public RelExpErrCal find(RelExpErrCal relexperrcal) {
		String query = "SELECT t1.ID_REL_EXP_ERR_CAL IDRELEXPERRCAL, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_CODIGOERROR IDCODIGOERROR, t1.FASE FASE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_EXP_ERR_CAL t1  WHERE t1.ID_REL_EXP_ERR_CAL = ?  ";

		List<RelExpErrCal> relexperrcalList = this.jdbcTemplate.query(query, this.rwMap,
				relexperrcal.getIdRelExpErrCal());
		return (RelExpErrCal) DataAccessUtils.uniqueResult(relexperrcalList);
	}

	/**
	 * Finds a single row in the RelExpErrCal table.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @return RelExpErrCal
	 */
	@Transactional(readOnly = true)
	public List<RelExpErrCal> findLimites(RelExpErrCal relexperrcal) {
		StringBuilder query = new StringBuilder(
				"SELECT t2.ID_CODIGOERROR IDCODIGOERROR, t2.DESCRIPCION_CASTELLANO DESCCASTELLANO, t2.DESCRIPCION_EUSKERA DESCEUSKERA, t2.ID_ACT_SUB IDACTSUB FROM REL_EXP_ERR_CAL t1, ERRORES_CALCULO t2  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexperrcal);
		StringBuilder where = new StringBuilder(" WHERE t1.ID_CODIGOERROR = t2.ID_CODIGOERROR ");
		where.append(mapaWhere.get("query"));
		query.append(where);
		query.append(" ORDER BY t1.ID_CODIGOERROR");

		List<?> params = (List<?>) mapaWhere.get("params");

		List<RelExpErrCal> relexperrcalList = null;

		relexperrcalList = this.jdbcTemplate.query(query.toString(), this.rwMapLimites, params.toArray());

		return relexperrcalList;
	}

	/**
	 * Removes a single row in the RelExpErrCal table.
	 * 
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @return
	 */
	public void remove(RelExpErrCal relexperrcal) {
		String query = "DELETE FROM REL_EXP_ERR_CAL WHERE ID_REL_EXP_ERR_CAL=?";
		this.jdbcTemplate.update(query, relexperrcal.getIdRelExpErrCal());
	}

	/**
	 * Finds a list of rows in the RelExpErrCal table.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpErrCal>
	 */
	@Transactional(readOnly = true)
	public List<RelExpErrCal> findAll(RelExpErrCal relexperrcal, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_ERR_CAL IDRELEXPERRCAL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_CODIGOERROR IDCODIGOERROR,t1.FASE FASE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_EXP_ERR_CAL t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexperrcal);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpErrCalDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpErrCal>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelExpErrCal table using like.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpErrCal>
	 */
	@Transactional(readOnly = true)
	public List<RelExpErrCal> findAllLike(RelExpErrCal relexperrcal, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_ERR_CAL IDRELEXPERRCAL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_CODIGOERROR IDCODIGOERROR,t1.FASE FASE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_EXP_ERR_CAL t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexperrcal, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpErrCalDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpErrCal>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelExpErrCal table.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelExpErrCal relexperrcal) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_ERR_CAL t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexperrcal);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelExpErrCal table using like.
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelExpErrCal relexperrcal, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_ERR_CAL t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexperrcal, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelExpErrCal selected for rup_table
	 *
	 * @param relexperrcal
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpErrCal>>
	 */
	@Override
	public List<TableRowDto<RelExpErrCal>> reorderSelection(RelExpErrCal relexperrcal,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ERR_CAL IDRELEXPERRCAL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_CODIGOERROR IDCODIGOERROR,t1.FASE FASE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_ERR_CAL t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexperrcal, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelExpErrCal.class,
				filterParamList, "ID_REL_EXP_ERR_CAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpErrCal>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelExpErrCal
	 * @param searchParams
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpErrCal>>
	 */
	@Override
	public List<TableRowDto<RelExpErrCal>> search(RelExpErrCal filterParams, RelExpErrCal searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ERR_CAL IDRELEXPERRCAL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_CODIGOERROR IDCODIGOERROR,t1.FASE FASE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_ERR_CAL t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelExpErrCal.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_EXP_ERR_CAL");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpErrCal>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelexperrcal
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelExpErrCal filterrelexperrcal, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ERR_CAL IDRELEXPERRCAL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_CODIGOERROR IDCODIGOERROR,t1.FASE FASE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_EXP_ERR_CAL t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelexperrcal, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelExpErrCal.class,
				query, params, "ID_REL_EXP_ERR_CAL");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelExpErrCal table.
	 *
	 * @param filterRelExpErrCal
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelExpErrCal>>
	 */
	@Override
	public List<JerarquiaDto<RelExpErrCal>> findAllLikeJerarquia(RelExpErrCal filterRelExpErrCal,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ERR_CAL IDRELEXPERRCAL,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_CODIGOERROR IDCODIGOERROR,t1.FASE FASE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ERR_CAL t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ERR_CAL");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpErrCal, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_EXP_ERR_CAL", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelExpErrCalDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelExpErrCal
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelExpErrCal filterRelExpErrCal, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ERR_CAL t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ERR_CAL");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpErrCal, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_EXP_ERR_CAL",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpErrCal
	 *            RelExpErrCal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpErrCal>>
	 */
	@Override
	public List<TableRowDto<RelExpErrCal>> findAllChild(RelExpErrCal filterRelExpErrCal,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ERR_CAL t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ERR_CAL");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpErrCal, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_EXP_ERR_CAL",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelExpErrCal>(this.rwMapPK, "ID_REL_EXP_ERR_CAL"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpErrCal entity
	 *
	 * @param relexperrcal
	 *            RelExpErrCal Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelExpErrCal relexperrcal) {

		StringBuilder where = new StringBuilder(RelExpErrCalDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexperrcal != null && relexperrcal.getIdRelExpErrCal() != null) {
			where.append(" AND t1.ID_REL_EXP_ERR_CAL = ?");
			params.add(relexperrcal.getIdRelExpErrCal());
		}
		if (relexperrcal != null && relexperrcal.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexperrcal.getIdExpediente());
		}
		if (relexperrcal != null && relexperrcal.getErroresCalculo() != null
				&& relexperrcal.getErroresCalculo().getIdCodigoerror() != null) {
			where.append(" AND t1.ID_CODIGOERROR = ?");
			params.add(relexperrcal.getErroresCalculo().getIdCodigoerror());
		}
		if (relexperrcal != null && relexperrcal.getFase() != null) {
			where.append(" AND t1.FASE = ?");
			params.add(relexperrcal.getFase());
		}
		if (relexperrcal != null && relexperrcal.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexperrcal.getFechaRegistro());
		}
		if (relexperrcal != null && relexperrcal.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relexperrcal.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpErrCal entity
	 *
	 * @param relexperrcal
	 *            RelExpErrCal Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelExpErrCal relexperrcal, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelExpErrCalDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexperrcal != null && relexperrcal.getIdRelExpErrCal() != null) {
			where.append(" AND t1.ID_REL_EXP_ERR_CAL = ?");
			params.add(relexperrcal.getIdRelExpErrCal());
		}
		if (relexperrcal != null && relexperrcal.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexperrcal.getIdExpediente());
		}
		if (relexperrcal != null && relexperrcal.getErroresCalculo().getIdCodigoerror() != null) {
			where.append(" AND t1.ID_CODIGOERROR = ?");
			params.add(relexperrcal.getErroresCalculo().getIdCodigoerror());
		}
		if (relexperrcal != null && relexperrcal.getFase() != null) {
			where.append(" AND t1.FASE = ?");
			params.add(relexperrcal.getFase());
		}
		if (relexperrcal != null && relexperrcal.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexperrcal.getFechaRegistro());
		}
		if (relexperrcal != null && relexperrcal.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexperrcal.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexperrcal.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
