package com.ejie.ab60.dao.estudioTecnico;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.RelTecResCon;

/**
 * 
 *  
 *
 */

@Repository
@Transactional
public class RelTecResConDaoImpl implements RelTecResConDao {

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelTecResCon> rwMap = new RowMapper<RelTecResCon>() {
		public RelTecResCon mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelTecResCon relTecResCon = new RelTecResCon();

			relTecResCon.setIdRelTecResCon(resultSet.getInt("IDRELTECRESCON"));
			relTecResCon.setIdTecnicoResponsable(resultSet.getInt("IDTECNICORESPONSABLE"));
			relTecResCon.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));

			return relTecResCon;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelTecResCon table.
	 *
	 * @param relTecResCon
	 *            RelTecResCon
	 * @return RelTecResCon
	 */
	@Override()
	public RelTecResCon add(RelTecResCon relTecResCon) {
		String query = "INSERT INTO REL_TEC_RES_CON (ID_REL_TEC_RES_CON,  ID_CONVOCATORIA, ID_TECNICO_RESPONSABLE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?, ?, ?, ?, ?)";
		relTecResCon.setIdRelTecResCon(this.jdbcTemplate.queryForInt("SELECT AB60.S_AB6098T00.NEXTVAL FROM DUAL"));
		this.jdbcTemplate.update(query, relTecResCon.getIdRelTecResCon(), relTecResCon.getIdConvocatoria(),
				relTecResCon.getIdTecnicoResponsable(), relTecResCon.getFechaRegistro(),
				relTecResCon.getUsuarioRegistro());
		return relTecResCon;
	}

	/**
	 * Removes a single row in the RelTecResCon table.
	 *
	 * @param idTecnicoResponsable
	 *            Integer
	 * @return
	 */
	@Override()
	public void remove(Integer idTecnicoResponsable) {
		String query = "DELETE FROM REL_TEC_RES_CON WHERE ID_TECNICO_RESPONSABLE=?";
		this.jdbcTemplate.update(query, idTecnicoResponsable);
	}

	/**
	 * Finds a list of rows in the RelTecResCon table.
	 *
	 * @param idTecnicoResponsable
	 *            Integer
	 * @return List<RelTecResCon>
	 */
	@Override()
	public List<RelTecResCon> findConvocatoriasPorTecnico(Integer idTecnicoResponsable) {
		StringBuilder query = new StringBuilder();

		query.append(
				"SELECT t98.ID_REL_TEC_RES_CON AS IDRELTECRESCON, t98.ID_TECNICO_RESPONSABLE AS IDTECNICORESPONSABLE, t98.ID_CONVOCATORIA AS IDCONVOCATORIA");
		query.append(" FROM REL_TEC_RES_CON t98");
		query.append(" WHERE t98.ID_TECNICO_RESPONSABLE = ?");

		return this.jdbcTemplate.query(query.toString(), this.rwMap, idTecnicoResponsable);
	}

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
