package com.ejie.ab60.dao.estudioTecnico;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridRequestDto;

/**
 * TecnicosResponsablesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TecnicosResponsablesDaoImpl implements TecnicosResponsablesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTECNICORESPONSABLE", "NOMBRETECNICO",
			"FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TecnicosResponsables> rwMap = new RowMapper<TecnicosResponsables>() {
		public TecnicosResponsables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			TecnicosResponsables tecnicosResponsable = new TecnicosResponsables();

			tecnicosResponsable.setIdTecnicoResponsable(resultSet.getInt("IDTECNICORESPONSABLE"));
			tecnicosResponsable.setNombreTecnico(resultSet.getString("NOMBRETECNICO"));
			tecnicosResponsable.setFechaRegistro(resultSet.getDate("FECHAREGISTRO"));
			tecnicosResponsable.setUsuarioRegistro(resultSet.getString("USUARIOREGISTRO"));

			return tecnicosResponsable;
		}
	};

	private RowMapper<TecnicosResponsables> rwMapTecnico = new RowMapper<TecnicosResponsables>() {
		public TecnicosResponsables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TecnicosResponsables(resultSet.getInt("IDTECNICORESPONSABLE"),
					resultSet.getString("NOMBRETECNICO"));
		}
	};
	private RowMapper<TecnicosResponsables> rwMapPK = new RowMapper<TecnicosResponsables>() {
		public TecnicosResponsables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TecnicosResponsables(resultSet.getInt("IDTECNICORESPONSABLE"));
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TecnicosResponsables table.
	 *
	 * @param tecnicosresponsables
	 *            TecnicosResponsables
	 * @return TecnicosResponsables
	 */
	public TecnicosResponsables add(TecnicosResponsables tecnicosresponsables) {
		String query = "INSERT INTO TECNICOS_RESPONSABLES (ID_TECNICO_RESPONSABLE, NOMBRE_TECNICO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?)";
		tecnicosresponsables
				.setIdTecnicoResponsable(this.jdbcTemplate.queryForInt("SELECT AB60.S_AB6011T00.NEXTVAL FROM DUAL"));
		this.jdbcTemplate.update(query, tecnicosresponsables.getIdTecnicoResponsable(),
				tecnicosresponsables.getNombreTecnico(), tecnicosresponsables.getFechaRegistro(),
				tecnicosresponsables.getUsuarioRegistro());
		return tecnicosresponsables;
	}

	/**
	 * Updates a single row in the TecnicosResponsables table.
	 *
	 * @param tecnicosresponsables
	 *            TecnicosResponsables
	 * @return TecnicosResponsables
	 */
	public TecnicosResponsables update(TecnicosResponsables tecnicosresponsables) {
		String query = "UPDATE TECNICOS_RESPONSABLES SET NOMBRE_TECNICO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_TECNICO_RESPONSABLE=?";
		this.jdbcTemplate.update(query, tecnicosresponsables.getNombreTecnico(),
				tecnicosresponsables.getFechaUltModificacion(), tecnicosresponsables.getUsuarioUltModificacion(),
				tecnicosresponsables.getIdTecnicoResponsable());
		return tecnicosresponsables;
	}

	/**
	 * Finds a single row in the TecnicosResponsables table.
	 *
	 * @param tecnicosresponsables
	 *            TecnicosResponsables
	 * @return TecnicosResponsables
	 */
	@Transactional(readOnly = true)
	public TecnicosResponsables find(TecnicosResponsables tecnicosresponsables) {
		String query = "SELECT t11.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE, t11.NOMBRE_TECNICO NOMBRETECNICO, t11.FECHA_REGISTRO FECHAREGISTRO, t11.USUARIO_REGISTRO USUARIOREGISTRO FROM TECNICOS_RESPONSABLES t11  WHERE t11.ID_TECNICO_RESPONSABLE = ?  ";

		List<TecnicosResponsables> tecnicosresponsablesList = this.jdbcTemplate.query(query, this.rwMap,
				tecnicosresponsables.getIdTecnicoResponsable());
		return (TecnicosResponsables) DataAccessUtils.uniqueResult(tecnicosresponsablesList);
	}

	/**
	 * Finds a list of rows in the TecnicosResponsables table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param idExpediente
	 *            Integer
	 * @param justificacion
	 *            boolean
	 * 
	 * @return List<TecnicosResponsables>
	 */
	@Transactional(readOnly = true)
	public List<TecnicosResponsables> findTecnico(Integer idConvocatoria, Integer idExpediente, boolean justificacion) {
		StringBuilder query = new StringBuilder();

		/* Consulta para obtener los técnicos asociados a una convocatoira */
		query.append("SELECT  t11.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE,t11.NOMBRE_TECNICO NOMBRETECNICO");
		query.append(" FROM TECNICOS_RESPONSABLES t11, REL_TEC_RES_CON t2");
		query.append(" WHERE t2.ID_CONVOCATORIA = ? AND t11.ID_TECNICO_RESPONSABLE = t2.ID_TECNICO_RESPONSABLE");

		query.append(" UNION ");

		/*
		 * Para obtener los técnicos del expediente, aunque no pertenezcan a la
		 * convocatoria
		 */
		query.append(" SELECT t11.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE,  t11.NOMBRE_TECNICO NOMBRETECNICO");
		query.append(" FROM TECNICOS_RESPONSABLES t11, DATOS_PROYECTO t05");
		query.append(" WHERE 1= 1");
		if (justificacion) {
			query.append(" AND t11.ID_TECNICO_RESPONSABLE = t05.ID_TEC_RES_JUS");
		} else {
			query.append(" AND t11.ID_TECNICO_RESPONSABLE = t05.ID_TECNICO_RESPONSABLE");
		}
		query.append(" AND ID_EXPEDIENTE = ?");

		return this.jdbcTemplate.query(query.toString(), this.rwMapTecnico, idConvocatoria, idExpediente);

	}

	/**
	 * Baja lógica
	 *
	 * @param tecnicosresponsables
	 *            TecnicosResponsables *
	 * @return tecnicosresponsables TecnicosResponsables
	 */
	public TecnicosResponsables remove(TecnicosResponsables tecnicosresponsables) {
		String query = "UPDATE TECNICOS_RESPONSABLES SET BAJA=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_TECNICO_RESPONSABLE=?";
		this.jdbcTemplate.update(query, tecnicosresponsables.getBaja(), tecnicosresponsables.getFechaUltModificacion(),
				tecnicosresponsables.getUsuarioUltModificacion(), tecnicosresponsables.getIdTecnicoResponsable());
		return tecnicosresponsables;
	}

	/**
	 * Finds a list of rows in the TecnicosResponsables table.
	 *
	 * @param tecnicosresponsables
	 *            TecnicosResponsables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TecnicosResponsables>
	 */
	@Transactional(readOnly = true)
	public List<TecnicosResponsables> findAll(TecnicosResponsables tecnicosresponsables,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder();

		query.append(
				"SELECT  t11.ID_TECNICO_RESPONSABLE IDTECNICORESPONSABLE,t11.NOMBRE_TECNICO NOMBRETECNICO,t11.FECHA_REGISTRO FECHAREGISTRO,t11.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append(" FROM TECNICOS_RESPONSABLES t11");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tecnicosresponsables);
		StringBuilder where = new StringBuilder(" WHERE 1 = 1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TecnicosResponsablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TecnicosResponsables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TecnicosResponsables table.
	 *
	 * @param tecnicosresponsables
	 *            TecnicosResponsables
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TecnicosResponsables tecnicosresponsables) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TECNICOS_RESPONSABLES t11 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tecnicosresponsables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TecnicosResponsables entity
	 *
	 * @param tecnicosresponsables
	 *            TecnicosResponsables Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TecnicosResponsables tecnicosresponsables) {

		StringBuilder where = new StringBuilder(TecnicosResponsablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tecnicosresponsables != null && tecnicosresponsables.getBaja() != null
				&& tecnicosresponsables.getBaja() == Constantes.BAJA) {
			where.append(" AND t11.BAJA = ?");
			params.add(tecnicosresponsables.getBaja());
		} else if (tecnicosresponsables != null && tecnicosresponsables.getBaja() != null
				&& tecnicosresponsables.getBaja() == Constantes.NO_BAJA) {
			where.append(" AND (t11.BAJA = ? OR t11.BAJA IS NULL)");
			params.add(tecnicosresponsables.getBaja());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
