package com.ejie.ab60.dao.estudioTecnico;

import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

import com.ejie.ab60.model.estudioTecnico.TiposGasto;

/**
 * TiposGastoDao  
 * 
 *  
 */

public interface TiposGastoDao {

	/**
	 * Inserts a single row in the TiposGasto table.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 * @return TiposGasto
	 */
	TiposGasto add(TiposGasto tiposgasto);

	/**
	 * Updates a single row in the TiposGasto table.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 * @return TiposGasto
	 */
	TiposGasto update(TiposGasto tiposgasto);

	/**
	 * Finds a single row in the TiposGasto table.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 * @return TiposGasto
	 */
	TiposGasto find(TiposGasto tiposgasto);

	/**
	 * Removes a single row in the TiposGasto table.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 */
	void remove(TiposGasto tiposgasto);

	/**
	 * Finds a List of rows in the TiposGasto table.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<TiposGasto> findAll(TiposGasto tiposgasto, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds a list of rows in the TiposGasto table filtrado por idActSub. Cada
	 * actuacion subvencionable muestra unos tipos
	 * 
	 * @param idConvocatoria
	 *
	 * 
	 * @return List<TiposGasto>
	 */
	List<TiposGasto> findTiposGasto(Integer idCriterio, Integer idConvocatoria);

	/**
	 * Finds rows in the TiposGasto table using like.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<TiposGasto> findAllLike(TiposGasto tiposgasto, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the TiposGasto table using like.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(TiposGasto tiposgasto, Boolean startsWith);

	/**
	 * Counts rows in the TiposGasto table.
	 *
	 * @param tiposgasto
	 *            TiposGasto
	 * @return Long
	 */
	Long findAllCount(TiposGasto tiposgasto);

	/**
	 * Reorder selection.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposGasto>>
	 */
	List<TableRowDto<TiposGasto>> reorderSelection(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param searchTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposGasto>>
	 */
	List<TableRowDto<TiposGasto>> search(TiposGasto filterTiposGasto, TiposGasto searchTiposGasto,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposGasto>>
	 */
	List<JerarquiaDto<TiposGasto>> findAllLikeJerarquia(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposGasto>>
	 */
	List<TableRowDto<TiposGasto>> findAllChild(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto);

}
