package com.ejie.ab60.dao.expedientes;

import java.math.BigDecimal;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.estudioTecnico.TiposResultado;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.procedimientos.Areas;
import com.ejie.ab60.model.procedimientos.Direcciones;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.terceros.DatosDirecciones;
import com.ejie.ab60.model.terceros.DatosTerceros;
import com.ejie.ab60.model.terceros.TiposTercero;
import com.ejie.ab60.service.calculoAyuda.CalculoAyudaServiceImpl;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

@Repository
@Transactional
public class ExpedientesDaoImpl implements ExpedientesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDEXPEDIENTE", "IDTERRITORIOHISTORICO",
			"FOLDERID", "FOLDERNUMBER", "TITULO", "FECHAENTRADA", "FECHADOCFORMAL", "FECHAULTAPOR", "DOCUMENTO",
			"FECHAREGISTRO", "USUARIOREGISTRO", "PROCEDIMIENTOSIDPROCEDIMIENTO", "PROCEDIMIENTOSCODPROCEDUREID",
			"PROCEDIMIENTOSFOLDERID", "PROCEDIMIENTOSFOLDERNUMBER", "PROCEDIMIENTOSTITULOEXPEDIENTE",
			"PROCEDIMIENTOSFECHAREGISTRO", "PROCEDIMIENTOSUSUARIOREGISTRO", "PROCEDIMIENTOSIDDIRECCION",
			"PROCEDIMIENTOSIDAREA", "PROCEDIMIENTODESCES", "PROCEDIMIENTODESCEU", "IMPORTEPRESENTADO",
			"IMPORTEADMITIDO", "SUBVENCIONCALCULADA", "SUBVENCIONRESUELTA", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "NOMBRETERCERO", "NOMBREEMPRESA", "IMPORTERESUELTO", "IMPORTELIQUIDADO" };

	private JdbcTemplate jdbcTemplate;
	private static final Logger logger = LoggerFactory.getLogger(CalculoAyudaServiceImpl.class);

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Expedientes> rwMap = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Expedientes(resultSet.getInt("IDEXPEDIENTE"), resultSet.getLong("IDTERRITORIOHISTORICO"),
					resultSet.getString("FOLDERID"), resultSet.getString("FOLDERNUMBER"), resultSet.getString("TITULO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new Procedimientos(resultSet.getInt("ProcedimientosIDPROCEDIMIENTO"),
							resultSet.getString("ProcedimientosCODPROCEDUREID"),
							resultSet.getString("ProcedimientosTITULOEXPEDIENTE"),
							resultSet.getDate("ProcedimientosFECHAREGISTRO"),
							resultSet.getString("ProcedimientosUSUARIOREGISTRO"),
							new Direcciones(resultSet.getInt("ProcedimientosIDDIRECCION"), null, null, null, null, null,
									null, null),
							new Areas(resultSet.getInt("ProcedimientosIDAREA"), null, null, null, null, null, null)),
					resultSet.getInt("RELACIONEXPEDIENTE"));
		}
	};

	private RowMapper<Expedientes> rwMapProcedureId = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Expedientes expedientes = new Expedientes();
			Procedimientos procedimientos = new Procedimientos();
			procedimientos.setIdProcedimiento(resultSet.getInt("IDPROCEDIMIENTO"));
			expedientes.setProcedimientos(procedimientos);

			return expedientes;
		}
	};

	private RowMapper<Expedientes> rwMapExpedienteId = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			return expedientes;
		}
	};

	private RowMapper<Expedientes> rwMapEmpTer = new RowMapper<Expedientes>() {
		SimpleDateFormat formatoDeFecha = new SimpleDateFormat("dd/MM/yyyy hh:mm:ss");

		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			String folderNumber = "";
			String folderId = "";
			String titulo = "";
			Date fechaEntrada = null;
			Date fechaDoc = null;
			Date fechaUltaPor = null;
			BigDecimal importePresentado = null;
			BigDecimal importeAdmitido = null;
			BigDecimal subvencionCalculada = null;
			BigDecimal subvencionResuelta = null;
			String descripcionCastellano = "";
			String descripcionEuskera = "";
			String documento = "";
			String nombre = "";
			String apellido1 = "";
			String apellido2 = "";
			Integer idTipoAyuda = resultSet.getInt("IDTIPOAYUDA");

			try {
				if (null != resultSet.getString("FOLDERNUMBER")) {
					folderNumber = resultSet.getString("FOLDERNUMBER");
				}
				if (null != resultSet.getString("FOLDERID")) {
					folderId = resultSet.getString("FOLDERID");
				}
				if (null != resultSet.getString("TITULO")) {
					titulo = resultSet.getString("TITULO");
				}
				if (null != resultSet.getString("FECHAENTRADA")) {
					fechaEntrada = formatoDeFecha.parse(resultSet.getString("FECHAENTRADA"));
				}
				if (null != resultSet.getString("FECHADOCFORMAL")) {
					fechaDoc = formatoDeFecha.parse(resultSet.getString("FECHADOCFORMAL"));
				}
				if (null != resultSet.getString("FECHAULTAPOR")) {
					fechaUltaPor = formatoDeFecha.parse(resultSet.getString("FECHAULTAPOR"));
				}
				if (null != resultSet.getBigDecimal("IMPORTEPRESENTADO")) {
					importePresentado = resultSet.getBigDecimal("IMPORTEPRESENTADO");
				}
				if (null != resultSet.getBigDecimal("IMPORTEADMITIDO")) {
					importeAdmitido = resultSet.getBigDecimal("IMPORTEADMITIDO");
				}
				if (null != resultSet.getBigDecimal("SUBVENCIONCALCULADA")) {
					subvencionCalculada = resultSet.getBigDecimal("SUBVENCIONCALCULADA");
				}
				if (null != resultSet.getBigDecimal("SUBVENCIONRESUELTA")) {
					subvencionResuelta = resultSet.getBigDecimal("SUBVENCIONRESUELTA");
				}
				if (null != resultSet.getString("DESCRIPCIONCASTELLANO")) {
					descripcionCastellano = resultSet.getString("DESCRIPCIONCASTELLANO");
				}
				if (null != resultSet.getString("DESCRIPCIONEUSKERA")) {
					descripcionEuskera = resultSet.getString("DESCRIPCIONEUSKERA");
				}

				if (null != resultSet.getString("NOMBRE")) {
					nombre = resultSet.getString("NOMBRE");
				}
				if (null != resultSet.getString("DOCUMENTO")) {
					documento = resultSet.getString("DOCUMENTO");
				}

				if (null != resultSet.getString("APELLIDO1")) {
					apellido1 = resultSet.getString("APELLIDO1");
				}
				if (null != resultSet.getString("APELLIDO2")) {
					apellido2 = resultSet.getString("APELLIDO2");
				}
			} catch (ParseException e) {
				logger.error(
						"Excepcion recogida en el mapRow al parsear las fechas de la busqueda de expedientes =  " + e);
			}
			logger.info("fechaEntrada = " + fechaEntrada);
			logger.info("fechaDoc = " + fechaDoc);
			logger.info("fechaUltaPor = " + fechaUltaPor);

			Expedientes expedientes = new Expedientes();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expedientes.setFolderNumber(folderNumber);
			expedientes.setFolderId(folderId);
			expedientes.setTitulo(titulo);
			expedientes.setFechaEntrada(fechaEntrada);
			expedientes.setFechaDocFormal(fechaDoc);
			expedientes.setFechaUltApor(fechaUltaPor);
			EstudioTecnico estudioTecnico = new EstudioTecnico();
			TiposResultado tipoResultado = new TiposResultado();

			DatosTerceros datosTerceros = new DatosTerceros();

			if (idTipoAyuda != Constantes.TIPO_AYUDA_BEC) {
				estudioTecnico.setImportePresentado(importePresentado);
				estudioTecnico.setImporteAdmitido(importeAdmitido);
				estudioTecnico.setSubvencionCalculada(subvencionCalculada);
				estudioTecnico.setSubvencionResuelta(subvencionResuelta);
				expedientes.setEstudioTecnico(estudioTecnico);
				tipoResultado.setDescripcionCastellano(descripcionCastellano);
				tipoResultado.setDescripcionEuskera(descripcionEuskera);
				expedientes.setTiposResultado(tipoResultado);

				datosTerceros.setDocumento(documento);
				datosTerceros.setNombre(nombre);
				datosTerceros.setApellido1(apellido1);
				datosTerceros.setApellido2(apellido2);
				expedientes.setDatosTerceros(datosTerceros);
			} else {
				datosTerceros.setDocumento(documento);
				datosTerceros.setNombre(nombre);
				datosTerceros.setApellido1(apellido1);
				datosTerceros.setApellido2(apellido2);
				expedientes.setDatosTerceros(datosTerceros);
				expedientes.setEstudioTecnico(estudioTecnico);
				expedientes.setTiposResultado(tipoResultado);
			}

			return expedientes;
		}
	};

	private RowMapper<Expedientes> rwMapPK = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Expedientes(resultSet.getInt("IDEXPEDIENTE"));
		}
	};

	private RowMapper<Expedientes> rwMapFolderNumber = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Expedientes(resultSet.getString("FOLDER_NUMBER"));
		}
	};

	private RowMapper<Expedientes> rwMapExpedientesRelacionadosTitular = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Expedientes expediente = new Expedientes();
			expediente.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expediente.setFolderId(resultSet.getString("FOLDERID"));
			expediente.setFolderNumber(resultSet.getString("FOLDERNUMBER"));
			expediente.setTitulo(resultSet.getString("TITULO"));
			expediente.setImporteResuelto(resultSet.getBigDecimal("IMPORTERESUELTO"));
			if (resultSet.wasNull()) {
				expediente.setImporteResuelto(BigDecimal.ZERO);
			}
			expediente.setImporteLiquidado(resultSet.getBigDecimal("IMPORTELIQUIDADO"));
			if (resultSet.wasNull()) {
				expediente.setImporteLiquidado(BigDecimal.ZERO);
			}
			expediente.setUrlAplicacion(resultSet.getString("URLAPLICACION"));
			expediente.setExpedienteHistorico(resultSet.getBoolean("EXPEDIENTEHISTORICO"));

			DatosTerceros datosTercero = new DatosTerceros();
			datosTercero.setDocumento(resultSet.getString("DOCUMENTOTITULAR"));
			expediente.setDatosTerceros(datosTercero);

			Procedimientos procedimiento = new Procedimientos();
			procedimiento.setDescripcionEs(resultSet.getString("PROCEDIMIENTODESCES"));
			procedimiento.setDescripcionEu(resultSet.getString("PROCEDIMIENTODESCEU"));
			expediente.setProcedimiento(procedimiento);

			return expediente;
		}
	};

	private RowMapper<Expedientes> rwMapExpedientesRelacionadosUbicacion = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Expedientes expediente = new Expedientes();
			expediente.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expediente.setFolderId(resultSet.getString("FOLDERID"));
			expediente.setFolderNumber(resultSet.getString("FOLDERNUMBER"));
			expediente.setTitulo(resultSet.getString("TITULO"));
			expediente.setImporteResuelto(resultSet.getBigDecimal("IMPORTERESUELTO"));
			if (resultSet.wasNull()) {
				expediente.setImporteResuelto(BigDecimal.ZERO);
			}
			expediente.setImporteLiquidado(resultSet.getBigDecimal("IMPORTELIQUIDADO"));
			if (resultSet.wasNull()) {
				expediente.setImporteLiquidado(BigDecimal.ZERO);
			}
			expediente.setUrlAplicacion(resultSet.getString("URLAPLICACION"));
			expediente.setExpedienteHistorico(resultSet.getBoolean("EXPEDIENTEHISTORICO"));

			DatosDirecciones datosDireccion = new DatosDirecciones();
			datosDireccion.setIdentificadorEstablecimiento(resultSet.getString("IDENTIFICADORESTABLECIMIENTO"));
			expediente.setDatosDirecciones(datosDireccion);

			Procedimientos procedimiento = new Procedimientos();
			procedimiento.setDescripcionEs(resultSet.getString("PROCEDIMIENTODESCES"));
			procedimiento.setDescripcionEu(resultSet.getString("PROCEDIMIENTODESCEU"));
			expediente.setProcedimiento(procedimiento);

			return expediente;
		}
	};

	private RowMapper<Expedientes> rwMapExpedientesRelacionadosUbicacionRelacionExpediente = new RowMapper<Expedientes>() {
		public Expedientes mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Expedientes expediente = new Expedientes();
			expediente.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expediente.setFolderId(resultSet.getString("FOLDERID"));
			expediente.setFolderNumber(resultSet.getString("FOLDERNUMBER"));
			expediente.setTitulo(resultSet.getString("TITULO"));
			expediente.setImporteResuelto(resultSet.getBigDecimal("IMPORTERESUELTO"));
			if (resultSet.wasNull()) {
				expediente.setImporteResuelto(BigDecimal.ZERO);
			}
			expediente.setImporteLiquidado(resultSet.getBigDecimal("IMPORTELIQUIDADO"));
			if (resultSet.wasNull()) {
				expediente.setImporteLiquidado(BigDecimal.ZERO);
			}
			expediente.setUrlAplicacion(resultSet.getString("URLAPLICACION"));
			expediente.setExpedienteHistorico(resultSet.getBoolean("EXPEDIENTEHISTORICO"));
			expediente.setRelacionExpediente(resultSet.getInt("RELACIONEXPEDIENTE"));

			Procedimientos procedimiento = new Procedimientos();
			procedimiento.setDescripcionEs(resultSet.getString("PROCEDIMIENTODESCES"));
			procedimiento.setDescripcionEu(resultSet.getString("PROCEDIMIENTODESCEU"));
			expediente.setProcedimiento(procedimiento);

			return expediente;
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Expedientes>> rwMapJerarquia = new RowMapper<JerarquiaDto<Expedientes>>() {
		public JerarquiaDto<Expedientes> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Expedientes expedientes = new Expedientes(resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getLong("IDTERRITORIOHISTORICO"), resultSet.getString("FOLDERID"),
					resultSet.getString("FOLDERNUMBER"), resultSet.getString("TITULO"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new Procedimientos(resultSet.getInt("ProcedimientosIDPROCEDIMIENTO"),
							resultSet.getString("ProcedimientosCODPROCEDUREID"),
							resultSet.getString("ProcedimientosTITULOEXPEDIENTE"),
							resultSet.getDate("ProcedimientosFECHAREGISTRO"),
							resultSet.getString("ProcedimientosUSUARIOREGISTRO"),
							new Direcciones(resultSet.getInt("ProcedimientosIDDIRECCION"), null, null, null, null, null,
									null, null),
							new Areas(resultSet.getInt("ProcedimientosIDAREA"), null, null, null, null, null, null)),
					resultSet.getInt("RELACIONEXPEDIENTE"));

			JerarquiaDto<Expedientes> jerarquia = new JerarquiaDto<Expedientes>();
			jerarquia.setModel(expedientes);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes add(Expedientes expedientes) {
		String query = "INSERT INTO EXPEDIENTES (ID_EXPEDIENTE, ID_PROCEDIMIENTO, ID_TERRITORIO_HISTORICO, FOLDER_ID, FOLDER_NUMBER, TITULO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?)";
		Object getProcedimientosIdProcedimientoAux = null;
		if (expedientes.getProcedimientos() != null && expedientes.getProcedimientos().getIdProcedimiento() != null) {
			getProcedimientosIdProcedimientoAux = expedientes.getProcedimientos().getIdProcedimiento();
		}
		this.jdbcTemplate.update(query, expedientes.getIdExpediente(), getProcedimientosIdProcedimientoAux,
				expedientes.getIdTerritorioHistorico(), expedientes.getFolderId(), expedientes.getFolderNumber(),
				expedientes.getTitulo(), expedientes.getFechaRegistro(), expedientes.getUsuarioRegistro());
		return expedientes;
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes update(Expedientes expedientes) {
		String query = "UPDATE EXPEDIENTES SET ID_PROCEDIMIENTO=?, ID_TERRITORIO_HISTORICO=?, FOLDER_ID=?, FOLDER_NUMBER=?, TITULO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_EXPEDIENTE=?";
		Object getProcedimientosIdProcedimientoAux = null;
		if (expedientes.getProcedimientos() != null && expedientes.getProcedimientos().getIdProcedimiento() != null) {
			getProcedimientosIdProcedimientoAux = expedientes.getProcedimientos().getIdProcedimiento();
		}
		this.jdbcTemplate.update(query, getProcedimientosIdProcedimientoAux, expedientes.getIdTerritorioHistorico(),
				expedientes.getFolderId(), expedientes.getFolderNumber(), expedientes.getTitulo(),
				expedientes.getFechaRegistro(), expedientes.getUsuarioRegistro(), expedientes.getIdExpediente());
		return expedientes;
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes updateFolder(Expedientes expedientes) {
		String query = "UPDATE EXPEDIENTES SET FOLDER_NUMBER=?, FOLDER_ID=? WHERE ID_EXPEDIENTE=?";

		this.jdbcTemplate.update(query, expedientes.getFolderNumber(), expedientes.getFolderId(),
				expedientes.getIdExpediente());
		return expedientes;
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes updateFolderTitle(Expedientes expedientes) {
		String query = "UPDATE EXPEDIENTES SET TITULO=?, FECHA_REGISTRO=sysdate, USUARIO_REGISTRO=? WHERE FOLDER_ID=?";
		logger.info("Inicio updateFolderTitle");
		logger.info("Query = " + query);
		logger.info("PARAMETRO TITULO = " + expedientes.getTitulo());
		logger.info("PARAMETRO FECHA_REGISTRO = SYSDATE");
		logger.info("PARAMETRO USUARIO_REGISTRO = " + expedientes.getUsuarioRegistro());
		logger.info("PARAMETRO FOLDER_ID = " + expedientes.getFolderId());
		this.jdbcTemplate.update(query, expedientes.getTitulo(), expedientes.getUsuarioRegistro(),
				expedientes.getFolderId());
		return expedientes;
	}

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(readOnly = true)
	public Expedientes find(Expedientes expedientes) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_TERRITORIO_HISTORICO IDTERRITORIOHISTORICO, t1.FOLDER_ID FOLDERID, t1.FOLDER_NUMBER FOLDERNUMBER, t1.TITULO TITULO, t1.RELACION_EXPEDIENTE RELACIONEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_PROCEDIMIENTO PROCEDIMIENTOSIDPROCEDIMIENTO, t2.COD_PROCEDURE_ID PROCEDIMIENTOSCODPROCEDUREID,  t2.CAMPOS_TITULO_EXPEDIENTE ProcedimientosTITULOEXPEDIENTE, t2.FECHA_REGISTRO PROCEDIMIENTOSFECHAREGISTRO, t2.USUARIO_REGISTRO PROCEDIMIENTOSUSUARIOREGISTRO, t2.ID_DIRECCION PROCEDIMIENTOSIDDIRECCION, t2.ID_AREA PROCEDIMIENTOSIDAREA FROM EXPEDIENTES t1 , PROCEDIMIENTOS t2  WHERE t1.ID_EXPEDIENTE = ?   AND t1.ID_PROCEDIMIENTO= t2.ID_PROCEDIMIENTO(+)";

		List<Expedientes> expedientesList = this.jdbcTemplate.query(query, this.rwMap, expedientes.getIdExpediente());
		return (Expedientes) DataAccessUtils.uniqueResult(expedientesList);
	}

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(readOnly = true)
	public Expedientes findProcedureIdPorExpediente(Expedientes expedientes) {
		String query = "SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO FROM AB61.EXPEDIENTES t1, AB61.PROCEDIMIENTOS t2 WHERE t1.ID_PROCEDIMIENTO = t2.ID_PROCEDIMIENTO(+) AND t1.ID_EXPEDIENTE   = ?";

		List<Expedientes> expedientesList = this.jdbcTemplate.query(query, this.rwMapProcedureId,
				expedientes.getIdExpediente());
		return (Expedientes) DataAccessUtils.uniqueResult(expedientesList);
	}

	/**
	 * Finds a single row in the Expedientes table por FolderId.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(readOnly = true)
	public Expedientes findByFolderId(Expedientes expedientes) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_TERRITORIO_HISTORICO IDTERRITORIOHISTORICO, t1.FOLDER_ID FOLDERID, t1.FOLDER_NUMBER FOLDERNUMBER, t1.TITULO TITULO, t1.RELACION_EXPEDIENTE RELACIONEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_PROCEDIMIENTO PROCEDIMIENTOSIDPROCEDIMIENTO, t2.COD_PROCEDURE_ID PROCEDIMIENTOSCODPROCEDUREID, t2.CAMPOS_TITULO_EXPEDIENTE ProcedimientosTITULOEXPEDIENTE, t2.FECHA_REGISTRO PROCEDIMIENTOSFECHAREGISTRO, t2.USUARIO_REGISTRO PROCEDIMIENTOSUSUARIOREGISTRO, t2.ID_DIRECCION PROCEDIMIENTOSIDDIRECCION, t2.ID_AREA PROCEDIMIENTOSIDAREA FROM EXPEDIENTES t1 , PROCEDIMIENTOS t2  WHERE t1.FOLDER_ID = ?   AND t1.ID_PROCEDIMIENTO= t2.ID_PROCEDIMIENTO(+)";

		List<Expedientes> expedientesList = this.jdbcTemplate.query(query, this.rwMap, expedientes.getFolderId());
		return (Expedientes) DataAccessUtils.uniqueResult(expedientesList);
	}

	/**
	 * Finds a single row in the Expedientes table por FolderId.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(readOnly = true)
	public Expedientes findByFolderNumber(Expedientes expedientes) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE FROM EXPEDIENTES t1 , PROCEDIMIENTOS t2  WHERE t1.FOLDER_NUMBER = ?";

		List<Expedientes> expedientesList = this.jdbcTemplate.query(query, this.rwMapFolderNumber,
				expedientes.getFolderNumber());
		return (Expedientes) DataAccessUtils.uniqueResult(expedientesList);
	}

	@Override
	public List<Expedientes> findExpedientesRelacionadosTitular(String documentosTitular, Integer idExpediente,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FOLDER_ID FOLDERID, t1.FOLDER_NUMBER FOLDERNUMBER, t1.TITULO TITULO, t3.DOCUMENTO DOCUMENTOTITULAR, t4.DESCRIPCION_CASTELLANO PROCEDIMIENTODESCES, t4.DESCRIPCION_EUSKERA PROCEDIMIENTODESCEU, t5.SUBVENCION_RESUELTA IMPORTERESUELTO, t5.IMPORTE_JUS_CALCULADO IMPORTELIQUIDADO, t6.URL_APLICACION URLAPLICACION, 0 EXPEDIENTEHISTORICO FROM EXPEDIENTES t1, REL_EXP_TER t2, DATOS_TERCEROS t3, PROCEDIMIENTOS t4, DATOS_PROYECTO t5, APLICACIONES t6 WHERE t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t1.ID_PROCEDIMIENTO = t4.ID_PROCEDIMIENTO AND t1.ID_EXPEDIENTE = t5.ID_EXPEDIENTE(+) AND t4.ID_APLICACION = t6.ID_APLICACION AND t3.DOCUMENTO IN ("
						+ documentosTitular + ")  AND t2.ID_TIPO_TERCERO IN (" + Constantes.PARTICIPACION_SOLICITANTE
						+ ", " + Constantes.PARTICIPACION_AFECTADO
						+ ") AND t1.ID_EXPEDIENTE <> ? UNION SELECT t7.ID_EXP_HISTORICO IDEXPEDIENTE, t7.FOLDER_ID FOLDERID, t7.FOLDER_NUMBER FOLDERNUMBER, t7.TITULO TITULO, t7.DOCUMENTO_TITULAR DOCUMENTOTITULAR, t7.NOM_PROCEDIMIENTO PROCEDIMIENTODESCES, t7.NOM_PROCEDIMIENTO PROCEDIMIENTODESCEU, t7.IMPORTE_RESUELTO IMPORTERESUELTO, t7.IMPORTE_LIQUIDADO IMPORTELIQUIDADO, NULL URLAPLICACION, 1 EXPEDIENTEHISTORICO FROM EXP_HISTORICO t7 WHERE t7.DOCUMENTO_TITULAR IN ("
						+ documentosTitular + ") ");

		return (List<Expedientes>) this.jdbcTemplate.query(query.toString(), this.rwMapExpedientesRelacionadosTitular,
				idExpediente);
	}

	@Override
	public Long findExpedientesRelacionadosTitularCount(String documentosTitular, Integer idExpediente) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM (SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE FROM EXPEDIENTES t1, REL_EXP_TER t2, DATOS_TERCEROS t3, PROCEDIMIENTOS t4, DATOS_PROYECTO t5, APLICACIONES t6 WHERE t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t1.ID_PROCEDIMIENTO = t4.ID_PROCEDIMIENTO AND t1.ID_EXPEDIENTE = t5.ID_EXPEDIENTE(+) AND t4.ID_APLICACION = t6.ID_APLICACION AND t3.DOCUMENTO IN ("
						+ documentosTitular
						+ ") AND t1.ID_EXPEDIENTE <> ? UNION SELECT t7.ID_EXP_HISTORICO IDEXPEDIENTE FROM EXP_HISTORICO t7 WHERE t7.DOCUMENTO_TITULAR IN ("
						+ documentosTitular + ") ) ");

		return this.jdbcTemplate.queryForLong(query.toString(), idExpediente);
	}

	@Override
	public List<Expedientes> findExpedientesRelacionadosUbicacion(String identificadorEstablecimiento,
			Integer idExpediente, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FOLDER_ID FOLDERID, t1.FOLDER_NUMBER FOLDERNUMBER, t1.TITULO TITULO, t4.DESCRIPCION_CASTELLANO PROCEDIMIENTODESCES, t4.DESCRIPCION_EUSKERA PROCEDIMIENTODESCEU, t5.SUBVENCION_RESUELTA IMPORTERESUELTO, t5.IMPORTE_JUS_CALCULADO IMPORTELIQUIDADO, t6.URL_APLICACION URLAPLICACION, t8.IDENTIFICADOR_ESTABLECIMIENTO IDENTIFICADORESTABLECIMIENTO, 0 EXPEDIENTEHISTORICO FROM EXPEDIENTES t1, REL_EXP_TER t2, DATOS_TERCEROS t3, PROCEDIMIENTOS t4, DATOS_PROYECTO t5, APLICACIONES t6, DATOS_DIRECCIONES t8 WHERE t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t3.ID_TERCERO = t8.ID_TERCERO AND t1.ID_PROCEDIMIENTO = t4.ID_PROCEDIMIENTO AND t1.ID_EXPEDIENTE = t5.ID_EXPEDIENTE AND t4.ID_APLICACION = t6.ID_APLICACION AND t8.IDENTIFICADOR_ESTABLECIMIENTO = ? AND t1.ID_EXPEDIENTE <> ? UNION SELECT t7.ID_EXP_HISTORICO IDEXPEDIENTE, t7.FOLDER_ID FOLDERID, t7.FOLDER_NUMBER FOLDERNUMBER, t7.TITULO TITULO, t7.NOM_PROCEDIMIENTO PROCEDIMIENTODESCES, t7.NOM_PROCEDIMIENTO PROCEDIMIENTODESCEU, t7.IMPORTE_RESUELTO IMPORTERESUELTO, t7.IMPORTE_LIQUIDADO IMPORTELIQUIDADO, NULL URLAPLICACION, t9.IDENTIFICADOR_ESTABLECIMIENTO IDENTIFICADORESTABLECIMIENTO, 1 EXPEDIENTEHISTORICO FROM EXP_HISTORICO t7, AB61.ESTABLECIMIENTOS_REGISTRADOS t9 WHERE t7.ID_ESTABLECIMIENTO = t9.ID_ESTABLECIMIENTO AND t9.IDENTIFICADOR_ESTABLECIMIENTO = ?");

		return (List<Expedientes>) this.jdbcTemplate.query(query.toString(), this.rwMapExpedientesRelacionadosUbicacion,
				identificadorEstablecimiento, idExpediente, identificadorEstablecimiento);
	}

	@Override
	public Long findExpedientesRelacionadosUbicacionCount(String identificadorEstablecimiento, Integer idExpediente) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM (SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE FROM EXPEDIENTES t1, REL_EXP_TER t2, DATOS_TERCEROS t3, PROCEDIMIENTOS t4, DATOS_PROYECTO t5, APLICACIONES t6, DATOS_DIRECCIONES t8 WHERE t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE AND t2.ID_TERCERO = t3.ID_TERCERO AND t3.ID_TERCERO = t8.ID_TERCERO AND t1.ID_PROCEDIMIENTO = t4.ID_PROCEDIMIENTO AND t1.ID_EXPEDIENTE = t5.ID_EXPEDIENTE AND t4.ID_APLICACION = t6.ID_APLICACION AND t8.IDENTIFICADOR_ESTABLECIMIENTO = ? AND t1.ID_EXPEDIENTE <> ? UNION SELECT t7.ID_EXP_HISTORICO IDEXPEDIENTE FROM EXP_HISTORICO t7, AB61.ESTABLECIMIENTOS_REGISTRADOS t9 WHERE t7.ID_ESTABLECIMIENTO = t9.ID_ESTABLECIMIENTO AND t9.IDENTIFICADOR_ESTABLECIMIENTO = ? ) ");

		return this.jdbcTemplate.queryForLong(query.toString(), identificadorEstablecimiento, idExpediente,
				identificadorEstablecimiento);
	}

	@Override
	public List<Expedientes> findExpedientesRelacionadosUbicacionRelacionExpediente(Integer relacionExpediente,
			Integer idExpediente, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FOLDER_ID FOLDERID, t1.FOLDER_NUMBER FOLDERNUMBER, t1.TITULO TITULO, t1.RELACION_EXPEDIENTE RELACIONEXPEDIENTE, t2.DESCRIPCION_CASTELLANO PROCEDIMIENTODESCES, t2.DESCRIPCION_EUSKERA PROCEDIMIENTODESCEU, t3.SUBVENCION_RESUELTA IMPORTERESUELTO, t3.IMPORTE_JUS_CALCULADO IMPORTELIQUIDADO, t4.URL_APLICACION URLAPLICACION, 0 EXPEDIENTEHISTORICO FROM EXPEDIENTES t1, PROCEDIMIENTOS t2, DATOS_PROYECTO t3, APLICACIONES t4 WHERE t1.ID_PROCEDIMIENTO = t2.ID_PROCEDIMIENTO AND t1.ID_EXPEDIENTE = t3.ID_EXPEDIENTE AND t2.ID_APLICACION = t4.ID_APLICACION AND t1.RELACION_EXPEDIENTE = ? AND t1.ID_EXPEDIENTE <> ? UNION SELECT t5.ID_EXP_HISTORICO IDEXPEDIENTE, t5.FOLDER_ID FOLDERID, t5.FOLDER_NUMBER FOLDERNUMBER, t5.TITULO TITULO, t5.RELACION_EXPEDIENTE RELACIONEXPEDIENTE, t5.NOM_PROCEDIMIENTO PROCEDIMIENTODESCES, t5.NOM_PROCEDIMIENTO PROCEDIMIENTODESCEU, t5.IMPORTE_RESUELTO IMPORTERESUELTO, t5.IMPORTE_LIQUIDADO IMPORTELIQUIDADO, NULL URLAPLICACION, 1 EXPEDIENTEHISTORICO FROM EXP_HISTORICO t5 WHERE t5.RELACION_EXPEDIENTE = ?");

		return (List<Expedientes>) this.jdbcTemplate.query(query.toString(),
				this.rwMapExpedientesRelacionadosUbicacionRelacionExpediente, relacionExpediente, idExpediente,
				relacionExpediente);
	}

	@Override
	public Long findExpedientesRelacionadosUbicacionRelacionExpedienteCount(Integer relacionExpediente,
			Integer idExpediente) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM (SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE FROM EXPEDIENTES t1, PROCEDIMIENTOS t2, DATOS_PROYECTO t3, APLICACIONES t4 WHERE t1.ID_PROCEDIMIENTO = t2.ID_PROCEDIMIENTO AND t1.ID_EXPEDIENTE = t3.ID_EXPEDIENTE AND t2.ID_APLICACION = t4.ID_APLICACION AND t1.RELACION_EXPEDIENTE = ? AND t1.ID_EXPEDIENTE <> ? UNION SELECT t5.ID_EXP_HISTORICO IDEXPEDIENTE FROM EXP_HISTORICO t5 WHERE t5.RELACION_EXPEDIENTE = ? ) ");

		return this.jdbcTemplate.queryForLong(query.toString(), relacionExpediente, idExpediente, relacionExpediente);
	}

	/**
	 * Removes a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return
	 */
	public void remove(Expedientes expedientes) {
		String query = "DELETE FROM EXPEDIENTES WHERE ID_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, expedientes.getIdExpediente());
	}

	/**
	 * Finds a list of rows in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Expedientes>
	 */
	@Transactional(readOnly = true)
	public List<Expedientes> findAll(Expedientes expedientes, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TERRITORIO_HISTORICO IDTERRITORIOHISTORICO,t1.FOLDER_ID FOLDERID,t1.FOLDER_NUMBER FOLDERNUMBER,t1.TITULO TITULO,t1.RELACION_EXPEDIENTE RELACIONEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_PROCEDIMIENTO PROCEDIMIENTOSIDPROCEDIMIENTO,t2.COD_PROCEDURE_ID PROCEDIMIENTOSCODPROCEDUREID,t2.CAMPOS_TITULO_EXPEDIENTE ProcedimientosTITULOEXPEDIENTE,t2.FECHA_REGISTRO PROCEDIMIENTOSFECHAREGISTRO,t2.USUARIO_REGISTRO PROCEDIMIENTOSUSUARIOREGISTRO,t2.ID_DIRECCION PROCEDIMIENTOSIDDIRECCION,t2.ID_AREA PROCEDIMIENTOSIDAREA ");
		query.append("FROM EXPEDIENTES t1 ,PROCEDIMIENTOS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(expedientes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_PROCEDIMIENTO= t2.ID_PROCEDIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ExpedientesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Expedientes>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Expedientes expedientes) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM EXPEDIENTES t1 , PROCEDIMIENTOS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(expedientes);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_PROCEDIMIENTO= t2.ID_PROCEDIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Finds rows in the Expedientes table using like.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Expedientes>
	 */

	@Transactional(readOnly = true)
	public List<Expedientes> findAllLikeTer(Expedientes expedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder();
		query.append(
				"SELECT T1.ID_EXPEDIENTE IDEXPEDIENTE, T1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, T1.FOLDER_NUMBER FOLDERNUMBER, t1.FOLDER_ID FOLDERID, T1.TITULO TITULO, (SELECT DISTINCT TO_CHAR(T11.FECHA_EXPEDIENTE,'DD/MM/YYYY HH24:MI:SS') FROM REL_EXP_FECH T11, FECHAS_EXPEDIENTE T12 WHERE T11.ID_EXPEDIENTE=T1.ID_EXPEDIENTE AND T11.ID_FECHA_EXPEDIENTE=T12.ID_FECHA_EXPEDIENTE AND UPPER(T12.ETIQUETA_FECHA) =UPPER(?)) AS FECHAENTRADA, ");
		query.append(
				"(SELECT DISTINCT TO_CHAR(T11.FECHA_EXPEDIENTE,'DD/MM/YYYY HH24:MI:SS') FROM REL_EXP_FECH T11, FECHAS_EXPEDIENTE T12 WHERE T11.ID_EXPEDIENTE=T1.ID_EXPEDIENTE AND T11.ID_FECHA_EXPEDIENTE=T12.ID_FECHA_EXPEDIENTE AND UPPER(T12.ETIQUETA_FECHA) =UPPER(?)) AS FECHADOCFORMAL, "
						+ "(SELECT DISTINCT TO_CHAR(T11.FECHA_EXPEDIENTE,'DD/MM/YYYY HH24:MI:SS') FROM REL_EXP_FECH T11, FECHAS_EXPEDIENTE T12 WHERE T11.ID_EXPEDIENTE=T1.ID_EXPEDIENTE AND T11.ID_FECHA_EXPEDIENTE=T12.ID_FECHA_EXPEDIENTE AND UPPER(T12.ETIQUETA_FECHA) =UPPER(?) ) AS FECHAULTAPOR,"
						+ " T10.ID_TIPO_AYUDA IDTIPOAYUDA, ");

		if (null != expedientes.getConvocatoria() && null != expedientes.getConvocatoria().getIdTipoAyuda()
				&& expedientes.getConvocatoria().getIdTipoAyuda() != Constantes.TIPO_AYUDA_BEC) {
			query.append(
					"T4.IMPORTE_PRESENTADO IMPORTEPRESENTADO, T4.IMPORTE_ADMITIDO IMPORTEADMITIDO, T4.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, T4.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, ");
			query.append(
					"T5.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T5.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, T8.DOCUMENTO DOCUMENTO, ");
			query.append("t8.nombre nombre, t8.apellido1 apellido1, t8.apellido2 apellido2 ");
		} else {
			query.append(
					"NULL AS IMPORTEPRESENTADO, NULL AS IMPORTEADMITIDO, NULL AS SUBVENCIONCALCULADA, NULL AS SUBVENCIONRESUELTA, NULL AS DESCRIPCIONCASTELLANO, ");
			query.append(
					"NULL AS DESCRIPCIONEUSKERA, T8.DOCUMENTO DOCUMENTO, T8.NOMBRE NOMBRE, T8.APELLIDO1 APELLIDO1, T8.APELLIDO2 APELLIDO2 ");
		}

		if (null != expedientes.getConvocatoria() && null != expedientes.getConvocatoria().getIdTipoAyuda()
				&& expedientes.getConvocatoria().getIdTipoAyuda() != Constantes.TIPO_AYUDA_BEC) {
			query.append(
					"FROM EXPEDIENTES T1 INNER JOIN REL_EXP_TER T2 ON T1.ID_EXPEDIENTE = T2.ID_EXPEDIENTE INNER JOIN DATOS_PROYECTO T4 ON T1.ID_EXPEDIENTE = T4.ID_EXPEDIENTE ");
			query.append(
					"FULL OUTER JOIN TIPOS_RESULTADO T5 ON T4.ID_RESULTADO = T5.ID_RESULTADO INNER JOIN PROCEDIMIENTOS T6 ON T1.ID_PROCEDIMIENTO = T6.ID_PROCEDIMIENTO ");
			query.append(
					"INNER JOIN CONVOCATORIAS T7 ON T6.ID_PROCEDIMIENTO = T7.ID_PROCEDIMIENTO INNER JOIN DATOS_TERCEROS T8 ON T2.ID_TERCERO = T8.ID_TERCERO INNER JOIN CONVOCATORIAS T10 ON T1.ID_PROCEDIMIENTO = T10.ID_PROCEDIMIENTO AND  T8.TIPO_PARTICIPANTE="
							+ Constantes.PARTICIPANTE_TITULAR);
		} else {
			query.append(
					"FROM EXPEDIENTES T1 INNER JOIN REL_EXP_TER T2 ON T1.ID_EXPEDIENTE = T2.ID_EXPEDIENTE INNER JOIN PROCEDIMIENTOS T6 ON T1.ID_PROCEDIMIENTO = T6.ID_PROCEDIMIENTO ");
			query.append(
					"INNER JOIN CONVOCATORIAS T7 ON T6.ID_PROCEDIMIENTO = T7.ID_PROCEDIMIENTO INNER JOIN DATOS_TERCEROS T8 ON T2.ID_TERCERO = T8.ID_TERCERO INNER JOIN CONVOCATORIAS T10 ON T1.ID_PROCEDIMIENTO = T10.ID_PROCEDIMIENTO  AND  T8.TIPO_PARTICIPANTE="
							+ Constantes.PARTICIPANTE_TITULAR);
		}

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereExpedientes(expedientes);
		query.append(mapaWhere.get("query"));

		List<?> params = (List<?>) mapaWhere.get("params");

		// añdimos los parametros de la subselect

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, ExpedientesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Expedientes>) this.jdbcTemplate.query(query.toString(), this.rwMapEmpTer, params.toArray());
	}

	/**
	 * Counts rows in the Expedientes table using like.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCountTer(Expedientes expedientes, Boolean startsWith) {

		StringBuilder query = new StringBuilder("SELECT COUNT(1) ");

		if (null != expedientes.getConvocatoria() && null != expedientes.getConvocatoria().getIdTipoAyuda()
				&& expedientes.getConvocatoria().getIdTipoAyuda() != Constantes.TIPO_AYUDA_BEC) {
			query.append(
					"FROM EXPEDIENTES T1 INNER JOIN REL_EXP_TER T2 ON T1.ID_EXPEDIENTE = T2.ID_EXPEDIENTE INNER JOIN DATOS_PROYECTO T4 ON T1.ID_EXPEDIENTE = T4.ID_EXPEDIENTE ");
			query.append(
					"FULL OUTER JOIN TIPOS_RESULTADO T5 ON T4.ID_RESULTADO = T5.ID_RESULTADO INNER JOIN PROCEDIMIENTOS T6 ON T1.ID_PROCEDIMIENTO = T6.ID_PROCEDIMIENTO ");
			query.append(
					"INNER JOIN CONVOCATORIAS T7 ON T6.ID_PROCEDIMIENTO = T7.ID_PROCEDIMIENTO INNER JOIN DATOS_TERCEROS T8 ON T2.ID_TERCERO = T8.ID_TERCERO INNER JOIN CONVOCATORIAS T10 ON T1.ID_PROCEDIMIENTO = T10.ID_PROCEDIMIENTO AND  T8.TIPO_PARTICIPANTE="
							+ Constantes.PARTICIPANTE_TITULAR);
		} else {
			query.append(
					"FROM EXPEDIENTES T1 INNER JOIN REL_EXP_TER T2 ON T1.ID_EXPEDIENTE = T2.ID_EXPEDIENTE INNER JOIN PROCEDIMIENTOS T6 ON T1.ID_PROCEDIMIENTO = T6.ID_PROCEDIMIENTO ");
			query.append(
					"INNER JOIN CONVOCATORIAS T7 ON T6.ID_PROCEDIMIENTO = T7.ID_PROCEDIMIENTO INNER JOIN DATOS_TERCEROS T8 ON T2.ID_TERCERO = T8.ID_TERCERO INNER JOIN CONVOCATORIAS T10 ON T1.ID_PROCEDIMIENTO = T10.ID_PROCEDIMIENTO  AND  T8.TIPO_PARTICIPANTE="
							+ Constantes.PARTICIPANTE_TITULAR);
		}

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereExpediente(expedientes);
		query.append(mapaWhere.get("query"));
		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Finds a list of rows in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Expedientes>
	 */
	@Transactional(readOnly = true)
	public List<Expedientes> findLupaExpediente(String folderNumber) {
		StringBuilder query = new StringBuilder(
				"SELECT T1.ID_EXPEDIENTE IDEXPEDIENTE FROM EXPEDIENTES T1 WHERE UPPER(t1.FOLDER_NUMBER) LIKE UPPER('%"
						+ folderNumber + "%')");
		return (List<Expedientes>) this.jdbcTemplate.query(query.toString(), this.rwMapExpedienteId);
	}

	/**
	 * Reorder the data list of Expedientes selected for rup_table
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Expedientes>>
	 */
	@Override
	public List<TableRowDto<Expedientes>> reorderSelection(Expedientes expedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TERRITORIO_HISTORICO IDTERRITORIOHISTORICO,t1.FOLDER_ID FOLDERID,t1.FOLDER_NUMBER FOLDERNUMBER,t1.TITULO TITULO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_PROCEDIMIENTO PROCEDIMIENTOSIDPROCEDIMIENTO,t2.COD_PROCEDURE_ID PROCEDIMIENTOSCODPROCEDUREID,t2.CAMPOS_TITULO_EXPEDIENTE ProcedimientosTITULOEXPEDIENTE,t2.FECHA_REGISTRO PROCEDIMIENTOSFECHAREGISTRO,t2.USUARIO_REGISTRO PROCEDIMIENTOSUSUARIOREGISTRO,t2.ID_DIRECCION PROCEDIMIENTOSIDDIRECCION,t2.ID_AREA PROCEDIMIENTOSIDAREA ");
		// FROM
		query.append("FROM EXPEDIENTES t1 ,PROCEDIMIENTOS t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(expedientes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_PROCEDIMIENTO= t2.ID_PROCEDIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Expedientes.class,
				filterParamList, "IDEXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Expedientes>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Expedientes
	 * @param searchParams
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Expedientes>>
	 */
	@Override
	public List<TableRowDto<Expedientes>> search(Expedientes filterParams, Expedientes searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TERRITORIO_HISTORICO IDTERRITORIOHISTORICO,t1.FOLDER_ID FOLDERID,t1.FOLDER_NUMBER FOLDERNUMBER,t1.TITULO TITULO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_PROCEDIMIENTO PROCEDIMIENTOSIDPROCEDIMIENTO,t2.COD_PROCEDURE_ID PROCEDIMIENTOSCODPROCEDUREID,t2.CAMPOS_TITULO_EXPEDIENTE ProcedimientosTITULOEXPEDIENTE,t2.FECHA_REGISTRO PROCEDIMIENTOSFECHAREGISTRO,t2.USUARIO_REGISTRO PROCEDIMIENTOSUSUARIOREGISTRO,t2.ID_DIRECCION PROCEDIMIENTOSIDDIRECCION,t2.ID_AREA PROCEDIMIENTOSIDAREA ");
		// FROM
		query.append("FROM EXPEDIENTES t1 ,PROCEDIMIENTOS t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_PROCEDIMIENTO= t2.ID_PROCEDIMIENTO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Expedientes.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_EXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Expedientes>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterexpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Expedientes filterexpedientes, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TERRITORIO_HISTORICO IDTERRITORIOHISTORICO,t1.FOLDER_ID FOLDERID,t1.FOLDER_NUMBER FOLDERNUMBER,t1.TITULO TITULO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_PROCEDIMIENTO PROCEDIMIENTOSIDPROCEDIMIENTO,t2.COD_PROCEDURE_ID PROCEDIMIENTOSCODPROCEDUREID,t2.CAMPOS_TITULO_EXPEDIENTE ProcedimientosTITULOEXPEDIENTE,t2.FECHA_REGISTRO PROCEDIMIENTOSFECHAREGISTRO,t2.USUARIO_REGISTRO PROCEDIMIENTOSUSUARIOREGISTRO,t2.ID_DIRECCION PROCEDIMIENTOSIDDIRECCION,t2.ID_AREA PROCEDIMIENTOSIDAREA ");
		// FROM
		query.append("FROM EXPEDIENTES t1 ,PROCEDIMIENTOS t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterexpedientes, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Expedientes.class,
				query, params, "ID_EXPEDIENTE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Expedientes>>
	 */
	@Override
	public List<JerarquiaDto<Expedientes>> findAllLikeJerarquia(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TERRITORIO_HISTORICO IDTERRITORIOHISTORICO,t1.FOLDER_ID FOLDERID,t1.FOLDER_NUMBER FOLDERNUMBER,t1.TITULO TITULO,t1.RELACION_EXPEDIENTE RELACIONEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_PROCEDIMIENTO PROCEDIMIENTOSIDPROCEDIMIENTO,t2.COD_PROCEDURE_ID PROCEDIMIENTOSCODPROCEDUREID,t2.CAMPOS_TITULO_EXPEDIENTE ProcedimientosTITULOEXPEDIENTE,t2.FECHA_REGISTRO PROCEDIMIENTOSFECHAREGISTRO,t2.USUARIO_REGISTRO PROCEDIMIENTOSUSUARIOREGISTRO,t2.ID_DIRECCION PROCEDIMIENTOSIDDIRECCION,t2.ID_AREA PROCEDIMIENTOSIDAREA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM EXPEDIENTES t1
		// ,PROCEDIMIENTOS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("EXPEDIENTES");
		from.add("PROCEDIMIENTOS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterExpedientes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_EXPEDIENTE", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ExpedientesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM EXPEDIENTES t1
		// ,PROCEDIMIENTOS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("EXPEDIENTES");
		from.add("PROCEDIMIENTOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterExpedientes, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_EXPEDIENTE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Expedientes>>
	 */
	@Override
	public List<TableRowDto<Expedientes>> findAllChild(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM EXPEDIENTES t1
		// ,PROCEDIMIENTOS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("EXPEDIENTES");
		from.add("PROCEDIMIENTOS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterExpedientes, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_EXPEDIENTE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Expedientes>(this.rwMapPK, "ID_EXPEDIENTE"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Expedientes entity
	 *
	 * @param expedientes
	 *            Expedientes Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Expedientes expedientes) {

		StringBuilder where = new StringBuilder(ExpedientesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (expedientes != null && expedientes.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(expedientes.getIdExpediente());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getIdProcedimiento() != null) {
			where.append(" AND t2.ID_PROCEDIMIENTO = ?");
			params.add(expedientes.getProcedimientos().getIdProcedimiento());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getDirecciones() != null
				&& expedientes.getProcedimientos().getDirecciones().getIdDireccion() != null) {
			where.append(" AND t2.ID_DIRECCION = ?");
			params.add(expedientes.getProcedimientos().getDirecciones().getIdDireccion());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getAreas() != null
				&& expedientes.getProcedimientos().getAreas().getIdArea() != null) {
			where.append(" AND t2.ID_AREA = ?");
			params.add(expedientes.getProcedimientos().getAreas().getIdArea());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getCodProcedureId() != null) {
			where.append(" AND t2.COD_PROCEDURE_ID = ?");
			params.add(expedientes.getProcedimientos().getCodProcedureId());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getCamposTituloExpediente() != null) {
			where.append(" AND t2.CAMPOS_TITULO_EXPEDIENTE = ?");
			params.add(expedientes.getProcedimientos().getCamposTituloExpediente());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(expedientes.getProcedimientos().getFechaRegistro());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(expedientes.getProcedimientos().getUsuarioRegistro());
		}
		if (expedientes != null && expedientes.getIdTerritorioHistorico() != null) {
			where.append(" AND t1.ID_TERRITORIO_HISTORICO = ?");
			params.add(expedientes.getIdTerritorioHistorico());
		}
		if (expedientes != null && expedientes.getFolderId() != null) {
			where.append(" AND t1.FOLDER_ID = ?");
			params.add(expedientes.getFolderId());
		}
		if (expedientes != null && expedientes.getFolderNumber() != null) {
			where.append(" AND t1.FOLDER_NUMBER = ?");
			params.add(expedientes.getFolderNumber());
		}
		if (expedientes != null && expedientes.getTitulo() != null) {
			where.append(" AND t1.TITULO = ?");
			params.add(expedientes.getTitulo());
		}
		if (expedientes != null && expedientes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(expedientes.getFechaRegistro());
		}
		if (expedientes != null && expedientes.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(expedientes.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Expedientes entity
	 *
	 * @param expedientes
	 *            Expedientes Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Expedientes expedientes, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ExpedientesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (expedientes != null && expedientes.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(expedientes.getIdExpediente());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getIdProcedimiento() != null) {
			where.append(" AND t2.ID_PROCEDIMIENTO = ?");
			params.add(expedientes.getProcedimientos().getIdProcedimiento());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getDirecciones() != null
				&& expedientes.getProcedimientos().getDirecciones().getIdDireccion() != null) {
			where.append(" AND t2.ID_DIRECCION = ?");
			params.add(expedientes.getProcedimientos().getDirecciones().getIdDireccion());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getAreas() != null
				&& expedientes.getProcedimientos().getAreas().getIdArea() != null) {
			where.append(" AND t2.ID_AREA = ?");
			params.add(expedientes.getProcedimientos().getAreas().getIdArea());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getCodProcedureId() != null) {
			where.append(" AND UPPER(t2.COD_PROCEDURE_ID) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(expedientes.getProcedimientos().getCodProcedureId().toUpperCase() + "%");
			} else {
				params.add("%" + expedientes.getProcedimientos().getCodProcedureId().toUpperCase() + "%");
			}
			where.append(" AND t2.COD_PROCEDURE_ID IS NOT NULL");
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getCamposTituloExpediente() != null) {
			where.append(" AND UPPER(t2.CAMPOS_TITULO_EXPEDIENTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(expedientes.getProcedimientos().getCamposTituloExpediente().toUpperCase() + "%");
			} else {
				params.add("%" + expedientes.getProcedimientos().getCamposTituloExpediente().toUpperCase() + "%");
			}
			where.append(" AND t2.CAMPOS_TITULO_EXPEDIENTE IS NOT NULL");
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(expedientes.getProcedimientos().getFechaRegistro());
		}
		if (expedientes != null && expedientes.getProcedimientos() != null
				&& expedientes.getProcedimientos().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(expedientes.getProcedimientos().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + expedientes.getProcedimientos().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (expedientes != null && expedientes.getIdTerritorioHistorico() != null) {
			where.append(" AND t1.ID_TERRITORIO_HISTORICO = ?");
			params.add(expedientes.getIdTerritorioHistorico());
		}
		if (expedientes != null && expedientes.getFolderId() != null) {
			where.append(" AND UPPER(t1.FOLDER_ID) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(expedientes.getFolderId().toUpperCase() + "%");
			} else {
				params.add("%" + expedientes.getFolderId().toUpperCase() + "%");
			}
			where.append(" AND t1.FOLDER_ID IS NOT NULL");
		}
		if (expedientes != null && expedientes.getFolderNumber() != null) {
			where.append(" AND UPPER(t1.FOLDER_NUMBER) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(expedientes.getFolderNumber().toUpperCase() + "%");
			} else {
				params.add("%" + expedientes.getFolderNumber().toUpperCase() + "%");
			}
			where.append(" AND t1.FOLDER_NUMBER IS NOT NULL");
		}
		if (expedientes != null && expedientes.getTitulo() != null) {
			where.append(" AND UPPER(t1.TITULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(expedientes.getTitulo().toUpperCase() + "%");
			} else {
				params.add("%" + expedientes.getTitulo().toUpperCase() + "%");
			}
			where.append(" AND t1.TITULO IS NOT NULL");
		}
		if (expedientes != null && expedientes.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(expedientes.getFechaRegistro());
		}
		if (expedientes != null && expedientes.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(expedientes.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + expedientes.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}

	private Map<String, ?> getWhereExpedientes(Expedientes expedientes) {

		StringBuilder where = new StringBuilder(ExpedientesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		where.append(" WHERE 1=1");
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		// SEGURIDAD
		List<GrantedAuthority> list = new ArrayList<GrantedAuthority>(
				SecurityContextHolder.getContext().getAuthentication().getAuthorities());

		// añadimos paramteros de las subselect para la extraccion de las
		// fechas: FECHA_APERTURA, FECHA_DOC_FORMAL Y FECHA_ULT_APOR
		params.add(Constantes.FECHA_ENTRADA);
		params.add(Constantes.FECHA_DOCUMENTACION_COMPLETA);
		params.add(Constantes.FECHA_ULTIMA_APORTACION);

		boolean esComercio = false;
		boolean esTurismo = false;
		boolean esConsumo = false;

		for (int i = 0; i < list.size(); i++) {

			if ("ROLE_AB60-IN-0001".equals(list.get(i).getAuthority())) {
				esComercio = true;
				esTurismo = true;
				esConsumo = true;
			} else if ("ROLE_AB60-IN-0002".equals(list.get(i).getAuthority())) {
				esTurismo = true;
			} else if ("ROLE_AB60-IN-0003".equals(list.get(i).getAuthority())) {
				esTurismo = true;
			} else if ("ROLE_AB60-IN-0004".equals(list.get(i).getAuthority())) {
				esComercio = true;
			} else if ("ROLE_AB60-IN-0005".equals(list.get(i).getAuthority())) {
				esComercio = true;
			} else if ("ROLE_AB60-IN-0006".equals(list.get(i).getAuthority())) {
				esConsumo = true;
			} else if ("ROLE_AB60-IN-0007".equals(list.get(i).getAuthority())) {
				esConsumo = true;
			}

		}

		if (esComercio && esTurismo && esConsumo) {
			where.append(" AND (t6.ID_DIRECCION IN (?,?,?)) ");

			params.add(Constantes.COD_DIRECCION_COMERCIO);
			params.add(Constantes.COD_DIRECCION_TURISMO);
			params.add(Constantes.COD_DIRECCION_CONSUMO);

		} else if (esComercio && esTurismo) {
			where.append(" AND (t6.ID_DIRECCION IN (?,?)) ");

			params.add(Constantes.COD_DIRECCION_COMERCIO);
			params.add(Constantes.COD_DIRECCION_TURISMO);

		} else {
			where.append(" AND (t6.ID_DIRECCION = ?)");
			if (esComercio) {
				params.add(Constantes.COD_DIRECCION_COMERCIO);
			} else if (esTurismo) {
				params.add(Constantes.COD_DIRECCION_TURISMO);
			} else if (esConsumo) {
				params.add(Constantes.COD_DIRECCION_CONSUMO);
			}
		}

		TiposTercero tiposTercero = new TiposTercero();
		tiposTercero.setIdTipoTercero(com.ejie.ab60.comun.Constantes.SOLICITANTE);

		if (expedientes != null && expedientes.getProcedimiento() != null
				&& expedientes.getProcedimiento().getIdProcedimiento() != null) {
			where.append(" AND t6.ID_PROCEDIMIENTO = ?");
			params.add(expedientes.getProcedimiento().getIdProcedimiento());
		}

		if (expedientes != null && expedientes.getFolderNumber() != null) {
			where.append(" AND UPPER(t1.FOLDER_NUMBER) LIKE UPPER('%" + expedientes.getFolderNumber() + "%')");
		}

		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImportePresentadoDesde() != null) {
			where.append(" AND t4.IMPORTE_PRESENTADO >= ?");
			params.add(expedientes.getEstudioTecnico().getImportePresentadoDesde());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImportePresentadoHasta() != null) {
			where.append(" AND t4.IMPORTE_PRESENTADO <= ?");
			params.add(expedientes.getEstudioTecnico().getImportePresentadoHasta());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImporteAdmitidoDesde() != null) {
			where.append(" AND t4.IMPORTE_ADMITIDO >= ?");
			params.add(expedientes.getEstudioTecnico().getImporteAdmitidoDesde());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImporteAdmitidoHasta() != null) {
			where.append(" AND t4.IMPORTE_ADMITIDO <= ?");
			params.add(expedientes.getEstudioTecnico().getImporteAdmitidoHasta());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getSubvencionResueltaDesde() != null) {
			where.append(" AND t4.SUBVENCION_RESUELTA >= ?");
			params.add(expedientes.getEstudioTecnico().getSubvencionResueltaDesde());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getSubvencionResueltaHasta() != null) {
			where.append(" AND t4.SUBVENCION_RESUELTA <= ?");
			params.add(expedientes.getEstudioTecnico().getSubvencionResueltaHasta());
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getDocumento() != null) {
			where.append(" AND UPPER(t8.DOCUMENTO) = UPPER(?)");
			params.add(expedientes.getDatosTerceros().getDocumento());
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getNombre() != null) {
			where.append(" AND UPPER(t8.NOMBRE) LIKE UPPER('%" + expedientes.getDatosTerceros().getNombre() + "%')");
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getApellido1() != null) {
			where.append(
					" AND UPPER(t8.APELLIDO1) LIKE UPPER('%" + expedientes.getDatosTerceros().getApellido1() + "%')");
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getApellido2() != null) {
			where.append(
					" AND UPPER(t8.APELLIDO2) LIKE UPPER('%" + expedientes.getDatosTerceros().getApellido2() + "%')");
		}
		if (tiposTercero != null && tiposTercero.getIdTipoTercero() != null) {
			where.append(" AND t2.ID_TIPO_TERCERO = ?");
			params.add(tiposTercero.getIdTipoTercero());
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getTipoParticipante() != null) {
			where.append(" AND t8.TIPO_PARTICIPANTE = ?");
			params.add(Constantes.PARTICIPANTE_TITULAR);
		}
		if (expedientes != null && expedientes.getConvocatoria() != null
				&& expedientes.getConvocatoria().getIdConvocatoria() != null) {
			where.append(" AND t10.ID_CONVOCATORIA = ?");
			params.add(expedientes.getConvocatoria().getIdConvocatoria());
		}
		if (expedientes != null && expedientes.getTitulo() != null) {
			where.append(" AND UPPER(t1.TITULO) LIKE UPPER('%" + expedientes.getTitulo() + "%')");
		}
		if (expedientes != null && expedientes.isInspeccionesSinEnviar()) {
			where.append(
					" AND (SELECT COUNT(1) FROM REL_EXP_INS t13 WHERE t13.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t13.TIPO_INSPECCION = "
							+ Constantes.TIPO_INSPECCION_JUSTIFICACION + ") = 0");
		}
		return mapWhere;
	}

	private Map<String, ?> getWhereExpediente(Expedientes expedientes) {

		StringBuilder where = new StringBuilder(ExpedientesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		where.append(" WHERE 1=1");
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		// SEGURIDAD
		List<GrantedAuthority> list = new ArrayList<GrantedAuthority>(
				SecurityContextHolder.getContext().getAuthentication().getAuthorities());

		boolean esComercio = false;
		boolean esTurismo = false;
		boolean esConsumo = false;

		for (int i = 0; i < list.size(); i++) {

			if ("ROLE_AB60-IN-0001".equals(list.get(i).getAuthority())) {
				esComercio = true;
				esTurismo = true;
				esConsumo = true;
			} else if ("ROLE_AB60-IN-0002".equals(list.get(i).getAuthority())) {
				esTurismo = true;
			} else if ("ROLE_AB60-IN-0003".equals(list.get(i).getAuthority())) {
				esTurismo = true;
			} else if ("ROLE_AB60-IN-0004".equals(list.get(i).getAuthority())) {
				esComercio = true;
			} else if ("ROLE_AB60-IN-0005".equals(list.get(i).getAuthority())) {
				esComercio = true;
			} else if ("ROLE_AB60-IN-0006".equals(list.get(i).getAuthority())) {
				esConsumo = true;
			} else if ("ROLE_AB60-IN-0007".equals(list.get(i).getAuthority())) {
				esConsumo = true;
			}

		}

		if (esComercio && esTurismo && esConsumo) {
			where.append(" AND (t6.ID_DIRECCION IN (?,?,?)) ");

			params.add(Constantes.COD_DIRECCION_COMERCIO);
			params.add(Constantes.COD_DIRECCION_TURISMO);
			params.add(Constantes.COD_DIRECCION_CONSUMO);

		} else if (esComercio && esTurismo) {
			where.append(" AND (t6.ID_DIRECCION IN (?,?)) ");

			params.add(Constantes.COD_DIRECCION_COMERCIO);
			params.add(Constantes.COD_DIRECCION_TURISMO);

		} else {
			where.append(" AND (t6.ID_DIRECCION = ?)");
			if (esComercio) {
				params.add(Constantes.COD_DIRECCION_COMERCIO);
			} else if (esTurismo) {
				params.add(Constantes.COD_DIRECCION_TURISMO);
			} else if (esConsumo) {
				params.add(Constantes.COD_DIRECCION_CONSUMO);
			}
		}

		TiposTercero tiposTercero = new TiposTercero();
		tiposTercero.setIdTipoTercero(com.ejie.ab60.comun.Constantes.SOLICITANTE);

		if (expedientes != null && expedientes.getProcedimiento() != null
				&& expedientes.getProcedimiento().getIdProcedimiento() != null) {
			where.append(" AND t6.ID_PROCEDIMIENTO = ?");
			params.add(expedientes.getProcedimiento().getIdProcedimiento());
		}

		if (expedientes != null && expedientes.getFolderNumber() != null) {
			where.append(" AND UPPER(t1.FOLDER_NUMBER) LIKE UPPER('%" + expedientes.getFolderNumber() + "%')");
		}

		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImportePresentadoDesde() != null) {
			where.append(" AND t4.IMPORTE_PRESENTADO >= ?");
			params.add(expedientes.getEstudioTecnico().getImportePresentadoDesde());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImportePresentadoHasta() != null) {
			where.append(" AND t4.IMPORTE_PRESENTADO <= ?");
			params.add(expedientes.getEstudioTecnico().getImportePresentadoHasta());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImporteAdmitidoDesde() != null) {
			where.append(" AND t4.IMPORTE_ADMITIDO >= ?");
			params.add(expedientes.getEstudioTecnico().getImporteAdmitidoDesde());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getImporteAdmitidoHasta() != null) {
			where.append(" AND t4.IMPORTE_ADMITIDO <= ?");
			params.add(expedientes.getEstudioTecnico().getImporteAdmitidoHasta());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getSubvencionResueltaDesde() != null) {
			where.append(" AND t4.SUBVENCION_RESUELTA >= ?");
			params.add(expedientes.getEstudioTecnico().getSubvencionResueltaDesde());
		}
		if (expedientes != null && expedientes.getEstudioTecnico() != null
				&& expedientes.getEstudioTecnico().getSubvencionResueltaHasta() != null) {
			where.append(" AND t4.SUBVENCION_RESUELTA <= ?");
			params.add(expedientes.getEstudioTecnico().getSubvencionResueltaHasta());
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getDocumento() != null) {
			where.append(" AND UPPER(t8.DOCUMENTO) = UPPER(?)");
			params.add(expedientes.getDatosTerceros().getDocumento());
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getNombre() != null) {
			where.append(" AND UPPER(t8.NOMBRE) LIKE UPPER('%" + expedientes.getDatosTerceros().getNombre() + "%')");
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getApellido1() != null) {
			where.append(
					" AND UPPER(t8.APELLIDO1) LIKE UPPER('%" + expedientes.getDatosTerceros().getApellido1() + "%')");
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getApellido2() != null) {
			where.append(
					" AND UPPER(t8.APELLIDO2) LIKE UPPER('%" + expedientes.getDatosTerceros().getApellido2() + "%')");
		}
		if (tiposTercero != null && tiposTercero.getIdTipoTercero() != null) {
			where.append(" AND t2.ID_TIPO_TERCERO = ?");
			params.add(tiposTercero.getIdTipoTercero());
		}
		if (expedientes != null && expedientes.getDatosTerceros() != null
				&& expedientes.getDatosTerceros().getTipoParticipante() != null) {
			where.append(" AND t8.TIPO_PARTICIPANTE = ?");
			params.add(Constantes.PARTICIPANTE_TITULAR);
		}
		if (expedientes != null && expedientes.getConvocatoria() != null
				&& expedientes.getConvocatoria().getIdConvocatoria() != null) {
			where.append(" AND t10.ID_CONVOCATORIA = ?");
			params.add(expedientes.getConvocatoria().getIdConvocatoria());
		}
		if (expedientes != null && expedientes.getTitulo() != null) {
			where.append(" AND UPPER(t1.TITULO) LIKE UPPER('%" + expedientes.getTitulo() + "%')");
		}
		if (expedientes != null && expedientes.isInspeccionesSinEnviar()) {
			where.append(
					" AND (SELECT COUNT(1) FROM REL_EXP_INS t13 WHERE t13.ID_EXPEDIENTE = t1.ID_EXPEDIENTE AND t13.TIPO_INSPECCION = "
							+ Constantes.TIPO_INSPECCION_JUSTIFICACION + ") = 0");
		}
		return mapWhere;
	}

	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

}
