package com.ejie.ab60.dao.expedientes;

import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.expedientes.MarcarInspeccionable;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;
import com.ejie.ab60.model.justificacion.Justificacion;

/**
 * JustificacionDao  
 * 
 *  
 */

public interface MarcarInspeccionableDao {

	/**
	 * Finds a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return Justificacion
	 */
	Justificacion find(Justificacion datosproyecto);

	/**
	 * Removes a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 */
	void remove(Justificacion datosproyecto);

	/**
	 * Updates a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return Justificacion
	 */
	Justificacion update(Justificacion datosproyecto);

	/**
	 * Select de todos los importes de Justificacion
	 *
	 * @param idExpediente
	 *            Integer
	 * @return Justificacion
	 */
	Justificacion refescarImportes(Integer idExpediente);

	/**
	 * Update importes de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	Justificacion updateImporte(Justificacion datosproyecto);

	MarcarInspeccionable findInspeccionable(MarcarInspeccionable marcarInspeccionable);

	MarcarInspeccionableAct findInspeccionableAct(MarcarInspeccionableAct marcarInspeccionableAct);

	/**
	 * Actualizar DATOS_PROYECTO (AB6005T00) con la Fecha Límite y las
	 * Observaciones
	 * 
	 * @param marcarInspeccionable
	 *            MarcarInspeccionable
	 * @param tipoInspeccion
	 *            Integer
	 * 
	 * @return marcarInspeccionable MarcarInspeccionable
	 */
	MarcarInspeccionable actualizarDatosProyecto(MarcarInspeccionable marcarInspeccionable, Integer tipoInspeccion);

	/**
	 * Actualizar DATOS_PROYECTO (AB6005T00) con la Fecha Límite y las
	 * Observaciones
	 * 
	 * @param marcarInspeccionableAct
	 *            MarcarInspeccionableAct
	 * 
	 * @return marcarInspeccionableAct MarcarInspeccionableAct
	 */
	MarcarInspeccionableAct actualizarDatosProyectoAct(MarcarInspeccionableAct marcarInspeccionableAct);

	/**
	 * Actualizar FACTURAS (AB6007T00) con las facturas enviadas a inspección
	 * 
	 * @param factura
	 *            Facturas
	 * 
	 * @return factura Facturas
	 */
	Facturas actualizarFacturas(Facturas factura);

	/**
	 * Actualizar REL_EXP_ACT_SUB (AB6023T00) con las actuaciones
	 * subcencionables enviadas a inspección
	 * 
	 * @param idRelExpActSub
	 *            Integer
	 * 
	 * @return idRelExpActSub Integer
	 */
	Integer actualizarActuaciones(Integer idRelExpActSub);

	/**
	 * Actualizar CONCEPTOS (AB6019T00) con los conceptos enviadas a inspección
	 * 
	 * @param idConcepto
	 *            Integer
	 * 
	 * @return idConcepto Integer
	 */
	Integer actualizarConcepto(Integer idConcepto);

	String findDatosProyectoPorId(Integer idExpediente, Integer tipoInspeccion);

}
