package com.ejie.ab60.dao.expedientes;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;
import com.ejie.ab60.model.expedientes.MarcarInspeccionable;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;
import com.ejie.ab60.model.justificacion.Justificacion;
import com.ejie.ab60.model.justificacion.MotivosIncumplimiento;
import com.ejie.ab60.model.justificacion.TiposResJus;

/**
 * JustificacionDaoImpl  
 * 
 * 
 */
@Repository
@Transactional

public class MarcarInspeccionableDaoImpl implements MarcarInspeccionableDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPROYECTOEXPEDIENTE", "IDEXPEDIENTE",
			"IMPORTEPRESENTADO", "IMPORTEADMITIDO", "SUBVENCIONCALCULADA", "SUBVENCIONJUSTIFICADA", "IMPORTERECURSO",
			"SUBVENCIONRESUELTA", "FECHAINFORME", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION", "IDTECNICORESPONSABLE", "NOMBRETECNICORESPONSABLE", "FECREGTECNICORESPONSABLE",
			"USUREGTECNICORESPONSABLE", "IDTIPOSRESULTADO", "TIPOSRESULTADODESCASTELLANO", "TIPOSRESULTADODESEUSKERA",
			"TIPOSRESULTADOFECHAREGISTRO", "TIPOSRESULTADOUSUARIOREGISTRO", "IDMOTIVOSDESESTIMACION",
			"DESMOTIVOCASTELLANO", "DESMOTIVOEUSKERA", "MOTIVOSDESESTIMACIONFECREG", "MOTIVOSDESESTIMACIONUSUREG",
			"IMPORTEFINAL", "IMPORTEDISPONIBLE", "DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "IDSOLICITANTE",
			"DCASTELLANO", "DEUSKERA", "CRIPUNCASTELLANO", "CRIPUNEUSKERA", "IDASOCIACION", "IDCRITERIO",
			"OBSINSPECCION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Justificacion> rwMap = new RowMapper<Justificacion>() {
		public Justificacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Justificacion(resultSet.getInt("IDPROYECTOEXPEDIENTE"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getBigDecimal("SUBVENCIONRESUELTA"), resultSet.getBigDecimal("SUBVENCIONJUSTIFICADA"),
					resultSet.getBigDecimal("IMPORTEJUSADMITIDO"), resultSet.getBigDecimal("IMPORTEJUSCALCULADO"),
					resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getString("OBSERVACIONESEUSKERA"),
					resultSet.getDate("FECHAINFORME"),

					new MotivosIncumplimiento(resultSet.getLong("IDMOTIVOINCUMPLIMIENTO"),
							resultSet.getString("DESMOTIVOCASTELLANO"), resultSet.getString("DESMOTIVOEUSKERA")),
					new TecnicosResponsables(resultSet.getInt("IDTECNICORESPONSABLE"),
							resultSet.getString("NOMBRETECNICORESPONSABLE")),
					new TiposResJus(resultSet.getLong("IDRESJUSTIFICACION"),
							resultSet.getString("TIPOSRESULTADODESCASTELLANO"),
							resultSet.getString("TIPOSRESULTADODESEUSKERA"),
							resultSet.getDate("TIPOSRESULTADOFECHAREGISTRO"),
							resultSet.getString("TIPOSRESULTADOUSUARIOREGISTRO"))

			);

		}
	};

	private RowMapper<Justificacion> rwMapTodoslosImportes = new RowMapper<Justificacion>() {
		public Justificacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Justificacion(resultSet.getBigDecimal("SUBVENCIONRESUELTA"),
					resultSet.getBigDecimal("SUBVENCIONJUSTIFICADA"), resultSet.getBigDecimal("IMPORTEJUSADMITIDO"),
					resultSet.getBigDecimal("IMPORTEJUSCALCULADO"));
		}
	};

	private RowMapper<MarcarInspeccionable> rwMapMarcarInspeccionable = new RowMapper<MarcarInspeccionable>() {
		public MarcarInspeccionable mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MarcarInspeccionable(resultSet.getDate("FECHA_LIM_INSPECCION"),
					resultSet.getDate("FECHA_LIM_INSPECCION_JUS"), resultSet.getString("OBSERVACIONES_INSPECCION"),
					resultSet.getString("OBSERVACIONES_INSPECCION_JUS"));
		}
	};

	private RowMapper<MarcarInspeccionableAct> rwMapMarcarInspeccionableAct = new RowMapper<MarcarInspeccionableAct>() {
		public MarcarInspeccionableAct mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MarcarInspeccionableAct(resultSet.getDate("FECHA_LIM_INSPECCION"),
					resultSet.getString("OBSERVACIONES_INSPECCION"));
		}
	};

	private RowMapper<String> rwMapDatosProyecto = new RowMapper<String>() {
		public String mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			String observaciones = resultSet.getString("OBSINSPECCION");

			return observaciones;
		}
	};

	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * Finds a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return Justificacion
	 */
	@Transactional(readOnly = true)
	public Justificacion find(Justificacion datosproyecto) {
		List<Object> params = new ArrayList<Object>();
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE, " + "t1.ID_EXPEDIENTE IDEXPEDIENTE, "
						+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA, "
						+ "t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO, t1.IMPORTE_JUS_CALCULADO IMPORTEJUSCALCULADO, "
						+ "t1.OBSERVACIONES_CAS_JUS OBSERVACIONESCASTELLANO, "
						+ "t1.OBSERVACIONES_EUS_JUS OBSERVACIONESEUSKERA,t1.FECHA_INFORME_JUS FECHAINFORME, "
						+ "t1.ID_TEC_RES_JUS IDTECNICORESPONSABLE, t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE, "
						+ "t3.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
						+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
						+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
						+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
						+ "t4.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO, "
						+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA "
						+ "FROM DATOS_PROYECTO t1 , TECNICOS_RESPONSABLES t2, TIPOS_RES_JUS t3, MOTIVOS_INCUMPLIMIENTO t4, CONVOCATORIAS t5 "
						+ "WHERE 1=1");

		if (datosproyecto.getIdExpediente() != null && datosproyecto.getIdExpediente() != 0) {
			query.append(" AND t1.ID_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdExpediente());
		}

		if (datosproyecto.getIdConvocatoria() != null && datosproyecto.getIdConvocatoria() != 0) {
			query.append(" AND t5.ID_CONVOCATORIA = ? ");
			params.add(datosproyecto.getIdConvocatoria());
		}

		if (datosproyecto.getIdProyectoExpediente() != null && datosproyecto.getIdProyectoExpediente() != 0) {
			query.append(" AND t1.ID_PROYECTO_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdProyectoExpediente());
		}
		query.append("AND t1.ID_TEC_RES_JUS= t2.ID_TECNICO_RESPONSABLE(+) "
				+ "AND t1.ID_RESULTADO_JUS= t3.ID_RES_JUSTIFICACION(+) AND t1.ID_MOTIVO_INCUMPLIMIENTO = t4.ID_MOTIVO_INCUMPLIMIENTO(+)");

		List<Justificacion> datosproyectoList = this.jdbcTemplate.query(query.toString(), this.rwMap,
				datosproyecto.getIdExpediente(), datosproyecto.getIdConvocatoria());
		return (Justificacion) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	/**
	 * Removes a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return
	 */
	public void remove(Justificacion datosproyecto) {
		String query = "DELETE FROM DATOS_PROYECTO WHERE ID_PROYECTO_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, datosproyecto.getIdProyectoExpediente());
	}

	/**
	 * Updates a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return Justificacion
	 */
	public Justificacion update(Justificacion datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET  " + "ID_EXPEDIENTE=?, " + "IMPORTE_JUS_ADMITIDO=?, "
				+ "IMPORTE_JUS_CALCULADO=?, " + "SUBVENCION_RESUELTA=?, " + "SUBVENCION_JUSTIFICADA=?, "
				+ "OBSERVACIONES_CAS_JUS=?, " + "OBSERVACIONES_EUS_JUS=?, "
				+ "FECHA_INFORME_JUS=TO_DATE (?,'DD/MM/YYYY'), " + "ID_TEC_RES_JUS=?, " + "ID_RESULTADO_JUS=?, "
				+ "ID_MOTIVO_INCUMPLIMIENTO=?, " + "FECHA_ULTMODIFICACION=?, " + "USUARIO_ULTMODIFICACION=? "
				+ "WHERE ID_PROYECTO_EXPEDIENTE=?";

		Object getTecnicosResponsablesIdTecnicoResponsableAux = null;
		if (datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable() != null) {
			getTecnicosResponsablesIdTecnicoResponsableAux = datosproyecto.getTecnicosResponsables()
					.getIdTecnicoResponsable();
		}

		Object getTiposResultadoAux = null;
		if (datosproyecto.getTiposResJus() != null && datosproyecto.getTiposResJus().getIdResJustificacion() != null) {
			getTiposResultadoAux = datosproyecto.getTiposResJus().getIdResJustificacion();
		}

		Object getMotivosDesestimacionAux = null;
		if (datosproyecto.getMotivosIncumplimiento() != null
				&& datosproyecto.getMotivosIncumplimiento().getIdMotivoIncumplimiento() != null) {
			getMotivosDesestimacionAux = datosproyecto.getMotivosIncumplimiento().getIdMotivoIncumplimiento();
		}

		this.jdbcTemplate.update(query, datosproyecto.getIdExpediente(), datosproyecto.getImporteJusAdmitido(),
				datosproyecto.getImporteJusCalculado(), datosproyecto.getSubvencionResuelta(),
				datosproyecto.getSubvencionJustificada(), datosproyecto.getObservacionesCastellano(),
				datosproyecto.getObservacionesEuskera(), datosproyecto.getFechaInformeStr(),
				getTecnicosResponsablesIdTecnicoResponsableAux, getTiposResultadoAux, getMotivosDesestimacionAux,
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion(),
				datosproyecto.getIdProyectoExpediente());
		return datosproyecto;
	}

	/**
	 * Update importes de Justificacion
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public Justificacion updateImporte(Justificacion datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET SUBVENCION_JUSTIFICADA= ?, IMPORTE_JUS_ADMITIDO= ?, IMPORTE_JUS_CALCULADO = ?, FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, datosproyecto.getSubvencionJustificada(), datosproyecto.getImporteJusAdmitido(),
				datosproyecto.getImporteJusCalculado(), datosproyecto.getFechaUltmodificacion(),
				datosproyecto.getUsuarioUltmodificacion(), datosproyecto.getIdExpediente());
		return datosproyecto;
	}

	/**
	 * 
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	/**
	 * Select de todos los importes de Justificacion
	 *
	 * @param idExpediente
	 *            Integer
	 * @return Justificacion
	 */
	public Justificacion refescarImportes(Integer idExpediente) {
		String query = "SELECT t2.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, t2.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA,t2.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t2.IMPORTE_JUS_CALCULADO IMPORTEJUSCALCULADO  FROM DATOS_PROYECTO t2 WHERE t2.ID_EXPEDIENTE = ?";
		List<Justificacion> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapTodoslosImportes,
				idExpediente);
		return (Justificacion) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	@Override
	public MarcarInspeccionable findInspeccionable(MarcarInspeccionable marcarInspeccionable) {
		String query = "SELECT t1.FECHA_LIM_INSPECCION, t1.FECHA_LIM_INSPECCION_JUS, t1.OBSERVACIONES_INSPECCION, t1.OBSERVACIONES_INSPECCION_JUS FROM DATOS_PROYECTO t1 WHERE T1.ID_EXPEDIENTE = ?";
		List<MarcarInspeccionable> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapMarcarInspeccionable,
				marcarInspeccionable.getExpediente().getIdExpediente());
		return (MarcarInspeccionable) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	@Override
	public MarcarInspeccionableAct findInspeccionableAct(MarcarInspeccionableAct marcarInspeccionableAct) {
		String query = "SELECT t1.FECHA_LIM_INSPECCION, t1.OBSERVACIONES_INSPECCION FROM DATOS_PROYECTO t1 WHERE T1.ID_EXPEDIENTE = ?";
		List<MarcarInspeccionableAct> datosproyectoList = this.jdbcTemplate.query(query,
				this.rwMapMarcarInspeccionableAct, marcarInspeccionableAct.getExpediente().getIdExpediente());
		return (MarcarInspeccionableAct) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	/**
	 * Actualizar DATOS_PROYECTO (AB6005T00) con la Fecha Límite y las
	 * Observaciones
	 * 
	 * @param marcarInspeccionable
	 *            MarcarInspeccionable
	 * @param tipoInspeccion
	 *            Integer
	 * 
	 * @return marcarInspeccionable MarcarInspeccionable
	 */
	@Override()
	public MarcarInspeccionable actualizarDatosProyecto(MarcarInspeccionable marcarInspeccionable,
			Integer tipoInspeccion) {
		String query;

		if (tipoInspeccion == Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO) {
			query = "UPDATE DATOS_PROYECTO SET FECHA_LIM_INSPECCION= ?, OBSERVACIONES_INSPECCION= ?, FECHA_ULTMODIFICACION=sysdate, USUARIO_ULTMODIFICACION=? WHERE ID_EXPEDIENTE= ?";
		} else {
			query = "UPDATE DATOS_PROYECTO SET FECHA_LIM_INSPECCION_JUS= ?, OBSERVACIONES_INSPECCION_JUS= ?, FECHA_ULTMODIFICACION=sysdate, USUARIO_ULTMODIFICACION=? WHERE ID_EXPEDIENTE= ?";
		}

		this.jdbcTemplate.update(query, marcarInspeccionable.getFechaLimInspeccion(),
				marcarInspeccionable.getObservacionInspeccion(), marcarInspeccionable.getUsuario().getNombreUsuario(),
				marcarInspeccionable.getExpediente().getIdExpediente());
		return marcarInspeccionable;

	}

	/**
	 * Actualizar DATOS_PROYECTO (AB6005T00) con la Fecha Límite y las
	 * Observaciones
	 * 
	 * @param marcarInspeccionableAct
	 *            MarcarInspeccionableAct
	 * 
	 * @return marcarInspeccionableAct MarcarInspeccionableAct
	 */
	@Override()
	public MarcarInspeccionableAct actualizarDatosProyectoAct(MarcarInspeccionableAct marcarInspeccionableAct) {
		String query = "UPDATE DATOS_PROYECTO SET FECHA_LIM_INSPECCION= ?, OBSERVACIONES_INSPECCION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, marcarInspeccionableAct.getFechaLimInspeccion(),
				marcarInspeccionableAct.getObservacionInspeccion(),
				marcarInspeccionableAct.getExpediente().getIdExpediente());
		return marcarInspeccionableAct;

	}

	/**
	 * Actualizar FACTURAS (AB6007T00) con las facturas enviadas a inspección
	 * 
	 * @param factura
	 *            Facturas
	 * 
	 * @return factura Facturas
	 */
	@Override()
	public Facturas actualizarFacturas(Facturas factura) {
		String query = "UPDATE FACTURAS SET ENVIADO_INSPECCIONAR= ?, FECHA_ULTMODIFICACION=sysdate, USUARIO_ULTMODIFICACION=? WHERE ID_FACTURA= ?";

		this.jdbcTemplate.update(query, Constantes.ENVIADO_INSPECCION, factura.getUsuarioUltmodificacion(),
				factura.getIdFactura());
		return factura;

	}

	/**
	 * Actualizar REL_EXP_ACT_SUB (AB6023T00) con las actuaciones
	 * subcencionables enviadas a inspección
	 * 
	 * @param idRelExpActSub
	 *            Integer
	 * 
	 * @return idRelExpActSub Integer
	 */
	@Override()
	public Integer actualizarActuaciones(Integer idRelExpActSub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET ENVIADO_INSPECCIONAR= ? WHERE ID_REL_EXP_ACT_SUB= ?";

		this.jdbcTemplate.update(query, Constantes.ENVIADO_INSPECCION, idRelExpActSub);
		return idRelExpActSub;

	}

	/**
	 * Actualizar CONCEPTOS (AB6019T00) con los conceptos enviadas a inspección
	 * 
	 * @param idConcepto
	 *            Integer
	 * 
	 * @return idConcepto Integer
	 */
	@Override()
	public Integer actualizarConcepto(Integer idConcepto) {
		String query = "UPDATE CONCEPTOS SET ENVIADO_INSPECCIONAR= ? WHERE ID_CONCEPTO = ?";

		this.jdbcTemplate.update(query, Constantes.ENVIADO_INSPECCION, idConcepto);
		return idConcepto;

	}

	@Override
	public String findDatosProyectoPorId(Integer idExpediente, Integer tipoInspeccion) {

		String query = "";
		if (tipoInspeccion == Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO) {
			query = "SELECT t1.OBSERVACIONES_INSPECCION OBSINSPECCION FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE = ?";
		} else if (tipoInspeccion == Constantes.TIPO_INSPECCION_JUSTIFICACION) {
			query = "SELECT t1.OBSERVACIONES_INSPECCION_JUS OBSINSPECCION FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE = ?";
		}

		List<String> observaciones = this.jdbcTemplate.query(query, this.rwMapDatosProyecto, idExpediente);
		return (String) DataAccessUtils.uniqueResult(observaciones);
	}
}
