package com.ejie.ab60.dao.justificacion;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.RelExpIns;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;
import com.ejie.ab60.model.justificacion.Justificacion;
import com.ejie.ab60.model.justificacion.MotivosIncumplimiento;
import com.ejie.ab60.model.justificacion.TiposResJus;

/**
 * JustificacionDaoImpl  
 * 
 * 
 */
@Repository
@Transactional

public class JustificacionDaoImpl implements JustificacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPROYECTOEXPEDIENTE", "IDEXPEDIENTE",
			"IMPORTEPRESENTADO", "IMPORTEADMITIDO", "SUBVENCIONCALCULADA", "SUBVENCIONJUSTIFICADA", "IMPORTERECURSO",
			"SUBVENCIONRESUELTA", "FECHAINFORME", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION", "IDTECNICORESPONSABLE", "NOMBRETECNICORESPONSABLE", "FECREGTECNICORESPONSABLE",
			"USUREGTECNICORESPONSABLE", "IDTIPOSRESULTADO", "TIPOSRESULTADODESCASTELLANO", "TIPOSRESULTADODESEUSKERA",
			"TIPOSRESULTADOFECHAREGISTRO", "TIPOSRESULTADOUSUARIOREGISTRO", "IDMOTIVOSDESESTIMACION",
			"DESMOTIVOCASTELLANO", "DESMOTIVOEUSKERA", "MOTIVOSDESESTIMACIONFECREG", "MOTIVOSDESESTIMACIONUSUREG",
			"IMPORTEFINAL", "IMPORTEDISPONIBLE", "DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "IDSOLICITANTE",
			"DCASTELLANO", "DEUSKERA", "CRIPUNCASTELLANO", "CRIPUNEUSKERA", "IDASOCIACION", "IDCRITERIO",
			"RENDIMIFINANCIERO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Justificacion> rwMap = new RowMapper<Justificacion>() {
		public Justificacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Justificacion justificacion = new Justificacion();
			justificacion.setIdProyectoExpediente(resultSet.getInt("IDPROYECTOEXPEDIENTE"));
			justificacion.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			justificacion.setSubvencionResuelta(resultSet.getBigDecimal("SUBVENCIONRESUELTA"));
			justificacion.setSubvencionJustificada(resultSet.getBigDecimal("SUBVENCIONJUSTIFICADA"));
			justificacion.setImporteJusAdmitido(resultSet.getBigDecimal("IMPORTEJUSADMITIDO"));
			justificacion.setImporteJusCalculado(resultSet.getBigDecimal("IMPORTEJUSCALCULADO"));
			justificacion.setObservacionesCastellano(resultSet.getString("OBSERVACIONESCASTELLANO"));
			justificacion.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEUSKERA"));
			justificacion.setFechaInformeJus(resultSet.getDate("FECHAINFORME"));
			justificacion.setRendimientoFinanciero(resultSet.getBigDecimal("RENDIMIFINANCIERO"));

			MotivosIncumplimiento motivosIncumplimiento = new MotivosIncumplimiento();
			motivosIncumplimiento.setIdMotivoIncumplimiento(resultSet.getLong("IDMOTIVOINCUMPLIMIENTO"));
			motivosIncumplimiento.setDescripcionCastellano(resultSet.getString("DESMOTIVOCASTELLANO"));
			motivosIncumplimiento.setDescripcionEuskera(resultSet.getString("DESMOTIVOEUSKERA"));

			justificacion.setMotivosIncumplimiento(motivosIncumplimiento);

			TecnicosResponsables tecnicosResponsables = new TecnicosResponsables();
			tecnicosResponsables.setIdTecnicoResponsable(resultSet.getInt("IDTECNICORESPONSABLE"));
			tecnicosResponsables.setNombreTecnico(resultSet.getString("NOMBRETECNICORESPONSABLE"));

			justificacion.setTecnicosResponsables(tecnicosResponsables);

			TiposResJus tiposResJus = new TiposResJus();

			tiposResJus.setIdResJustificacion(resultSet.getLong("IDRESJUSTIFICACION"));
			tiposResJus.setDescripcionCastellano(resultSet.getString("TIPOSRESULTADODESCASTELLANO"));
			tiposResJus.setDescripcionEuskera(resultSet.getString("TIPOSRESULTADODESEUSKERA"));
			tiposResJus.setFechaRegistro(resultSet.getDate("TIPOSRESULTADOFECHAREGISTRO"));
			tiposResJus.setUsuarioRegistro(resultSet.getString("TIPOSRESULTADOUSUARIOREGISTRO"));

			justificacion.setTiposResJus(tiposResJus);

			RelExpIns relExpIns = new RelExpIns();
			relExpIns.setIdInspeccion(resultSet.getInt("IDINSPECCION"));

			justificacion.setRelExpIns(relExpIns);

			return justificacion;

		}
	};

	private RowMapper<Justificacion> rwMapTodoslosImportes = new RowMapper<Justificacion>() {
		public Justificacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Justificacion(resultSet.getBigDecimal("SUBVENCIONRESUELTA"),
					resultSet.getBigDecimal("SUBVENCIONJUSTIFICADA"), resultSet.getBigDecimal("IMPORTEJUSADMITIDO"),
					resultSet.getBigDecimal("IMPORTEJUSCALCULADO"));
		}
	};

	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * Finds a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return Justificacion
	 */
	@Transactional(readOnly = true)
	public Justificacion find(Justificacion datosproyecto) {
		List<Object> params = new ArrayList<Object>();
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROYECTO_EXPEDIENTE IDPROYECTOEXPEDIENTE, " + "t1.ID_EXPEDIENTE IDEXPEDIENTE, "
						+ "t1.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, t1.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA, "
						+ "t1.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO, t1.IMPORTE_JUS_CALCULADO IMPORTEJUSCALCULADO, "
						+ "t1.OBSERVACIONES_CAS_JUS OBSERVACIONESCASTELLANO, "
						+ "t1.OBSERVACIONES_EUS_JUS OBSERVACIONESEUSKERA,t1.FECHA_INFORME_JUS FECHAINFORME, "
						+ "t1.ID_TEC_RES_JUS IDTECNICORESPONSABLE, t1.RENDIMIENTO_FINANCIERO RENDIMIFINANCIERO, t2.NOMBRE_TECNICO NOMBRETECNICORESPONSABLE, "
						+ "t3.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t3.DESCRIPCION_CASTELLANO TIPOSRESULTADODESCASTELLANO, "
						+ "t3.DESCRIPCION_EUSKERA TIPOSRESULTADODESEUSKERA, "
						+ "t3.FECHA_REGISTRO TIPOSRESULTADOFECHAREGISTRO, "
						+ "t3.USUARIO_REGISTRO TIPOSRESULTADOUSUARIOREGISTRO, "
						+ "t4.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO, "
						+ "t4.DESCRIPCION_CASTELLANO DESMOTIVOCASTELLANO, t4.DESCRIPCION_EUSKERA DESMOTIVOEUSKERA , t6.ID_INSPECCION IDINSPECCION "
						+ "FROM DATOS_PROYECTO t1 , TECNICOS_RESPONSABLES t2, TIPOS_RES_JUS t3, MOTIVOS_INCUMPLIMIENTO t4, CONVOCATORIAS t5, REL_EXP_INS t6 "
						+ "WHERE 1=1");

		if (datosproyecto.getIdExpediente() != null && datosproyecto.getIdExpediente() != 0) {
			query.append(" AND t1.ID_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdExpediente());
		}

		if (datosproyecto.getIdConvocatoria() != null && datosproyecto.getIdConvocatoria() != 0) {
			query.append(" AND t5.ID_CONVOCATORIA = ? ");
			params.add(datosproyecto.getIdConvocatoria());
		}

		if (datosproyecto.getIdProyectoExpediente() != null && datosproyecto.getIdProyectoExpediente() != 0) {
			query.append(" AND t1.ID_PROYECTO_EXPEDIENTE = ? ");
			params.add(datosproyecto.getIdProyectoExpediente());
		}
		query.append("AND t1.ID_TEC_RES_JUS= t2.ID_TECNICO_RESPONSABLE(+) "
				+ "AND t1.ID_RESULTADO_JUS= t3.ID_RES_JUSTIFICACION(+) AND t1.ID_MOTIVO_INCUMPLIMIENTO = t4.ID_MOTIVO_INCUMPLIMIENTO(+) AND t1.ID_EXPEDIENTE = t6.ID_EXPEDIENTE(+) AND t6.TIPO_INSPECCION(+) = ?");

		List<Justificacion> datosproyectoList = this.jdbcTemplate.query(query.toString(), this.rwMap,
				datosproyecto.getIdExpediente(), datosproyecto.getIdConvocatoria(),
				Constantes.ORIGEN_INSPECCION_JUSTIFICACION_TECNICO);
		return (Justificacion) DataAccessUtils.uniqueResult(datosproyectoList);
	}

	/**
	 * Removes a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return
	 */
	public void remove(Justificacion datosproyecto) {
		String query = "DELETE FROM DATOS_PROYECTO WHERE ID_PROYECTO_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, datosproyecto.getIdProyectoExpediente());
	}

	/**
	 * Updates a single row in the Justificacion table.
	 *
	 * @param datosproyecto
	 *            Justificacion
	 * @return Justificacion
	 */
	public Justificacion update(Justificacion datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET  " + "ID_EXPEDIENTE=?, " + "IMPORTE_JUS_ADMITIDO=?, "
				+ "IMPORTE_JUS_CALCULADO=?, " + "SUBVENCION_RESUELTA=?, " + "SUBVENCION_JUSTIFICADA=?, "
				+ "OBSERVACIONES_CAS_JUS=?, " + "OBSERVACIONES_EUS_JUS=?, "
				+ "FECHA_INFORME_JUS=TO_DATE (?,'DD/MM/YYYY'), " + "ID_TEC_RES_JUS=?, " + "ID_RESULTADO_JUS=?, "
				+ "ID_MOTIVO_INCUMPLIMIENTO=?, " + "FECHA_ULTMODIFICACION=?, " + "USUARIO_ULTMODIFICACION=?, "
				+ "RENDIMIENTO_FINANCIERO=? " + "WHERE ID_PROYECTO_EXPEDIENTE=?";

		Object getTecnicosResponsablesIdTecnicoResponsableAux = null;
		if (datosproyecto.getTecnicosResponsables() != null
				&& datosproyecto.getTecnicosResponsables().getIdTecnicoResponsable() != null) {
			getTecnicosResponsablesIdTecnicoResponsableAux = datosproyecto.getTecnicosResponsables()
					.getIdTecnicoResponsable();
		}

		Object getTiposResultadoAux = null;
		if (datosproyecto.getTiposResJus() != null && datosproyecto.getTiposResJus().getIdResJustificacion() != null) {
			getTiposResultadoAux = datosproyecto.getTiposResJus().getIdResJustificacion();
		}

		Object getMotivosDesestimacionAux = null;
		if (datosproyecto.getMotivosIncumplimiento() != null
				&& datosproyecto.getMotivosIncumplimiento().getIdMotivoIncumplimiento() != null) {
			getMotivosDesestimacionAux = datosproyecto.getMotivosIncumplimiento().getIdMotivoIncumplimiento();
		}

		this.jdbcTemplate.update(query, datosproyecto.getIdExpediente(), datosproyecto.getImporteJusAdmitido(),
				datosproyecto.getImporteJusCalculado(), datosproyecto.getSubvencionResuelta(),
				datosproyecto.getSubvencionJustificada(), datosproyecto.getObservacionesCastellano(),
				datosproyecto.getObservacionesEuskera(), datosproyecto.getFechaInformeStr(),
				getTecnicosResponsablesIdTecnicoResponsableAux, getTiposResultadoAux, getMotivosDesestimacionAux,
				datosproyecto.getFechaUltmodificacion(), datosproyecto.getUsuarioUltmodificacion(),
				datosproyecto.getRendimientoFinanciero(), datosproyecto.getIdProyectoExpediente());
		return datosproyecto;
	}

	/**
	 * Update importes de Justificacion
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public Justificacion updateImporte(Justificacion datosproyecto) {
		String query = "UPDATE DATOS_PROYECTO SET SUBVENCION_JUSTIFICADA= ?, IMPORTE_JUS_ADMITIDO= ?, IMPORTE_JUS_CALCULADO = ?, FECHA_ULTMODIFICACION= ?, USUARIO_ULTMODIFICACION= ? WHERE ID_EXPEDIENTE= ?";

		this.jdbcTemplate.update(query, datosproyecto.getSubvencionJustificada(), datosproyecto.getImporteJusAdmitido(),
				datosproyecto.getImporteJusCalculado(), datosproyecto.getFechaUltmodificacion(),
				datosproyecto.getUsuarioUltmodificacion(), datosproyecto.getIdExpediente());
		return datosproyecto;
	}

	/**
	 * 
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	/**
	 * Select de todos los importes de Justificacion
	 *
	 * @param idExpediente
	 *            Integer
	 * @return Justificacion
	 */
	public Justificacion refescarImportes(Integer idExpediente) {
		String query = "SELECT t2.SUBVENCION_RESUELTA SUBVENCIONRESUELTA, t2.SUBVENCION_JUSTIFICADA SUBVENCIONJUSTIFICADA,t2.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO,t2.IMPORTE_JUS_CALCULADO IMPORTEJUSCALCULADO  FROM DATOS_PROYECTO t2 WHERE t2.ID_EXPEDIENTE = ?";
		List<Justificacion> datosproyectoList = this.jdbcTemplate.query(query, this.rwMapTodoslosImportes,
				idExpediente);
		return (Justificacion) DataAccessUtils.uniqueResult(datosproyectoList);
	}
}
