package com.ejie.ab60.dao.justificacion;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.justificacion.MotivosIncumplimiento;

/**
 * MotivosIncumplimientoDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class MotivosIncumplimientoDaoImpl implements MotivosIncumplimientoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDMOTIVOINCUMPLIMIENTO", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */

	private RowMapper<MotivosIncumplimiento> rwMap = new RowMapper<MotivosIncumplimiento>() {
		public MotivosIncumplimiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosIncumplimiento(resultSet.getLong("IDMOTIVOINCUMPLIMIENTO"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<MotivosIncumplimiento> rwMapMotivo = new RowMapper<MotivosIncumplimiento>() {
		public MotivosIncumplimiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosIncumplimiento(resultSet.getLong("IDMOTIVOINCUMPLIMIENTO"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"));
		}
	};
	private RowMapper<MotivosIncumplimiento> rwMapPK = new RowMapper<MotivosIncumplimiento>() {
		public MotivosIncumplimiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new MotivosIncumplimiento(resultSet.getLong("IDMOTIVOINCUMPLIMIENTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<MotivosIncumplimiento>> rwMapJerarquia = new RowMapper<JerarquiaDto<MotivosIncumplimiento>>() {
		public JerarquiaDto<MotivosIncumplimiento> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MotivosIncumplimiento motivosincumplimiento = new MotivosIncumplimiento(
					resultSet.getLong("IDMOTIVOINCUMPLIMIENTO"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<MotivosIncumplimiento> jerarquia = new JerarquiaDto<MotivosIncumplimiento>();
			jerarquia.setModel(motivosincumplimiento);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the MotivosIncumplimiento table.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @return MotivosIncumplimiento
	 */
	public MotivosIncumplimiento add(MotivosIncumplimiento motivosincumplimiento) {
		String query = "INSERT INTO MOTIVOS_INCUMPLIMIENTO (ID_MOTIVO_INCUMPLIMIENTO, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, motivosincumplimiento.getIdMotivoIncumplimiento(),
				motivosincumplimiento.getDescripcionCastellano(), motivosincumplimiento.getDescripcionEuskera(),
				motivosincumplimiento.getFechaRegistro(), motivosincumplimiento.getUsuarioRegistro());
		return motivosincumplimiento;
	}

	/**
	 * Finds a list of rows in the Motivos table.
	 *
	 * 
	 * @return List<MotivosIncumplimiento>
	 */
	@Transactional(readOnly = true)
	public List<MotivosIncumplimiento> findMotivo() {
		String query = "SELECT t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM MOTIVOS_INCUMPLIMIENTO t1";
		return (List<MotivosIncumplimiento>) this.jdbcTemplate.query(query, this.rwMapMotivo);

	}

	/**
	 * Updates a single row in the MotivosIncumplimiento table.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @return MotivosIncumplimiento
	 */
	public MotivosIncumplimiento update(MotivosIncumplimiento motivosincumplimiento) {
		String query = "UPDATE MOTIVOS_INCUMPLIMIENTO SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_MOTIVO_INCUMPLIMIENTO=?";
		this.jdbcTemplate.update(query, motivosincumplimiento.getDescripcionCastellano(),
				motivosincumplimiento.getDescripcionEuskera(), motivosincumplimiento.getFechaRegistro(),
				motivosincumplimiento.getUsuarioRegistro(), motivosincumplimiento.getIdMotivoIncumplimiento());
		return motivosincumplimiento;
	}

	/**
	 * Finds a single row in the MotivosIncumplimiento table.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @return MotivosIncumplimiento
	 */
	@Transactional(readOnly = true)
	public MotivosIncumplimiento find(MotivosIncumplimiento motivosincumplimiento) {
		String query = "SELECT t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM MOTIVOS_INCUMPLIMIENTO t1  WHERE t1.ID_MOTIVO_INCUMPLIMIENTO = ?  ";

		List<MotivosIncumplimiento> motivosincumplimientoList = this.jdbcTemplate.query(query, this.rwMap,
				motivosincumplimiento.getIdMotivoIncumplimiento());
		return (MotivosIncumplimiento) DataAccessUtils.uniqueResult(motivosincumplimientoList);
	}

	/**
	 * Removes a single row in the MotivosIncumplimiento table.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @return
	 */
	public void remove(MotivosIncumplimiento motivosincumplimiento) {
		String query = "DELETE FROM MOTIVOS_INCUMPLIMIENTO WHERE ID_MOTIVO_INCUMPLIMIENTO=?";
		this.jdbcTemplate.update(query, motivosincumplimiento.getIdMotivoIncumplimiento());
	}

	/**
	 * Finds a list of rows in the MotivosIncumplimiento table.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<MotivosIncumplimiento>
	 */
	@Transactional(readOnly = true)
	public List<MotivosIncumplimiento> findAll(MotivosIncumplimiento motivosincumplimiento,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM MOTIVOS_INCUMPLIMIENTO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosincumplimiento);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosIncumplimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosIncumplimiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the MotivosIncumplimiento table using like.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<MotivosIncumplimiento>
	 */
	@Transactional(readOnly = true)
	public List<MotivosIncumplimiento> findAllLike(MotivosIncumplimiento motivosincumplimiento,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM MOTIVOS_INCUMPLIMIENTO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosincumplimiento, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					MotivosIncumplimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<MotivosIncumplimiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the MotivosIncumplimiento table.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(MotivosIncumplimiento motivosincumplimiento) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_INCUMPLIMIENTO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(motivosincumplimiento);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the MotivosIncumplimiento table using like.
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(MotivosIncumplimiento motivosincumplimiento, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM MOTIVOS_INCUMPLIMIENTO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosincumplimiento, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of MotivosIncumplimiento selected for rup_table
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosIncumplimiento>>
	 */
	@Override
	public List<TableRowDto<MotivosIncumplimiento>> reorderSelection(MotivosIncumplimiento motivosincumplimiento,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_INCUMPLIMIENTO t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(motivosincumplimiento, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				MotivosIncumplimiento.class, filterParamList, "ID_MOTIVO_INCUMPLIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosIncumplimiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            MotivosIncumplimiento
	 * @param searchParams
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosIncumplimiento>>
	 */
	@Override
	public List<TableRowDto<MotivosIncumplimiento>> search(MotivosIncumplimiento filterParams,
			MotivosIncumplimiento searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_INCUMPLIMIENTO t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				MotivosIncumplimiento.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_MOTIVO_INCUMPLIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<MotivosIncumplimiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtermotivosincumplimiento
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(MotivosIncumplimiento filtermotivosincumplimiento, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM MOTIVOS_INCUMPLIMIENTO t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtermotivosincumplimiento, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				MotivosIncumplimiento.class, query, params, "ID_MOTIVO_INCUMPLIMIENTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical MotivosIncumplimiento table.
	 *
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<MotivosIncumplimiento>>
	 */
	@Override
	public List<JerarquiaDto<MotivosIncumplimiento>> findAllLikeJerarquia(
			MotivosIncumplimiento filterMotivosIncumplimiento, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_MOTIVO_INCUMPLIMIENTO IDMOTIVOINCUMPLIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_INCUMPLIMIENTO
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_INCUMPLIMIENTO");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosIncumplimiento, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_MOTIVO_INCUMPLIMIENTO",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					MotivosIncumplimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(MotivosIncumplimiento filterMotivosIncumplimiento,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_INCUMPLIMIENTO
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_INCUMPLIMIENTO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosIncumplimiento, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_MOTIVO_INCUMPLIMIENTO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<MotivosIncumplimiento>>
	 */
	@Override
	public List<TableRowDto<MotivosIncumplimiento>> findAllChild(MotivosIncumplimiento filterMotivosIncumplimiento,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM MOTIVOS_INCUMPLIMIENTO
		// t1 ");
		List<String> from = new ArrayList<String>();
		from.add("MOTIVOS_INCUMPLIMIENTO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterMotivosIncumplimiento, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_MOTIVO_INCUMPLIMIENTO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<MotivosIncumplimiento>(this.rwMapPK, "ID_MOTIVO_INCUMPLIMIENTO"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosIncumplimiento entity
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(MotivosIncumplimiento motivosincumplimiento) {

		StringBuilder where = new StringBuilder(MotivosIncumplimientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (motivosincumplimiento != null && motivosincumplimiento.getIdMotivoIncumplimiento() != null) {
			where.append(" AND t1.ID_MOTIVO_INCUMPLIMIENTO = ?");
			params.add(motivosincumplimiento.getIdMotivoIncumplimiento());
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(motivosincumplimiento.getDescripcionCastellano());
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(motivosincumplimiento.getDescripcionEuskera());
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(motivosincumplimiento.getFechaRegistro());
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(motivosincumplimiento.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the MotivosIncumplimiento entity
	 *
	 * @param motivosincumplimiento
	 *            MotivosIncumplimiento Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(MotivosIncumplimiento motivosincumplimiento, Boolean startsWith) {

		StringBuilder where = new StringBuilder(MotivosIncumplimientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (motivosincumplimiento != null && motivosincumplimiento.getIdMotivoIncumplimiento() != null) {
			where.append(" AND t1.ID_MOTIVO_INCUMPLIMIENTO = ?");
			params.add(motivosincumplimiento.getIdMotivoIncumplimiento());
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosincumplimiento.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + motivosincumplimiento.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosincumplimiento.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + motivosincumplimiento.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(motivosincumplimiento.getFechaRegistro());
		}
		if (motivosincumplimiento != null && motivosincumplimiento.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(motivosincumplimiento.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + motivosincumplimiento.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
