package com.ejie.ab60.dao.justificacion;

import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.justificacion.RelFacActSubvencionables;
import com.ejie.ab60.model.justificacion.RelTipGasCon;

/**
 * RelTipGasConDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelTipGasConDaoImpl implements RelTipGasConDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELTIPGASCON", "IDTIPOGASTOFAC",
			"IDCONVOCATORIA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelTipGasCon> rwMap = new RowMapper<RelTipGasCon>() {
		public RelTipGasCon mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelTipGasCon(resultSet.getLong("IDRELTIPGASCON"), resultSet.getLong("IDTIPOGASTOFAC"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<RelTipGasCon> rwMapTipos = new RowMapper<RelTipGasCon>() {
		public RelTipGasCon mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelTipGasCon(resultSet.getLong("IDRELTIPGASCON"), resultSet.getLong("IDTIPOGASTOFAC"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getString("DESCCASTELLANO"),
					resultSet.getString("DESCEUSKERA"));
		}
	};

	private RowMapper<RelTipGasCon> rwMapPK = new RowMapper<RelTipGasCon>() {
		public RelTipGasCon mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelTipGasCon(resultSet.getLong("IDRELTIPGASCON"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<RelTipGasCon>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelTipGasCon>>() {
		public JerarquiaDto<RelTipGasCon> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelTipGasCon reltipgascon = new RelTipGasCon(resultSet.getLong("IDRELTIPGASCON"),
					resultSet.getLong("IDTIPOGASTOFAC"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<RelTipGasCon> jerarquia = new JerarquiaDto<RelTipGasCon>();
			jerarquia.setModel(reltipgascon);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelTipGasCon table.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @return RelTipGasCon
	 */
	public RelTipGasCon add(RelTipGasCon reltipgascon) {
		String query = "INSERT INTO REL_TIP_GAS_CON (ID_REL_TIP_GAS_CON, ID_TIPO_GASTO_FAC, ID_CONVOCATORIA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, reltipgascon.getIdRelTipGasCon(), reltipgascon.getIdTipoGastoFac(),
				reltipgascon.getIdConvocatoria(), reltipgascon.getFechaRegistro(), reltipgascon.getUsuarioRegistro());
		return reltipgascon;
	}

	/**
	 * Updates a single row in the RelTipGasCon table.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @return RelTipGasCon
	 */
	public RelTipGasCon update(RelTipGasCon reltipgascon) {
		String query = "UPDATE REL_TIP_GAS_CON SET ID_TIPO_GASTO_FAC=?, ID_CONVOCATORIA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_REL_TIP_GAS_CON=?";
		this.jdbcTemplate.update(query, reltipgascon.getIdTipoGastoFac(), reltipgascon.getIdConvocatoria(),
				reltipgascon.getFechaRegistro(), reltipgascon.getUsuarioRegistro(), reltipgascon.getIdRelTipGasCon());
		return reltipgascon;
	}

	/**
	 * Finds a single row in the RelTipGasCon table.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @return RelTipGasCon
	 */
	@Transactional(readOnly = true)
	public RelTipGasCon find(RelTipGasCon reltipgascon) {
		String query = "SELECT t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON, t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM REL_TIP_GAS_CON t1  WHERE t1.ID_REL_TIP_GAS_CON = ?  ";

		List<RelTipGasCon> reltipgasconList = this.jdbcTemplate.query(query, this.rwMap,
				reltipgascon.getIdRelTipGasCon());
		return (RelTipGasCon) DataAccessUtils.uniqueResult(reltipgasconList);
	}

	/**
	 * Removes a single row in the RelTipGasCon table.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @return
	 */
	public void remove(RelTipGasCon reltipgascon) {
		String query = "DELETE FROM REL_TIP_GAS_CON WHERE ID_REL_TIP_GAS_CON=?";
		this.jdbcTemplate.update(query, reltipgascon.getIdRelTipGasCon());
	}

	/**
	 * Finds a list of rows in the RelTipGasCon table.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelTipGasCon>
	 */
	@Transactional(readOnly = true)
	public List<RelTipGasCon> findAll(RelTipGasCon reltipgascon, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON,t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_TIP_GAS_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(reltipgascon);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelTipGasConDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelTipGasCon>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelTipGasCon table using like.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelTipGasCon>
	 */
	@Transactional(readOnly = true)
	public List<RelTipGasCon> findAllLike(RelTipGasCon reltipgascon, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON,t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM REL_TIP_GAS_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(reltipgascon, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelTipGasConDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelTipGasCon>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Lista de actuaciones
	 */
	@Override
	public List<RelTipGasCon> findTipos(Integer idConvocatoria) {
		String query = "SELECT  t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON,t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.DESCRIPCION_CASTELLANO DESCCASTELLANO, t2.DESCRIPCION_EUSKERA DESCEUSKERA "
				+ "from REL_TIP_GAS_CON t1 "
				+ "INNER JOIN TIPOS_GASTO_FAC t2 ON t1.ID_TIPO_GASTO_FAC = t2.ID_TIPO_GASTO_FAC "
				+ "WHERE ID_CONVOCATORIA = " + idConvocatoria;

		return (List<RelTipGasCon>) this.jdbcTemplate.query(query, this.rwMapTipos);

	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelTipGasCon table.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelTipGasCon reltipgascon) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_TIP_GAS_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(reltipgascon);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelTipGasCon table using like.
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelTipGasCon reltipgascon, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_TIP_GAS_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(reltipgascon, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelTipGasCon selected for rup_table
	 *
	 * @param reltipgascon
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelTipGasCon>>
	 */
	@Override
	public List<TableRowDto<RelTipGasCon>> reorderSelection(RelTipGasCon reltipgascon,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON,t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_TIP_GAS_CON t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(reltipgascon, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelTipGasCon.class,
				filterParamList, "ID_REL_TIP_GAS_CON");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelTipGasCon>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelTipGasCon
	 * @param searchParams
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelTipGasCon>>
	 */
	@Override
	public List<TableRowDto<RelTipGasCon>> search(RelTipGasCon filterParams, RelTipGasCon searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON,t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_TIP_GAS_CON t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelTipGasCon.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_TIP_GAS_CON");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelTipGasCon>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterreltipgascon
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelTipGasCon filterreltipgascon, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON,t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM REL_TIP_GAS_CON t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterreltipgascon, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelTipGasCon.class,
				query, params, "ID_REL_TIP_GAS_CON");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelTipGasCon table.
	 *
	 * @param filterRelTipGasCon
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelTipGasCon>>
	 */
	@Override
	public List<JerarquiaDto<RelTipGasCon>> findAllLikeJerarquia(RelTipGasCon filterRelTipGasCon,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_TIP_GAS_CON IDRELTIPGASCON,t1.ID_TIPO_GASTO_FAC IDTIPOGASTOFAC,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_TIP_GAS_CON t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_TIP_GAS_CON");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelTipGasCon, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_TIP_GAS_CON", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelTipGasConDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelTipGasCon
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelTipGasCon filterRelTipGasCon, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_TIP_GAS_CON t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_TIP_GAS_CON");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelTipGasCon, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_TIP_GAS_CON",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelTipGasCon
	 *            RelTipGasCon
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelTipGasCon>>
	 */
	@Override
	public List<TableRowDto<RelTipGasCon>> findAllChild(RelTipGasCon filterRelTipGasCon,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_TIP_GAS_CON t1 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_TIP_GAS_CON");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelTipGasCon, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_TIP_GAS_CON",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelTipGasCon>(this.rwMapPK, "ID_REL_TIP_GAS_CON"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelTipGasCon entity
	 *
	 * @param reltipgascon
	 *            RelTipGasCon Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelTipGasCon reltipgascon) {

		StringBuilder where = new StringBuilder(RelTipGasConDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (reltipgascon != null && reltipgascon.getIdRelTipGasCon() != null) {
			where.append(" AND t1.ID_REL_TIP_GAS_CON = ?");
			params.add(reltipgascon.getIdRelTipGasCon());
		}
		if (reltipgascon != null && reltipgascon.getIdTipoGastoFac() != null) {
			where.append(" AND t1.ID_TIPO_GASTO_FAC = ?");
			params.add(reltipgascon.getIdTipoGastoFac());
		}
		if (reltipgascon != null && reltipgascon.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(reltipgascon.getIdConvocatoria());
		}
		if (reltipgascon != null && reltipgascon.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(reltipgascon.getFechaRegistro());
		}
		if (reltipgascon != null && reltipgascon.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(reltipgascon.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelTipGasCon entity
	 *
	 * @param reltipgascon
	 *            RelTipGasCon Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelTipGasCon reltipgascon, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelTipGasConDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (reltipgascon != null && reltipgascon.getIdRelTipGasCon() != null) {
			where.append(" AND t1.ID_REL_TIP_GAS_CON = ?");
			params.add(reltipgascon.getIdRelTipGasCon());
		}
		if (reltipgascon != null && reltipgascon.getIdTipoGastoFac() != null) {
			where.append(" AND t1.ID_TIPO_GASTO_FAC = ?");
			params.add(reltipgascon.getIdTipoGastoFac());
		}
		if (reltipgascon != null && reltipgascon.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(reltipgascon.getIdConvocatoria());
		}
		if (reltipgascon != null && reltipgascon.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(reltipgascon.getFechaRegistro());
		}
		if (reltipgascon != null && reltipgascon.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(reltipgascon.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + reltipgascon.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
