package com.ejie.ab60.dao.justificacion;

import com.ejie.ab60.model.estudioTecnico.TiposResultado;
import com.ejie.ab60.model.justificacion.TiposResJus;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * TiposResJusDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposResJusDaoImpl implements TiposResJusDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRESJUSTIFICACION", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposResJus> rwMap = new RowMapper<TiposResJus>() {
		public TiposResJus mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposResJus(resultSet.getLong("IDRESJUSTIFICACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<TiposResJus> rwMapResultado = new RowMapper<TiposResJus>() {
		public TiposResJus mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposResJus(resultSet.getLong("IDRESJUSTIFICACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"));
		}
	};

	private RowMapper<TiposResJus> rwMapPK = new RowMapper<TiposResJus>() {
		public TiposResJus mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposResJus(resultSet.getLong("IDRESJUSTIFICACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposResJus>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposResJus>>() {
		public JerarquiaDto<TiposResJus> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposResJus tiposresjus = new TiposResJus(resultSet.getLong("IDRESJUSTIFICACION"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<TiposResJus> jerarquia = new JerarquiaDto<TiposResJus>();
			jerarquia.setModel(tiposresjus);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposResJus table.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @return TiposResJus
	 */
	public TiposResJus add(TiposResJus tiposresjus) {
		String query = "INSERT INTO TIPOS_RES_JUS (ID_RES_JUSTIFICACION, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, tiposresjus.getIdResJustificacion(), tiposresjus.getDescripcionCastellano(),
				tiposresjus.getDescripcionEuskera(), tiposresjus.getFechaRegistro(), tiposresjus.getUsuarioRegistro());
		return tiposresjus;
	}

	/**
	 * Updates a single row in the TiposResJus table.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @return TiposResJus
	 */
	public TiposResJus update(TiposResJus tiposresjus) {
		String query = "UPDATE TIPOS_RES_JUS SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_RES_JUSTIFICACION=?";
		this.jdbcTemplate.update(query, tiposresjus.getDescripcionCastellano(), tiposresjus.getDescripcionEuskera(),
				tiposresjus.getFechaRegistro(), tiposresjus.getUsuarioRegistro(), tiposresjus.getIdResJustificacion());
		return tiposresjus;
	}

	/**
	 * Finds a single row in the TiposResJus table.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @return TiposResJus
	 */
	@Transactional(readOnly = true)
	public TiposResJus find(TiposResJus tiposresjus) {
		String query = "SELECT t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_RES_JUS t1  WHERE t1.ID_RES_JUSTIFICACION = ?  ";

		List<TiposResJus> tiposresjusList = this.jdbcTemplate.query(query, this.rwMap,
				tiposresjus.getIdResJustificacion());
		return (TiposResJus) DataAccessUtils.uniqueResult(tiposresjusList);
	}

	/**
	 * Removes a single row in the TiposResJus table.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @return
	 */
	public void remove(TiposResJus tiposresjus) {
		String query = "DELETE FROM TIPOS_RES_JUS WHERE ID_RES_JUSTIFICACION=?";
		this.jdbcTemplate.update(query, tiposresjus.getIdResJustificacion());
	}

	/**
	 * Finds a list of rows in the TiposResJus table.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposResJus>
	 */
	@Transactional(readOnly = true)
	public List<TiposResJus> findAll(TiposResJus tiposresjus, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_RES_JUS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposresjus);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, TiposResJusDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposResJus>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposResJus table using like.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposResJus>
	 */
	@Transactional(readOnly = true)
	public List<TiposResJus> findAllLike(TiposResJus tiposresjus, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_RES_JUS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposresjus, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, TiposResJusDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposResJus>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposResJus table.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposResJus tiposresjus) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_RES_JUS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposresjus);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposResJus table using like.
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposResJus tiposresjus, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_RES_JUS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposresjus, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposResJus selected for rup_table
	 *
	 * @param tiposresjus
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposResJus>>
	 */
	@Override
	public List<TableRowDto<TiposResJus>> reorderSelection(TiposResJus tiposresjus, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_RES_JUS t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposresjus, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, TiposResJus.class,
				filterParamList, "ID_RES_JUSTIFICACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposResJus>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposResJus
	 * @param searchParams
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposResJus>>
	 */
	@Override
	public List<TableRowDto<TiposResJus>> search(TiposResJus filterParams, TiposResJus searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_RES_JUS t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, TiposResJus.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_RES_JUSTIFICACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposResJus>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertiposresjus
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposResJus filtertiposresjus, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_RES_JUS t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertiposresjus, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, TiposResJus.class,
				query, params, "ID_RES_JUSTIFICACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposResJus table.
	 *
	 * @param filterTiposResJus
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposResJus>>
	 */
	@Override
	public List<JerarquiaDto<TiposResJus>> findAllLikeJerarquia(TiposResJus filterTiposResJus,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_RES_JUS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_RES_JUS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposResJus, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_RES_JUSTIFICACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposResJusDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposResJus
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposResJus filterTiposResJus, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_RES_JUS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_RES_JUS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposResJus, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_RES_JUSTIFICACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposResJus
	 *            TiposResJus
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposResJus>>
	 */
	@Override
	public List<TableRowDto<TiposResJus>> findAllChild(TiposResJus filterTiposResJus,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_RES_JUS t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_RES_JUS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposResJus, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_RES_JUSTIFICACION", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposResJus>(this.rwMapPK, "ID_RES_JUSTIFICACION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposResJus entity
	 *
	 * @param tiposresjus
	 *            TiposResJus Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposResJus tiposresjus) {

		StringBuilder where = new StringBuilder(TiposResJusDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposresjus != null && tiposresjus.getIdResJustificacion() != null) {
			where.append(" AND t1.ID_RES_JUSTIFICACION = ?");
			params.add(tiposresjus.getIdResJustificacion());
		}
		if (tiposresjus != null && tiposresjus.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposresjus.getDescripcionCastellano());
		}
		if (tiposresjus != null && tiposresjus.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposresjus.getDescripcionEuskera());
		}
		if (tiposresjus != null && tiposresjus.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposresjus.getFechaRegistro());
		}
		if (tiposresjus != null && tiposresjus.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposresjus.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposResJus entity
	 *
	 * @param tiposresjus
	 *            TiposResJus Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposResJus tiposresjus, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposResJusDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposresjus != null && tiposresjus.getIdResJustificacion() != null) {
			where.append(" AND t1.ID_RES_JUSTIFICACION = ?");
			params.add(tiposresjus.getIdResJustificacion());
		}
		if (tiposresjus != null && tiposresjus.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposresjus.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tiposresjus.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tiposresjus != null && tiposresjus.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposresjus.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tiposresjus.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tiposresjus != null && tiposresjus.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposresjus.getFechaRegistro());
		}
		if (tiposresjus != null && tiposresjus.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposresjus.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tiposresjus.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	/**
	 * Finds a list of rows in the Resultados table.
	 *
	 * 
	 * @return List<TiposResultado>
	 */
	@Transactional(readOnly = true)
	public List<TiposResJus> findResultado() {

		String query = "SELECT  t1.ID_RES_JUSTIFICACION IDRESJUSTIFICACION, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM TIPOS_RES_JUS t1";

		return (List<TiposResJus>) this.jdbcTemplate.query(query, this.rwMapResultado);

	}

}
