package com.ejie.ab60.dao.moduloContable;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.moduloContable.DocContables;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * DocContablesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class DocContablesDODaoImpl implements DocContablesDODao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPROCEDIMIENTO", "IDEXPEDIENTE",
			"IDDOCUMENTOCONTABLE", "IDAPLICACIONPRESUPUESTARIA", "IDREFERENCIAINTERVENCION", "TIPOREGISTRO",
			"TIPODOCUMENTO", "NUMEROEXPEDIENTE", "REFERENCIACONTRATACION", "TIPOOPEGAS", "FECHALIMJUS",
			"APLICACIONPRESUPUESTARIA", "EJERCICIOAPLPRE", "AGRUPACION", "GASTOINGRESO", "SECCION", "SERVICIO",
			"CENTRO", "TERRITORIO", "CAC", "SC", "PROGRAMA", "PARTIDA", "LETRACONTROL", "CUENTAPCP", "INMOVILIZADO",
			"EJERCICIOREFINT", "ANYOORIGEN", "NUMERO", "DISPONIBLE", "OBLIGACION", "NUMEROORDEN", "NUMEROPLURIANUAL",
			"CODIGOSUBVENCION", "IMPORTECOMRESTO", "NUMEROFACTURA", "FECHAFACTURA", "CONCEPTORESUMIDO",
			"TERCEROMOSTRAR", "TERCER", "IMPORTE", "EJERCICIOENDOSO", "NUMEROENDOSO", "OTROPERCEPTOR",
			"FECHAVENCIMIENTO", "CODIGORETENCION", "BASERETENCION", "FORMAPAGO", "CUENTAFINANCIERA", "EJERCICIOMAQTER",
			"NUMEROMAQTER", "EJERCICIOMAQTERPER", "NUMEROMAQTERPER", "FECHAINIPERPAG", "CODIGOCONTRATO",
			"REGISTROCONTABLE", "FECHARESOLUCION", "FECHADOCUMENTODO" };

	private JdbcTemplate jdbcTemplate;

	private RowMapper<DocContables> rwMap = new RowMapper<DocContables>() {
		public DocContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			DocContables docContables = new DocContables(resultSet.getInt("IDPROCEDIMIENTO"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getString("IDDOCUMENTOCONTABLE"),
					resultSet.getInt("IDAPLICACIONPRESUPUESTARIA"), resultSet.getString("APLICACIONPRESUPUESTARIA"),
					resultSet.getString("IDREFERENCIAINTERVENCION"), resultSet.getInt("TIPOREGISTRO"),
					resultSet.getString("TIPODOCUMENTO"), resultSet.getString("NUMEROEXPEDIENTE"),
					resultSet.getString("REFERENCIACONTRATACION"), resultSet.getString("TIPOOPEGAS"),
					resultSet.getDate("FECHALIMJUS"), resultSet.getString("EJERCICIOAPLPRE"),
					resultSet.getString("AGRUPACION"), resultSet.getString("GASTOINGRESO"),
					resultSet.getString("SECCION"), resultSet.getString("SERVICIO"), resultSet.getString("CENTRO"),
					resultSet.getString("TERRITORIO"), resultSet.getString("CAC"), resultSet.getString("SC"),
					resultSet.getString("PROGRAMA"), resultSet.getString("PARTIDA"),
					resultSet.getString("LETRACONTROL"), resultSet.getString("CUENTAPCP"),
					resultSet.getString("INMOVILIZADO"), resultSet.getString("EJERCICIOREFINT"),
					resultSet.getString("ANYOORIGEN"), resultSet.getString("NUMERO"), resultSet.getString("DISPONIBLE"),
					resultSet.getString("OBLIGACION"), resultSet.getString("NUMEROORDEN"),
					resultSet.getString("NUMEROPLURIANUAL"), resultSet.getString("CODIGOSUBVENCION"),
					resultSet.getString("IMPORTECOMRESTO"), resultSet.getString("NUMEROFACTURA"),
					resultSet.getDate("FECHAFACTURA"), resultSet.getString("CONCEPTORESUMIDO"),
					resultSet.getString("TERCERO"), resultSet.getString("TERCEROMOSTRAR"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getString("EJERCICIOENDOSO"),
					resultSet.getString("NUMEROENDOSO"), resultSet.getString("OTROPERCEPTOR"),
					resultSet.getDate("FECHAVENCIMIENTO"), resultSet.getString("CODIGORETENCION"),
					resultSet.getString("BASERETENCION"), resultSet.getString("FORMAPAGO"),
					resultSet.getString("CUENTAFINANCIERA"), resultSet.getString("EJERCICIOMAQTER"),
					resultSet.getString("NUMEROMAQTER"), resultSet.getString("EJERCICIOMAQTERPER"),
					resultSet.getString("NUMEROMAQTERPER"), resultSet.getString("CODIGOCONTRATO"),
					resultSet.getDate("FECHAINIPERPAG"), resultSet.getString("REGISTROCONTABLE"),
					resultSet.getDate("FECHARESOLUCION"), resultSet.getDate("FECHADOCUMENTODO"));

			// Los documentos contables Pendientes serán los que tengan
			// FECHA_DOCUMENTO_DO igual a NULL. Esto registros tendrán un check
			// para poder seleccionar cada uno de ellos.
			if (docContables.getFechaDocumentoDO() == null) {
				docContables.setEstado(Constantes.ESTADO_PENDIENTE);
			}

			// Los documentos contables Incompletos serán los siguientes:
			// - Los documentos que el campo NUMERO_EXPEDIENTE de la vista sea
			// NULL.
			// - Los documentos que el campo CONCEPTO_RESUMIDO de la vista sea
			// NULL.
			// - Los documentos que algún campo de la APLICACION_PRESUPUESTARIA
			// de la vista sea NULL.
			// - Los documentos que algún campo de la REFERENCIA_INTERVENCION de
			// la vista sea NULL.
			// - Los documentos que el campo TERCERO de la vista sea NULL.
			else if (docContables.getExpediente() == null || docContables.getConceptoResumido() == null
					|| docContables.getAplicacionPresupuestaria() == null
					|| docContables.getReferenciaIntervencion() == null || docContables.getTercero() == null) {
				docContables.setEstado(Constantes.ESTADO_INCOMPLETO);
			}

			// Los documentos contables Enviados serán los que tengan
			// FECHA_DOCUMENTO_DO diferente a NULL, es decir, ya se han añadido
			// en un fichero contable.
			else if (docContables.getFechaDocumentoDO() != null) {
				docContables.setEstado(Constantes.ESTADO_ENVIADO);
			}

			// Aquí no tendremos documentos contables Confirmados.

			return docContables;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	@Transactional(readOnly = true)
	public List<DocContables> findAllLike(DocContables docContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA, t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA, t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION, t1.TIPO_REGISTRO TIPOREGISTRO, t1.TIPO_DOCUMENTO TIPODOCUMENTO, t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE, t1.REFERENCIA_CONTRATACION REFERENCIACONTRATACION, t1.TIPO_OPE_GAS TIPOOPEGAS, t1.FECHA_LIM_JUS FECHALIMJUS, t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE, t1.AGRUPACION AGRUPACION, t1.GASTO_INGRESO GASTOINGRESO, t1.SECCION SECCION, t1.SERVICIO SERVICIO, t1.CENTRO CENTRO, t1.TERRITORIO TERRITORIO, t1.CAC CAC, t1.SC SC, t1.PROGRAMA PROGRAMA, t1.PARTIDA PARTIDA, t1.LETRA_CONTROL LETRACONTROL, t1.CUENTA_PCP CUENTAPCP, t1.INMOVILIZADO INMOVILIZADO, t1.EJERCICIO_REF_INT EJERCICIOREFINT, t1.ANYO_ORIGEN ANYOORIGEN, t1.NUMERO NUMERO, t1.DISPONIBLE DISPONIBLE, t1.OBLIGACION OBLIGACION, t1.NUMERO_ORDEN NUMEROORDEN, t1.NUMERO_PLURIANUAL NUMEROPLURIANUAL, t1.CODIGO_SUBVENCION CODIGOSUBVENCION, t1.IMPORTE_COM_RESTO IMPORTECOMRESTO, t1.NUMERO_FACTURA NUMEROFACTURA, t1.FECHA_FACTURA FECHAFACTURA, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.TERCER TERCERO, t1.TERCERO_MOSTRAR TERCEROMOSTRAR, t1.IMPORTE IMPORTE, t1.EJERCICIO_ENDOSO EJERCICIOENDOSO, t1.NUMERO_ENDOSO NUMEROENDOSO, t1.OTRO_PERCEPTOR OTROPERCEPTOR, t1.FECHA_VENCIMIENTO FECHAVENCIMIENTO, t1.CODIGO_RETENCION CODIGORETENCION, t1.BASE_RETENCION BASERETENCION, t1.FORMA_PAGO FORMAPAGO, t1.CUENTA_FINANCIERA CUENTAFINANCIERA, t1.EJERCICIO_MAQ_TER EJERCICIOMAQTER, t1.NUMERO_MAQ_TER NUMEROMAQTER, t1.EJERCICIO_MAQ_TER_PER EJERCICIOMAQTERPER, t1.NUMERO_MAQ_TER_PER NUMEROMAQTERPER, t1.FECHA_INI_PER_PAG FECHAINIPERPAG, t1.CODIGO_CONTRATO CODIGOCONTRATO, t1.REGISTRO_CONTABLE REGISTROCONTABLE, t1.FECHA_RESOLUCION FECHARESOLUCION, t1.FECHA_DOCUMENTO_DO FECHADOCUMENTODO ");
		query.append("FROM V_EXP_INF_CONTABLE_DO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			// Transformamos aquí los campos de ordenación de la vista
			// V_EXP_INF_CONTABLE a los de V_EXP_INF_CONTABLE_DO para no romper
			// la compatibilidad.
			if ("EXPEDIENTE".equals(jqGridRequestDto.getSidx().toUpperCase())) {
				jqGridRequestDto.setSidx("NUMEROEXPEDIENTE");
			} else if ("IMPORTEPAGO".equals(jqGridRequestDto.getSidx().toUpperCase())) {
				jqGridRequestDto.setSidx("IMPORTE");
			}

			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DocContablesDODaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<DocContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	@Transactional(readOnly = true)
	public Long findAllLikeCount(DocContables docContables, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM V_EXP_INF_CONTABLE_DO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), params.toArray(), Long.class);
	}

	/*
	 * MÉTODOS PRIVADOS
	 */
	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DocContables entity
	 *
	 * @param docContables
	 *            DocContables Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(DocContables docContables, Boolean startsWith) {

		StringBuilder where = new StringBuilder(DocContablesODaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (docContables != null && docContables.getIdProcedimiento() != null) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(docContables.getIdProcedimiento());
		}
		if (docContables != null && docContables.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(docContables.getIdExpediente());
		}
		if (docContables != null && docContables.getExpediente() != null) {
			where.append(" AND UPPER(t1.EXPEDIENTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getExpediente().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getExpediente().toUpperCase() + "%");
			}
			where.append(" AND t1.EXPEDIENTE IS NOT NULL");
		}
		if (docContables != null && docContables.getConceptoResumido() != null) {
			where.append(" AND UPPER(t1.CONCEPTO_RESUMIDO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getConceptoResumido().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getConceptoResumido().toUpperCase() + "%");
			}
			where.append(" AND t1.CONCEPTO_RESUMIDO IS NOT NULL");
		}
		if (docContables != null && docContables.getImportePago() != null) {
			where.append(" AND t1.IMPORTE_PAGO = ?");
			params.add(docContables.getImportePago());
		}
		if (docContables != null && docContables.getAplicacionPresupuestaria() != null) {
			where.append(" AND UPPER(t1.APLICACION_PRESUPUESTARIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getAplicacionPresupuestaria().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getAplicacionPresupuestaria().toUpperCase() + "%");
			}
			where.append(" AND t1.APLICACION_PRESUPUESTARIA IS NOT NULL");
		}
		if (docContables != null && docContables.getEjercicioAplPre() != null) {
			where.append(" AND t1.EJERCICIO_APL_PRE = ?");
			params.add(docContables.getEjercicioAplPre());
		}
		if (docContables != null && docContables.getAgrupacion() != null) {
			where.append(" AND t1.AGRUPACION = ?");
			params.add(docContables.getAgrupacion());
		}
		if (docContables != null && docContables.getGastoIngreso() != null) {
			where.append(" AND t1.GASTO_INGRESO = ?");
			params.add(docContables.getGastoIngreso());
		}
		if (docContables != null && docContables.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(docContables.getSeccion());
		}
		if (docContables != null && docContables.getServicio() != null) {
			where.append(" AND t1.SERVICIO = ?");
			params.add(docContables.getServicio());
		}
		if (docContables != null && docContables.getCentro() != null) {
			where.append(" AND t1.CENTRO = ?");
			params.add(docContables.getCentro());
		}
		if (docContables != null && docContables.getTerritorio() != null) {
			where.append(" AND UPPER(t1.TERRITORIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getTerritorio().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getTerritorio().toUpperCase() + "%");
			}
			where.append(" AND t1.TERRITORIO IS NOT NULL");
		}
		if (docContables != null && docContables.getCac() != null) {
			where.append(" AND t1.CAC = ?");
			params.add(docContables.getCac());
		}
		if (docContables != null && docContables.getSc() != null) {
			where.append(" AND t1.SC = ?");
			params.add(docContables.getSc());
		}
		if (docContables != null && docContables.getPrograma() != null) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(docContables.getPrograma());
		}
		if (docContables != null && docContables.getPartida() != null) {
			where.append(" AND t1.PARTIDA = ?");
			params.add(docContables.getPartida());
		}
		if (docContables != null && docContables.getLetraControl() != null) {
			where.append(" AND UPPER(t1.LETRA_CONTROL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getLetraControl().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getLetraControl().toUpperCase() + "%");
			}
			where.append(" AND t1.LETRA_CONTROL IS NOT NULL");
		}
		if (docContables != null && docContables.getEjercicioRefInt() != null) {
			where.append(" AND t1.EJERCICIO_REF_INT = ?");
			params.add(docContables.getEjercicioRefInt());
		}
		if (docContables != null && docContables.getAnyoOrigen() != null) {
			where.append(" AND t1.ANYO_ORIGEN = ?");
			params.add(docContables.getAnyoOrigen());
		}
		if (docContables != null && docContables.getNumero() != null) {
			where.append(" AND t1.NUMERO = ?");
			params.add(docContables.getNumero());
		}
		if (docContables != null && docContables.getDisponible() != null) {
			where.append(" AND t1.DISPONIBLE = ?");
			params.add(docContables.getDisponible());
		}
		if (docContables != null && docContables.getTerceroMostrar() != null) {
			where.append(" AND UPPER(t1.TERCERO_MOSTRAR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getTerceroMostrar().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getTerceroMostrar().toUpperCase() + "%");
			}
			where.append(" AND t1.TERCERO_MOSTRAR IS NOT NULL");
		}
		if (docContables != null && docContables.getTercero() != null) {
			where.append(" AND UPPER(t1.TERCERO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getTercero().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getTercero().toUpperCase() + "%");
			}
			where.append(" AND t1.TERCERO IS NOT NULL");
		}
		if (docContables != null && docContables.getFechaDocumentoD() != null) {
			where.append(" AND t1.FECHA_DOCUMENTO_D = ?");
			params.add(docContables.getFechaDocumentoD());
		}
		if (docContables != null && docContables.getRefIntD() != null) {
			where.append(" AND UPPER(t1.REF_INT_D) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getRefIntD().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getRefIntD().toUpperCase() + "%");
			}
			where.append(" AND t1.REF_INT_D IS NOT NULL");
		}
		if (docContables != null && docContables.getRefIntO() != null) {
			where.append(" AND UPPER(t1.REF_INT_O) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getRefIntO().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getRefIntO().toUpperCase() + "%");
			}
			where.append(" AND t1.REF_INT_O IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Reorder the data list of DocContables selected for rup_table
	 *
	 * @param docContables
	 *            DocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DocContables>>
	 */
	@Override
	public List<TableRowDto<DocContables>> reorderSelection(DocContables docContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA, t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA, t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION, t1.TIPO_REGISTRO TIPOREGISTRO, t1.TIPO_DOCUMENTO TIPODOCUMENTO, t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE, t1.REFERENCIA_CONTRATACION REFERENCIACONTRATACION, t1.TIPO_OPE_GAS TIPOOPEGAS, t1.FECHA_LIM_JUS FECHALIMJUS, t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE, t1.AGRUPACION AGRUPACION, t1.GASTO_INGRESO GASTOINGRESO, t1.SECCION SECCION, t1.SERVICIO SERVICIO, t1.CENTRO CENTRO, t1.TERRITORIO TERRITORIO, t1.CAC CAC, t1.SC SC, t1.PROGRAMA PROGRAMA, t1.PARTIDA PARTIDA, t1.LETRA_CONTROL LETRACONTROL, t1.CUENTA_PCP CUENTAPCP, t1.INMOVILIZADO INMOVILIZADO, t1.EJERCICIO_REF_INT EJERCICIOREFINT, t1.ANYO_ORIGEN ANYOORIGEN, t1.NUMERO NUMERO, t1.DISPONIBLE DISPONIBLE, t1.OBLIGACION OBLIGACION, t1.NUMERO_ORDEN NUMEROORDEN, t1.NUMERO_PLURIANUAL NUMEROPLURIANUAL, t1.CODIGO_SUBVENCION CODIGOSUBVENCION, t1.IMPORTE_COM_RESTO IMPORTECOMRESTO, t1.NUMERO_FACTURA NUMEROFACTURA, t1.FECHA_FACTURA FECHAFACTURA, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.TERCER TERCERO, t1.TERCERO_MOSTRAR TERCEROMOSTRAR, t1.IMPORTE IMPORTE, t1.EJERCICIO_ENDOSO EJERCICIOENDOSO, t1.NUMERO_ENDOSO NUMEROENDOSO, t1.OTRO_PERCEPTOR OTROPERCEPTOR, t1.FECHA_VENCIMIENTO FECHAVENCIMIENTO, t1.CODIGO_RETENCION CODIGORETENCION, t1.BASE_RETENCION BASERETENCION, t1.FORMA_PAGO FORMAPAGO, t1.CUENTA_FINANCIERA CUENTAFINANCIERA, t1.EJERCICIO_MAQ_TER EJERCICIOMAQTER, t1.NUMERO_MAQ_TER NUMEROMAQTER, t1.EJERCICIO_MAQ_TER_PER EJERCICIOMAQTERPER, t1.NUMERO_MAQ_TER_PER NUMEROMAQTERPER, t1.FECHA_INI_PER_PAG FECHAINIPERPAG, t1.CODIGO_CONTRATO CODIGOCONTRATO, t1.REGISTRO_CONTABLE REGISTROCONTABLE, t1.FECHA_RESOLUCION FECHARESOLUCION, t1.FECHA_DOCUMENTO_DO FECHADOCUMENTODO ");
		// FROM
		query.append("FROM V_EXP_INF_CONTABLE_DO t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, DocContables.class,
				filterParamList,
				"ID_PROCEDIMIENTO, ID_EXPEDIENTE, ID_DOCUMENTO_CONTABLE, ID_APLICACION_PRESUPUESTARIA, APLICACION_PRESUPUESTARIA, ID_REFERENCIA_INTERVENCION, TIPO_REGISTRO, TIPO_DOCUMENTO, NUMERO_EXPEDIENTE, REFERENCIA_CONTRATACION, TIPO_OPE_GAS, FECHA_LIM_JUS, EJERCICIO_APL_PRE, AGRUPACION, GASTO_INGRESO, SECCION, SERVICIO, CENTRO, TERRITORIO, CAC, SC, PROGRAMA, PARTIDA, LETRA_CONTROL, CUENTA_PCP, INMOVILIZADO, EJERCICIO_REF_INT, ANYO_ORIGEN, NUMERO, DISPONIBLE, OBLIGACION, NUMERO_ORDEN, NUMERO_PLURIANUAL, CODIGO_SUBVENCION, IMPORTE_COM_RESTO, NUMERO_FACTURA, FECHA_FACTURA, CONCEPTO_RESUMIDO, TERCER, TERCERO_MOSTRAR, IMPORTE, EJERCICIO_ENDOSO, NUMERO_ENDOSO, OTRO_PERCEPTOR, FECHA_VENCIMIENTO, CODIGO_RETENCION, BASE_RETENCION, FORMA_PAGO, CUENTA_FINANCIERA, EJERCICIO_MAQ_TER, NUMERO_MAQ_TER, EJERCICIO_MAQ_TER_PER, NUMERO_MAQ_TER_PER, FECHA_INI_PER_PAG, CODIGO_CONTRATO, REGISTRO_CONTABLE, FECHA_RESOLUCION, FECHA_DOCUMENTO_DO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DocContables>(this.rwMap, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
