package com.ejie.ab60.dao.moduloContable;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.moduloContable.DocContables;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * DocContablesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class DocContablesODaoImpl implements DocContablesODao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "FECHADOCUMENTODO", "NUMEROPAGO",
			"FECHARESOLUCION", "REGISTROCONTABLE", "CODIGOCONTRATO", "FECHAINIPERPAG", "NUMEROMAQTERPER",
			"EJERCICIOMAQTERPER", "NUMEROMAQTER", "EJERCICIOMAQTER", "CUENTAFINANCIERA", "FORMAPAGO", "BASERETENCION",
			"CODIGORETENCION", "FECHAVENCIMIENTO", "OTROPERCEPTOR", "NUMEROENDOSO", "EJERCICIOENDOSO", "IMPORTE",
			"TERCER", "TERCEROMOSTRAR", "CONCEPTORESUMIDO", "FECHAFACTURA", "NUMEROFACTURA", "IMPORTECOMRESTO",
			"CODIGOSUBVENCION", "NUMEROPLURIANUAL", "NUMEROORDEN", "OBLIGACION", "DISPONIBLE", "NUMERO", "ANYOORIGEN",
			"EJERCICIOREFINT", "INMOVILIZADO", "CUENTAPCP", "LETRACONTROL", "PARTIDA", "PROGRAMA", "SC", "CAC",
			"TERRITORIO", "CENTRO", "SERVICIO", "SECCION", "GASTOINGRESO", "AGRUPACION", "EJERCICIOAPLPRE",
			"APLICACIONPRESUPUESTARIA", "FECHALIMJUS", "TIPOOPEGAS", "REFERENCIACONTRATACION", "NUMEROEXPEDIENTE",
			"TIPODOCUMENTO", "TIPOREGISTRO", "IDREFERENCIAINTERVENCION", "IDAPLICACIONPRESUPUESTARIA",
			"IDDOCUMENTOCONTABLE", "IDEXPEDIENTE", "IDPROCEDIMIENTO" };

	private JdbcTemplate jdbcTemplate;

	private RowMapper<DocContables> rwMap = new RowMapper<DocContables>() {
		public DocContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			DocContables docContables = new DocContables(resultSet.getInt("TIPOREGISTRO"),
					resultSet.getString("TIPODOCUMENTO"), resultSet.getString("NUMEROEXPEDIENTE"),
					resultSet.getString("TIPOOPEGAS"), resultSet.getDate("FECHALIMJUS"),
					resultSet.getString("EJERCICIOAPLPRE"), resultSet.getString("AGRUPACION"),
					resultSet.getString("GASTOINGRESO"), resultSet.getString("SECCION"),
					resultSet.getString("SERVICIO"), resultSet.getString("CENTRO"), resultSet.getString("TERRITORIO"),
					resultSet.getString("CAC"), resultSet.getString("SC"), resultSet.getString("PROGRAMA"),
					resultSet.getString("PARTIDA"), resultSet.getString("LETRACONTROL"),
					resultSet.getString("CUENTAPCP"), resultSet.getString("INMOVILIZADO"),
					resultSet.getString("EJERCICIOREFINT"), resultSet.getString("ANYOORIGEN"),
					resultSet.getString("NUMERO"), resultSet.getString("DISPONIBLE"), resultSet.getString("OBLIGACION"),
					resultSet.getString("NUMEROORDEN"), resultSet.getString("NUMEROPLURIANUAL"),
					resultSet.getString("CODIGOSUBVENCION"), resultSet.getString("IMPORTECOMRESTO"),
					resultSet.getString("NUMEROFACTURA"), resultSet.getDate("FECHAFACTURA"),
					resultSet.getString("CONCEPTORESUMIDO"), resultSet.getString("TERCER"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getString("EJERCICIOENDOSO"),
					resultSet.getString("NUMEROENDOSO"), resultSet.getString("OTROPERCEPTOR"),
					resultSet.getDate("FECHAVENCIMIENTO"), resultSet.getString("CODIGORETENCION"),
					resultSet.getString("BASERETENCION"), resultSet.getString("FORMAPAGO"),
					resultSet.getString("CUENTAFINANCIERA"), resultSet.getString("EJERCICIOMAQTER"),
					resultSet.getString("NUMEROMAQTER"), resultSet.getString("EJERCICIOMAQTERPER"),
					resultSet.getString("NUMEROMAQTERPER"), resultSet.getDate("FECHAINIPERPAG"),
					resultSet.getString("CODIGOCONTRATO"), resultSet.getString("REGISTROCONTABLE"),
					resultSet.getDate("FECHARESOLUCION"));

			// Los documentos contables Pendientes serán los que tengan
			// FECHA_DOCUMENTO_O igual a NULL. Esto registros tendrán un check
			// para poder seleccionar cada uno de ellos.
			if (docContables.getFechaDocumentoO() == null) {
				docContables.setEstado(Constantes.ESTADO_PENDIENTE);
			}

			// Los documentos contables Incompletos serán los siguientes:
			// - Los documentos que el campo NUMERO_EXPEDIENTE de la vista sea
			// NULL.
			// - Los documentos que el campo CONCEPTO_RESUMIDO de la vista sea
			// NULL.
			// - Los documentos que algún campo de la APLICACION_PRESUPUESTARIA
			// de la vista sea NULL.
			// - Los documentos que algún campo de la REFERENCIA_INTERVENCION de
			// la vista sea NULL.
			// - Los documentos que el campo TERCERO de la vista sea NULL.
			else if (docContables.getExpediente() == null || docContables.getConceptoResumido() == null
					|| docContables.getAplicacionPresupuestaria() == null
					|| docContables.getReferenciaIntervencion() == null || docContables.getTercero() == null) {
				docContables.setEstado(Constantes.ESTADO_INCOMPLETO);
			}

			// Los documentos contables Enviados serán los que tengan
			// FECHA_DOCUMENTO_O diferente a NULL, es decir, ya se han añadido
			// en un fichero contable.
			else if (docContables.getFechaDocumentoO() != null) {
				docContables.setEstado(Constantes.ESTADO_ENVIADO);
			}

			// Aquí no tendremos documentos contables Confirmados.

			return docContables;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	@Transactional(readOnly = true)
	public List<DocContables> findAllLike(DocContables docContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.FECHA_DOCUMENTO_DO FECHADOCUMENTODO, t1.NUMERO_PAGO NUMEROPAGO, t1.FECHA_RESOLUCION FECHARESOLUCION, t1.REGISTRO_CONTABLE REGISTROCONTABLE,t1.CODIGO_CONTRATO CODIGOCONTRATO, t1.FECHA_INI_PER_PAG FECHAINIPERPAG, t1.NUMERO_MAQ_TER_PER NUMEROMAQTERPER, t1.EJERCICIO_MAQ_TER_PER EJERCICIOMAQTERPER, t1.NUMERO_MAQ_TER NUMEROMAQTER, t1.EJERCICIO_MAQ_TER EJERCICIOMAQTER, t1.CUENTA_FINANCIERA CUENTAFINANCIERA, t1.FORMA_PAGO FORMAPAGO, t1.BASE_RETENCION BASERETENCION, t1.CODIGO_RETENCION CODIGORETENCION, t1.FECHA_VENCIMIENTO FECHAVENCIMIENTO, t1.OTRO_PERCEPTOR OTROPERCEPTOR, t1.NUMERO_ENDOSO NUMEROENDOSO, t1.EJERCICIO_ENDOSO EJERCICIOENDOSO, t1.IMPORTE IMPORTE, t1.TERCER TERCER, t1.TERCERO_MOSTRAR TERCEROMOSTRAR, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.FECHA_FACTURA FECHAFACTURA, t1.NUMERO_FACTURA NUMEROFACTURA, t1.IMPORTE_COM_RESTO IMPORTECOMRESTO, t1.CODIGO_SUBVENCION CODIGOSUBVENCION, t1.NUMERO_PLURIANUAL NUMEROPLURIANUAL, t1.NUMERO_ORDEN NUMEROORDEN, t1.OBLIGACION OBLIGACION, t1.DISPONIBLE DISPONIBLE, t1.NUMERO NUMERO, t1.ANYO_ORIGEN ANYOORIGEN, t1.EJERCICIO_REF_INT EJERCICIOREFINT, t1.INMOVILIZADO INMOVILIZADO, t1.CUENTA_PCP CUENTAPCP, t1.LETRA_CONTROL LETRACONTROL, t1.PARTIDA PARTIDA, t1.PROGRAMA PROGRAMA, t1.SC SC, t1.CAC CAC, t1.TERRITORIO TERRITORIO, t1.CENTRO CENTRO, t1.SERVICIO SERVICIO, t1.SECCION SECCION, t1.GASTO_INGRESO GASTOINGRESO, t1.AGRUPACION AGRUPACION, t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE, t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA, t1.FECHA_LIM_JUS FECHALIMJUS, t1.TIPO_OPE_GAS TIPOOPEGAS, t1.REFERENCIA_CONTRATACION REFERENCIACONTRATACION, t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE, t1.TIPO_DOCUMENTO TIPODOCUMENTO, t1.TIPO_REGISTRO TIPOREGISTRO, t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION, t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA, t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO ");
		query.append("FROM V_EXP_INF_CONTABLE_O t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder("WHERE 1=1");
		where.append(mapaWhere.get("query"));
		query.append(where);
		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			// Transformamos aquí los campos de ordenación de la vista
			// V_EXP_INF_CONTABLE a los de V_EXP_INF_CONTABLE_O para no romper
			// la compatibilidad.
			if ("EXPEDIENTE".equals(jqGridRequestDto.getSidx().toUpperCase())) {
				jqGridRequestDto.setSidx("NUMEROEXPEDIENTE");
			} else if ("IMPORTEPAGO".equals(jqGridRequestDto.getSidx().toUpperCase())) {
				jqGridRequestDto.setSidx("IMPORTE");
			}

			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, DocContablesODaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<DocContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	@Transactional(readOnly = true)
	public Long findAllLikeCount(DocContables docContables, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM V_EXP_INF_CONTABLE_O t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder("WHERE t1.NUMERO_PAGO = " + docContables.getNumeroPago());
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), params.toArray(), Long.class);
	}

	/*
	 * MÉTODOS PRIVADOS
	 */
	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DocContables entity
	 *
	 * @param docContables
	 *            DocContables Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(DocContables docContables, Boolean startsWith) {

		StringBuilder where = new StringBuilder(DocContablesDODaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (docContables != null && docContables.getFechaDocumentoO() != null) {
			where.append(" AND t1.FECHA_DOCUMENTO_O = ?");
			params.add(docContables.getFechaDocumentoO());
		}
		if (docContables != null && docContables.getNumeroPago() != null) {
			where.append(" AND t1.NUMERO_PAGO = ?");
			params.add(docContables.getNumeroPago());
		}
		if (docContables != null && docContables.getFechaResolucion() != null) {
			where.append(" AND t1.FECHA_RESOLUCION = ?");
			params.add(docContables.getFechaResolucion());
		}

		if (docContables != null && docContables.getRegistroContable() != null) {
			where.append(" AND UPPER(t1.REGISTRO_CONTABLE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getRegistroContable().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getRegistroContable().toUpperCase() + "%");
			}
			where.append(" AND t1.REGISTRO_CONTABLE IS NOT NULL");
		}
		if (docContables != null && docContables.getCodigoContrato() != null) {
			where.append(" AND UPPER(t1.CODIGO_CONTRATO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getCodigoContrato().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getCodigoContrato().toUpperCase() + "%");
			}
			where.append(" AND t1.CODIGO_CONTRATO IS NOT NULL");
		}
		if (docContables != null && docContables.getFechaInicioPeriodoPago() != null) {
			where.append(" AND UPPER(t1.FECHA_INI_PER_PAG) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getFechaInicioPeriodoPago().toString() + "%");
			} else {
				params.add("%" + docContables.getFechaInicioPeriodoPago().toString() + "%");
			}
			where.append(" AND t1.FECHA_INI_PER_PAG IS NOT NULL");
		}
		if (docContables != null && docContables.getNumeroMaquetaTerceroOtroPerceptor() != null) {
			where.append(" AND UPPER(t1.NUMERO_MAQ_TER_PER) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumeroMaquetaTerceroOtroPerceptor().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumeroMaquetaTerceroOtroPerceptor().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_MAQ_TER_PER IS NOT NULL");
		}
		if (docContables != null && docContables.getEjercicioMaquetaTerceroOtroPerceptor() != null) {
			where.append(" AND UPPER(t1.EJERCICIO_MAQ_TER_PER) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getEjercicioMaquetaTerceroOtroPerceptor().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getEjercicioMaquetaTerceroOtroPerceptor().toUpperCase() + "%");
			}
			where.append(" AND t1.EJERCICIO_MAQ_TER_PER IS NOT NULL");
		}
		if (docContables != null && docContables.getNumeroMaquetaTercero() != null) {
			where.append(" AND UPPER(t1.NUMERO_MAQ_TER) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumeroMaquetaTercero().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumeroMaquetaTercero().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_MAQ_TER IS NOT NULL");
		}
		if (docContables != null && docContables.getEjercicioMaquetaTercero() != null) {
			where.append(" AND UPPER(t1.EJERCICIO_MAQ_TER) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getEjercicioMaquetaTercero().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getEjercicioMaquetaTercero().toUpperCase() + "%");
			}
			where.append(" AND t1.EJERCICIO_MAQ_TER IS NOT NULL");
		}
		if (docContables != null && docContables.getCuentaFinanciera() != null) {
			where.append(" AND UPPER(t1.CUENTA_FINANCIERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getCuentaFinanciera().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getCuentaFinanciera().toUpperCase() + "%");
			}
			where.append(" AND t1.CUENTA_FINANCIERA IS NOT NULL");
		}
		if (docContables != null && docContables.getFormaPago() != null) {
			where.append(" AND UPPER(t1.FORMA_PAGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getFormaPago().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getFormaPago().toUpperCase() + "%");
			}
			where.append(" AND t1.FORMA_PAGO IS NOT NULL");
		}
		if (docContables != null && docContables.getBaseRetencion() != null) {
			where.append(" AND UPPER(t1.BASE_RETENCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getBaseRetencion().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getBaseRetencion().toUpperCase() + "%");
			}
			where.append(" AND t1.BASE_RETENCION IS NOT NULL");
		}
		if (docContables != null && docContables.getCodigoRetencion() != null) {
			where.append(" AND UPPER(t1.CODIGO_RETENCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getCodigoRetencion().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getCodigoRetencion().toUpperCase() + "%");
			}
			where.append(" AND t1.CODIGO_RETENCION IS NOT NULL");
		}
		if (docContables != null && docContables.getFechaVencimiento() != null) {
			where.append(" AND UPPER(t1.FECHA_VENCIMIENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getFechaVencimiento().toString() + "%");
			} else {
				params.add("%" + docContables.getFechaVencimiento().toString() + "%");
			}
			where.append(" AND t1.FECHA_VENCIMIENTO IS NOT NULL");
		}
		if (docContables != null && docContables.getOtroPerceptor() != null) {
			where.append(" AND UPPER(t1.OTRO_PERCEPTOR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getOtroPerceptor().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getOtroPerceptor().toUpperCase() + "%");
			}
			where.append(" AND t1.OTRO_PERCEPTOR IS NOT NULL");
		}
		if (docContables != null && docContables.getNumeroEndoso() != null) {
			where.append(" AND UPPER(t1.NUMERO_ENDOSO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumeroEndoso().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumeroEndoso().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_ENDOSO IS NOT NULL");
		}
		if (docContables != null && docContables.getEjercicioEndoso() != null) {
			where.append(" AND UPPER(t1.EJERCICIO_ENDOSO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getEjercicioEndoso().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getEjercicioEndoso().toUpperCase() + "%");
			}
			where.append(" AND t1.EJERCICIO_ENDOSO IS NOT NULL");
		}
		if (docContables != null && docContables.getNumeroEndoso() != null) {
			where.append(" AND UPPER(t1.NUMERO_ENDOSO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumeroEndoso().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumeroEndoso().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_ENDOSO IS NOT NULL");
		}
		if (docContables != null && docContables.getImportePago() != null) {
			where.append(" AND t1.IMPORTE = ?");
			params.add(docContables.getImportePago());
		}
		if (docContables != null && docContables.getTercero() != null) {
			where.append(" AND UPPER(t1.TERCER) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getTercero().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getTercero().toUpperCase() + "%");
			}
			where.append(" AND t1.TERCER IS NOT NULL");
		}
		if (docContables != null && docContables.getTerceroMostrar() != null) {
			where.append(" AND UPPER(t1.TERCERO_MOSTRAR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getTerceroMostrar().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getTerceroMostrar().toUpperCase() + "%");
			}
			where.append(" AND t1.TERCERO_MOSTRAR IS NOT NULL");
		}
		if (docContables != null && docContables.getConceptoResumido() != null) {
			where.append(" AND UPPER(t1.CONCEPTO_RESUMIDO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getConceptoResumido().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getConceptoResumido().toUpperCase() + "%");
			}
			where.append(" AND t1.CONCEPTO_RESUMIDO IS NOT NULL");
		}
		if (docContables != null && docContables.getFechaFactura() != null) {
			where.append(" AND UPPER(t1.FECHA_FACTURA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getFechaFactura().toString() + "%");
			} else {
				params.add("%" + docContables.getFechaFactura().toString() + "%");
			}
			where.append(" AND t1.FECHA_FACTURA IS NOT NULL");
		}
		if (docContables != null && docContables.getNumeroFactura() != null) {
			where.append(" AND UPPER(t1.NUMERO_FACTURA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumeroFactura().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumeroFactura().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_FACTURA IS NOT NULL");
		}
		if (docContables != null && docContables.getImporteCompromisoResto() != null) {
			where.append(" AND UPPER(t1.IMPORTE_COM_RESTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getImporteCompromisoResto().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getImporteCompromisoResto().toUpperCase() + "%");
			}
			where.append(" AND t1.IMPORTE_COM_RESTO IS NOT NULL");
		}
		if (docContables != null && docContables.getCodigoSubvencion() != null) {
			where.append(" AND UPPER(t1.CODIGO_SUBVENCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getCodigoSubvencion().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getCodigoSubvencion().toUpperCase() + "%");
			}
			where.append(" AND t1.CODIGO_SUBVENCION IS NOT NULL");
		}
		if (docContables != null && docContables.getNumeroPlurianual() != null) {
			where.append(" AND UPPER(t1.NUMERO_PLURIANUAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumeroPlurianual().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumeroPlurianual().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_PLURIANUAL IS NOT NULL");
		}
		if (docContables != null && docContables.getNumeroOrden() != null) {
			where.append(" AND UPPER(t1.NUMERO_ORDEN) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumeroOrden().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumeroOrden().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_ORDEN IS NOT NULL");
		}
		if (docContables != null && docContables.getObligacion() != null) {
			where.append(" AND UPPER(t1.OBLIGACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getObligacion().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getObligacion().toUpperCase() + "%");
			}
			where.append(" AND t1.OBLIGACION IS NOT NULL");
		}
		if (docContables != null && docContables.getDisponible() != null) {
			where.append(" AND UPPER(t1.DISPONIBLE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getDisponible().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getDisponible().toUpperCase() + "%");
			}
			where.append(" AND t1.DISPONIBLE IS NOT NULL");
		}
		if (docContables != null && docContables.getNumero() != null) {
			where.append(" AND UPPER(t1.NUMERO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getNumero().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getNumero().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO IS NOT NULL");
		}
		if (docContables != null && docContables.getAnyoOrigen() != null) {
			where.append(" AND UPPER(t1.ANYO_ORIGEN) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getAnyoOrigen().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getAnyoOrigen().toUpperCase() + "%");
			}
			where.append(" AND t1.ANYO_ORIGEN IS NOT NULL");
		}
		if (docContables != null && docContables.getEjercicioRefInt() != null) {
			where.append(" AND UPPER(t1.EJERCICIO_REF_INT) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getEjercicioRefInt().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getEjercicioRefInt().toUpperCase() + "%");
			}
			where.append(" AND t1.EJERCICIO_REF_INT IS NOT NULL");
		}
		if (docContables != null && docContables.getInmovilizado() != null) {
			where.append(" AND UPPER(t1.INMOVILIZADO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getInmovilizado().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getInmovilizado().toUpperCase() + "%");
			}
			where.append(" AND t1.INMOVILIZADO IS NOT NULL");
		}
		if (docContables != null && docContables.getCuentaPCP() != null) {
			where.append(" AND UPPER(t1.CUENTA_PCP) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getCuentaPCP().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getCuentaPCP().toUpperCase() + "%");
			}
			where.append(" AND t1.CUENTA_PCP IS NOT NULL");
		}
		if (docContables != null && docContables.getLetraControl() != null) {
			where.append(" AND UPPER(t1.LETRA_CONTROL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getLetraControl().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getLetraControl().toUpperCase() + "%");
			}
			where.append(" AND t1.LETRA_CONTROL IS NOT NULL");
		}
		if (docContables != null && docContables.getPartida() != null) {
			where.append(" AND UPPER(t1.PARTIDA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getPartida().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getPartida().toUpperCase() + "%");
			}
			where.append(" AND t1.PARTIDA IS NOT NULL");
		}
		if (docContables != null && docContables.getPrograma() != null) {
			where.append(" AND UPPER(t1.PROGRAMA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getPrograma().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getPrograma().toUpperCase() + "%");
			}
			where.append(" AND t1.PROGRAMA IS NOT NULL");
		}
		if (docContables != null && docContables.getSc() != null) {
			where.append(" AND UPPER(t1.SC) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getSc().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getSc().toUpperCase() + "%");
			}
			where.append(" AND t1.SC IS NOT NULL");
		}
		if (docContables != null && docContables.getCac() != null) {
			where.append(" AND UPPER(t1.CAC) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getCac().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getCac().toUpperCase() + "%");
			}
			where.append(" AND t1.CAC IS NOT NULL");
		}
		if (docContables != null && docContables.getTerritorio() != null) {
			where.append(" AND UPPER(t1.TERRITORIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getTerritorio().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getTerritorio().toUpperCase() + "%");
			}
			where.append(" AND t1.TERRITORIO IS NOT NULL");
		}
		if (docContables != null && docContables.getCentro() != null) {
			where.append(" AND UPPER(t1.CENTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getCentro().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getCentro().toUpperCase() + "%");
			}
			where.append(" AND t1.CENTRO IS NOT NULL");
		}
		if (docContables != null && docContables.getServicio() != null) {
			where.append(" AND UPPER(t1.SERVICIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getServicio().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getServicio().toUpperCase() + "%");
			}
			where.append(" AND t1.SERVICIO IS NOT NULL");
		}
		if (docContables != null && docContables.getSeccion() != null) {
			where.append(" AND UPPER(t1.SECCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getSeccion().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getSeccion().toUpperCase() + "%");
			}
			where.append(" AND t1.SECCION IS NOT NULL");
		}
		if (docContables != null && docContables.getGastoIngreso() != null) {
			where.append(" AND UPPER(t1.GASTO_INGRESO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getGastoIngreso().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getGastoIngreso().toUpperCase() + "%");
			}
			where.append(" AND t1.GASTO_INGRESO IS NOT NULL");
		}
		if (docContables != null && docContables.getAgrupacion() != null) {
			where.append(" AND UPPER(t1.AGRUPACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getAgrupacion().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getAgrupacion().toUpperCase() + "%");
			}
			where.append(" AND t1.AGRUPACION IS NOT NULL");
		}
		if (docContables != null && docContables.getEjercicioAplPre() != null) {
			where.append(" AND UPPER(t1.EJERCICIO_APL_PRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getEjercicioAplPre().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getEjercicioAplPre().toUpperCase() + "%");
			}
			where.append(" AND t1.EJERCICIO_APL_PRE IS NOT NULL");
		}
		if (docContables != null && docContables.getAplicacionPresupuestaria() != null) {
			where.append(" AND UPPER(t1.APLICACION_PRESUPUESTARIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getAplicacionPresupuestaria().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getAplicacionPresupuestaria().toUpperCase() + "%");
			}
			where.append(" AND t1.APLICACION_PRESUPUESTARIA IS NOT NULL");
		}
		if (docContables != null && docContables.getFechaLimiteJustificacion() != null) {
			where.append(" AND UPPER(t1.FECHA_LIM_JUS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getFechaLimiteJustificacion().toString() + "%");
			} else {
				params.add("%" + docContables.getFechaLimiteJustificacion().toString() + "%");
			}
			where.append(" AND t1.FECHA_LIM_JUS IS NOT NULL");
		}
		if (docContables != null && docContables.getTipoOperacionGastos() != null) {
			where.append(" AND UPPER(t1.TIPO_OPE_GAS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getTipoOperacionGastos().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getTipoOperacionGastos().toUpperCase() + "%");
			}
			where.append(" AND t1.TIPO_OPE_GAS IS NOT NULL");
		}
		if (docContables != null && docContables.getReferenciaContratacion() != null) {
			where.append(" AND UPPER(t1.REFERENCIA_CONTRATACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getReferenciaContratacion().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getReferenciaContratacion().toUpperCase() + "%");
			}
			where.append(" AND t1.REFERENCIA_CONTRATACION IS NOT NULL");
		}
		if (docContables != null && docContables.getExpediente() != null) {
			where.append(" AND UPPER(t1.NUMERO_EXPEDIENTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(docContables.getExpediente().toUpperCase() + "%");
			} else {
				params.add("%" + docContables.getExpediente().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_EXPEDIENTE IS NOT NULL");
		}
		if (docContables != null && docContables.getTipoRegistro() != null) {
			where.append(" AND t1.TIPO_REGISTRO = ?");
			params.add(docContables.getTipoRegistro());
		}
		if (docContables != null && docContables.getReferenciaContratacion() != null) {
			where.append(" AND t1.ID_REFERENCIA_INTERVENCION = ?");
			params.add(docContables.getReferenciaContratacion());
		}
		if (docContables != null && docContables.getIdAplicacionPresupuestaria() != null) {
			where.append(" AND t1.ID_APLICACION_PRESUPUESTARIA = ?");
			params.add(docContables.getIdAplicacionPresupuestaria());
		}
		if (docContables != null && docContables.getIdDocumentoContable() != null) {
			where.append(" AND t1.ID_DOCUMENTO_CONTABLE = ?");
			params.add(docContables.getIdDocumentoContable());
		}
		if (docContables != null && docContables.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(docContables.getIdExpediente());
		}
		if (docContables != null && docContables.getIdProcedimiento() != null) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(docContables.getIdProcedimiento());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Reorder the data list of DocContables selected for rup_table
	 *
	 * @param docContables
	 *            DocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DocContables>>
	 */
	@Override
	public List<TableRowDto<DocContables>> reorderSelection(DocContables docContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.FECHA_DOCUMENTO_DO FECHADOCUMENTODO, t1.NUMERO_PAGO NUMEROPAGO, t1.FECHA_RESOLUCION FECHARESOLUCION, t1.REGISTRO_CONTABLE REGISTROCONTABLE,t1.CODIGO_CONTRATO CODIGOCONTRATO, t1.FECHA_INI_PER_PAG FECHAINIPERPAG, t1.NUMERO_MAQ_TER_PER NUMEROMAQTERPER, t1.EJERCICIO_MAQ_TER_PER EJERCICIOMAQTERPER, t1.NUMERO_MAQ_TER NUMEROMAQTER, t1.EJERCICIO_MAQ_TER EJERCICIOMAQTER, t1.CUENTA_FINANCIERA CUENTAFINANCIERA, t1.FORMA_PAGO FORMAPAGO, t1.BASE_RETENCION BASERETENCION, t1.CODIGO_RETENCION CODIGORETENCION, t1.FECHA_VENCIMIENTO FECHAVENCIMIENTO, t1.OTRO_PERCEPTOR OTROPERCEPTOR, t1.NUMERO_ENDOSO NUMEROENDOSO, t1.EJERCICIO_ENDOSO EJERCICIOENDOSO, t1.IMPORTE IMPORTE, t1.TERCER TERCER, t1.TERCERO_MOSTRAR TERCEROMOSTRAR, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.FECHA_FACTURA FECHAFACTURA, t1.NUMERO_FACTURA NUMEROFACTURA, t1.IMPORTE_COM_RESTO IMPORTECOMRESTO, t1.CODIGO_SUBVENCION CODIGOSUBVENCION, t1.NUMERO_PLURIANUAL NUMEROPLURIANUAL, t1.NUMERO_ORDEN NUMEROORDEN, t1.OBLIGACION OBLIGACION, t1.DISPONIBLE DISPONIBLE, t1.NUMERO NUMERO, t1.ANYO_ORIGEN ANYOORIGEN, t1.EJERCICIO_REF_INT EJERCICIOREFINT, t1.INMOVILIZADO INMOVILIZADO, t1.CUENTA_PCP CUENTAPCP, t1.LETRA_CONTROL LETRACONTROL, t1.PARTIDA PARTIDA, t1.PROGRAMA PROGRAMA, t1.SC SC, t1.CAC CAC, t1.TERRITORIO TERRITORIO, t1.CENTRO CENTRO, t1.SERVICIO SERVICIO, t1.SECCION SECCION, t1.GASTO_INGRESO GASTOINGRESO, t1.AGRUPACION AGRUPACION, t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE, t1.APLICACION_PRESUPUESTARIA APLICACIONPRESUPUESTARIA, t1.FECHA_LIM_JUS FECHALIMJUS, t1.TIPO_OPE_GAS TIPOOPEGAS, t1.REFERENCIA_CONTRATACION REFERENCIACONTRATACION, t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE, t1.TIPO_DOCUMENTO TIPODOCUMENTO, t1.TIPO_REGISTRO TIPOREGISTRO, t1.ID_REFERENCIA_INTERVENCION IDREFERENCIAINTERVENCION, t1.ID_APLICACION_PRESUPUESTARIA IDAPLICACIONPRESUPUESTARIA, t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO ");
		// FROM
		query.append("FROM V_EXP_INF_CONTABLE_O t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder("");

		if (docContables.getPagosConvocatoria().getNumeroPago() == 1) {
			where.append(" WHERE 1=1");
			where.append(" AND (t1.TIPO_DOCUMENTO='" + Constantes.TIPO_DOCUMENTO_CONTABLE_D
					+ "' AND t1.FECHA_DOCUMENTO_D is not null and t1.REF_INT_D IS NOT NULL AND t1.FECHA_DOCUMENTO_O IS NULL)");
			where.append(" OR (t1.TIPO_DOCUMENTO = '" + Constantes.TIPO_DOCUMENTO_CONTABLE_O
					+ "' AND t1.ID_PAGO_CONVOCATORIA =" + docContables.getPagosConvocatoria().getIdPagoConvocatoria()
					+ ")");
		} else if (docContables.getPagosConvocatoria().getNumeroPago() > 1) {
			query.append(",PAGOS_CONVOCATORIA t3");
			where.append(" WHERE 1=1");
			where.append(" AND t3.ID_PAGO_CONVOCATORIA  = t1.ID_PAGO_CONVOCATORIA");
			where.append(" AND (t1.TIPO_DOCUMENTO='" + Constantes.TIPO_DOCUMENTO_CONTABLE_O + "' and t3.NUMERO_PAGO = "
					+ (docContables.getPagosConvocatoria().getNumeroPago() - 1)
					+ " and t1.FECHA_DOCUMENTO_O IS NOT NULL)");
			where.append(" OR (t1.TIPO_DOCUMENTO ='" + Constantes.TIPO_DOCUMENTO_CONTABLE_O
					+ "' AND t1.ID_PAGO_CONVOCATORIA =" + docContables.getPagosConvocatoria().getIdPagoConvocatoria()
					+ ")");
		}

		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, DocContables.class,
				filterParamList,
				"FECHA_DOCUMENTO_DO, NUMERO_PAGO, FECHA_RESOLUCION, REGISTRO_CONTABLE, CODIGO_CONTRATO, FECHA_INI_PER_PAG, NUMERO_MAQ_TER_PER, EJERCICIO_MAQ_TER_PER, NUMERO_MAQ_TER, EJERCICIO_MAQ_TER, CUENTA_FINANCIERA, FORMA_PAGO, BASE_RETENCION, CODIGO_RETENCION, FECHA_VENCIMIENTO, OTRO_PERCEPTOR, NUMERO_ENDOSO, EJERCICIO_ENDOSO, IMPORTE, TERCER, TERCERO_MOSTRAR, CONCEPTO_RESUMIDO, FECHA_FACTURA, NUMERO_FACTURA, IMPORTE_COM_RESTO, CODIGO_SUBVENCION, NUMERO_PLURIANUAL, NUMERO_ORDEN, OBLIGACION, DISPONIBLE, NUMERO, ANYO_ORIGEN, EJERCICIO_REF_INT, INMOVILIZADO, CUENTA_PCP, LETRA_CONTROL, PARTIDA, PROGRAMA, SC, CAC, TERRITORIO, CENTRO, SERVICIO, SECCION, GASTO_INGRESO, AGRUPACION, EJERCICIO_APL_PRE, APLICACION_PRESUPUESTARIA, FECHA_LIM_JUS, TIPO_OPE_GAS, REFERENCIA_CONTRATACION, NUMERO_EXPEDIENTE, TIPO_DOCUMENTO, TIPO_REGISTRO, ID_REFERENCIA_INTERVENCION, ID_APLICACION_PRESUPUESTARIA, ID_DOCUMENTO_CONTABLE, ID_EXPEDIENTE, ID_PROCEDIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DocContables>(this.rwMap, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
