package com.ejie.ab60.dao.moduloContable;

import java.util.List;

import com.ejie.ab60.model.moduloContable.DocumentosContables;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * DocumentosContablesDao  
 * 
 *  
 */

public interface DocumentosContablesDao {

	/**
	 * Inserts a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	DocumentosContables add(DocumentosContables documentoscontables);

	/**
	 * Updates a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	DocumentosContables update(DocumentosContables documentoscontables);

	DocumentosContables updateRegistrosDocContableMAK(DocumentosContables documentoscontables);

	DocumentosContables updateRegistrosDocContableREL(DocumentosContables documentoscontables);

	/**
	 * Finds a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	DocumentosContables find(DocumentosContables documentoscontables);

	/**
	 * Removes a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 */
	void remove(DocumentosContables documentoscontables);

	/**
	 * Removes a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 */
	void removeByFicheroContable(DocumentosContables documentoscontables);

	/**
	 * Finds a List of rows in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<DocumentosContables> findAll(DocumentosContables documentoscontables, JQGridRequestDto jqGridRequestDto);

	List<DocumentosContables> findImporteAplicPresu(DocumentosContables documentoscontables);

	/**
	 * Finds rows in the DocumentosContables table using like.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<DocumentosContables> findAllLike(DocumentosContables documentoscontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	List<DocumentosContables> findAllLikeDocumentos(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, Integer idFicheroContable);

	List<DocumentosContables> findAllLikeByFichero(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, Integer idFichero);

	List<DocumentosContables> findAllLikeArchivos(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, List<String> lista);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the DocumentosContables table.
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(DocumentosContables filterDocumentosContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Counts rows in the DocumentosContables table using like.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(DocumentosContables documentoscontables, Boolean startsWith);

	Long findAllLikeCountDocumentos(DocumentosContables documentoscontables, Boolean startsWith,
			Integer idFicheroContable);

	Long findAllLikeCountArchivos(DocumentosContables documentoscontables, Boolean startsWith, List<String> lista);

	/**
	 * Counts rows in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return Long
	 */
	Long findAllCount(DocumentosContables documentoscontables);

	/**
	 * Reorder selection.
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DocumentosContables>>
	 */
	List<TableRowDto<DocumentosContables>> reorderSelection(DocumentosContables filterDocumentosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	List<TableRowDto<DocumentosContables>> reorderSelectionDocumentos(DocumentosContables filterDocumentosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, Integer idFicheroContable);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param searchDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DocumentosContables>>
	 */
	List<TableRowDto<DocumentosContables>> search(DocumentosContables filterDocumentosContables,
			DocumentosContables searchDocumentosContables, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical DocumentosContables table.
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<DocumentosContables>>
	 */
	List<JerarquiaDto<DocumentosContables>> findAllLikeJerarquia(DocumentosContables filterDocumentosContables,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(DocumentosContables filterDocumentosContables, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<DocumentosContables>>
	 */
	List<TableRowDto<DocumentosContables>> findAllChild(DocumentosContables filterDocumentosContables,
			JQGridRequestDto jqGridRequestDto);

}
