package com.ejie.ab60.dao.moduloContable;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.moduloContable.DocumentosContables;
import com.ejie.ab60.model.terceros.TiposDocumento;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * DocumentosContablesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class DocumentosContablesDaoImpl implements DocumentosContablesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDDOCUMENTOCONTABLE", "IDCONVOCATORIA",
			"IDFICHEROCONTABLE", "IDEXPEDIENTE", "FECHADOCUMENTOD", "REFINTD", "IDPAGOCONVOCATORIA", "REFINTO",
			"TIPOREGISTRO", "TIPODOCUMENTO", "NUMEROEXPEDIENTE", "EXPEDIENTE", "APLICACIONPRESUPUESTARIA",
			"EJERCICIOAPLPRE", "AGRUPACION", "GASTOINGRESO", "SECCION", "SERVICIO", "CENTRO", "TERRITORIO", "CAC", "SC",
			"PROGRAMA", "PARTIDA", "LETRACONTROL", "EJERCICIOREFINT", "ANYOORIGEN", "NUMERO", "DISPONIBLE",
			"CONCEPTORESUMIDO", "TERCERO", "IMPORTE", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private static final String SEPARATOR = ",";

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<DocumentosContables> rwMap = new RowMapper<DocumentosContables>() {
		public DocumentosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DocumentosContables(resultSet.getString("IDDOCUMENTOCONTABLE"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getInt("IDFICHEROCONTABLE"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getDate("FECHADOCUMENTOD"),
					resultSet.getString("REFINTD"), resultSet.getInt("IDPAGOCONVOCATORIA"),
					resultSet.getString("REFINTO"), resultSet.getString("TIPOREGISTRO"),
					resultSet.getString("TIPODOCUMENTO"), resultSet.getString("NUMEROEXPEDIENTE"),
					resultSet.getString("EJERCICIOAPLPRE"), resultSet.getString("AGRUPACION"),
					resultSet.getString("GASTOINGRESO"), resultSet.getString("SECCION"),
					resultSet.getString("SERVICIO"), resultSet.getString("CENTRO"), resultSet.getString("TERRITORIO"),
					resultSet.getString("CAC"), resultSet.getString("SC"), resultSet.getString("PROGRAMA"),
					resultSet.getString("PARTIDA"), resultSet.getString("LETRACONTROL"),
					resultSet.getString("EJERCICIOREFINT"), resultSet.getString("ANYOORIGEN"),
					resultSet.getString("NUMERO"), resultSet.getString("DISPONIBLE"),
					resultSet.getString("CONCEPTORESUMIDO"), resultSet.getString("TERCERO"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<DocumentosContables> rwMapTablaFicheros = new RowMapper<DocumentosContables>() {
		public DocumentosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DocumentosContables(resultSet.getString("IDDOCUMENTOCONTABLE"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getInt("IDFICHEROCONTABLE"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getDate("FECHADOCUMENTOD"),
					resultSet.getString("EXPEDIENTE"), resultSet.getString("APLICACIONPRESUPUESTARIA"),
					resultSet.getString("CONCEPTORESUMIDO"), resultSet.getString("TERCERO"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getString("TERRITORIO"),
					resultSet.getInt("IDAPLICPRESU"));
		}
	};

	private RowMapper<DocumentosContables> rwMapTablaCargaArchivos = new RowMapper<DocumentosContables>() {
		public DocumentosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DocumentosContables(resultSet.getString("IDDOCUMENTOCONTABLE"),
					resultSet.getString("PUNTOTRAMITACION"), resultSet.getString("NUMEROMAQUETA"),
					resultSet.getDate("FECHAACTUALIZACION"), resultSet.getDate("FECHACONTABILIZACION"),
					resultSet.getString("EXPEDIENTE"), resultSet.getString("INDICADORERROR"),
					resultSet.getString("NUMEROAPUNTE"), resultSet.getString("NUMEROORDEN"),
					resultSet.getString("TERRITORIO"), resultSet.getString("FECHAACTUALIZACION"));
		}
	};

	private RowMapper<DocumentosContables> rwMapTipoDoc = new RowMapper<DocumentosContables>() {
		public DocumentosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DocumentosContables(resultSet.getString("IDDOCUMENTOCONTABLE"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getInt("IDFICHEROCONTABLE"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getDate("FECHADOCUMENTOD"),
					resultSet.getString("REFINTD"), resultSet.getInt("IDPAGOCONVOCATORIA"),
					resultSet.getString("REFINTO"), resultSet.getString("TIPOREGISTRO"),
					new TiposDocumento(resultSet.getLong("TIPODOCUMENTO"), resultSet.getString("DESCASTELLANO"),
							resultSet.getString("DESEUSKERA"), null, null),
					resultSet.getString("NUMEROEXPEDIENTE"), resultSet.getString("EJERCICIOAPLPRE"),
					resultSet.getString("AGRUPACION"), resultSet.getString("GASTOINGRESO"),
					resultSet.getString("SECCION"), resultSet.getString("SERVICIO"), resultSet.getString("CENTRO"),
					resultSet.getString("TERRITORIO"), resultSet.getString("CAC"), resultSet.getString("SC"),
					resultSet.getString("PROGRAMA"), resultSet.getString("PARTIDA"),
					resultSet.getString("LETRACONTROL"), resultSet.getString("EJERCICIOREFINT"),
					resultSet.getString("ANYOORIGEN"), resultSet.getString("NUMERO"), resultSet.getString("DISPONIBLE"),
					resultSet.getString("CONCEPTORESUMIDO"), resultSet.getString("TERCERO"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<DocumentosContables> rwMapPK = new RowMapper<DocumentosContables>() {
		public DocumentosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DocumentosContables(resultSet.getString("IDDOCUMENTOCONTABLE"));
		}
	};

	private RowMapper<DocumentosContables> rwMapImporteAplicPresu = new RowMapper<DocumentosContables>() {
		public DocumentosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new DocumentosContables(resultSet.getBigDecimal("IMPORTE"), resultSet.getInt("IDAPLICPRESU"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<DocumentosContables>> rwMapJerarquia = new RowMapper<JerarquiaDto<DocumentosContables>>() {
		public JerarquiaDto<DocumentosContables> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			DocumentosContables documentoscontables = new DocumentosContables(
					resultSet.getString("IDDOCUMENTOCONTABLE"), resultSet.getInt("IDFICHEROCONTABLE"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getDate("FECHADOCUMENTOD"),
					resultSet.getString("REFINTD"), resultSet.getInt("IDPAGOCONVOCATORIA"),
					resultSet.getString("REFINTO"), resultSet.getString("TIPOREGISTRO"),
					resultSet.getString("TIPODOCUMENTO"), resultSet.getString("NUMEROEXPEDIENTE"),
					resultSet.getString("EJERCICIOAPLPRE"), resultSet.getString("AGRUPACION"),
					resultSet.getString("GASTOINGRESO"), resultSet.getString("SECCION"),
					resultSet.getString("SERVICIO"), resultSet.getString("CENTRO"), resultSet.getString("TERRITORIO"),
					resultSet.getString("CAC"), resultSet.getString("SC"), resultSet.getString("PROGRAMA"),
					resultSet.getString("PARTIDA"), resultSet.getString("LETRACONTROL"),
					resultSet.getString("EJERCICIOREFINT"), resultSet.getString("ANYOORIGEN"),
					resultSet.getString("NUMERO"), resultSet.getString("DISPONIBLE"),
					resultSet.getString("CONCEPTORESUMIDO"), resultSet.getString("TERCERO"),
					resultSet.getBigDecimal("IMPORTE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<DocumentosContables> jerarquia = new JerarquiaDto<DocumentosContables>();
			jerarquia.setModel(documentoscontables);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	static String TIPO_DOCUMENTO = "CASE TIPO_DOCUMENTO WHEN '" + Constantes.TIPO_DOCUMENTO_CONTABLE_D_STR + "' THEN "
			+ Constantes.TIPO_DOCUMENTO_CONTABLE_D + " WHEN '" + Constantes.TIPO_DOCUMENTO_CONTABLE_O_STR + "' THEN "
			+ Constantes.TIPO_DOCUMENTO_CONTABLE_O + " WHEN '" + Constantes.TIPO_DOCUMENTO_CONTABLE_DO_STR + "' THEN "
			+ Constantes.TIPO_DOCUMENTO_CONTABLE_DO + " ELSE TO_NUMBER(TIPO_DOCUMENTO) END";

	/**
	 * Inserts a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	public DocumentosContables add(DocumentosContables documentoscontables) {
		String query = "INSERT INTO DOCUMENTOS_CONTABLES (ID_DOCUMENTO_CONTABLE, ID_FICHERO_CONTABLE, ID_EXPEDIENTE, FECHA_DOCUMENTO_D, REF_INT_D, ID_PAGO_CONVOCATORIA, REF_INT_O, TIPO_REGISTRO, TIPO_DOCUMENTO, NUMERO_EXPEDIENTE, EJERCICIO_APL_PRE, AGRUPACION, GASTO_INGRESO, SECCION, SERVICIO, CENTRO, TERRITORIO, CAC, SC, PROGRAMA, PARTIDA, LETRA_CONTROL, EJERCICIO_REF_INT, ANYO_ORIGEN, NUMERO, DISPONIBLE, OBLIGACION, CONCEPTO_RESUMIDO, TERCERO, IMPORTE, FECHA_REGISTRO, USUARIO_REGISTRO, ID_CONVOCATORIA, FECHA_DOCUMENTO_O, FECHA_DOCUMENTO_DO, FECHA_RESOLUCION, REFERENCIA_CONTRATACION, NUMERO_PLURIANUAL, CODIGO_SUBVENCION, EJERCICIO_COM1, EJERCICIO_COM2, EJERCICIO_COM3, EJERCICIO_COM4, IMPORTE_COM1, IMPORTE_COM2, IMPORTE_COM3, IMPORTE_COM4, IMPORTE_COM_RESTO, EJERCICIO_MAQ_TER, NUMERO_MAQ_TER) VALUES (S_AB6099T00.NEXTVAL,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, documentoscontables.getIdFicheroContable(),
				documentoscontables.getIdExpediente(), documentoscontables.getFechaDocumentoD(),
				documentoscontables.getRefIntD(), documentoscontables.getIdPagoConvocatoria(),
				documentoscontables.getRefIntO(), documentoscontables.getTipoRegistro(),
				documentoscontables.getTipoDocumento().getIdTipoDocumento(), documentoscontables.getNumeroExpediente(),
				documentoscontables.getEjercicioAplPre(), documentoscontables.getAgrupacion(),
				documentoscontables.getGastoIngreso(), documentoscontables.getSeccion(),
				documentoscontables.getServicio(), documentoscontables.getCentro(), documentoscontables.getTerritorio(),
				documentoscontables.getCac(), documentoscontables.getSc(), documentoscontables.getPrograma(),
				documentoscontables.getPartida(), documentoscontables.getLetraControl(),
				documentoscontables.getEjercicioRefInt(), documentoscontables.getAnyoOrigen(),
				documentoscontables.getNumero(), documentoscontables.getDisponible(),
				documentoscontables.getObligacion(), documentoscontables.getConceptoResumido(),
				documentoscontables.getTercero(), documentoscontables.getImporte(),
				documentoscontables.getFechaRegistro(), documentoscontables.getUsuarioRegistro(),
				documentoscontables.getIdConvocatoria(), documentoscontables.getFechaDocumentoO(),
				documentoscontables.getFechaDocumentoDO(), documentoscontables.getFechaResolucion(),
				documentoscontables.getReferenciaContratacion(), documentoscontables.getNumeroPlurianual(),
				documentoscontables.getCodigoSubvencion(), documentoscontables.getEjercicioCompromiso1(),
				documentoscontables.getEjercicioCompromiso2(), documentoscontables.getEjercicioCompromiso3(),
				documentoscontables.getEjercicioCompromiso4(), documentoscontables.getImporteCompromiso1(),
				documentoscontables.getImporteCompromiso2(), documentoscontables.getImporteCompromiso3(),
				documentoscontables.getImporteCompromiso4(), documentoscontables.getImporteCompromisoResto(),
				documentoscontables.getEjercicioMaquetaTercero(), documentoscontables.getNumeroMaquetaTercero());
		return documentoscontables;
	}

	/**
	 * Updates a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	public DocumentosContables update(DocumentosContables documentoscontables) {
		String query = "UPDATE DOCUMENTOS_CONTABLES SET ID_FICHERO_CONTABLE=?, ID_EXPEDIENTE=?, FECHA_DOCUMENTO_D=?, REF_INT_D=?, ID_PAGO_CONVOCATORIA=?, REF_INT_O=?, TIPO_REGISTRO=?, TIPO_DOCUMENTO=?, NUMERO_EXPEDIENTE=?, EJERCICIO_APL_PRE=?, AGRUPACION=?, GASTO_INGRESO=?, SECCION=?, SERVICIO=?, CENTRO=?, TERRITORIO=?, CAC=?, SC=?, PROGRAMA=?, PARTIDA=?, LETRA_CONTROL=?, EJERCICIO_REF_INT=?, ANYO_ORIGEN=?, NUMERO=?, DISPONIBLE=?, CONCEPTO_RESUMIDO=?, TERCERO=?, IMPORTE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_DOCUMENTO_O=? WHERE ID_DOCUMENTO_CONTABLE=?";
		this.jdbcTemplate.update(query, documentoscontables.getIdFicheroContable(),
				documentoscontables.getIdExpediente(), documentoscontables.getFechaDocumentoD(),
				documentoscontables.getRefIntD(), documentoscontables.getIdPagoConvocatoria(),
				documentoscontables.getRefIntO(), documentoscontables.getTipoRegistro(),
				documentoscontables.getTipoDocumento().getIdTipoDocumento(), documentoscontables.getNumeroExpediente(),
				documentoscontables.getEjercicioAplPre(), documentoscontables.getAgrupacion(),
				documentoscontables.getGastoIngreso(), documentoscontables.getSeccion(),
				documentoscontables.getServicio(), documentoscontables.getCentro(), documentoscontables.getTerritorio(),
				documentoscontables.getCac(), documentoscontables.getSc(), documentoscontables.getPrograma(),
				documentoscontables.getPartida(), documentoscontables.getLetraControl(),
				documentoscontables.getEjercicioRefInt(), documentoscontables.getAnyoOrigen(),
				documentoscontables.getNumero(), documentoscontables.getDisponible(),
				documentoscontables.getConceptoResumido(), documentoscontables.getTercero(),
				documentoscontables.getImporte(), documentoscontables.getFechaRegistro(),
				documentoscontables.getUsuarioRegistro(), documentoscontables.getFechaDocumentoO(),
				documentoscontables.getIdDocumentoContable());
		return documentoscontables;
	}

	/**
	 * Updates a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	public DocumentosContables updateRegistrosDocContableMAK(DocumentosContables documentoscontables) {
		String query = "UPDATE DOCUMENTOS_CONTABLES SET PUNTO_TRAMITACION=?, NUMERO_MAQUETA=?, FECHA_ACTUALIZACION=	?, FECHA_CONTABILIZACION=?, USUARIO_ULTMODIFICACION=?, FECHA_ULTMODIFICACION=?";

		String numeroExp = documentoscontables.getNumeroExpediente().replaceAll("\\s+", "");

		if ("0".equals(documentoscontables.getIndicadorError())) {
			query = query + ",INDICADOR_ERROR=? WHERE NUMERO_EXPEDIENTE=?";
			this.jdbcTemplate.update(query, documentoscontables.getPuntoTramitacion(),
					documentoscontables.getNumeroMaqueta(), documentoscontables.getFechaActualizacion(),
					documentoscontables.getFechaContabilizacion(), documentoscontables.getUsuarioUltModificacion(),
					documentoscontables.getFechaUltModificacion(), documentoscontables.getIndicadorError(), numeroExp);
		} else {
			query = query + " WHERE NUMERO_EXPEDIENTE=?";
			this.jdbcTemplate.update(query, documentoscontables.getPuntoTramitacion(),
					documentoscontables.getNumeroMaqueta(), documentoscontables.getFechaActualizacion(),
					documentoscontables.getFechaContabilizacion(), documentoscontables.getUsuarioUltModificacion(),
					documentoscontables.getFechaUltModificacion(), numeroExp);
		}

		return documentoscontables;
	}

	/**
	 * Updates a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	public DocumentosContables updateRegistrosDocContableREL(DocumentosContables documentoscontables) {
		String query = "UPDATE DOCUMENTOS_CONTABLES SET NUMERO_APUNTE=?, REF_INT_D=?, REF_INT_O=?, NUMERO_ORDEN=?, NUMERO_ORDEN_MV=?, FECHA_CONTABILIZACION=?, REFERENCIAL=?, NUMERO_APUNTE_EP=?, USUARIO_ULTMODIFICACION=?, FECHA_ULTMODIFICACION=?";

		String numeroExp = documentoscontables.getNumeroExpediente().replaceAll("\\s+", "");

		query = query + " WHERE NUMERO_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, documentoscontables.getNumeroApunte(), documentoscontables.getRefIntD(),
				documentoscontables.getRefIntO(), documentoscontables.getNumeroOrden(),
				documentoscontables.getNumeroOrdenMV(), documentoscontables.getFechaContabilizacion(),
				documentoscontables.getReferencial(), documentoscontables.getNumeroApunteEP(),
				documentoscontables.getUsuarioUltModificacion(), documentoscontables.getFechaUltModificacion(),
				numeroExp);

		return documentoscontables;
	}

	/**
	 * Finds a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return DocumentosContables
	 */
	@Transactional(readOnly = true)
	public DocumentosContables find(DocumentosContables documentoscontables) {
		String query = "SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD, t1.REF_INT_D REFINTD, t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA, t1.REF_INT_O REFINTO, t1.TIPO_REGISTRO TIPOREGISTRO, "
				+ TIPO_DOCUMENTO
				+ " TIPODOCUMENTO, t2.DESCRIPCION_CASTELLANO DESCASTELLANO, t2.DESCRIPCION_EUSKERA DESEUSKERA, t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE, t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE, t1.AGRUPACION AGRUPACION, t1.GASTO_INGRESO GASTOINGRESO, t1.SECCION SECCION, t1.SERVICIO SERVICIO, t1.CENTRO CENTRO, t1.TERRITORIO TERRITORIO, t1.CAC CAC, t1.SC SC, t1.PROGRAMA PROGRAMA, t1.PARTIDA PARTIDA, t1.LETRA_CONTROL LETRACONTROL, t1.EJERCICIO_REF_INT EJERCICIOREFINT, t1.ANYO_ORIGEN ANYOORIGEN, t1.NUMERO NUMERO, t1.DISPONIBLE DISPONIBLE, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.TERCERO TERCERO, t1.IMPORTE IMPORTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM DOCUMENTOS_CONTABLES t1, TIPOS_DOC_CON t2  WHERE t1.ID_DOCUMENTO_CONTABLE ="
				+ documentoscontables.getIdDocumentoContable() + " " + " AND t2.ID_TIPO_DOC_CON = " + TIPO_DOCUMENTO;

		List<DocumentosContables> documentoscontablesList = this.jdbcTemplate.query(query, this.rwMapTipoDoc);
		DocumentosContables dc = (DocumentosContables) DataAccessUtils.uniqueResult(documentoscontablesList);

		// Recupero la descripción del tipo documento
		/*
		 * if (dc.getTipoDocumento() != null &&
		 * !"".equals(dc.getTipoDocumento())) { TiposDocumento tiposDoc = new
		 * TiposDocumento();
		 * tiposDoc.setIdTipoDocumento(Long.parseLong(dc.getTipoDocumento()));
		 * tiposDoc = tiposDocumentoDao.find(tiposDoc);
		 * 
		 * dc.setNombreTipoDocumentoCas(tiposDoc.getDescripcionCastellano());
		 * dc.setNombreTipoDocumentoEus(tiposDoc.getDescripcionEuskera()); }
		 */
		return dc;
	}

	/**
	 * Removes a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return
	 */
	public void remove(DocumentosContables documentoscontables) {
		String query = "DELETE FROM DOCUMENTOS_CONTABLES WHERE ID_DOCUMENTO_CONTABLE=?";
		this.jdbcTemplate.update(query, documentoscontables.getIdDocumentoContable());
	}

	/**
	 * Removes a single row in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return
	 */
	public void removeByFicheroContable(DocumentosContables documentoscontables) {
		StringBuilder query = new StringBuilder();
		query.append("DELETE FROM DOCUMENTOS_CONTABLES WHERE ID_FICHERO_CONTABLE=?");

		if (documentoscontables.getIdExpediente() != null) {
			query.append(" AND ID_DOCUMENTO_CONTABLE=" + documentoscontables.getIdExpediente());
		}

		this.jdbcTemplate.update(query.toString(), documentoscontables.getIdFicheroContable());
	}

	/**
	 * Finds a list of rows in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<DocumentosContables>
	 */
	@Transactional(readOnly = true)
	public List<DocumentosContables> findAll(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE,t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.REF_INT_O REFINTO,t1.TIPO_REGISTRO TIPOREGISTRO, "
						+ TIPO_DOCUMENTO
						+ " TIPODOCUMENTO,t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.TERCERO TERCERO,t1.IMPORTE IMPORTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_CONVOCATORIA IDCONVOCATORIA ");
		query.append("FROM DOCUMENTOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(documentoscontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DocumentosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<DocumentosContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the DocumentosContables table using like.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<DocumentosContables>
	 */
	@Transactional(readOnly = true)
	public List<DocumentosContables> findAllLike(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE,t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.REF_INT_O REFINTO,t1.TIPO_REGISTRO TIPOREGISTRO, "
						+ TIPO_DOCUMENTO
						+ " TIPODOCUMENTO, t2.DESCRIPCION_CASTELLANO DESCASTELLANO, t2.DESCRIPCION_EUSKERA DESEUSKERA,t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.TERCERO TERCERO,t1.IMPORTE IMPORTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_CONVOCATORIA IDCONVOCATORIA ");
		query.append("FROM DOCUMENTOS_CONTABLES t1, TIPOS_DOC_CON t2");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(documentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append("AND t1.ID_CONVOCATORIA = " + documentoscontables.getIdConvocatoria());
		// where.append(" AND t1.TIPO_DOCUMENTO = t2.ID_TIPO_DOC_CON");
		where.append(" AND t2.ID_TIPO_DOC_CON = " + TIPO_DOCUMENTO);

		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DocumentosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}
		return (List<DocumentosContables>) this.jdbcTemplate.query(query.toString(), this.rwMapTipoDoc,
				params.toArray());
	}

	@Transactional(readOnly = true)
	public List<DocumentosContables> findImporteAplicPresu(DocumentosContables documentoscontables) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.IMPORTE IMPORTE, t2.ID_APLICACION_PRESUPUESTARIA IDAPLICPRESU FROM DOCUMENTOS_CONTABLES t1 INNER JOIN V_EXP_INF_CONTABLE t2 ON t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE WHERE t1.ID_FICHERO_CONTABLE = ?");

		return (List<DocumentosContables>) this.jdbcTemplate.query(query.toString(), this.rwMapImporteAplicPresu,
				documentoscontables.getIdFicheroContable());
	}

	@Transactional(readOnly = true)
	public List<DocumentosContables> findAllLikeByFichero(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, Integer idFichero) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE,t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.REF_INT_O REFINTO,t1.TIPO_REGISTRO TIPOREGISTRO, "
						+ TIPO_DOCUMENTO
						+ " TIPODOCUMENTO, t2.DESCRIPCION_CASTELLANO DESCASTELLANO, t2.DESCRIPCION_EUSKERA DESEUSKERA,t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.TERCERO TERCERO,t1.IMPORTE IMPORTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_CONVOCATORIA IDCONVOCATORIA ");
		query.append("FROM DOCUMENTOS_CONTABLES t1, TIPOS_DOC_CON t2");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(documentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append("AND t1.ID_FICHERO_CONTABLE = " + idFichero);
		where.append(" AND t2.ID_TIPO_DOC_CON = " + TIPO_DOCUMENTO);
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DocumentosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}
		return (List<DocumentosContables>) this.jdbcTemplate.query(query.toString(), this.rwMapTipoDoc,
				params.toArray());
	}

	@Transactional(readOnly = true)
	public List<DocumentosContables> findAllLikeDocumentos(DocumentosContables docContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, Integer idFicheroContable) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE ,t1.NUMERO_EXPEDIENTE EXPEDIENTE, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.IMPORTE IMPORTE, (t1.EJERCICIO_APL_PRE || '|' || t1.AGRUPACION || '|' || t1.GASTO_INGRESO || '|' || t1.SECCION || '|' || t1.SERVICIO || '|' || t1.CENTRO || '|' || t1.CAC || '|' || t1.SC || '|' || t1.PROGRAMA || '|' || t1.PARTIDA || '|' || t1.LETRA_CONTROL) APLICACIONPRESUPUESTARIA, t1.TERCERO TERCERO, t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD, t1.TERRITORIO TERRITORIO, t2.ID_APLICACION_PRESUPUESTARIA IDAPLICPRESU ");
		query.append("FROM DOCUMENTOS_CONTABLES t1 ");
		query.append("INNER JOIN V_EXP_INF_CONTABLE t2 ON t1.ID_EXPEDIENTE = t2.ID_EXPEDIENTE ");
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(" AND t1.ID_FICHERO_CONTABLE = " + idFicheroContable);
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DocumentosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}
		return (List<DocumentosContables>) this.jdbcTemplate.query(query.toString(), this.rwMapTablaFicheros,
				params.toArray());
	}

	@Transactional(readOnly = true)
	public List<DocumentosContables> findAllLikeArchivos(DocumentosContables docContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, List<String> lista) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.PUNTO_TRAMITACION PUNTOTRAMITACION, t1.NUMERO_MAQUETA NUMEROMAQUETA, t1.NUMERO_EXPEDIENTE EXPEDIENTE, t1.FECHA_ACTUALIZACION FECHAACTUALIZACION, t1.FECHA_CONTABILIZACION FECHACONTABILIZACION, t1.INDICADOR_ERROR INDICADORERROR, t1.NUMERO_APUNTE NUMEROAPUNTE, t1.NUMERO_ORDEN NUMEROORDEN, t1.TERRITORIO TERRITORIO ");
		query.append("FROM DOCUMENTOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(docContables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(" AND t1.NUMERO_EXPEDIENTE IN( ");

		if (lista != null && !lista.isEmpty()) {
			StringBuilder sbr = new StringBuilder();
			for (String s : lista) {
				sbr.append("'" + s + "'");
				sbr.append(SEPARATOR);
			}

			String sb = sbr.toString();
			sb = sb.substring(0, sb.length() - SEPARATOR.length());
			where.append(sb + ")");
		} else {
			where.append("'0')");
		}

		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					DocumentosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}
		return (List<DocumentosContables>) this.jdbcTemplate.query(query.toString(), this.rwMapTablaCargaArchivos,
				params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the DocumentosContables table.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(DocumentosContables documentoscontables) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DOCUMENTOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(documentoscontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the DocumentosContables table using like.
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(DocumentosContables documentoscontables, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DOCUMENTOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(documentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append("AND t1.ID_CONVOCATORIA = " + documentoscontables.getIdConvocatoria());
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Transactional(readOnly = true)
	public Long findAllLikeCountDocumentos(DocumentosContables documentoscontables, Boolean startsWith,
			Integer idFicheroContable) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DOCUMENTOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(documentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(" AND t1.ID_FICHERO_CONTABLE =" + idFicheroContable);
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Transactional(readOnly = true)
	public Long findAllLikeCountArchivos(DocumentosContables documentoscontables, Boolean startsWith,
			List<String> lista) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM DOCUMENTOS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(documentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(" AND t1.NUMERO_EXPEDIENTE IN( ");

		if (lista != null && !lista.isEmpty()) {
			StringBuilder sbr = new StringBuilder();
			for (String s : lista) {
				sbr.append("'" + s + "'");
				sbr.append(SEPARATOR);
			}

			String sb = sbr.toString();
			sb = sb.substring(0, sb.length() - SEPARATOR.length());
			where.append(sb + ")");
		} else {
			where.append("'0')");
		}
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of DocumentosContables selected for rup_table
	 *
	 * @param documentoscontables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DocumentosContables>>
	 */
	@Override
	public List<TableRowDto<DocumentosContables>> reorderSelection(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE,t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.REF_INT_O REFINTO,t1.TIPO_REGISTRO TIPOREGISTRO, "
						+ TIPO_DOCUMENTO
						+ " TIPODOCUMENTO,t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.TERCERO TERCERO,t1.IMPORTE IMPORTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_CONVOCATORIA IDCONVOCATORIA ");
		// FROM
		query.append("FROM DOCUMENTOS_CONTABLES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(documentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				DocumentosContables.class, filterParamList, "ID_DOCUMENTO_CONTABLE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DocumentosContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	@Override
	public List<TableRowDto<DocumentosContables>> reorderSelectionDocumentos(DocumentosContables documentoscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith, Integer idFicheroContable) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE ,t1.NUMERO_EXPEDIENTE EXPEDIENTE, t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO, t1.IMPORTE IMPORTE, (t1.EJERCICIO_APL_PRE || '|' || t1.AGRUPACION || '|' || t1.GASTO_INGRESO || '|' || t1.SECCION || '|' || t1.SERVICIO || '|' || t1.CENTRO || '|' || t1.CAC || '|' || t1.SC || '|' || t1.PROGRAMA || '|' || t1.PARTIDA || '|' || t1.LETRA_CONTROL) AS APLICACIONPRESUPUESTARIA, t1.TERCERO TERCERO, t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD ");
		// FROM
		query.append("FROM DOCUMENTOS_CONTABLES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(documentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(" AND t1.ID_FICHERO_CONTABLE =" + idFicheroContable);
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				DocumentosContables.class, filterParamList, "ID_DOCUMENTO_CONTABLE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DocumentosContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            DocumentosContables
	 * @param searchParams
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DocumentosContables>>
	 */
	@Override
	public List<TableRowDto<DocumentosContables>> search(DocumentosContables filterParams,
			DocumentosContables searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE,t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.REF_INT_O REFINTO,t1.TIPO_REGISTRO TIPOREGISTRO, "
						+ TIPO_DOCUMENTO
						+ " TIPODOCUMENTO,t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.TERCERO TERCERO,t1.IMPORTE IMPORTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM DOCUMENTOS_CONTABLES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				DocumentosContables.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_DOCUMENTO_CONTABLE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<DocumentosContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterdocumentoscontables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(DocumentosContables filterdocumentoscontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE,t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.REF_INT_O REFINTO,t1.TIPO_REGISTRO TIPOREGISTRO, "
						+ TIPO_DOCUMENTO
						+ " TIPODOCUMENTO,t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.TERCERO TERCERO,t1.IMPORTE IMPORTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM DOCUMENTOS_CONTABLES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterdocumentoscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				DocumentosContables.class, query, params, "ID_DOCUMENTO_CONTABLE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical DocumentosContables table.
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<DocumentosContables>>
	 */
	@Override
	public List<JerarquiaDto<DocumentosContables>> findAllLikeJerarquia(DocumentosContables filterDocumentosContables,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DOCUMENTO_CONTABLE IDDOCUMENTOCONTABLE,t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_DOCUMENTO_D FECHADOCUMENTOD,t1.REF_INT_D REFINTD,t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.REF_INT_O REFINTO,t1.TIPO_REGISTRO TIPOREGISTRO, "
						+ TIPO_DOCUMENTO
						+ " TIPODOCUMENTO,t1.NUMERO_EXPEDIENTE NUMEROEXPEDIENTE,t1.EJERCICIO_APL_PRE EJERCICIOAPLPRE,t1.AGRUPACION AGRUPACION,t1.GASTO_INGRESO GASTOINGRESO,t1.SECCION SECCION,t1.SERVICIO SERVICIO,t1.CENTRO CENTRO,t1.TERRITORIO TERRITORIO,t1.CAC CAC,t1.SC SC,t1.PROGRAMA PROGRAMA,t1.PARTIDA PARTIDA,t1.LETRA_CONTROL LETRACONTROL,t1.EJERCICIO_REF_INT EJERCICIOREFINT,t1.ANYO_ORIGEN ANYOORIGEN,t1.NUMERO NUMERO,t1.DISPONIBLE DISPONIBLE,t1.CONCEPTO_RESUMIDO CONCEPTORESUMIDO,t1.TERCERO TERCERO,t1.IMPORTE IMPORTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM DOCUMENTOS_CONTABLES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("DOCUMENTOS_CONTABLES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDocumentosContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_DOCUMENTO_CONTABLE", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					DocumentosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(DocumentosContables filterDocumentosContables,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM DOCUMENTOS_CONTABLES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("DOCUMENTOS_CONTABLES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDocumentosContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_DOCUMENTO_CONTABLE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<DocumentosContables>>
	 */
	@Override
	public List<TableRowDto<DocumentosContables>> findAllChild(DocumentosContables filterDocumentosContables,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM DOCUMENTOS_CONTABLES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("DOCUMENTOS_CONTABLES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterDocumentosContables, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_DOCUMENTO_CONTABLE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<DocumentosContables>(this.rwMapPK, "ID_DOCUMENTO_CONTABLE"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DocumentosContables entity
	 *
	 * @param documentoscontables
	 *            DocumentosContables Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(DocumentosContables documentoscontables) {

		StringBuilder where = new StringBuilder(DocumentosContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (documentoscontables != null && documentoscontables.getIdDocumentoContable() != null) {
			where.append(" AND t1.ID_DOCUMENTO_CONTABLE = ?");
			params.add(documentoscontables.getIdDocumentoContable());
		}
		if (documentoscontables != null && documentoscontables.getIdFicheroContable() != null) {
			where.append(" AND t1.ID_FICHERO_CONTABLE = ?");
			params.add(documentoscontables.getIdFicheroContable());
		}
		if (documentoscontables != null && documentoscontables.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(documentoscontables.getIdExpediente());
		}
		if (documentoscontables != null && documentoscontables.getFechaDocumentoD() != null) {
			where.append(" AND t1.FECHA_DOCUMENTO_D = ?");
			params.add(documentoscontables.getFechaDocumentoD());
		}
		if (documentoscontables != null && documentoscontables.getRefIntD() != null) {
			where.append(" AND t1.REF_INT_D = ?");
			params.add(documentoscontables.getRefIntD());
		}
		if (documentoscontables != null && documentoscontables.getIdPagoConvocatoria() != null) {
			where.append(" AND t1.ID_PAGO_CONVOCATORIA = ?");
			params.add(documentoscontables.getIdPagoConvocatoria());
		}
		if (documentoscontables != null && documentoscontables.getRefIntO() != null) {
			where.append(" AND t1.REF_INT_O = ?");
			params.add(documentoscontables.getRefIntO());
		}
		if (documentoscontables != null && documentoscontables.getTipoRegistro() != null) {
			where.append(" AND t1.TIPO_REGISTRO = ?");
			params.add(documentoscontables.getTipoRegistro());
		}
		if (documentoscontables != null && documentoscontables.getTipoDocumento() != null) {
			where.append(" AND t1.TIPO_DOCUMENTO = ?");
			params.add(documentoscontables.getTipoDocumento().getIdTipoDocumento());
		}
		if (documentoscontables != null && documentoscontables.getNumeroExpediente() != null) {
			where.append(" AND t1.NUMERO_EXPEDIENTE = ?");
			params.add(documentoscontables.getNumeroExpediente());
		}
		if (documentoscontables != null && documentoscontables.getEjercicioAplPre() != null) {
			where.append(" AND t1.EJERCICIO_APL_PRE = ?");
			params.add(documentoscontables.getEjercicioAplPre());
		}
		if (documentoscontables != null && documentoscontables.getAgrupacion() != null) {
			where.append(" AND t1.AGRUPACION = ?");
			params.add(documentoscontables.getAgrupacion());
		}
		if (documentoscontables != null && documentoscontables.getGastoIngreso() != null) {
			where.append(" AND t1.GASTO_INGRESO = ?");
			params.add(documentoscontables.getGastoIngreso());
		}
		if (documentoscontables != null && documentoscontables.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(documentoscontables.getSeccion());
		}
		if (documentoscontables != null && documentoscontables.getServicio() != null) {
			where.append(" AND t1.SERVICIO = ?");
			params.add(documentoscontables.getServicio());
		}
		if (documentoscontables != null && documentoscontables.getCentro() != null) {
			where.append(" AND t1.CENTRO = ?");
			params.add(documentoscontables.getCentro());
		}
		if (documentoscontables != null && documentoscontables.getTerritorio() != null) {
			where.append(" AND t1.TERRITORIO = ?");
			params.add(documentoscontables.getTerritorio());
		}
		if (documentoscontables != null && documentoscontables.getCac() != null) {
			where.append(" AND t1.CAC = ?");
			params.add(documentoscontables.getCac());
		}
		if (documentoscontables != null && documentoscontables.getSc() != null) {
			where.append(" AND t1.SC = ?");
			params.add(documentoscontables.getSc());
		}
		if (documentoscontables != null && documentoscontables.getPrograma() != null) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(documentoscontables.getPrograma());
		}
		if (documentoscontables != null && documentoscontables.getPartida() != null) {
			where.append(" AND t1.PARTIDA = ?");
			params.add(documentoscontables.getPartida());
		}
		if (documentoscontables != null && documentoscontables.getLetraControl() != null) {
			where.append(" AND t1.LETRA_CONTROL = ?");
			params.add(documentoscontables.getLetraControl());
		}
		if (documentoscontables != null && documentoscontables.getEjercicioRefInt() != null) {
			where.append(" AND t1.EJERCICIO_REF_INT = ?");
			params.add(documentoscontables.getEjercicioRefInt());
		}
		if (documentoscontables != null && documentoscontables.getAnyoOrigen() != null) {
			where.append(" AND t1.ANYO_ORIGEN = ?");
			params.add(documentoscontables.getAnyoOrigen());
		}
		if (documentoscontables != null && documentoscontables.getNumero() != null) {
			where.append(" AND t1.NUMERO = ?");
			params.add(documentoscontables.getNumero());
		}
		if (documentoscontables != null && documentoscontables.getDisponible() != null) {
			where.append(" AND t1.DISPONIBLE = ?");
			params.add(documentoscontables.getDisponible());
		}
		if (documentoscontables != null && documentoscontables.getConceptoResumido() != null) {
			where.append(" AND t1.CONCEPTO_RESUMIDO = ?");
			params.add(documentoscontables.getConceptoResumido());
		}
		if (documentoscontables != null && documentoscontables.getTercero() != null) {
			where.append(" AND t1.TERCERO = ?");
			params.add(documentoscontables.getTercero());
		}
		if (documentoscontables != null && documentoscontables.getImporte() != null) {
			where.append(" AND t1.IMPORTE = ?");
			params.add(documentoscontables.getImporte());
		}
		if (documentoscontables != null && documentoscontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(documentoscontables.getFechaRegistro());
		}
		if (documentoscontables != null && documentoscontables.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(documentoscontables.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the DocumentosContables entity
	 *
	 * @param documentoscontables
	 *            DocumentosContables Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(DocumentosContables documentoscontables, Boolean startsWith) {

		StringBuilder where = new StringBuilder(DocumentosContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (documentoscontables != null && documentoscontables.getIdDocumentoContable() != null) {
			where.append(" AND UPPER(t1.ID_DOCUMENTO_CONTABLE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getIdDocumentoContable().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getIdDocumentoContable().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_DOCUMENTO_CONTABLE IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getIdFicheroContable() != null) {
			where.append(" AND t1.ID_FICHERO_CONTABLE = ?");
			params.add(documentoscontables.getIdFicheroContable());
		}
		if (documentoscontables != null && documentoscontables.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(documentoscontables.getIdExpediente());
		}
		if (documentoscontables != null && documentoscontables.getFechaDocumentoD() != null) {
			where.append(" AND t1.FECHA_DOCUMENTO_D = ?");
			params.add(documentoscontables.getFechaDocumentoD());
		}
		if (documentoscontables != null && documentoscontables.getRefIntD() != null) {
			where.append(" AND UPPER(t1.REF_INT_D) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getRefIntD().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getRefIntD().toUpperCase() + "%");
			}
			where.append(" AND t1.REF_INT_D IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getIdPagoConvocatoria() != null) {
			where.append(" AND t1.ID_PAGO_CONVOCATORIA = ?");
			params.add(documentoscontables.getIdPagoConvocatoria());
		}
		if (documentoscontables != null && documentoscontables.getRefIntO() != null) {
			where.append(" AND UPPER(t1.REF_INT_O) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getRefIntO().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getRefIntO().toUpperCase() + "%");
			}
			where.append(" AND t1.REF_INT_O IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getTipoRegistro() != null) {
			where.append(" AND UPPER(t1.TIPO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getTipoRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getTipoRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.TIPO_REGISTRO IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getTipoDocumento() != null) {
			where.append(" AND UPPER(t1.TIPO_DOCUMENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getTipoDocumento().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getTipoDocumento().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.TIPO_DOCUMENTO IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getNumeroExpediente() != null) {
			where.append(" AND UPPER(t1.NUMERO_EXPEDIENTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getNumeroExpediente().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getNumeroExpediente().toUpperCase() + "%");
			}
			where.append(" AND t1.NUMERO_EXPEDIENTE IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getEjercicioAplPre() != null) {
			where.append(" AND t1.EJERCICIO_APL_PRE = ?");
			params.add(documentoscontables.getEjercicioAplPre());
		}
		if (documentoscontables != null && documentoscontables.getAgrupacion() != null) {
			where.append(" AND t1.AGRUPACION = ?");
			params.add(documentoscontables.getAgrupacion());
		}
		if (documentoscontables != null && documentoscontables.getGastoIngreso() != null) {
			where.append(" AND t1.GASTO_INGRESO = ?");
			params.add(documentoscontables.getGastoIngreso());
		}
		if (documentoscontables != null && documentoscontables.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(documentoscontables.getSeccion());
		}
		if (documentoscontables != null && documentoscontables.getServicio() != null) {
			where.append(" AND t1.SERVICIO = ?");
			params.add(documentoscontables.getServicio());
		}
		if (documentoscontables != null && documentoscontables.getCentro() != null) {
			where.append(" AND t1.CENTRO = ?");
			params.add(documentoscontables.getCentro());
		}
		if (documentoscontables != null && documentoscontables.getTerritorio() != null) {
			where.append(" AND t1.TERRITORIO = ?");
			params.add(documentoscontables.getTerritorio());
		}
		if (documentoscontables != null && documentoscontables.getCac() != null) {
			where.append(" AND t1.CAC = ?");
			params.add(documentoscontables.getCac());
		}
		if (documentoscontables != null && documentoscontables.getSc() != null) {
			where.append(" AND t1.SC = ?");
			params.add(documentoscontables.getSc());
		}
		if (documentoscontables != null && documentoscontables.getPrograma() != null) {
			where.append(" AND t1.PROGRAMA = ?");
			params.add(documentoscontables.getPrograma());
		}
		if (documentoscontables != null && documentoscontables.getPartida() != null) {
			where.append(" AND t1.PARTIDA = ?");
			params.add(documentoscontables.getPartida());
		}
		if (documentoscontables != null && documentoscontables.getLetraControl() != null) {
			where.append(" AND UPPER(t1.LETRA_CONTROL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getLetraControl().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getLetraControl().toUpperCase() + "%");
			}
			where.append(" AND t1.LETRA_CONTROL IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getEjercicioRefInt() != null) {
			where.append(" AND t1.EJERCICIO_REF_INT = ?");
			params.add(documentoscontables.getEjercicioRefInt());
		}
		if (documentoscontables != null && documentoscontables.getAnyoOrigen() != null) {
			where.append(" AND t1.ANYO_ORIGEN = ?");
			params.add(documentoscontables.getAnyoOrigen());
		}
		if (documentoscontables != null && documentoscontables.getNumero() != null) {
			where.append(" AND t1.NUMERO = ?");
			params.add(documentoscontables.getNumero());
		}
		if (documentoscontables != null && documentoscontables.getDisponible() != null) {
			where.append(" AND t1.DISPONIBLE = ?");
			params.add(documentoscontables.getDisponible());
		}
		if (documentoscontables != null && documentoscontables.getConceptoResumido() != null) {
			where.append(" AND UPPER(t1.CONCEPTO_RESUMIDO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getConceptoResumido().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getConceptoResumido().toUpperCase() + "%");
			}
			where.append(" AND t1.CONCEPTO_RESUMIDO IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getTercero() != null) {
			where.append(" AND UPPER(t1.TERCERO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getTercero().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getTercero().toUpperCase() + "%");
			}
			where.append(" AND t1.TERCERO IS NOT NULL");
		}
		if (documentoscontables != null && documentoscontables.getImporte() != null) {
			where.append(" AND t1.IMPORTE = ?");
			params.add(documentoscontables.getImporte());
		}
		if (documentoscontables != null && documentoscontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(documentoscontables.getFechaRegistro());
		}
		if (documentoscontables != null && documentoscontables.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(documentoscontables.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + documentoscontables.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
