package com.ejie.ab60.dao.moduloContable;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.moduloContable.FicherosContables;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * FicherosContablesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class FicherosContablesDaoImpl implements FicherosContablesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDFICHEROCONTABLE", "IDCONVOCATORIA",
			"NOMBREFICHERO", "IDTIPODOCCON", "ESTADO", "TIPOREGISTRO", "INSTITUCION", "EJERCICIO", "SECCION",
			"ORIGENMAQUETA", "IDENTIFICADORCINTA", "USUARIO", "IDIDIOMA", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "IMPORTE", "N_REGISTROS" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<FicherosContables> rwMap = new RowMapper<FicherosContables>() {
		public FicherosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FicherosContables(resultSet.getInt("IDFICHEROCONTABLE"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("NOMBREFICHERO"), resultSet.getLong("IDTIPODOCCON"), resultSet.getInt("ESTADO"),
					resultSet.getString("TIPOREGISTRO"), resultSet.getString("INSTITUCION"),
					resultSet.getString("EJERCICIO"), resultSet.getString("SECCION"),
					resultSet.getString("ORIGENMAQUETA"), resultSet.getString("IDENTIFICADORCINTA"),
					resultSet.getString("USUARIO"), resultSet.getLong("IDIDIOMA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<FicherosContables> rwMapIdiomas = new RowMapper<FicherosContables>() {
		public FicherosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FicherosContables(resultSet.getInt("IDFICHEROCONTABLE"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("NOMBREFICHERO"), resultSet.getLong("IDTIPODOCCON"),
					resultSet.getString("DESCTIPODOCCONES"), resultSet.getString("DESCTIPODOCCONEU"),
					resultSet.getInt("ESTADO"), resultSet.getString("TIPOREGISTRO"), resultSet.getString("INSTITUCION"),
					resultSet.getString("EJERCICIO"), resultSet.getString("SECCION"),
					resultSet.getString("ORIGENMAQUETA"), resultSet.getString("IDENTIFICADORCINTA"),
					resultSet.getString("USUARIO"), resultSet.getLong("IDIDIOMA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<FicherosContables> rwMapImpRegistros = new RowMapper<FicherosContables>() {
		public FicherosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FicherosContables(resultSet.getInt("IDFICHEROCONTABLE"), resultSet.getInt("IDCONVOCATORIA"),
					resultSet.getString("NOMBREFICHERO"), resultSet.getLong("IDTIPODOCCON"),
					resultSet.getString("DESCTIPODOCCONES"), resultSet.getString("DESCTIPODOCCONEU"),
					resultSet.getInt("ESTADO"), resultSet.getString("TIPOREGISTRO"), resultSet.getString("INSTITUCION"),
					resultSet.getString("EJERCICIO"), resultSet.getString("SECCION"),
					resultSet.getString("ORIGENMAQUETA"), resultSet.getString("IDENTIFICADORCINTA"),
					resultSet.getString("USUARIO"), resultSet.getLong("IDIDIOMA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getBigDecimal("IMPORTE"),
					resultSet.getInt("N_REGISTROS"));
		}
	};

	private RowMapper<FicherosContables> rwMapNew = new RowMapper<FicherosContables>() {
		public FicherosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FicherosContables(resultSet.getInt("IDCONVOCATORIA"), resultSet.getString("NOMBREFICHERO"),
					resultSet.getString("INSTITUCION"), resultSet.getString("EJERCICIO"),
					resultSet.getString("SECCION"), resultSet.getString("USUARIOIKUS"), resultSet.getLong("IDIDIOMA"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getString("ORIGENMAQUETA"));
		}
	};

	private RowMapper<FicherosContables> rwMapPK = new RowMapper<FicherosContables>() {
		public FicherosContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FicherosContables(resultSet.getInt("IDFICHEROCONTABLE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<FicherosContables>> rwMapJerarquia = new RowMapper<JerarquiaDto<FicherosContables>>() {
		public JerarquiaDto<FicherosContables> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			FicherosContables ficheroscontables = new FicherosContables(resultSet.getInt("IDFICHEROCONTABLE"),
					resultSet.getInt("IDCONVOCATORIA"), resultSet.getString("NOMBREFICHERO"),
					resultSet.getLong("IDTIPODOCCON"), resultSet.getInt("ESTADO"), resultSet.getString("TIPOREGISTRO"),
					resultSet.getString("INSTITUCION"), resultSet.getString("EJERCICIO"),
					resultSet.getString("SECCION"), resultSet.getString("ORIGENMAQUETA"),
					resultSet.getString("IDENTIFICADORCINTA"), resultSet.getString("USUARIO"),
					resultSet.getLong("IDIDIOMA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<FicherosContables> jerarquia = new JerarquiaDto<FicherosContables>();
			jerarquia.setModel(ficheroscontables);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	public FicherosContables add(FicherosContables ficheroscontables, Usuario usuario) {

		// Hay que obtener el ultimo idCinta para la convocatoria

		String q = "SELECT S_AB601AT00.NEXTVAL FROM DUAL";
		ficheroscontables.setIdFicheroContable(this.jdbcTemplate.queryForInt(q));

		String query = "INSERT INTO FICHEROS_CONTABLES (ID_FICHERO_CONTABLE, ID_CONVOCATORIA, NOMBRE_FICHERO, ID_TIPO_DOC_CON, ESTADO, TIPO_REGISTRO, INSTITUCION, EJERCICIO, SECCION, ORIGEN_MAQUETA, IDENTIFICADOR_CINTA, USUARIO, ID_IDIOMA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, sysdate, ?)";
		this.jdbcTemplate.update(query, ficheroscontables.getIdFicheroContable(), ficheroscontables.getIdConvocatoria(),
				ficheroscontables.getNombreFichero(), ficheroscontables.getIdTipoDocCon(),
				ficheroscontables.getEstado(), ficheroscontables.getTipoRegistro(), ficheroscontables.getInstitucion(),
				ficheroscontables.getEjercicio(), ficheroscontables.getSeccion(), ficheroscontables.getOrigenMaqueta(),
				this.getNextIdCinta(ficheroscontables.getIdConvocatoria()), ficheroscontables.getUsuario(),
				ficheroscontables.getIdIdioma(), usuario.getNombreUsuario());
		return ficheroscontables;
	}

	/**
	 * Finds a single row in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	@Transactional(readOnly = true)
	private Integer getNextIdCinta(int idConvocatoria) {
		String query = "SELECT max (nvl(t1.IDENTIFICADOR_CINTA,0))+1 IDENTIFICADORCINTA FROM FICHEROS_CONTABLES t1  WHERE t1.ID_CONVOCATORIA = ? ";

		if (this.jdbcTemplate.queryForObject(query, Integer.class, idConvocatoria) == null) {
			return 0;
		} else {
			return this.jdbcTemplate.queryForObject(query, Integer.class, idConvocatoria);
		}

	}

	/**
	 * Updates a single row in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	public FicherosContables update(FicherosContables ficheroscontables, Usuario usuario) {
		String query = "UPDATE FICHEROS_CONTABLES SET ID_CONVOCATORIA=?, NOMBRE_FICHERO=?, ID_TIPO_DOC_CON=?, ESTADO=?, TIPO_REGISTRO=?, INSTITUCION=?, EJERCICIO=?, SECCION=?, ORIGEN_MAQUETA=?, IDENTIFICADOR_CINTA=?, USUARIO=?, ID_IDIOMA=?, FECHA_ULTMODIFICACION=sysdate, USUARIO_ULTMODIFICACION=? WHERE ID_FICHERO_CONTABLE=?";
		this.jdbcTemplate.update(query, ficheroscontables.getIdConvocatoria(), ficheroscontables.getNombreFichero(),
				ficheroscontables.getIdTipoDocCon(), ficheroscontables.getEstado(), ficheroscontables.getTipoRegistro(),
				ficheroscontables.getInstitucion(), ficheroscontables.getEjercicio(), ficheroscontables.getSeccion(),
				ficheroscontables.getOrigenMaqueta(), ficheroscontables.getIdentificadorCinta(),
				ficheroscontables.getUsuario(), ficheroscontables.getIdIdioma(), usuario.getNombreUsuario(),
				ficheroscontables.getIdFicheroContable());
		return ficheroscontables;
	}

	/**
	 * Finds a single row in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	@Transactional(readOnly = true)
	public FicherosContables find(FicherosContables ficheroscontables) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE, t1.ID_CONVOCATORIA IDCONVOCATORIA, t1.NOMBRE_FICHERO NOMBREFICHERO, t1.ID_TIPO_DOC_CON IDTIPODOCCON, T3.DESCRIPCION_CASTELLANO DESCTIPODOCCONES, T3.DESCRIPCION_EUSKERA DESCTIPODOCCONEU, t1.ESTADO ESTADO, t1.TIPO_REGISTRO TIPOREGISTRO, t1.INSTITUCION INSTITUCION, t1.EJERCICIO EJERCICIO, t1.SECCION SECCION, t1.ORIGEN_MAQUETA ORIGENMAQUETA, t1.IDENTIFICADOR_CINTA IDENTIFICADORCINTA, t1.USUARIO USUARIO, t1.ID_IDIOMA IDIDIOMA,t2.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM FICHEROS_CONTABLES t1 ");
		query.append("INNER JOIN IDIOMAS t2 ON t2.ID_IDIOMA = t1.ID_IDIOMA ");
		query.append("INNER JOIN TIPOS_DOC_CON T3 ON T3.ID_TIPO_DOC_CON = t1.ID_TIPO_DOC_CON ");
		query.append("WHERE t1.ID_FICHERO_CONTABLE = ?");

		List<FicherosContables> ficheroscontablesList = this.jdbcTemplate.query(query.toString(), this.rwMapIdiomas,
				ficheroscontables.getIdFicheroContable());
		return (FicherosContables) DataAccessUtils.uniqueResult(ficheroscontablesList);
	}

	/**
	 * Finds a single row in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	@Transactional(readOnly = true)
	public FicherosContables findNew(FicherosContables ficheroscontables) {
		int idCinta = getNextIdCinta(ficheroscontables.getIdConvocatoria());
		Date date = new Date();
		String modifiedDate = new SimpleDateFormat("yyyyMMdd").format(date);

		StringBuilder query = new StringBuilder(
				"SELECT T2.ID_CONVOCATORIA IDCONVOCATORIA, T2.EJERCICIO||'-'||T2.SECCION||'-'||t4.ORIGEN_MAQUETA||'-'||"
						+ idCinta + "|| '-'||" + modifiedDate
						+ " AS NOMBREFICHERO , T2.INSTITUCION INSTITUCION, T2.EJERCICIO EJERCICIO, T2.SECCION SECCION, T2.USUARIO_IKUS USUARIOIKUS, T2.ID_IDIOMA IDIDIOMA, T3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, T4.ORIGEN_MAQUETA ORIGENMAQUETA ");
		query.append("FROM DATOS_CONTABLES T2 ");
		query.append("LEFT JOIN IDIOMAS T3 ON T3.ID_CONVOCATORIA is null AND T3.ID_IDIOMA = T2.ID_IDIOMA ");
		query.append("INNER JOIN CONVOCATORIAS T4 ON T4.ID_CONVOCATORIA = T2.ID_CONVOCATORIA ");
		query.append("WHERE T2.ID_CONVOCATORIA = ?");

		List<FicherosContables> ficheroscontablesList = this.jdbcTemplate.query(query.toString(), this.rwMapNew,
				ficheroscontables.getIdConvocatoria());
		return (FicherosContables) DataAccessUtils.uniqueResult(ficheroscontablesList);
	}

	/**
	 * Removes a single row in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @return
	 */
	public void remove(FicherosContables ficheroscontables) {
		String query = "DELETE FROM FICHEROS_CONTABLES WHERE ID_FICHERO_CONTABLE=?";
		this.jdbcTemplate.update(query, ficheroscontables.getIdFicheroContable());
	}

	/**
	 * Finds a list of rows in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<FicherosContables>
	 */
	@Transactional(readOnly = true)
	public List<FicherosContables> findAll(FicherosContables ficheroscontables, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.NOMBRE_FICHERO NOMBREFICHERO,t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.ESTADO ESTADO,t1.TIPO_REGISTRO TIPOREGISTRO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.ORIGEN_MAQUETA ORIGENMAQUETA,t1.IDENTIFICADOR_CINTA IDENTIFICADORCINTA,t1.USUARIO USUARIO,t1.ID_IDIOMA IDIDIOMA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM FICHEROS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ficheroscontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					FicherosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<FicherosContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the FicherosContables table using like.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<FicherosContables>
	 */
	@Transactional(readOnly = true)
	public List<FicherosContables> findAllLike(FicherosContables ficheroscontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t2.ID_FICHERO_CONTABLE IDFICHEROCONTABLEAUX,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.NOMBRE_FICHERO NOMBREFICHERO,t1.ID_TIPO_DOC_CON IDTIPODOCCON, T3.DESCRIPCION_CASTELLANO DESCTIPODOCCONES, T3.DESCRIPCION_EUSKERA DESCTIPODOCCONEU, t1.ESTADO ESTADO,t1.TIPO_REGISTRO TIPOREGISTRO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.ORIGEN_MAQUETA ORIGENMAQUETA,t1.IDENTIFICADOR_CINTA IDENTIFICADORCINTA,t1.USUARIO USUARIO,t1.ID_IDIOMA IDIDIOMA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,SUM(IMPORTE) IMPORTE,case when (t2.id_fichero_contable is null ) then 0 else COUNT(1) end N_REGISTROS ");
		query.append("FROM FICHEROS_CONTABLES t1 ");
		query.append("LEFT JOIN DOCUMENTOS_CONTABLES t2 ON t1.ID_FICHERO_CONTABLE= t2.ID_FICHERO_CONTABLE ");
		query.append("INNER JOIN TIPOS_DOC_CON T3 ON T3.ID_TIPO_DOC_CON = t1.ID_TIPO_DOC_CON ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ficheroscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);
		query.append(
				" group by t1.ID_FICHERO_CONTABLE,t2.ID_FICHERO_CONTABLE,t1.ID_CONVOCATORIA ,t1.NOMBRE_FICHERO ,t1.ID_TIPO_DOC_CON, T3.DESCRIPCION_CASTELLANO, T3.DESCRIPCION_EUSKERA, t1.ESTADO ,t1.TIPO_REGISTRO ,t1.INSTITUCION ,t1.EJERCICIO ,t1.SECCION ,t1.ORIGEN_MAQUETA ,t1.IDENTIFICADOR_CINTA ,t1.USUARIO ,t1.ID_IDIOMA ,t1.FECHA_REGISTRO ,t1.USUARIO_REGISTRO ,t1.FECHA_ULTMODIFICACION ,t1.USUARIO_ULTMODIFICACION ");

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					FicherosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<FicherosContables>) this.jdbcTemplate.query(query.toString(), this.rwMapImpRegistros,
				params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the FicherosContables table.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(FicherosContables ficheroscontables) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM FICHEROS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ficheroscontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the FicherosContables table using like.
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(FicherosContables ficheroscontables, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM FICHEROS_CONTABLES t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ficheroscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of FicherosContables selected for rup_table
	 *
	 * @param ficheroscontables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<FicherosContables>>
	 */
	@Override
	public List<TableRowDto<FicherosContables>> reorderSelection(FicherosContables ficheroscontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.NOMBRE_FICHERO NOMBREFICHERO,t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.ESTADO ESTADO,t1.TIPO_REGISTRO TIPOREGISTRO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.ORIGEN_MAQUETA ORIGENMAQUETA,t1.IDENTIFICADOR_CINTA IDENTIFICADORCINTA,t1.USUARIO USUARIO,t1.ID_IDIOMA IDIDIOMA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM FICHEROS_CONTABLES t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ficheroscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				FicherosContables.class, filterParamList, "ID_FICHERO_CONTABLE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<FicherosContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            FicherosContables
	 * @param searchParams
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<FicherosContables>>
	 */
	@Override
	public List<TableRowDto<FicherosContables>> search(FicherosContables filterParams, FicherosContables searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.NOMBRE_FICHERO NOMBREFICHERO,t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.ESTADO ESTADO,t1.TIPO_REGISTRO TIPOREGISTRO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.ORIGEN_MAQUETA ORIGENMAQUETA,t1.IDENTIFICADOR_CINTA IDENTIFICADORCINTA,t1.USUARIO USUARIO,t1.ID_IDIOMA IDIDIOMA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM FICHEROS_CONTABLES t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				FicherosContables.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_FICHERO_CONTABLE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<FicherosContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterficheroscontables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(FicherosContables filterficheroscontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.NOMBRE_FICHERO NOMBREFICHERO,t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.ESTADO ESTADO,t1.TIPO_REGISTRO TIPOREGISTRO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.ORIGEN_MAQUETA ORIGENMAQUETA,t1.IDENTIFICADOR_CINTA IDENTIFICADORCINTA,t1.USUARIO USUARIO,t1.ID_IDIOMA IDIDIOMA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM FICHEROS_CONTABLES t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterficheroscontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				FicherosContables.class, query, params, "ID_FICHERO_CONTABLE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical FicherosContables table.
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<FicherosContables>>
	 */
	@Override
	public List<JerarquiaDto<FicherosContables>> findAllLikeJerarquia(FicherosContables filterFicherosContables,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FICHERO_CONTABLE IDFICHEROCONTABLE,t1.ID_CONVOCATORIA IDCONVOCATORIA,t1.NOMBRE_FICHERO NOMBREFICHERO,t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.ESTADO ESTADO,t1.TIPO_REGISTRO TIPOREGISTRO,t1.INSTITUCION INSTITUCION,t1.EJERCICIO EJERCICIO,t1.SECCION SECCION,t1.ORIGEN_MAQUETA ORIGENMAQUETA,t1.IDENTIFICADOR_CINTA IDENTIFICADORCINTA,t1.USUARIO USUARIO,t1.ID_IDIOMA IDIDIOMA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM FICHEROS_CONTABLES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("FICHEROS_CONTABLES");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterFicherosContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_FICHERO_CONTABLE", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					FicherosContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(FicherosContables filterFicherosContables,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM FICHEROS_CONTABLES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("FICHEROS_CONTABLES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterFicherosContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_FICHERO_CONTABLE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<FicherosContables>>
	 */
	@Override
	public List<TableRowDto<FicherosContables>> findAllChild(FicherosContables filterFicherosContables,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM FICHEROS_CONTABLES t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("FICHEROS_CONTABLES");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterFicherosContables, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_FICHERO_CONTABLE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<FicherosContables>(this.rwMapPK, "ID_FICHERO_CONTABLE"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the FicherosContables entity
	 *
	 * @param ficheroscontables
	 *            FicherosContables Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(FicherosContables ficheroscontables) {

		StringBuilder where = new StringBuilder(FicherosContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ficheroscontables != null && ficheroscontables.getIdFicheroContable() != null) {
			where.append(" AND t1.ID_FICHERO_CONTABLE = ?");
			params.add(ficheroscontables.getIdFicheroContable());
		}
		if (ficheroscontables != null && ficheroscontables.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(ficheroscontables.getIdConvocatoria());
		}
		if (ficheroscontables != null && ficheroscontables.getNombreFichero() != null) {
			where.append(" AND t1.NOMBRE_FICHERO = ?");
			params.add(ficheroscontables.getNombreFichero());
		}
		if (ficheroscontables != null && ficheroscontables.getIdTipoDocCon() != null) {
			where.append(" AND t1.ID_TIPO_DOC_CON = ?");
			params.add(ficheroscontables.getIdTipoDocCon());
		}
		if (ficheroscontables != null && ficheroscontables.getEstado() != null) {
			where.append(" AND t1.ESTADO = ?");
			params.add(ficheroscontables.getEstado());
		}
		if (ficheroscontables != null && ficheroscontables.getTipoRegistro() != null) {
			where.append(" AND t1.TIPO_REGISTRO = ?");
			params.add(ficheroscontables.getTipoRegistro());
		}
		if (ficheroscontables != null && ficheroscontables.getInstitucion() != null) {
			where.append(" AND t1.INSTITUCION = ?");
			params.add(ficheroscontables.getInstitucion());
		}
		if (ficheroscontables != null && ficheroscontables.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(ficheroscontables.getEjercicio());
		}
		if (ficheroscontables != null && ficheroscontables.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(ficheroscontables.getSeccion());
		}
		if (ficheroscontables != null && ficheroscontables.getOrigenMaqueta() != null) {
			where.append(" AND t1.ORIGEN_MAQUETA = ?");
			params.add(ficheroscontables.getOrigenMaqueta());
		}
		if (ficheroscontables != null && ficheroscontables.getIdentificadorCinta() != null) {
			where.append(" AND t1.IDENTIFICADOR_CINTA = ?");
			params.add(ficheroscontables.getIdentificadorCinta());
		}
		if (ficheroscontables != null && ficheroscontables.getUsuario() != null) {
			where.append(" AND t1.USUARIO = ?");
			params.add(ficheroscontables.getUsuario());
		}
		if (ficheroscontables != null && ficheroscontables.getIdIdioma() != null) {
			where.append(" AND t1.ID_IDIOMA = ?");
			params.add(ficheroscontables.getIdIdioma());
		}
		if (ficheroscontables != null && ficheroscontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ficheroscontables.getFechaRegistro());
		}
		if (ficheroscontables != null && ficheroscontables.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ficheroscontables.getUsuarioRegistro());
		}
		if (ficheroscontables != null && ficheroscontables.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ficheroscontables.getFechaUltmodificacion());
		}
		if (ficheroscontables != null && ficheroscontables.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ficheroscontables.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the FicherosContables entity
	 *
	 * @param ficheroscontables
	 *            FicherosContables Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(FicherosContables ficheroscontables, Boolean startsWith) {

		StringBuilder where = new StringBuilder(FicherosContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ficheroscontables != null && ficheroscontables.getIdFicheroContable() != null) {
			where.append(" AND t1.ID_FICHERO_CONTABLE = ?");
			params.add(ficheroscontables.getIdFicheroContable());
		}
		if (ficheroscontables != null && ficheroscontables.getIdConvocatoria() != null) {
			where.append(" AND t1.ID_CONVOCATORIA = ?");
			params.add(ficheroscontables.getIdConvocatoria());
		}
		if (ficheroscontables != null && ficheroscontables.getNombreFichero() != null) {
			where.append(" AND UPPER(t1.NOMBRE_FICHERO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ficheroscontables.getNombreFichero().toUpperCase() + "%");
			} else {
				params.add("%" + ficheroscontables.getNombreFichero().toUpperCase() + "%");
			}
			where.append(" AND t1.NOMBRE_FICHERO IS NOT NULL");
		}
		if (ficheroscontables != null && ficheroscontables.getIdTipoDocCon() != null) {
			where.append(" AND t1.ID_TIPO_DOC_CON = ?");
			params.add(ficheroscontables.getIdTipoDocCon());
		}
		if (ficheroscontables != null && ficheroscontables.getEstado() != null) {
			where.append(" AND t1.ESTADO = ?");
			params.add(ficheroscontables.getEstado());
		}
		if (ficheroscontables != null && ficheroscontables.getTipoRegistro() != null) {
			where.append(" AND UPPER(t1.TIPO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ficheroscontables.getTipoRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ficheroscontables.getTipoRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.TIPO_REGISTRO IS NOT NULL");
		}
		if (ficheroscontables != null && ficheroscontables.getInstitucion() != null) {
			where.append(" AND t1.INSTITUCION = ?");
			params.add(ficheroscontables.getInstitucion());
		}
		if (ficheroscontables != null && ficheroscontables.getEjercicio() != null) {
			where.append(" AND t1.EJERCICIO = ?");
			params.add(ficheroscontables.getEjercicio());
		}
		if (ficheroscontables != null && ficheroscontables.getSeccion() != null) {
			where.append(" AND t1.SECCION = ?");
			params.add(ficheroscontables.getSeccion());
		}
		if (ficheroscontables != null && ficheroscontables.getOrigenMaqueta() != null) {
			where.append(" AND UPPER(t1.ORIGEN_MAQUETA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ficheroscontables.getOrigenMaqueta().toUpperCase() + "%");
			} else {
				params.add("%" + ficheroscontables.getOrigenMaqueta().toUpperCase() + "%");
			}
			where.append(" AND t1.ORIGEN_MAQUETA IS NOT NULL");
		}
		if (ficheroscontables != null && ficheroscontables.getIdentificadorCinta() != null) {
			where.append(" AND t1.IDENTIFICADOR_CINTA = ?");
			params.add(ficheroscontables.getIdentificadorCinta());
		}
		if (ficheroscontables != null && ficheroscontables.getUsuario() != null) {
			where.append(" AND UPPER(t1.USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ficheroscontables.getUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ficheroscontables.getUsuario().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO IS NOT NULL");
		}
		if (ficheroscontables != null && ficheroscontables.getIdIdioma() != null) {
			where.append(" AND t1.ID_IDIOMA = ?");
			params.add(ficheroscontables.getIdIdioma());
		}
		if (ficheroscontables != null && ficheroscontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ficheroscontables.getFechaRegistro());
		}
		if (ficheroscontables != null && ficheroscontables.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ficheroscontables.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ficheroscontables.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ficheroscontables != null && ficheroscontables.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ficheroscontables.getFechaUltmodificacion());
		}
		if (ficheroscontables != null && ficheroscontables.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ficheroscontables.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ficheroscontables.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
