package com.ejie.ab60.dao.moduloContable;

import com.ejie.ab60.model.moduloContable.TiposDocContables;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * TiposDocContablesDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposDocContablesDaoImpl implements TiposDocContablesDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPODOCCON", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposDocContables> rwMap = new RowMapper<TiposDocContables>() {
		public TiposDocContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposDocContables(resultSet.getLong("IDTIPODOCCON"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));
		}
	};

	private RowMapper<TiposDocContables> rwMapPK = new RowMapper<TiposDocContables>() {
		public TiposDocContables mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposDocContables(resultSet.getLong("IDTIPODOCCON"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposDocContables>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposDocContables>>() {
		public JerarquiaDto<TiposDocContables> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposDocContables tiposdoccontables = new TiposDocContables(resultSet.getLong("IDTIPODOCCON"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"));

			JerarquiaDto<TiposDocContables> jerarquia = new JerarquiaDto<TiposDocContables>();
			jerarquia.setModel(tiposdoccontables);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposDocContables table.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @return TiposDocContables
	 */
	public TiposDocContables add(TiposDocContables tiposdoccontables) {
		String query = "INSERT INTO TIPOS_DOC_CON (ID_TIPO_DOC_CON, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, tiposdoccontables.getIdTipoDocCon(),
				tiposdoccontables.getDescripcionCastellano(), tiposdoccontables.getDescripcionEuskera(),
				tiposdoccontables.getFechaRegistro(), tiposdoccontables.getUsuarioRegistro());
		return tiposdoccontables;
	}

	/**
	 * Updates a single row in the TiposDocContables table.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @return TiposDocContables
	 */
	public TiposDocContables update(TiposDocContables tiposdoccontables) {
		String query = "UPDATE TIPOS_DOC_CON SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_TIPO_DOC_CON=?";
		this.jdbcTemplate.update(query, tiposdoccontables.getDescripcionCastellano(),
				tiposdoccontables.getDescripcionEuskera(), tiposdoccontables.getFechaRegistro(),
				tiposdoccontables.getUsuarioRegistro(), tiposdoccontables.getIdTipoDocCon());
		return tiposdoccontables;
	}

	/**
	 * Finds a single row in the TiposDocContables table.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @return TiposDocContables
	 */
	@Transactional(readOnly = true)
	public TiposDocContables find(TiposDocContables tiposdoccontables) {
		String query = "SELECT t1.ID_TIPO_DOC_CON IDTIPODOCCON, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM TIPOS_DOC_CON t1  WHERE t1.ID_TIPO_DOC_CON = ?  ";

		List<TiposDocContables> tiposdoccontablesList = this.jdbcTemplate.query(query, this.rwMap,
				tiposdoccontables.getIdTipoDocCon());
		return (TiposDocContables) DataAccessUtils.uniqueResult(tiposdoccontablesList);
	}

	/**
	 * Removes a single row in the TiposDocContables table.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @return
	 */
	public void remove(TiposDocContables tiposdoccontables) {
		String query = "DELETE FROM TIPOS_DOC_CON WHERE ID_TIPO_DOC_CON=?";
		this.jdbcTemplate.update(query, tiposdoccontables.getIdTipoDocCon());
	}

	/**
	 * Finds a list of rows in the TiposDocContables table.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposDocContables>
	 */
	@Transactional(readOnly = true)
	public List<TiposDocContables> findAll(TiposDocContables tiposdoccontables, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_DOC_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposdoccontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposDocContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposDocContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposDocContables table using like.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposDocContables>
	 */
	@Transactional(readOnly = true)
	public List<TiposDocContables> findAllLike(TiposDocContables tiposdoccontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_DOC_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposdoccontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposDocContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposDocContables>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposDocContables table.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposDocContables tiposdoccontables) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_DOC_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposdoccontables);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposDocContables table using like.
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposDocContables tiposdoccontables, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM TIPOS_DOC_CON t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposdoccontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposDocContables selected for rup_table
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposDocContables>>
	 */
	@Override
	public List<TableRowDto<TiposDocContables>> reorderSelection(TiposDocContables tiposdoccontables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_DOC_CON t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tiposdoccontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				TiposDocContables.class, filterParamList, "ID_TIPO_DOC_CON");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposDocContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposDocContables
	 * @param searchParams
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposDocContables>>
	 */
	@Override
	public List<TableRowDto<TiposDocContables>> search(TiposDocContables filterParams, TiposDocContables searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_DOC_CON t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				TiposDocContables.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_TIPO_DOC_CON");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposDocContables>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertiposdoccontables
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposDocContables filtertiposdoccontables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM TIPOS_DOC_CON t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertiposdoccontables, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				TiposDocContables.class, query, params, "ID_TIPO_DOC_CON");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposDocContables table.
	 *
	 * @param filterTiposDocContables
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposDocContables>>
	 */
	@Override
	public List<JerarquiaDto<TiposDocContables>> findAllLikeJerarquia(TiposDocContables filterTiposDocContables,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_DOC_CON IDTIPODOCCON,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_DOC_CON t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_DOC_CON");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposDocContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_DOC_CON", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposDocContablesDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposDocContables
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposDocContables filterTiposDocContables,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_DOC_CON t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_DOC_CON");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposDocContables, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_DOC_CON",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposDocContables
	 *            TiposDocContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposDocContables>>
	 */
	@Override
	public List<TableRowDto<TiposDocContables>> findAllChild(TiposDocContables filterTiposDocContables,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM TIPOS_DOC_CON t1 ");
		List<String> from = new ArrayList<String>();
		from.add("TIPOS_DOC_CON");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposDocContables, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_TIPO_DOC_CON",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposDocContables>(this.rwMapPK, "ID_TIPO_DOC_CON"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposDocContables entity
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposDocContables tiposdoccontables) {

		StringBuilder where = new StringBuilder(TiposDocContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposdoccontables != null && tiposdoccontables.getIdTipoDocCon() != null) {
			where.append(" AND t1.ID_TIPO_DOC_CON = ?");
			params.add(tiposdoccontables.getIdTipoDocCon());
		}
		if (tiposdoccontables != null && tiposdoccontables.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposdoccontables.getDescripcionCastellano());
		}
		if (tiposdoccontables != null && tiposdoccontables.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposdoccontables.getDescripcionEuskera());
		}
		if (tiposdoccontables != null && tiposdoccontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposdoccontables.getFechaRegistro());
		}
		if (tiposdoccontables != null && tiposdoccontables.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposdoccontables.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposDocContables entity
	 *
	 * @param tiposdoccontables
	 *            TiposDocContables Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposDocContables tiposdoccontables, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposDocContablesDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposdoccontables != null && tiposdoccontables.getIdTipoDocCon() != null) {
			where.append(" AND t1.ID_TIPO_DOC_CON = ?");
			params.add(tiposdoccontables.getIdTipoDocCon());
		}
		if (tiposdoccontables != null && tiposdoccontables.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposdoccontables.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tiposdoccontables.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tiposdoccontables != null && tiposdoccontables.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposdoccontables.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tiposdoccontables.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tiposdoccontables != null && tiposdoccontables.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposdoccontables.getFechaRegistro());
		}
		if (tiposdoccontables != null && tiposdoccontables.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tiposdoccontables.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tiposdoccontables.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
