package com.ejie.ab60.dao.pagos;

import java.util.List;

import com.ejie.ab60.model.pagos.PagosConvocatoria;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PagosConvocatoriaDao  
 * 
 *  
 */

public interface PagosConvocatoriaDao {

	/**
	 * Inserts a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	PagosConvocatoria add(PagosConvocatoria pagosconvocatoria);

	/**
	 * Updates a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	PagosConvocatoria update(PagosConvocatoria pagosconvocatoria);

	/**
	 * Finds a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	PagosConvocatoria find(PagosConvocatoria pagosconvocatoria);

	/**
	 * Removes a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 */
	void remove(PagosConvocatoria pagosconvocatoria);

	/**
	 * Finds a List of rows in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<PagosConvocatoria> findAll(PagosConvocatoria pagosconvocatoria, JQGridRequestDto jqGridRequestDto);

	List<PagosConvocatoria> findAllPagos(PagosConvocatoria pagosconvocatoria, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the PagosConvocatoria table using like.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<PagosConvocatoria> findAllLike(PagosConvocatoria pagosconvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(PagosConvocatoria filterPagosConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Counts rows in the PagosConvocatoria table using like.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(PagosConvocatoria pagosconvocatoria, Boolean startsWith);

	/**
	 * Counts rows in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return Long
	 */
	Long findAllCount(PagosConvocatoria pagosconvocatoria);

	/**
	 * Reorder selection.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PagosConvocatoria>>
	 */
	List<TableRowDto<PagosConvocatoria>> reorderSelection(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param searchPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PagosConvocatoria>>
	 */
	List<TableRowDto<PagosConvocatoria>> search(PagosConvocatoria filterPagosConvocatoria,
			PagosConvocatoria searchPagosConvocatoria, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<PagosConvocatoria>>
	 */
	List<JerarquiaDto<PagosConvocatoria>> findAllLikeJerarquia(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(PagosConvocatoria filterPagosConvocatoria, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<PagosConvocatoria>>
	 */
	List<TableRowDto<PagosConvocatoria>> findAllChild(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto);

}
