package com.ejie.ab60.dao.pagos;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.ab60.model.pagos.PagosConvocatoria;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PagosConvocatoriaDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PagosConvocatoriaDaoImpl implements PagosConvocatoriaDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPAGOCONVOCATORIA", "NUMEROPAGO",
			"PORCENTAJEPAGO", "ANYOPRESUPUESTO", "OBSERVACIONES", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUULTMODIFICACION", "IDCONVOCATORIA", "IDPROCEDIMIENTO", "CONVOCATORIA",
			"CONVOFECHASOLUCION", "CONVOIMPORTE", "CONVOPORCENTAJESUB", "MAXSUBVENCION", "CONVOPLSQLCALCULO",
			"CONVOPLSQLREPARTO", "CONVOOBSERVACIONES", "CONVOIMPORTEMIN", "CONVOFECHAORDENDIA", "CONVOFECHAREGISTRO",
			"CONVOUSUREGISTRO", "CONVOFECHAULTMODIF", "CONVOUSUULTMODIF", "CONVOLIMITELOCAL", "IDTIPOCONVO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<PagosConvocatoria> rwMap = new RowMapper<PagosConvocatoria>() {
		public PagosConvocatoria mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PagosConvocatoria(resultSet.getInt("IDPAGOCONVOCATORIA"), resultSet.getLong("NUMEROPAGO"),
					resultSet.getBigDecimal("PORCENTAJEPAGO"), resultSet.getLong("ANYOPRESUPUESTO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUULTMODIFICACION"),
					new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getInt("IDPROCEDIMIENTO"),
							resultSet.getString("CONVOCATORIA"), resultSet.getDate("CONVOFECHARESOLUCION"),
							resultSet.getBigDecimal("CONVOIMPORTE"), resultSet.getBigDecimal("CONVOPORCENTAJESUB"),
							resultSet.getBigDecimal("MAXSUBVENCION"), resultSet.getString("CONVOPLSQLCALCULO"),
							resultSet.getString("CONVOPLSQLREPARTO"), resultSet.getString("CONVOOBSERVACIONES"),
							resultSet.getDate("CONVOFECHAORDENDIA"), resultSet.getDate("CONVOFECHAREGISTRO"),
							resultSet.getString("CONVOUSUREGISTRO"), resultSet.getDate("CONVOFECHAULTMODIF"),
							resultSet.getString("CONVOUSUULTMODIF"), resultSet.getBigDecimal("CONVOLIMITELOCAL"),
							new TiposConvocatoria(resultSet.getLong("IDTIPOCONVO"))));
		}
	};

	private RowMapper<PagosConvocatoria> rwMapPagos = new RowMapper<PagosConvocatoria>() {
		public PagosConvocatoria mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PagosConvocatoria(resultSet.getInt("IDPAGOCONVOCATORIA"), resultSet.getLong("NUMEROPAGO"));
		}
	};

	private RowMapper<PagosConvocatoria> rwMapPK = new RowMapper<PagosConvocatoria>() {
		public PagosConvocatoria mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PagosConvocatoria(resultSet.getInt("IDPAGOCONVOCATORIA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<PagosConvocatoria>> rwMapJerarquia = new RowMapper<JerarquiaDto<PagosConvocatoria>>() {
		public JerarquiaDto<PagosConvocatoria> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			PagosConvocatoria pagosconvocatoria = new PagosConvocatoria(resultSet.getInt("IDPAGOCONVOCATORIA"),
					resultSet.getLong("NUMEROPAGO"), resultSet.getBigDecimal("PORCENTAJEPAGO"),
					resultSet.getLong("ANYOPRESUPUESTO"), resultSet.getString("OBSERVACIONES"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUULTMODIFICACION"),
					new Convocatorias(resultSet.getInt("IDCONVOCATORIA"), resultSet.getInt("IDPROCEDIMIENTO"),
							resultSet.getString("CONVOCATORIA"), resultSet.getDate("CONVOFECHARESOLUCION"),
							resultSet.getBigDecimal("CONVOIMPORTE"), resultSet.getBigDecimal("CONVOPORCENTAJESUB"),
							resultSet.getBigDecimal("MAXSUBVENCION"), resultSet.getString("CONVOPLSQLCALCULO"),
							resultSet.getString("CONVOPLSQLREPARTO"), resultSet.getString("CONVOOBSERVACIONES"),
							resultSet.getDate("CONVOFECHAORDENDIA"), resultSet.getDate("CONVOFECHAREGISTRO"),
							resultSet.getString("CONVOUSUREGISTRO"), resultSet.getDate("CONVOFECHAULTMODIF"),
							resultSet.getString("CONVOUSUULTMODIF"), resultSet.getBigDecimal("CONVOLIMITELOCAL"),
							new TiposConvocatoria(resultSet.getLong("IDTIPOCONVO"), null, null, null, null, null)));

			JerarquiaDto<PagosConvocatoria> jerarquia = new JerarquiaDto<PagosConvocatoria>();
			jerarquia.setModel(pagosconvocatoria);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	public PagosConvocatoria add(PagosConvocatoria pagosconvocatoria) {
		String query = "INSERT INTO PAGOS_CONVOCATORIA (ID_PAGO_CONVOCATORIA, ID_CONVOCATORIA, NUMERO_PAGO, PORCENTAJE_PAGO, ANYO_PRESUPUESTO, OBSERVACIONES, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?)";
		Object getConvocatoriasIdConvocatoriaAux = null;
		if (pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getIdConvocatoria() != null) {
			getConvocatoriasIdConvocatoriaAux = pagosconvocatoria.getConvocatorias().getIdConvocatoria();
		}
		this.jdbcTemplate.update(query, pagosconvocatoria.getIdPagoConvocatoria(), getConvocatoriasIdConvocatoriaAux,
				pagosconvocatoria.getNumeroPago(), pagosconvocatoria.getPorcentajePago(),
				pagosconvocatoria.getAnyoPresupuesto(), pagosconvocatoria.getObservaciones(),
				pagosconvocatoria.getFechaRegistro(), pagosconvocatoria.getUsuarioRegistro(),
				pagosconvocatoria.getFechaUltmodificacion(), pagosconvocatoria.getUsuarioUltmodificacion());
		return pagosconvocatoria;
	}

	/**
	 * Updates a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	public PagosConvocatoria update(PagosConvocatoria pagosconvocatoria) {
		String query = "UPDATE PAGOS_CONVOCATORIA SET ID_CONVOCATORIA=?, NUMERO_PAGO=?, PORCENTAJE_PAGO=?, ANYO_PRESUPUESTO=?, OBSERVACIONES=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PAGO_CONVOCATORIA=?";
		Object getConvocatoriasIdConvocatoriaAux = null;
		if (pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getIdConvocatoria() != null) {
			getConvocatoriasIdConvocatoriaAux = pagosconvocatoria.getConvocatorias().getIdConvocatoria();
		}
		this.jdbcTemplate.update(query, getConvocatoriasIdConvocatoriaAux, pagosconvocatoria.getNumeroPago(),
				pagosconvocatoria.getPorcentajePago(), pagosconvocatoria.getAnyoPresupuesto(),
				pagosconvocatoria.getObservaciones(), pagosconvocatoria.getFechaRegistro(),
				pagosconvocatoria.getUsuarioRegistro(), pagosconvocatoria.getFechaUltmodificacion(),
				pagosconvocatoria.getUsuarioUltmodificacion(), pagosconvocatoria.getIdPagoConvocatoria());
		return pagosconvocatoria;
	}

	/**
	 * Finds a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */

	@Transactional(readOnly = true)
	public PagosConvocatoria find(PagosConvocatoria pagosconvocatoria) {
		String query = "SELECT t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA, t1.NUMERO_PAGO NUMEROPAGO, t1.PORCENTAJE_PAGO PORCENTAJEPAGO, t1.ANYO_PRESUPUESTO ANYOPRESUPUESTO, t1.OBSERVACIONES OBSERVACIONES, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUULTMODIFICACION, t2.ID_CONVOCATORIA IDCONVOCATORIA, t2.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t2.CONVOCATORIA CONVOCATORIA, t2.FECHA_RESOLUCION CONVOFECHARESOLUCION, t2.IMPORTE CONVOIMPORTE, t2.PORCENTAJE_SUBVENCION CONVOPORCENTAJESUB, t2.CANT_MAX_SUBVENCION MAXSUBVENCION, t2.PLSQL_CALCULO CONVOPLSQLCALCULO, t2.PLSQL_REPARTO CONVOPLSQLREPARTO, t2.OBSERVACIONES CONVOOBSERVACIONES, t2.FECHA_ORDEN_DIA CONVOFECHAORDENDIA, t2.FECHA_REGISTRO CONVOFECHAREGISTRO, t2.USUARIO_REGISTRO CONVOUSUREGISTRO, t2.FECHA_ULTMODIFICACION CONVOFECHAULTMODIF, t2.USUARIO_ULTMODIFICACION CONVOUSUULTMODIF, t2.LIMITE_AT CONVOLIMITELOCAL, t2.ID_TIPO_CONVOCATORIA IDTIPOCONVO FROM PAGOS_CONVOCATORIA t1 , CONVOCATORIAS t2  WHERE t1.ID_PAGO_CONVOCATORIA = ?   AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+)";

		List<PagosConvocatoria> pagosconvocatoriaList = this.jdbcTemplate.query(query, this.rwMap,
				pagosconvocatoria.getIdPagoConvocatoria());
		return (PagosConvocatoria) DataAccessUtils.uniqueResult(pagosconvocatoriaList);
	}

	/**
	 * Removes a single row in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return
	 */
	public void remove(PagosConvocatoria pagosconvocatoria) {
		String query = "DELETE FROM PAGOS_CONVOCATORIA WHERE ID_PAGO_CONVOCATORIA=?";
		this.jdbcTemplate.update(query, pagosconvocatoria.getIdPagoConvocatoria());
	}

	/**
	 * Finds a list of rows in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PagosConvocatoria>
	 */
	@Transactional(readOnly = true)
	public List<PagosConvocatoria> findAll(PagosConvocatoria pagosconvocatoria, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.ANYO_PRESUPUESTO ANYOPRESUPUESTO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUULTMODIFICACION,t2.ID_CONVOCATORIA IDCONVOCATORIA,t2.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIA,t2.FECHA_RESOLUCION CONVOFECHARESOLUCION,t2.IMPORTE CONVOIMPORTE,t2.PORCENTAJE_SUBVENCION CONVOPORCENTAJESUB,t2.CANT_MAX_SUBVENCION MAXSUBVENCION,t2.PLSQL_CALCULO CONVOPLSQLCALCULO,t2.PLSQL_REPARTO CONVOPLSQLREPARTO,t2.OBSERVACIONES CONVOOBSERVACIONES,t2.IMPORTE_MINIMO_INVERSION CONVOIMPORTEMIN,t2.FECHA_ORDEN_DIA CONVOFECHAORDENDIA,t2.FECHA_REGISTRO CONVOFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOUSUREGISTRO,t2.FECHA_ULTMODIFICACION CONVOFECHAULTMODIF,t2.USUARIO_ULTMODIFICACION CONVOUSUULTMODIF,t2.LIMITE_AT CONVOLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA IDTIPOCONVO ");
		query.append("FROM PAGOS_CONVOCATORIA t1 ,CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(pagosconvocatoria);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PagosConvocatoriaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PagosConvocatoria>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	@Transactional(readOnly = true)
	public List<PagosConvocatoria> findAllPagos(PagosConvocatoria pagosconvocatoria,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.NUMERO_PAGO NUMEROPAGO ");
		query.append("FROM PAGOS_CONVOCATORIA t1, CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(pagosconvocatoria);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PagosConvocatoriaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PagosConvocatoria>) this.jdbcTemplate.query(query.toString(), this.rwMapPagos, params.toArray());
	}

	/**
	 * Finds rows in the PagosConvocatoria table using like.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PagosConvocatoria>
	 */
	@Transactional(readOnly = true)
	public List<PagosConvocatoria> findAllLike(PagosConvocatoria pagosconvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.ANYO_PRESUPUESTO ANYOPRESUPUESTO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUULTMODIFICACION,t2.ID_CONVOCATORIA IDCONVOCATORIA,t2.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIA,t2.FECHA_RESOLUCION CONVOFECHARESOLUCION,t2.IMPORTE CONVOIMPORTE,t2.PORCENTAJE_SUBVENCION CONVOPORCENTAJESUB,t2.CANT_MAX_SUBVENCION MAXSUBVENCION,t2.PLSQL_CALCULO CONVOPLSQLCALCULO,t2.PLSQL_REPARTO CONVOPLSQLREPARTO,t2.OBSERVACIONES CONVOOBSERVACIONES,t2.IMPORTE_MINIMO_INVERSION CONVOIMPORTEMIN,t2.FECHA_ORDEN_DIA CONVOFECHAORDENDIA,t2.FECHA_REGISTRO CONVOFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOUSUREGISTRO,t2.FECHA_ULTMODIFICACION CONVOFECHAULTMODIF,t2.USUARIO_ULTMODIFICACION CONVOUSUULTMODIF,t2.LIMITE_AT CONVOLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA IDTIPOCONVO ");
		query.append("FROM PAGOS_CONVOCATORIA t1 ,CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pagosconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PagosConvocatoriaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PagosConvocatoria>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the PagosConvocatoria table.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(PagosConvocatoria pagosconvocatoria) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PAGOS_CONVOCATORIA t1 , CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(pagosconvocatoria);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the PagosConvocatoria table using like.
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(PagosConvocatoria pagosconvocatoria, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PAGOS_CONVOCATORIA t1 ,CONVOCATORIAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pagosconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of PagosConvocatoria selected for rup_table
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PagosConvocatoria>>
	 */
	@Override
	public List<TableRowDto<PagosConvocatoria>> reorderSelection(PagosConvocatoria pagosconvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.ANYO_PRESUPUESTO ANYOPRESUPUESTO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUULTMODIFICACION,t2.ID_CONVOCATORIA IDCONVOCATORIA,t2.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIA,t2.FECHA_RESOLUCION CONVOFECHARESOLUCION,t2.IMPORTE CONVOIMPORTE,t2.PORCENTAJE_SUBVENCION CONVOPORCENTAJESUB,t2.CANT_MAX_SUBVENCION MAXSUBVENCION,t2.PLSQL_CALCULO CONVOPLSQLCALCULO,t2.PLSQL_REPARTO CONVOPLSQLREPARTO,t2.OBSERVACIONES CONVOOBSERVACIONES,t2.IMPORTE_MINIMO_INVERSION CONVOIMPORTEMIN,t2.FECHA_ORDEN_DIA CONVOFECHAORDENDIA,t2.FECHA_REGISTRO CONVOFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOUSUREGISTRO,t2.FECHA_ULTMODIFICACION CONVOFECHAULTMODIF,t2.USUARIO_ULTMODIFICACION CONVOUSUULTMODIF,t2.LIMITE_AT CONVOLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA IDTIPOCONVO ");
		// FROM
		query.append("FROM PAGOS_CONVOCATORIA t1 ,CONVOCATORIAS t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pagosconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				PagosConvocatoria.class, filterParamList, "ID_PAGO_CONVOCATORIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PagosConvocatoria>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            PagosConvocatoria
	 * @param searchParams
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PagosConvocatoria>>
	 */
	@Override
	public List<TableRowDto<PagosConvocatoria>> search(PagosConvocatoria filterParams, PagosConvocatoria searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.ANYO_PRESUPUESTO ANYOPRESUPUESTO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUULTMODIFICACION,t2.ID_CONVOCATORIA IDCONVOCATORIA,t2.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIA,t2.FECHA_RESOLUCION CONVOFECHARESOLUCION,t2.IMPORTE CONVOIMPORTE,t2.PORCENTAJE_SUBVENCION CONVOPORCENTAJESUB,t2.CANT_MAX_SUBVENCION MAXSUBVENCION,t2.PLSQL_CALCULO CONVOPLSQLCALCULO,t2.PLSQL_REPARTO CONVOPLSQLREPARTO,t2.OBSERVACIONES CONVOOBSERVACIONES,t2.IMPORTE_MINIMO_INVERSION CONVOIMPORTEMIN,t2.FECHA_ORDEN_DIA CONVOFECHAORDENDIA,t2.FECHA_REGISTRO CONVOFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOUSUREGISTRO,t2.FECHA_ULTMODIFICACION CONVOFECHAULTMODIF,t2.USUARIO_ULTMODIFICACION CONVOUSUULTMODIF,t2.LIMITE_AT CONVOLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA IDTIPOCONVO ");
		// FROM
		query.append("FROM PAGOS_CONVOCATORIA t1 ,CONVOCATORIAS t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_CONVOCATORIA= t2.ID_CONVOCATORIA(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				PagosConvocatoria.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_PAGO_CONVOCATORIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PagosConvocatoria>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterpagosconvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(PagosConvocatoria filterpagosconvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.ANYO_PRESUPUESTO ANYOPRESUPUESTO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUULTMODIFICACION,t2.ID_CONVOCATORIA IDCONVOCATORIA,t2.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIA,t2.FECHA_RESOLUCION CONVOFECHARESOLUCION,t2.IMPORTE CONVOIMPORTE,t2.PORCENTAJE_SUBVENCION CONVOPORCENTAJESUB,t2.CANT_MAX_SUBVENCION MAXSUBVENCION,t2.PLSQL_CALCULO CONVOPLSQLCALCULO,t2.PLSQL_REPARTO CONVOPLSQLREPARTO,t2.OBSERVACIONES CONVOOBSERVACIONES,t2.IMPORTE_MINIMO_INVERSION CONVOIMPORTEMIN,t2.FECHA_ORDEN_DIA CONVOFECHAORDENDIA,t2.FECHA_REGISTRO CONVOFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOUSUREGISTRO,t2.FECHA_ULTMODIFICACION CONVOFECHAULTMODIF,t2.USUARIO_ULTMODIFICACION CONVOUSUULTMODIF,t2.LIMITE_AT CONVOLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA IDTIPOCONVO ");
		// FROM
		query.append("FROM PAGOS_CONVOCATORIA t1 ,CONVOCATORIAS t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterpagosconvocatoria, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				PagosConvocatoria.class, query, params, "ID_PAGO_CONVOCATORIA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<PagosConvocatoria>>
	 */
	@Override
	public List<JerarquiaDto<PagosConvocatoria>> findAllLikeJerarquia(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_CONVOCATORIA IDPAGOCONVOCATORIA,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.ANYO_PRESUPUESTO ANYOPRESUPUESTO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUULTMODIFICACION,t2.ID_CONVOCATORIA IDCONVOCATORIA,t2.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t2.CONVOCATORIA CONVOCATORIA,t2.FECHA_RESOLUCION CONVOFECHARESOLUCION,t2.IMPORTE CONVOIMPORTE,t2.PORCENTAJE_SUBVENCION CONVOPORCENTAJESUB,t2.CANT_MAX_SUBVENCION MAXSUBVENCION,t2.PLSQL_CALCULO CONVOPLSQLCALCULO,t2.PLSQL_REPARTO CONVOPLSQLREPARTO,t2.OBSERVACIONES CONVOOBSERVACIONES,t2.IMPORTE_MINIMO_INVERSION CONVOIMPORTEMIN,t2.FECHA_ORDEN_DIA CONVOFECHAORDENDIA,t2.FECHA_REGISTRO CONVOFECHAREGISTRO,t2.USUARIO_REGISTRO CONVOUSUREGISTRO,t2.FECHA_ULTMODIFICACION CONVOFECHAULTMODIF,t2.USUARIO_ULTMODIFICACION CONVOUSUULTMODIF,t2.LIMITE_AT CONVOLIMITELOCAL,t2.ID_TIPO_CONVOCATORIA IDTIPOCONVO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PAGOS_CONVOCATORIA t1
		// ,CONVOCATORIAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("PAGOS_CONVOCATORIA");
		from.add("CONVOCATORIAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPagosConvocatoria, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PAGO_CONVOCATORIA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					PagosConvocatoriaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PAGOS_CONVOCATORIA t1
		// ,CONVOCATORIAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("PAGOS_CONVOCATORIA");
		from.add("CONVOCATORIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPagosConvocatoria, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PAGO_CONVOCATORIA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<PagosConvocatoria>>
	 */
	@Override
	public List<TableRowDto<PagosConvocatoria>> findAllChild(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PAGOS_CONVOCATORIA t1
		// ,CONVOCATORIAS t2 ");
		List<String> from = new ArrayList<String>();
		from.add("PAGOS_CONVOCATORIA");
		from.add("CONVOCATORIAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPagosConvocatoria, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_PAGO_CONVOCATORIA", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<PagosConvocatoria>(this.rwMapPK, "ID_PAGO_CONVOCATORIA"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PagosConvocatoria entity
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(PagosConvocatoria pagosconvocatoria) {

		StringBuilder where = new StringBuilder(PagosConvocatoriaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (pagosconvocatoria != null && pagosconvocatoria.getIdPagoConvocatoria() != null) {
			where.append(" AND t1.ID_PAGO_CONVOCATORIA = ?");
			params.add(pagosconvocatoria.getIdPagoConvocatoria());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(pagosconvocatoria.getConvocatorias().getIdConvocatoria());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getTiposConvocatoria() != null
				&& pagosconvocatoria.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t2.ID_TIPO_CONVOCATORIA = ?");
			params.add(pagosconvocatoria.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getIdProcedimiento() != null) {
			where.append(" AND t2.ID_PROCEDIMIENTO = ?");
			params.add(pagosconvocatoria.getConvocatorias().getIdProcedimiento());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getConvocatoria() != null) {
			where.append(" AND t2.CONVOCATORIA = ?");
			params.add(pagosconvocatoria.getConvocatorias().getConvocatoria());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaResolucion() != null) {
			where.append(" AND t2.FECHA_RESOLUCION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaResolucion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getImporte() != null) {
			where.append(" AND t2.IMPORTE = ?");
			params.add(pagosconvocatoria.getConvocatorias().getImporte());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getPorcentajeSubvencion() != null) {
			where.append(" AND t2.PORCENTAJE_SUBVENCION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getPorcentajeSubvencion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getCantMaxSubvencion() != null) {
			where.append(" AND t2.CANT_MAX_SUBVENCION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getCantMaxSubvencion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getPlsqlCalculo() != null) {
			where.append(" AND t2.PLSQL_CALCULO = ?");
			params.add(pagosconvocatoria.getConvocatorias().getPlsqlCalculo());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getPlsqlReparto() != null) {
			where.append(" AND t2.PLSQL_REPARTO = ?");
			params.add(pagosconvocatoria.getConvocatorias().getPlsqlReparto());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getObservaciones() != null) {
			where.append(" AND t2.OBSERVACIONES = ?");
			params.add(pagosconvocatoria.getConvocatorias().getObservaciones());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaOrdenDia() != null) {
			where.append(" AND t2.FECHA_ORDEN_DIA = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaOrdenDia());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaRegistro());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(pagosconvocatoria.getConvocatorias().getUsuarioRegistro());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaUltmodificacion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getUsuarioUltmodificacion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getLimiteLocal() != null) {
			where.append(" AND t2.LIMITE_AT = ?");
			params.add(pagosconvocatoria.getConvocatorias().getLimiteLocal());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getNumeroPago() != null) {
			where.append(" AND t1.NUMERO_PAGO = ?");
			params.add(pagosconvocatoria.getNumeroPago());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getPorcentajePago() != null) {
			where.append(" AND t1.PORCENTAJE_PAGO = ?");
			params.add(pagosconvocatoria.getPorcentajePago());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getAnyoPresupuesto() != null) {
			where.append(" AND t1.ANYO_PRESUPUESTO = ?");
			params.add(pagosconvocatoria.getAnyoPresupuesto());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getObservaciones() != null) {
			where.append(" AND t1.OBSERVACIONES = ?");
			params.add(pagosconvocatoria.getObservaciones());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(pagosconvocatoria.getFechaRegistro());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(pagosconvocatoria.getUsuarioRegistro());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(pagosconvocatoria.getFechaUltmodificacion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(pagosconvocatoria.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PagosConvocatoria entity
	 *
	 * @param pagosconvocatoria
	 *            PagosConvocatoria Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(PagosConvocatoria pagosconvocatoria, Boolean startsWith) {

		StringBuilder where = new StringBuilder(PagosConvocatoriaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (pagosconvocatoria != null && pagosconvocatoria.getIdPagoConvocatoria() != null) {
			where.append(" AND t1.ID_PAGO_CONVOCATORIA = ?");
			params.add(pagosconvocatoria.getIdPagoConvocatoria());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(pagosconvocatoria.getConvocatorias().getIdConvocatoria());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getTiposConvocatoria() != null
				&& pagosconvocatoria.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria() != null) {
			where.append(" AND t2.ID_TIPO_CONVOCATORIA = ?");
			params.add(pagosconvocatoria.getConvocatorias().getTiposConvocatoria().getIdTipoConvocatoria());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getIdProcedimiento() != null) {
			where.append(" AND t2.ID_PROCEDIMIENTO = ?");
			params.add(pagosconvocatoria.getConvocatorias().getIdProcedimiento());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getConvocatoria() != null) {
			where.append(" AND UPPER(t2.CONVOCATORIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getConvocatorias().getConvocatoria().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getConvocatorias().getConvocatoria().toUpperCase() + "%");
			}
			where.append(" AND t2.CONVOCATORIA IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaResolucion() != null) {
			where.append(" AND t2.FECHA_RESOLUCION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaResolucion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getImporte() != null) {
			where.append(" AND t2.IMPORTE = ?");
			params.add(pagosconvocatoria.getConvocatorias().getImporte());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getPorcentajeSubvencion() != null) {
			where.append(" AND t2.PORCENTAJE_SUBVENCION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getPorcentajeSubvencion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getCantMaxSubvencion() != null) {
			where.append(" AND t2.CANT_MAX_SUBVENCION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getCantMaxSubvencion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getPlsqlCalculo() != null) {
			where.append(" AND UPPER(t2.PLSQL_CALCULO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getConvocatorias().getPlsqlCalculo().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getConvocatorias().getPlsqlCalculo().toUpperCase() + "%");
			}
			where.append(" AND t2.PLSQL_CALCULO IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getPlsqlReparto() != null) {
			where.append(" AND UPPER(t2.PLSQL_REPARTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getConvocatorias().getPlsqlReparto().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getConvocatorias().getPlsqlReparto().toUpperCase() + "%");
			}
			where.append(" AND t2.PLSQL_REPARTO IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getObservaciones() != null) {
			where.append(" AND UPPER(t2.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getConvocatorias().getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getConvocatorias().getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t2.OBSERVACIONES IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaOrdenDia() != null) {
			where.append(" AND t2.FECHA_ORDEN_DIA = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaOrdenDia());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaRegistro());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getConvocatorias().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getConvocatorias().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(pagosconvocatoria.getConvocatorias().getFechaUltmodificacion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getConvocatorias().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getConvocatorias().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getConvocatorias() != null
				&& pagosconvocatoria.getConvocatorias().getLimiteLocal() != null) {
			where.append(" AND t2.LIMITE_AT = ?");
			params.add(pagosconvocatoria.getConvocatorias().getLimiteLocal());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getNumeroPago() != null) {
			where.append(" AND t1.NUMERO_PAGO = ?");
			params.add(pagosconvocatoria.getNumeroPago());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getPorcentajePago() != null) {
			where.append(" AND t1.PORCENTAJE_PAGO = ?");
			params.add(pagosconvocatoria.getPorcentajePago());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getAnyoPresupuesto() != null) {
			where.append(" AND t1.ANYO_PRESUPUESTO = ?");
			params.add(pagosconvocatoria.getAnyoPresupuesto());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getObservaciones() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(pagosconvocatoria.getFechaRegistro());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(pagosconvocatoria.getFechaUltmodificacion());
		}
		if (pagosconvocatoria != null && pagosconvocatoria.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosconvocatoria.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + pagosconvocatoria.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
