package com.ejie.ab60.dao.plantillas;

import com.ejie.ab60.model.plantillas.CamposPlantilla;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * CamposPlantillaDao  
 * 
 *  
 */

public interface CamposPlantillaDao {

	/**
	 * Inserts a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return CamposPlantilla
	 */
	CamposPlantilla add(CamposPlantilla camposplantilla);

	/**
	 * Updates a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return CamposPlantilla
	 */
	CamposPlantilla update(CamposPlantilla camposplantilla);

	/**
	 * Finds a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return CamposPlantilla
	 */
	CamposPlantilla find(CamposPlantilla camposplantilla);

	/**
	 * Removes a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 */
	void remove(CamposPlantilla camposplantilla);

	/**
	 * Finds a List of rows in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<CamposPlantilla> findAll(CamposPlantilla camposplantilla, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the CamposPlantilla table using like.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<CamposPlantilla> findAllLike(CamposPlantilla camposplantilla, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the CamposPlantilla table.
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(CamposPlantilla filterCamposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the CamposPlantilla table using like.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(CamposPlantilla camposplantilla, Boolean startsWith);

	/**
	 * Counts rows in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return Long
	 */
	Long findAllCount(CamposPlantilla camposplantilla);

	/**
	 * Reorder selection.
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<CamposPlantilla>>
	 */
	List<TableRowDto<CamposPlantilla>> reorderSelection(CamposPlantilla filterCamposPlantilla,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param searchCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<CamposPlantilla>>
	 */
	List<TableRowDto<CamposPlantilla>> search(CamposPlantilla filterCamposPlantilla,
			CamposPlantilla searchCamposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical CamposPlantilla table.
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<CamposPlantilla>>
	 */
	List<JerarquiaDto<CamposPlantilla>> findAllLikeJerarquia(CamposPlantilla filterCamposPlantilla,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(CamposPlantilla filterCamposPlantilla, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<CamposPlantilla>>
	 */
	List<TableRowDto<CamposPlantilla>> findAllChild(CamposPlantilla filterCamposPlantilla,
			JQGridRequestDto jqGridRequestDto);

}
