package com.ejie.ab60.dao.plantillas;

import com.ejie.ab60.model.plantillas.CamposPlantilla;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

/**
 * CamposPlantillaDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class CamposPlantillaDaoImpl implements CamposPlantillaDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDCAMPO", "NOMBRECAMPO", "SELECTCAMPO",
			"NOMBREXML", "DESCRIPCION", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<CamposPlantilla> rwMap = new RowMapper<CamposPlantilla>() {
		public CamposPlantilla mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new CamposPlantilla(resultSet.getInt("IDCAMPO"), resultSet.getString("NOMBRECAMPO"),
					resultSet.getString("SELECTCAMPO"), resultSet.getString("NOMBREXML"),
					resultSet.getString("DESCRIPCION"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getInt("ID_TIPO_CAMPO"),
					resultSet.getInt("IDPLANTILLA"));
		}
	};

	private RowMapper<CamposPlantilla> rwMapPK = new RowMapper<CamposPlantilla>() {
		public CamposPlantilla mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new CamposPlantilla(resultSet.getInt("IDCAMPO"));
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return CamposPlantilla
	 */
	public CamposPlantilla add(CamposPlantilla camposplantilla) {
		String query = "INSERT INTO CAMPOS_PLANTILLA (ID_CAMPO, NOMBRE_CAMPO, SELECT_CAMPO, NOMBRE_XML, DESCRIPCION, FECHA_REGISTRO, USUARIO_REGISTRO,ID_TIPO_CAMPO) VALUES (?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, camposplantilla.getIdCampo(), camposplantilla.getNombreCampo(),
				camposplantilla.getSelectCampo(), camposplantilla.getNombreXml(), camposplantilla.getDescripcion(),
				camposplantilla.getFechaRegistro(), camposplantilla.getUsuarioRegistro(),
				camposplantilla.getIdTipoCampo());
		return camposplantilla;
	}

	/**
	 * Updates a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return CamposPlantilla
	 */
	public CamposPlantilla update(CamposPlantilla camposplantilla) {
		String query = "UPDATE CAMPOS_PLANTILLA SET NOMBRE_CAMPO=?, SELECT_CAMPO=?, NOMBRE_XML=?, DESCRIPCION=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, ID_TIPO_CAMPO=? WHERE ID_CAMPO=?";
		this.jdbcTemplate.update(query, camposplantilla.getNombreCampo(), camposplantilla.getSelectCampo(),
				camposplantilla.getNombreXml(), camposplantilla.getDescripcion(), camposplantilla.getFechaRegistro(),
				camposplantilla.getUsuarioRegistro(), camposplantilla.getIdTipoCampo(), camposplantilla.getIdCampo());
		return camposplantilla;
	}

	/**
	 * Finds a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return CamposPlantilla
	 */
	@Transactional(readOnly = true)
	public CamposPlantilla find(CamposPlantilla camposplantilla) {
		String query = "SELECT t1.ID_CAMPO IDCAMPO, t1.NOMBRE_CAMPO NOMBRECAMPO, t1.ID_PLANTILLA IDPLANTILLA, t1.SELECT_CAMPO SELECTCAMPO, t1.NOMBRE_XML NOMBREXML, t1.DESCRIPCION DESCRIPCION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_TIPO_CAMPO FROM CAMPOS_PLANTILLA t1  WHERE t1.ID_CAMPO = ?  ";

		List<CamposPlantilla> camposplantillaList = this.jdbcTemplate.query(query, this.rwMap,
				camposplantilla.getIdCampo());
		return (CamposPlantilla) DataAccessUtils.uniqueResult(camposplantillaList);
	}

	/**
	 * Removes a single row in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return
	 */
	public void remove(CamposPlantilla camposplantilla) {
		String query = "DELETE FROM CAMPOS_PLANTILLA WHERE ID_CAMPO=?";
		this.jdbcTemplate.update(query, camposplantilla.getIdCampo());
	}

	/**
	 * Finds a list of rows in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<CamposPlantilla>
	 */
	@Transactional(readOnly = true)
	public List<CamposPlantilla> findAll(CamposPlantilla camposplantilla, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CAMPO IDCAMPO,t1.NOMBRE_CAMPO NOMBRECAMPO,t1.SELECT_CAMPO SELECTCAMPO,t1.NOMBRE_XML NOMBREXML,t1.DESCRIPCION DESCRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_TIPO_CAMPO ");
		query.append("FROM CAMPOS_PLANTILLA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(camposplantilla);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CamposPlantillaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<CamposPlantilla>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the CamposPlantilla table using like.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<CamposPlantilla>
	 */
	@Transactional(readOnly = true)
	public List<CamposPlantilla> findAllLike(CamposPlantilla camposplantilla, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_CAMPO IDCAMPO,t1.NOMBRE_CAMPO NOMBRECAMPO,t1.SELECT_CAMPO SELECTCAMPO,t1.NOMBRE_XML NOMBREXML,t1.DESCRIPCION DESCRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_TIPO_CAMPO ");
		query.append("FROM CAMPOS_PLANTILLA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(camposplantilla, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					CamposPlantillaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<CamposPlantilla>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the CamposPlantilla table.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(CamposPlantilla camposplantilla) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM CAMPOS_PLANTILLA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(camposplantilla);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the CamposPlantilla table using like.
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(CamposPlantilla camposplantilla, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM CAMPOS_PLANTILLA t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(camposplantilla, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of CamposPlantilla selected for rup_table
	 *
	 * @param camposplantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<CamposPlantilla>>
	 */
	@Override
	public List<TableRowDto<CamposPlantilla>> reorderSelection(CamposPlantilla camposplantilla,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CAMPO IDCAMPO,t1.NOMBRE_CAMPO NOMBRECAMPO,t1.SELECT_CAMPO SELECTCAMPO,t1.NOMBRE_XML NOMBREXML,t1.DESCRIPCION DESCRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_TIPO_CAMPO ");
		// FROM
		query.append("FROM CAMPOS_PLANTILLA t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(camposplantilla, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				CamposPlantilla.class, filterParamList, "ID_CAMPO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<CamposPlantilla>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            CamposPlantilla
	 * @param searchParams
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<CamposPlantilla>>
	 */
	@Override
	public List<TableRowDto<CamposPlantilla>> search(CamposPlantilla filterParams, CamposPlantilla searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CAMPO IDCAMPO,t1.NOMBRE_CAMPO NOMBRECAMPO,t1.SELECT_CAMPO SELECTCAMPO,t1.NOMBRE_XML NOMBREXML,t1.DESCRIPCION DESCRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_TIPO_CAMPO ");
		// FROM
		query.append("FROM CAMPOS_PLANTILLA t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				CamposPlantilla.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_CAMPO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<CamposPlantilla>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtercamposplantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(CamposPlantilla filtercamposplantilla, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_CAMPO IDCAMPO,t1.NOMBRE_CAMPO NOMBRECAMPO,t1.SELECT_CAMPO SELECTCAMPO,t1.NOMBRE_XML NOMBREXML,t1.DESCRIPCION DESCRIPCION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ID_TIPO_CAMPO ");
		// FROM
		query.append("FROM CAMPOS_PLANTILLA t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtercamposplantilla, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				CamposPlantilla.class, query, params, "ID_CAMPO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(CamposPlantilla filterCamposPlantilla, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM CAMPOS_PLANTILLA t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CAMPOS_PLANTILLA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCamposPlantilla, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_CAMPO", "ID_PADRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterCamposPlantilla
	 *            CamposPlantilla
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<CamposPlantilla>>
	 */
	@Override
	public List<TableRowDto<CamposPlantilla>> findAllChild(CamposPlantilla filterCamposPlantilla,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM CAMPOS_PLANTILLA t1 ");
		List<String> from = new ArrayList<String>();
		from.add("CAMPOS_PLANTILLA");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterCamposPlantilla, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_CAMPO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<CamposPlantilla>(this.rwMapPK, "ID_CAMPO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the CamposPlantilla entity
	 *
	 * @param camposplantilla
	 *            CamposPlantilla Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(CamposPlantilla camposplantilla) {

		StringBuilder where = new StringBuilder(CamposPlantillaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (camposplantilla != null && camposplantilla.getIdCampo() != null) {
			where.append(" AND t1.ID_CAMPO = ?");
			params.add(camposplantilla.getIdCampo());
		}
		if (camposplantilla != null && camposplantilla.getNombreCampo() != null) {
			where.append(" AND t1.NOMBRE_CAMPO = ?");
			params.add(camposplantilla.getNombreCampo());
		}
		if (camposplantilla != null && camposplantilla.getSelectCampo() != null) {
			where.append(" AND t1.SELECT_CAMPO = ?");
			params.add(camposplantilla.getSelectCampo());
		}
		if (camposplantilla != null && camposplantilla.getNombreXml() != null) {
			where.append(" AND t1.NOMBRE_XML = ?");
			params.add(camposplantilla.getNombreXml());
		}
		if (camposplantilla != null && camposplantilla.getDescripcion() != null) {
			where.append(" AND t1.DESCRIPCION = ?");
			params.add(camposplantilla.getDescripcion());
		}
		if (camposplantilla != null && camposplantilla.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(camposplantilla.getFechaRegistro());
		}
		if (camposplantilla != null && camposplantilla.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(camposplantilla.getUsuarioRegistro());
		}

		if (camposplantilla != null && camposplantilla.getIdTipoCampo() != null) {
			where.append(" AND t1.ID_TIPO_CAMPO = ?");
			params.add(camposplantilla.getIdTipoCampo());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the CamposPlantilla entity
	 *
	 * @param camposplantilla
	 *            CamposPlantilla Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(CamposPlantilla camposplantilla, Boolean startsWith) {

		StringBuilder where = new StringBuilder(CamposPlantillaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (camposplantilla != null && camposplantilla.getIdCampo() != null) {
			where.append(" AND t1.ID_CAMPO = ?");
			params.add(camposplantilla.getIdCampo());
		}
		if (camposplantilla != null && camposplantilla.getNombreCampo() != null) {
			where.append(" AND UPPER(t1.NOMBRE_CAMPO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(camposplantilla.getNombreCampo().toUpperCase() + "%");
			} else {
				params.add("%" + camposplantilla.getNombreCampo().toUpperCase() + "%");
			}
			where.append(" AND t1.NOMBRE_CAMPO IS NOT NULL");
		}
		if (camposplantilla != null && camposplantilla.getSelectCampo() != null) {
			where.append(" AND UPPER(t1.SELECT_CAMPO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(camposplantilla.getSelectCampo().toUpperCase() + "%");
			} else {
				params.add("%" + camposplantilla.getSelectCampo().toUpperCase() + "%");
			}
			where.append(" AND t1.SELECT_CAMPO IS NOT NULL");
		}
		if (camposplantilla != null && camposplantilla.getNombreXml() != null) {
			where.append(" AND UPPER(t1.NOMBRE_XML) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(camposplantilla.getNombreXml().toUpperCase() + "%");
			} else {
				params.add("%" + camposplantilla.getNombreXml().toUpperCase() + "%");
			}
			where.append(" AND t1.NOMBRE_XML IS NOT NULL");
		}
		if (camposplantilla != null && camposplantilla.getDescripcion() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(camposplantilla.getDescripcion().toUpperCase() + "%");
			} else {
				params.add("%" + camposplantilla.getDescripcion().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION IS NOT NULL");
		}
		if (camposplantilla != null && camposplantilla.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(camposplantilla.getFechaRegistro());
		}
		if (camposplantilla != null && camposplantilla.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(camposplantilla.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + camposplantilla.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (camposplantilla != null && camposplantilla.getIdTipoCampo() != null) {
			where.append(" AND t1.ID_TIPO_CAMPO = ?");
			params.add(camposplantilla.getIdTipoCampo());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public List<JerarquiaDto<CamposPlantilla>> findAllLikeJerarquia(CamposPlantilla filterCamposPlantilla,
			JQGridRequestDto jqGridRequestDto) {
		// TODO Auto-generated method stub
		return null;
	}
}
