package com.ejie.ab60.dao.plantillas;

import com.ejie.ab60.model.plantillas.TiposPlantilla;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * TiposPlantillaDao  
 *  
 */

public interface TiposPlantillaDao {
    
    /**
     * Inserts a single row in the TiposPlantilla table.
     *
     * @param tiposplantilla TiposPlantilla
     * @return TiposPlantilla
     */
    TiposPlantilla add(TiposPlantilla tiposplantilla);

    /**
     * Updates a single row in the TiposPlantilla table.
     *
     * @param tiposplantilla TiposPlantilla
     * @return TiposPlantilla
     */
    TiposPlantilla update(TiposPlantilla tiposplantilla);

    /**
     * Finds a single row in the TiposPlantilla table.
     *
     * @param tiposplantilla TiposPlantilla
     * @return TiposPlantilla
     */
    TiposPlantilla find(TiposPlantilla tiposplantilla);

    /**
     * Removes a single row in the TiposPlantilla table.
     *
     * @param tiposplantilla TiposPlantilla
     */
    void remove(TiposPlantilla tiposplantilla);

    /**
     * Finds a List of rows in the TiposPlantilla table.
     *
     * @param tiposplantilla TiposPlantilla
     * @param jqGridRequestDto JQGridRequestDto
     * @return List
     */
    List<TiposPlantilla> findAll(TiposPlantilla tiposplantilla, JQGridRequestDto jqGridRequestDto);

	/**
     * Finds rows in the TiposPlantilla table using like.
     *
     * @param tiposplantilla TiposPlantilla
     * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean
     * @return List
     */
	List<TiposPlantilla> findAllLike(TiposPlantilla tiposplantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith);
	
	
	/*
	 * OPERACIONES RUP_TABLE
	 */
	 
	/**
	 * Filter in the TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 */	
	 void removeMultiple(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith);
	
	
    /**
     * Counts rows in the TiposPlantilla table using like.
     *
     * @param tiposplantilla TiposPlantilla
     * @param startsWith Boolean
     * @return Long
     */
    Long findAllLikeCount(TiposPlantilla tiposplantilla, Boolean startsWith);
    
    /**
     * Counts rows in the TiposPlantilla table.
     *
     * @param tiposplantilla TiposPlantilla
     * @return Long
     */
    Long findAllCount(TiposPlantilla tiposplantilla);
    
    /**
	 * Reorder selection.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return List<TableRowDto<TiposPlantilla>>
	 */	
    List<TableRowDto<TiposPlantilla>> reorderSelection(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith);
    
     /**
	 * Searches in the Usuario table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param searchTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return List<TableRowDto<TiposPlantilla>>	 
	 */	
    List<TableRowDto<TiposPlantilla>> search(TiposPlantilla filterTiposPlantilla, TiposPlantilla searchTiposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

    /*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */
    
    /**
	 * Filter in the hierarchical TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return List<JerarquiaDto<TiposPlantilla>>
	 */	
	List<JerarquiaDto<TiposPlantilla>> findAllLikeJerarquia(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto);
	
	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return Long
	 */	
	Long findAllLikeCountJerarquia(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto);
	
	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return List<TableRowDto<TiposPlantilla>>
	 */	
	List<TableRowDto<TiposPlantilla>> findAllChild(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto);
	
	
}

