package com.ejie.ab60.dao.preguntasExpediente;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.model.preguntasExpediente.PreguntasExpediente;
import com.ejie.ab60.model.preguntasExpediente.TiposPreguntas;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PreguntasExpedienteDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PreguntasExpedienteDaoImpl implements PreguntasExpedienteDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPREGUNTAEXPEDIENTE", "IDEXPEDIENTE",
			"TIPOINSPECCION", "TIPOPREGUNTA", "DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "OPCIONESCASTELLANO",
			"OPCIONESEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO", "TIPOSPREGUNTASDESCES", "TIPOSPREGUNTASDESCEU" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<PreguntasExpediente> rwMap = new RowMapper<PreguntasExpediente>() {
		public PreguntasExpediente mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			PreguntasExpediente preguntaExpediente = new PreguntasExpediente();
			preguntaExpediente.setIdPreguntaExpediente(resultSet.getInt("IDPREGUNTAEXPEDIENTE"));
			preguntaExpediente.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			preguntaExpediente.setTipoInspeccion(resultSet.getInt("TIPOINSPECCION"));
			preguntaExpediente.setTipoPregunta(resultSet.getInt("TIPOPREGUNTA"));
			preguntaExpediente.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			preguntaExpediente.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			preguntaExpediente.setOpcionesCastellano(resultSet.getString("OPCIONESCASTELLANO"));
			preguntaExpediente.setOpcionesEuskera(resultSet.getString("OPCIONESEUSKERA"));
			preguntaExpediente.setFechaRegistro(resultSet.getDate("FECHAREGISTRO"));
			preguntaExpediente.setUsuarioRegistro(resultSet.getString("USUARIOREGISTRO"));

			TiposPreguntas tiposPregunta = new TiposPreguntas();
			tiposPregunta.setIdTipoPregunta(resultSet.getInt("TIPOPREGUNTA"));
			tiposPregunta.setDescripcionCastellano(resultSet.getString("TIPOSPREGUNTASDESCES"));
			tiposPregunta.setDescripcionEuskera(resultSet.getString("TIPOSPREGUNTASDESCEU"));
			tiposPregunta.setFechaRegistro(resultSet.getDate("TIPOSPREGUNTASFECHAREGISTRO"));
			tiposPregunta.setUsuarioRegistro(resultSet.getString("TIPOSPREGUNTASUSUARIOREGISTRO"));

			preguntaExpediente.setTiposPreguntas(tiposPregunta);

			return preguntaExpediente;
		}
	};

	private RowMapper<PreguntasExpediente> rwMapPK = new RowMapper<PreguntasExpediente>() {
		public PreguntasExpediente mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PreguntasExpediente(resultSet.getInt("IDPREGUNTAEXPEDIENTE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<PreguntasExpediente>> rwMapJerarquia = new RowMapper<JerarquiaDto<PreguntasExpediente>>() {
		public JerarquiaDto<PreguntasExpediente> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			PreguntasExpediente preguntaExpediente = new PreguntasExpediente();
			preguntaExpediente.setIdPreguntaExpediente(resultSet.getInt("IDPREGUNTAEXPEDIENTE"));
			preguntaExpediente.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			preguntaExpediente.setTipoInspeccion(resultSet.getInt("TIPOINSPECCION"));
			preguntaExpediente.setTipoPregunta(resultSet.getInt("TIPOPREGUNTA"));
			preguntaExpediente.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			preguntaExpediente.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			preguntaExpediente.setOpcionesCastellano(resultSet.getString("OPCIONESCASTELLANO"));
			preguntaExpediente.setOpcionesCastellano(resultSet.getString("OPCIONESEUSKERA"));
			preguntaExpediente.setFechaRegistro(resultSet.getDate("FECHAREGISTRO"));
			preguntaExpediente.setUsuarioRegistro(resultSet.getString("USUARIOREGISTRO"));

			TiposPreguntas tiposPregunta = new TiposPreguntas();
			tiposPregunta.setIdTipoPregunta(resultSet.getInt("TIPOPREGUNTA"));
			tiposPregunta.setDescripcionCastellano(resultSet.getString("TIPOSPREGUNTASDESCES"));
			tiposPregunta.setDescripcionEuskera(resultSet.getString("TIPOSPREGUNTASDESCEU"));
			tiposPregunta.setFechaRegistro(resultSet.getDate("TIPOSPREGUNTASFECHAREGISTRO"));
			tiposPregunta.setUsuarioRegistro(resultSet.getString("TIPOSPREGUNTASUSUARIOREGISTRO"));

			preguntaExpediente.setTiposPreguntas(tiposPregunta);

			JerarquiaDto<PreguntasExpediente> jerarquia = new JerarquiaDto<PreguntasExpediente>();
			jerarquia.setModel(preguntaExpediente);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the PreguntasExpediente table.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @return PreguntasExpediente
	 */
	public PreguntasExpediente add(PreguntasExpediente preguntasexpediente) {

		int idPreguntaExpediente = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6031T00"));
		preguntasexpediente.setIdPreguntaExpediente(idPreguntaExpediente);

		String query = "INSERT INTO PREGUNTAS_EXPEDIENTE (ID_PREGUNTA_EXPEDIENTE, ID_EXPEDIENTE, TIPO_INSPECCION, TIPO_PREGUNTA, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, OPCIONES_CASTELLANO, OPCIONES_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, preguntasexpediente.getIdPreguntaExpediente(),
				preguntasexpediente.getIdExpediente(), preguntasexpediente.getTipoInspeccion(),
				preguntasexpediente.getTipoPregunta(), preguntasexpediente.getDescripcionCastellano(),
				preguntasexpediente.getDescripcionEuskera(), preguntasexpediente.getOpcionesCastellano(),
				preguntasexpediente.getOpcionesEuskera(), preguntasexpediente.getFechaRegistro(),
				preguntasexpediente.getUsuarioRegistro());
		return preguntasexpediente;
	}

	/**
	 * Updates a single row in the PreguntasExpediente table.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @return PreguntasExpediente
	 */
	public PreguntasExpediente update(PreguntasExpediente preguntasexpediente) {
		String query = "UPDATE PREGUNTAS_EXPEDIENTE SET ID_EXPEDIENTE=?, TIPO_INSPECCION=?, TIPO_PREGUNTA=?, DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, OPCIONES_CASTELLANO=?, OPCIONES_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_PREGUNTA_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, preguntasexpediente.getIdExpediente(), preguntasexpediente.getTipoInspeccion(),
				preguntasexpediente.getTipoPregunta(), preguntasexpediente.getDescripcionCastellano(),
				preguntasexpediente.getDescripcionEuskera(), preguntasexpediente.getOpcionesCastellano(),
				preguntasexpediente.getOpcionesEuskera(), preguntasexpediente.getFechaRegistro(),
				preguntasexpediente.getUsuarioRegistro(), preguntasexpediente.getIdPreguntaExpediente());
		return preguntasexpediente;
	}

	/**
	 * Finds a single row in the PreguntasExpediente table.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @return PreguntasExpediente
	 */
	@Transactional(readOnly = true)
	public PreguntasExpediente find(PreguntasExpediente preguntasexpediente) {
		String query = "SELECT t1.ID_PREGUNTA_EXPEDIENTE IDPREGUNTAEXPEDIENTE, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.TIPO_INSPECCION TIPOINSPECCION, t1.TIPO_PREGUNTA TIPOPREGUNTA, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.OPCIONES_CASTELLANO OPCIONESCASTELLANO, t1.OPCIONES_EUSKERA OPCIONESEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.DESCRIPCION_CASTELLANO TIPOSPREGUNTASDESCES, t2.DESCRIPCION_EUSKERA TIPOSPREGUNTASDESCEU, t2.FECHA_REGISTRO TIPOSPREGUNTASFECHAREGISTRO, t2.USUARIO_REGISTRO TIPOSPREGUNTASUSUARIOREGISTRO FROM PREGUNTAS_EXPEDIENTE t1, TIPOS_PREGUNTAS t2  WHERE t1.ID_PREGUNTA_EXPEDIENTE = ? AND t1.TIPO_PREGUNTA = t2.ID_TIPO_PREGUNTA ";

		List<PreguntasExpediente> preguntasexpedienteList = this.jdbcTemplate.query(query, this.rwMap,
				preguntasexpediente.getIdPreguntaExpediente());
		return (PreguntasExpediente) DataAccessUtils.uniqueResult(preguntasexpedienteList);
	}

	/**
	 * Removes a single row in the PreguntasExpediente table.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @return
	 */
	public void remove(PreguntasExpediente preguntasexpediente) {
		String query = "DELETE FROM PREGUNTAS_EXPEDIENTE WHERE ID_PREGUNTA_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, preguntasexpediente.getIdPreguntaExpediente());
	}

	/**
	 * Finds a list of rows in the PreguntasExpediente table.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PreguntasExpediente>
	 */
	@Transactional(readOnly = true)
	public List<PreguntasExpediente> findAll(PreguntasExpediente preguntasexpediente,
			JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PREGUNTA_EXPEDIENTE IDPREGUNTAEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_INSPECCION TIPOINSPECCION,t1.TIPO_PREGUNTA TIPOPREGUNTA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.OPCIONES_CASTELLANO OPCIONESCASTELLANO,t1.OPCIONES_EUSKERA OPCIONESEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.DESCRIPCION_CASTELLANO TIPOSPREGUNTASDESCES, t2.DESCRIPCION_EUSKERA TIPOSPREGUNTASDESCEU, t2.FECHA_REGISTRO TIPOSPREGUNTASFECHAREGISTRO, t2.USUARIO_REGISTRO TIPOSPREGUNTASUSUARIOREGISTRO ");
		query.append("FROM PREGUNTAS_EXPEDIENTE t1, TIPOS_PREGUNTAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(preguntasexpediente);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.TIPO_PREGUNTA = t2.ID_TIPO_PREGUNTA ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PreguntasExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PreguntasExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the PreguntasExpediente table using like.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PreguntasExpediente>
	 */
	@Transactional(readOnly = true)
	public List<PreguntasExpediente> findAllLike(PreguntasExpediente preguntasexpediente,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PREGUNTA_EXPEDIENTE IDPREGUNTAEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_INSPECCION TIPOINSPECCION,t1.TIPO_PREGUNTA TIPOPREGUNTA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.OPCIONES_CASTELLANO OPCIONESCASTELLANO,t1.OPCIONES_EUSKERA OPCIONESEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.DESCRIPCION_CASTELLANO TIPOSPREGUNTASDESCES, t2.DESCRIPCION_EUSKERA TIPOSPREGUNTASDESCEU, t2.FECHA_REGISTRO TIPOSPREGUNTASFECHAREGISTRO, t2.USUARIO_REGISTRO TIPOSPREGUNTASUSUARIOREGISTRO ");
		query.append("FROM PREGUNTAS_EXPEDIENTE t1, TIPOS_PREGUNTAS t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(preguntasexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.TIPO_PREGUNTA = t2.ID_TIPO_PREGUNTA ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PreguntasExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PreguntasExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the PreguntasExpediente table.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(PreguntasExpediente preguntasexpediente) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PREGUNTAS_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(preguntasexpediente);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the PreguntasExpediente table using like.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(PreguntasExpediente preguntasexpediente, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PREGUNTAS_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(preguntasexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of PreguntasExpediente selected for rup_table
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PreguntasExpediente>>
	 */
	@Override
	public List<TableRowDto<PreguntasExpediente>> reorderSelection(PreguntasExpediente preguntasexpediente,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PREGUNTA_EXPEDIENTE IDPREGUNTAEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_INSPECCION TIPOINSPECCION,t1.TIPO_PREGUNTA TIPOPREGUNTA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.OPCIONES_CASTELLANO OPCIONESCASTELLANO,t1.OPCIONES_EUSKERA OPCIONESEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM PREGUNTAS_EXPEDIENTE t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(preguntasexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				PreguntasExpediente.class, filterParamList, "ID_PREGUNTA_EXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PreguntasExpediente>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            PreguntasExpediente
	 * @param searchParams
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PreguntasExpediente>>
	 */
	@Override
	public List<TableRowDto<PreguntasExpediente>> search(PreguntasExpediente filterParams,
			PreguntasExpediente searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PREGUNTA_EXPEDIENTE IDPREGUNTAEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_INSPECCION TIPOINSPECCION,t1.TIPO_PREGUNTA TIPOPREGUNTA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.OPCIONES_CASTELLANO OPCIONESCASTELLANO,t1.OPCIONES_EUSKERA OPCIONESEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM PREGUNTAS_EXPEDIENTE t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				PreguntasExpediente.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_PREGUNTA_EXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PreguntasExpediente>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterpreguntasexpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(PreguntasExpediente filterpreguntasexpediente, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PREGUNTA_EXPEDIENTE IDPREGUNTAEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_INSPECCION TIPOINSPECCION,t1.TIPO_PREGUNTA TIPOPREGUNTA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.OPCIONES_CASTELLANO OPCIONESCASTELLANO,t1.OPCIONES_EUSKERA OPCIONESEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM PREGUNTAS_EXPEDIENTE t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterpreguntasexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				PreguntasExpediente.class, query, params, "ID_PREGUNTA_EXPEDIENTE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical PreguntasExpediente table.
	 *
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<PreguntasExpediente>>
	 */
	@Override
	public List<JerarquiaDto<PreguntasExpediente>> findAllLikeJerarquia(PreguntasExpediente filterPreguntasExpediente,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PREGUNTA_EXPEDIENTE IDPREGUNTAEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.TIPO_INSPECCION TIPOINSPECCION,t1.TIPO_PREGUNTA TIPOPREGUNTA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.OPCIONES_CASTELLANO OPCIONESCASTELLANO,t1.OPCIONES_EUSKERA OPCIONESEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PREGUNTAS_EXPEDIENTE t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("PREGUNTAS_EXPEDIENTE");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPreguntasExpediente, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PREGUNTA_EXPEDIENTE",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					PreguntasExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(PreguntasExpediente filterPreguntasExpediente,
			JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PREGUNTAS_EXPEDIENTE t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("PREGUNTAS_EXPEDIENTE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPreguntasExpediente, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_PREGUNTA_EXPEDIENTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<PreguntasExpediente>>
	 */
	@Override
	public List<TableRowDto<PreguntasExpediente>> findAllChild(PreguntasExpediente filterPreguntasExpediente,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PREGUNTAS_EXPEDIENTE t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("PREGUNTAS_EXPEDIENTE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPreguntasExpediente, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_PREGUNTA_EXPEDIENTE", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<PreguntasExpediente>(this.rwMapPK, "ID_PREGUNTA_EXPEDIENTE"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PreguntasExpediente entity
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(PreguntasExpediente preguntasexpediente) {

		StringBuilder where = new StringBuilder(PreguntasExpedienteDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (preguntasexpediente != null && preguntasexpediente.getIdPreguntaExpediente() != null) {
			where.append(" AND t1.ID_PREGUNTA_EXPEDIENTE = ?");
			params.add(preguntasexpediente.getIdPreguntaExpediente());
		}
		if (preguntasexpediente != null && preguntasexpediente.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(preguntasexpediente.getIdExpediente());
		}
		if (preguntasexpediente != null && preguntasexpediente.getTipoInspeccion() != null) {
			where.append(" AND t1.TIPO_INSPECCION = ?");
			params.add(preguntasexpediente.getTipoInspeccion());
		}
		if (preguntasexpediente != null && preguntasexpediente.getTipoPregunta() != null) {
			where.append(" AND t1.TIPO_PREGUNTA = ?");
			params.add(preguntasexpediente.getTipoPregunta());
		}
		if (preguntasexpediente != null && preguntasexpediente.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(preguntasexpediente.getDescripcionCastellano());
		}
		if (preguntasexpediente != null && preguntasexpediente.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(preguntasexpediente.getDescripcionEuskera());
		}
		if (preguntasexpediente != null && preguntasexpediente.getOpcionesCastellano() != null) {
			where.append(" AND t1.OPCIONES_CASTELLANO = ?");
			params.add(preguntasexpediente.getOpcionesCastellano());
		}
		if (preguntasexpediente != null && preguntasexpediente.getOpcionesEuskera() != null) {
			where.append(" AND t1.OPCIONES_EUSKERA = ?");
			params.add(preguntasexpediente.getOpcionesEuskera());
		}
		if (preguntasexpediente != null && preguntasexpediente.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(preguntasexpediente.getFechaRegistro());
		}
		if (preguntasexpediente != null && preguntasexpediente.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(preguntasexpediente.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PreguntasExpediente entity
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente Bean with the criteria values to filter
	 *            by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(PreguntasExpediente preguntasexpediente, Boolean startsWith) {

		StringBuilder where = new StringBuilder(PreguntasExpedienteDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (preguntasexpediente != null && preguntasexpediente.getIdPreguntaExpediente() != null) {
			where.append(" AND t1.ID_PREGUNTA_EXPEDIENTE = ?");
			params.add(preguntasexpediente.getIdPreguntaExpediente());
		}
		if (preguntasexpediente != null && preguntasexpediente.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(preguntasexpediente.getIdExpediente());
		}
		if (preguntasexpediente != null && preguntasexpediente.getTipoInspeccion() != null) {
			where.append(" AND t1.TIPO_INSPECCION = ?");
			params.add(preguntasexpediente.getTipoInspeccion());
		}
		if (preguntasexpediente != null && preguntasexpediente.getTipoPregunta() != null) {
			where.append(" AND t1.TIPO_PREGUNTA = ?");
			params.add(preguntasexpediente.getTipoPregunta());
		}
		if (preguntasexpediente != null && preguntasexpediente.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(preguntasexpediente.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + preguntasexpediente.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (preguntasexpediente != null && preguntasexpediente.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(preguntasexpediente.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + preguntasexpediente.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (preguntasexpediente != null && preguntasexpediente.getOpcionesCastellano() != null) {
			where.append(" AND UPPER(t1.OPCIONES_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(preguntasexpediente.getOpcionesCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + preguntasexpediente.getOpcionesCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.OPCIONES_CASTELLANO IS NOT NULL");
		}
		if (preguntasexpediente != null && preguntasexpediente.getOpcionesEuskera() != null) {
			where.append(" AND UPPER(t1.OPCIONES_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(preguntasexpediente.getOpcionesEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + preguntasexpediente.getOpcionesEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.OPCIONES_EUSKERA IS NOT NULL");
		}
		if (preguntasexpediente != null && preguntasexpediente.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(preguntasexpediente.getFechaRegistro());
		}
		if (preguntasexpediente != null && preguntasexpediente.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(preguntasexpediente.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + preguntasexpediente.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
