package com.ejie.ab60.dao.preguntasExpediente;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.preguntasExpediente.TiposPreguntas;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridRequestDto;

/**
 * PreguntasExpedienteDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposPreguntasDaoImpl implements TiposPreguntasDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOPREGUNTA", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposPreguntas> rwMap = new RowMapper<TiposPreguntas>() {
		public TiposPreguntas mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposPreguntas(resultSet.getInt("IDTIPOPREGUNTA"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"));
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Finds a list of rows in the PreguntasExpediente table.
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PreguntasExpediente>
	 */
	@Transactional(readOnly = true)
	public List<TiposPreguntas> findAll(TiposPreguntas tiposPreguntas, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_PREGUNTA IDTIPOPREGUNTA,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM TIPOS_PREGUNTAS t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tiposPreguntas);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TiposPreguntasDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposPreguntas>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PreguntasExpediente entity
	 *
	 * @param preguntasexpediente
	 *            PreguntasExpediente Bean with the criteria values to filter
	 *            by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposPreguntas tiposPreguntas) {

		StringBuilder where = new StringBuilder(TiposPreguntasDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tiposPreguntas != null && tiposPreguntas.getIdTipoPregunta() != null) {
			where.append(" AND t1.ID_TIPO_PREGUNTA = ?");
			params.add(tiposPreguntas.getIdTipoPregunta());
		}
		if (tiposPreguntas != null && tiposPreguntas.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tiposPreguntas.getDescripcionCastellano());
		}
		if (tiposPreguntas != null && tiposPreguntas.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tiposPreguntas.getDescripcionEuskera());
		}
		if (tiposPreguntas != null && tiposPreguntas.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tiposPreguntas.getFechaRegistro());
		}
		if (tiposPreguntas != null && tiposPreguntas.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tiposPreguntas.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
