package com.ejie.ab60.service.BEC;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.BEC.CaracteristicasDao;
import com.ejie.ab60.model.BEC.Caracteristicas;

/**
 * CaracteristicasServiceImpl  
 *  
 */

@Service(value = "caracteristicasService")
public class CaracteristicasServiceImpl implements CaracteristicasService {

	@Autowired
	private CaracteristicasDao caracteristicasDao;

	/**
	 * Inserts a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas Caracteristicas
	 * @return Caracteristicas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Caracteristicas add(Caracteristicas caracteristicas) {
		return this.caracteristicasDao.add(caracteristicas);
	}

	/**
	 * Updates a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas Caracteristicas
	 * @return Caracteristicas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Caracteristicas update(Caracteristicas caracteristicas) {
		return this.caracteristicasDao.update(caracteristicas);
	 }

	/**
	 * Finds a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas Caracteristicas
	 * @return Caracteristicas
	 */
	public Caracteristicas find(Caracteristicas caracteristicas) {
		return (Caracteristicas) this.caracteristicasDao.find(caracteristicas);
	}
	
	/**
	 * Deletes a single row in the Caracteristicas table.
	 *
	 * @param caracteristicas Caracteristicas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Caracteristicas caracteristicas) {
		this.caracteristicasDao.remove(caracteristicas);
	}

	/**
	 * Finds a list of rows in the Caracteristicas table.
	 *
	 * @param caracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return List<Caracteristicas>
	 */
	public List<Caracteristicas> findAll(Caracteristicas caracteristicas, JQGridRequestDto jqGridRequestDto){
		return (List<Caracteristicas>) this.caracteristicasDao.findAll(caracteristicas, jqGridRequestDto);
	}
    
	/**
	 * Finds rows in the Caracteristicas table using like.
	 *
	 * @param caracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean	 
	 * @return List<Caracteristicas>
	 */
	public List<Caracteristicas> findAllLike(Caracteristicas caracteristicas, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return (List<Caracteristicas>) this.caracteristicasDao.findAllLike(caracteristicas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */
	 
	/**
	 * Removes rows from the Caracteristicas table.
	 *
	 * @param filterCaracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 */	
	public void removeMultiple(Caracteristicas filterCaracteristicas, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		this.caracteristicasDao.removeMultiple(filterCaracteristicas, jqGridRequestDto, startsWith);
	}
        
	/**
	 * Filter method in the Caracteristicas table.
	 *
	 * @param filterCaracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<Caracteristicas>
	 */	
	public JQGridResponseDto< Caracteristicas> filter(Caracteristicas filterCaracteristicas, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		List<Caracteristicas> listaCaracteristicas =  this.caracteristicasDao.findAllLike(filterCaracteristicas, jqGridRequestDto, false);
		Long recordNum =  this.caracteristicasDao.findAllLikeCount(filterCaracteristicas != null ? filterCaracteristicas: new Caracteristicas (),false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds()!=null){
			List< TableRowDto< Caracteristicas>> reorderSelection = this.caracteristicasDao.reorderSelection(filterCaracteristicas, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Caracteristicas>(jqGridRequestDto, recordNum, listaCaracteristicas, reorderSelection);
		}
		return new JQGridResponseDto<Caracteristicas>(jqGridRequestDto, recordNum, listaCaracteristicas);   
	}
    
    /**
	 * Searches rows in the Caracteristicas table.
	 *
	 * @param filterCaracteristicas Caracteristicas
	 * @param searchCaracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return List<TableRowDto<Caracteristicas>>
	 */	
    public List< TableRowDto< Caracteristicas>> search(Caracteristicas filterCaracteristicas, Caracteristicas searchCaracteristicas, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.caracteristicasDao.search(filterCaracteristicas, searchCaracteristicas, jqGridRequestDto, startsWith);
	}
    
    /**
	 * Reorder the selection made in Caracteristicas table.
	 *
	 * @param filterCaracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return Object
	 */	
    public Object reorderSelection(Caracteristicas filterCaracteristicas, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.caracteristicasDao.reorderSelection(filterCaracteristicas, jqGridRequestDto, startsWith);
	}
    
    /*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */
	 
	/**
	 * Finder method in the hierarchical the Caracteristicas table.
	 *
	 * @param filterCaracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Caracteristicas>>
	 */	
	public JQGridResponseDto<JerarquiaDto<Caracteristicas>> jerarquia(Caracteristicas filterCaracteristicas, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		List<JerarquiaDto<Caracteristicas>> listaCaracteristicas =  this.caracteristicasDao.findAllLikeJerarquia(filterCaracteristicas, jqGridRequestDto);
		Long recordNum = this.caracteristicasDao.findAllLikeCountJerarquia(filterCaracteristicas, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Caracteristicas>>(jqGridRequestDto, recordNum, listaCaracteristicas);
	}
	
	/**
	 * Finder method for siblings rows in the hierarchical the Caracteristicas table.
	 *
	 * @param filterCaracteristicas Caracteristicas
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Caracteristicas>>
	 */	
	public JQGridResponseDto<JerarquiaDto<Caracteristicas>> jerarquiaChildren(Caracteristicas filterCaracteristicas, JQGridRequestDto jqGridRequestDto){
		JQGridResponseDto<JerarquiaDto<Caracteristicas>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Caracteristicas>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN, this.caracteristicasDao.findAllChild(filterCaracteristicas, jqGridRequestDto));
		return jqGridResponseDto;
	}
	
	
}

