package com.ejie.ab60.service.BEC;

import com.ejie.ab60.dao.BEC.CurriculumDao;
import com.ejie.ab60.dao.BEC.PuntuacionesDao;
import com.ejie.ab60.dao.criteriosPuntuacion.RelExpCriPunDao;
import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.ab60.model.criteriosPuntuacion.RelExpCriPun;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * CurriculumServiceImpl  
 * 
 *  
 */

@Service(value = "curriculumService")
public class CurriculumServiceImpl implements CurriculumService {

	private static final Logger logger = LoggerFactory.getLogger(CurriculumServiceImpl.class);

	@Autowired
	private CurriculumDao curriculumDao;

	@Autowired
	private RelExpCriPunDao relExpCriPunDao;

	@Autowired
	private PuntuacionesDao puntuacionesDao;

	/**
	 * Inserts a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Curriculum add(Curriculum curriculum) {
		return this.curriculumDao.add(curriculum);
	}

	/**
	 * Updates a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Curriculum update(Curriculum curriculum) {
		return this.curriculumDao.update(curriculum);
	}

	/**
	 * Updates a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Curriculum save(Integer idExpediente, Curriculum curriculum, Usuario usuario) {

		curriculum.setIdExpediente(idExpediente);
		if (curriculum.getTiposCertificacionByIdCertificacionEuskera() != null
				&& curriculum.getTiposCertificacionByIdCertificacionEuskera().getIdTipoCertificacion() != null) {
			curriculum.setEuskera(1);
		} else {
			curriculum.setEuskera(0);
		}
		if (curriculum.getTiposCertificacionByIdCertificacionIngles() != null
				&& curriculum.getTiposCertificacionByIdCertificacionIngles().getIdTipoCertificacion() != null) {
			curriculum.setIngles(1);
		} else {
			curriculum.setIngles(0);
		}
		if (curriculum.getTiposCertificacionByIdCertificacionFrances() != null
				&& curriculum.getTiposCertificacionByIdCertificacionFrances().getIdTipoCertificacion() != null) {
			curriculum.setFrances(1);
		} else {
			curriculum.setFrances(0);
		}
		if (curriculum.getTiposCertificacionByIdCertificacionItaliano() != null
				&& curriculum.getTiposCertificacionByIdCertificacionItaliano().getIdTipoCertificacion() != null) {
			curriculum.setItaliano(1);
		} else {
			curriculum.setItaliano(0);
		}

		if (curriculum.getBandera() != 0) {

			// Borarremos todo lo que haya referente a es idExpediente
			relExpCriPunDao.removeCriteriosPorExpediente(idExpediente);
			if (curriculum.getCriterios() != null) {
				CurriculumServiceImpl.logger.info("[obtener lista de criterios] ");

				List<CriteriosPuntuacion> lcriterios = new ArrayList<CriteriosPuntuacion>();
				CriteriosPuntuacion crit = null;

				for (Integer criterio : curriculum.getCriterios()) {
					crit = new CriteriosPuntuacion();
					crit.setIdCriterio(criterio);
					lcriterios.add(crit);
				}

				RelExpCriPun relExpCriPun = null;
				for (int i = 0; i < lcriterios.size(); i++) {
					// crear un objeto
					relExpCriPun = new RelExpCriPun();
					relExpCriPun.setIdExpediente(idExpediente);
					relExpCriPun.setCriteriosPuntuacion(lcriterios.get(i));
					relExpCriPun.setFechaRegistro(new Date());

					relExpCriPun.setUsuarioRegistro(usuario.getNombreUsuario());
					relExpCriPunDao.add(relExpCriPun);

					CurriculumServiceImpl.logger.info("[Anyadir criterios] ");
				}
			}
		}
		curriculum.setFechaUltmodificacion(new Date());
		curriculum.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		curriculumDao.update(curriculum);
		if (null != curriculum && null != curriculum.getPuntuaciones()) {
			curriculum.getPuntuaciones().setIdExpediente(idExpediente);
			curriculum.getPuntuaciones().setFechaUltmodificacion(new Date());
			curriculum.getPuntuaciones().setUsuarioUltmodificacion(usuario.getNombreUsuario());
		} else {
			Puntuaciones puntuaciones = new Puntuaciones();
			puntuaciones.setIdExpediente(idExpediente);
			puntuaciones.setUsuarioRegistro(usuario.getNombreUsuario());
			Puntuaciones puntuacionesAux = puntuacionesDao.add(puntuaciones);
			puntuacionesAux.setFechaUltmodificacion(new Date());
			puntuacionesAux.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			curriculum.setPuntuaciones(puntuacionesAux);
		}
		puntuacionesDao.updateCurriculum(curriculum.getPuntuaciones());

		return curriculum;

	}

	/**
	 * Finds a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @return Curriculum
	 */
	public Curriculum find(Curriculum curriculum) {
		return (Curriculum) this.curriculumDao.find(curriculum);
	}

	/**
	 * Deletes a single row in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Curriculum curriculum) {
		this.curriculumDao.remove(curriculum);
	}

	/**
	 * Finds a list of rows in the Curriculum table.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Curriculum>
	 */
	public List<Curriculum> findAll(Curriculum curriculum, JQGridRequestDto jqGridRequestDto) {
		return (List<Curriculum>) this.curriculumDao.findAll(curriculum, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Curriculum table using like.
	 *
	 * @param curriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Curriculum>
	 */
	public List<Curriculum> findAllLike(Curriculum curriculum, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Curriculum>) this.curriculumDao.findAllLike(curriculum, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.curriculumDao.removeMultiple(filterCurriculum, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Curriculum>
	 */
	public JQGridResponseDto<Curriculum> filter(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<Curriculum> listaCurriculum = this.curriculumDao.findAllLike(filterCurriculum, jqGridRequestDto, false);
		Long recordNum = this.curriculumDao
				.findAllLikeCount(filterCurriculum != null ? filterCurriculum : new Curriculum(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Curriculum>> reorderSelection = this.curriculumDao.reorderSelection(filterCurriculum,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Curriculum>(jqGridRequestDto, recordNum, listaCurriculum, reorderSelection);
		}
		return new JQGridResponseDto<Curriculum>(jqGridRequestDto, recordNum, listaCurriculum);
	}

	/**
	 * Searches rows in the Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param searchCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Curriculum>>
	 */
	public List<TableRowDto<Curriculum>> search(Curriculum filterCurriculum, Curriculum searchCurriculum,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.curriculumDao.search(filterCurriculum, searchCurriculum, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Curriculum filterCurriculum, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.curriculumDao.reorderSelection(filterCurriculum, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Curriculum>>
	 */
	public JQGridResponseDto<JerarquiaDto<Curriculum>> jerarquia(Curriculum filterCurriculum,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Curriculum>> listaCurriculum = this.curriculumDao.findAllLikeJerarquia(filterCurriculum,
				jqGridRequestDto);
		Long recordNum = this.curriculumDao.findAllLikeCountJerarquia(filterCurriculum, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Curriculum>>(jqGridRequestDto, recordNum, listaCurriculum);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Curriculum table.
	 *
	 * @param filterCurriculum
	 *            Curriculum
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Curriculum>>
	 */
	public JQGridResponseDto<JerarquiaDto<Curriculum>> jerarquiaChildren(Curriculum filterCurriculum,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Curriculum>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Curriculum>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.curriculumDao.findAllChild(filterCurriculum, jqGridRequestDto));
		return jqGridResponseDto;
	}
}
