package com.ejie.ab60.service.BEC;
import com.ejie.ab60.dao.BEC.ExperienciaLaboralDao;
import com.ejie.ab60.model.BEC.ExperienciaLaboral;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * ExperienciaLaboralServiceImpl  
 *  
 */

@Service(value = "experienciaLaboralService")
public class ExperienciaLaboralServiceImpl implements ExperienciaLaboralService {

	@Autowired
	private ExperienciaLaboralDao experienciaLaboralDao;

	/**
	 * Inserts a single row in the ExperienciaLaboral table.
	 *
	 * @param experienciaLaboral ExperienciaLaboral
	 * @return ExperienciaLaboral
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ExperienciaLaboral add(ExperienciaLaboral experienciaLaboral) {
		return this.experienciaLaboralDao.add(experienciaLaboral);
	}

	/**
	 * Updates a single row in the ExperienciaLaboral table.
	 *
	 * @param experienciaLaboral ExperienciaLaboral
	 * @return ExperienciaLaboral
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ExperienciaLaboral update(ExperienciaLaboral experienciaLaboral) {
		return this.experienciaLaboralDao.update(experienciaLaboral);
	 }

	/**
	 * Finds a single row in the ExperienciaLaboral table.
	 *
	 * @param experienciaLaboral ExperienciaLaboral
	 * @return ExperienciaLaboral
	 */
	public ExperienciaLaboral find(ExperienciaLaboral experienciaLaboral) {
		return (ExperienciaLaboral) this.experienciaLaboralDao.find(experienciaLaboral);
	}
	
	/**
	 * Deletes a single row in the ExperienciaLaboral table.
	 *
	 * @param experienciaLaboral ExperienciaLaboral
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(ExperienciaLaboral experienciaLaboral) {
		this.experienciaLaboralDao.remove(experienciaLaboral);
	}

	/**
	 * Finds a list of rows in the ExperienciaLaboral table.
	 *
	 * @param experienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return List<ExperienciaLaboral>
	 */
	public List<ExperienciaLaboral> findAll(ExperienciaLaboral experienciaLaboral, JQGridRequestDto jqGridRequestDto){
		return (List<ExperienciaLaboral>) this.experienciaLaboralDao.findAll(experienciaLaboral, jqGridRequestDto);
	}
    
	/**
	 * Finds rows in the ExperienciaLaboral table using like.
	 *
	 * @param experienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean	 
	 * @return List<ExperienciaLaboral>
	 */
	public List<ExperienciaLaboral> findAllLike(ExperienciaLaboral experienciaLaboral, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return (List<ExperienciaLaboral>) this.experienciaLaboralDao.findAllLike(experienciaLaboral, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */
	 
	/**
	 * Removes rows from the ExperienciaLaboral table.
	 *
	 * @param filterExperienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 */	
	public void removeMultiple(ExperienciaLaboral filterExperienciaLaboral, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		this.experienciaLaboralDao.removeMultiple(filterExperienciaLaboral, jqGridRequestDto, startsWith);
	}
        
	/**
	 * Filter method in the ExperienciaLaboral table.
	 *
	 * @param filterExperienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<ExperienciaLaboral>
	 */	
	public JQGridResponseDto< ExperienciaLaboral> filter(ExperienciaLaboral filterExperienciaLaboral, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		List<ExperienciaLaboral> listaExperienciaLaboral =  this.experienciaLaboralDao.findAllLike(filterExperienciaLaboral, jqGridRequestDto, false);
		Long recordNum =  this.experienciaLaboralDao.findAllLikeCount(filterExperienciaLaboral != null ? filterExperienciaLaboral: new ExperienciaLaboral (),false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds()!=null){
			List< TableRowDto< ExperienciaLaboral>> reorderSelection = this.experienciaLaboralDao.reorderSelection(filterExperienciaLaboral, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<ExperienciaLaboral>(jqGridRequestDto, recordNum, listaExperienciaLaboral, reorderSelection);
		}
		return new JQGridResponseDto<ExperienciaLaboral>(jqGridRequestDto, recordNum, listaExperienciaLaboral);   
	}
    
    /**
	 * Searches rows in the ExperienciaLaboral table.
	 *
	 * @param filterExperienciaLaboral ExperienciaLaboral
	 * @param searchExperienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return List<TableRowDto<ExperienciaLaboral>>
	 */	
    public List< TableRowDto< ExperienciaLaboral>> search(ExperienciaLaboral filterExperienciaLaboral, ExperienciaLaboral searchExperienciaLaboral, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.experienciaLaboralDao.search(filterExperienciaLaboral, searchExperienciaLaboral, jqGridRequestDto, startsWith);
	}
    
    /**
	 * Reorder the selection made in ExperienciaLaboral table.
	 *
	 * @param filterExperienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return Object
	 */	
    public Object reorderSelection(ExperienciaLaboral filterExperienciaLaboral, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.experienciaLaboralDao.reorderSelection(filterExperienciaLaboral, jqGridRequestDto, startsWith);
	}
    
    /*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */
	 
	/**
	 * Finder method in the hierarchical the ExperienciaLaboral table.
	 *
	 * @param filterExperienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<JerarquiaDto<ExperienciaLaboral>>
	 */	
	public JQGridResponseDto<JerarquiaDto<ExperienciaLaboral>> jerarquia(ExperienciaLaboral filterExperienciaLaboral, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		List<JerarquiaDto<ExperienciaLaboral>> listaExperienciaLaboral =  this.experienciaLaboralDao.findAllLikeJerarquia(filterExperienciaLaboral, jqGridRequestDto);
		Long recordNum = this.experienciaLaboralDao.findAllLikeCountJerarquia(filterExperienciaLaboral, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<ExperienciaLaboral>>(jqGridRequestDto, recordNum, listaExperienciaLaboral);
	}
	
	/**
	 * Finder method for siblings rows in the hierarchical the ExperienciaLaboral table.
	 *
	 * @param filterExperienciaLaboral ExperienciaLaboral
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<ExperienciaLaboral>>
	 */	
	public JQGridResponseDto<JerarquiaDto<ExperienciaLaboral>> jerarquiaChildren(ExperienciaLaboral filterExperienciaLaboral, JQGridRequestDto jqGridRequestDto){
		JQGridResponseDto<JerarquiaDto<ExperienciaLaboral>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<ExperienciaLaboral>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN, this.experienciaLaboralDao.findAllChild(filterExperienciaLaboral, jqGridRequestDto));
		return jqGridResponseDto;
	}
	
	
}

