package com.ejie.ab60.service.BEC;

import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.BEC.FasesDao;
import com.ejie.ab60.model.BEC.Fases;

/**
 * FasesServiceImpl  
 * 
 *  
 */

@Service(value = "fasesService")
public class FasesServiceImpl implements FasesService {

	@Autowired
	private FasesDao fasesDao;

	/**
	 * Inserts a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @return Fases
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Fases add(Fases fases) {
		return this.fasesDao.add(fases);
	}

	/**
	 * Updates a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @return Fases
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Fases update(Fases fases) {
		return this.fasesDao.update(fases);
	}

	/**
	 * Finds a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @return Fases
	 */
	public Fases find(Fases fases) {
		return (Fases) this.fasesDao.find(fases);
	}

	/**
	 * Finds a list of rows in the Fases table.
	 *
	 * 
	 * @return List<Fases>
	 */
	public List<Fases> findFases() {
		return (List<Fases>) this.fasesDao.findFases();
	}

	/**
	 * Deletes a single row in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Fases fases) {
		this.fasesDao.remove(fases);
	}

	/**
	 * Finds a list of rows in the Fases table.
	 *
	 * @param fases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Fases>
	 */
	public List<Fases> findAll(Fases fases, JQGridRequestDto jqGridRequestDto) {
		return (List<Fases>) this.fasesDao.findAll(fases, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Fases table using like.
	 *
	 * @param fases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Fases>
	 */
	public List<Fases> findAllLike(Fases fases, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Fases>) this.fasesDao.findAllLike(fases, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Fases filterFases, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.fasesDao.removeMultiple(filterFases, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Fases>
	 */
	public JQGridResponseDto<Fases> filter(Fases filterFases, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<Fases> listaFases = this.fasesDao.findAllLike(filterFases, jqGridRequestDto, false);
		Long recordNum = this.fasesDao.findAllLikeCount(filterFases != null ? filterFases : new Fases(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Fases>> reorderSelection = this.fasesDao.reorderSelection(filterFases, jqGridRequestDto,
					startsWith);
			return new JQGridResponseDto<Fases>(jqGridRequestDto, recordNum, listaFases, reorderSelection);
		}
		return new JQGridResponseDto<Fases>(jqGridRequestDto, recordNum, listaFases);
	}

	/**
	 * Searches rows in the Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param searchFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Fases>>
	 */
	public List<TableRowDto<Fases>> search(Fases filterFases, Fases searchFases, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.fasesDao.search(filterFases, searchFases, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Fases filterFases, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.fasesDao.reorderSelection(filterFases, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Fases>>
	 */
	public JQGridResponseDto<JerarquiaDto<Fases>> jerarquia(Fases filterFases, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<JerarquiaDto<Fases>> listaFases = this.fasesDao.findAllLikeJerarquia(filterFases, jqGridRequestDto);
		Long recordNum = this.fasesDao.findAllLikeCountJerarquia(filterFases, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Fases>>(jqGridRequestDto, recordNum, listaFases);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Fases table.
	 *
	 * @param filterFases
	 *            Fases
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Fases>>
	 */
	public JQGridResponseDto<JerarquiaDto<Fases>> jerarquiaChildren(Fases filterFases,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Fases>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Fases>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.fasesDao.findAllChild(filterFases, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
