package com.ejie.ab60.service.BEC;
import com.ejie.ab60.dao.BEC.OtrosTitulosDao;
import com.ejie.ab60.model.BEC.OtrosTitulos;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * OtrosTitulosServiceImpl  
 *  
 */

@Service(value = "otrosTitulosService")
public class OtrosTitulosServiceImpl implements OtrosTitulosService {

	@Autowired
	private OtrosTitulosDao otrosTitulosDao;

	/**
	 * Inserts a single row in the OtrosTitulos table.
	 *
	 * @param otrosTitulos OtrosTitulos
	 * @return OtrosTitulos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public OtrosTitulos add(OtrosTitulos otrosTitulos) {
		return this.otrosTitulosDao.add(otrosTitulos);
	}

	/**
	 * Updates a single row in the OtrosTitulos table.
	 *
	 * @param otrosTitulos OtrosTitulos
	 * @return OtrosTitulos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public OtrosTitulos update(OtrosTitulos otrosTitulos) {
		return this.otrosTitulosDao.update(otrosTitulos);
	 }

	/**
	 * Finds a single row in the OtrosTitulos table.
	 *
	 * @param otrosTitulos OtrosTitulos
	 * @return OtrosTitulos
	 */
	public OtrosTitulos find(OtrosTitulos otrosTitulos) {
		return (OtrosTitulos) this.otrosTitulosDao.find(otrosTitulos);
	}
	
	/**
	 * Deletes a single row in the OtrosTitulos table.
	 *
	 * @param otrosTitulos OtrosTitulos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(OtrosTitulos otrosTitulos) {
		this.otrosTitulosDao.remove(otrosTitulos);
	}

	/**
	 * Finds a list of rows in the OtrosTitulos table.
	 *
	 * @param otrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return List<OtrosTitulos>
	 */
	public List<OtrosTitulos> findAll(OtrosTitulos otrosTitulos, JQGridRequestDto jqGridRequestDto){
		return (List<OtrosTitulos>) this.otrosTitulosDao.findAll(otrosTitulos, jqGridRequestDto);
	}
    
	/**
	 * Finds rows in the OtrosTitulos table using like.
	 *
	 * @param otrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean	 
	 * @return List<OtrosTitulos>
	 */
	public List<OtrosTitulos> findAllLike(OtrosTitulos otrosTitulos, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return (List<OtrosTitulos>) this.otrosTitulosDao.findAllLike(otrosTitulos, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */
	 
	/**
	 * Removes rows from the OtrosTitulos table.
	 *
	 * @param filterOtrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 */	
	public void removeMultiple(OtrosTitulos filterOtrosTitulos, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		this.otrosTitulosDao.removeMultiple(filterOtrosTitulos, jqGridRequestDto, startsWith);
	}
        
	/**
	 * Filter method in the OtrosTitulos table.
	 *
	 * @param filterOtrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<OtrosTitulos>
	 */	
	public JQGridResponseDto< OtrosTitulos> filter(OtrosTitulos filterOtrosTitulos, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		List<OtrosTitulos> listaOtrosTitulos =  this.otrosTitulosDao.findAllLike(filterOtrosTitulos, jqGridRequestDto, false);
		Long recordNum =  this.otrosTitulosDao.findAllLikeCount(filterOtrosTitulos != null ? filterOtrosTitulos: new OtrosTitulos (),false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds()!=null){
			List< TableRowDto< OtrosTitulos>> reorderSelection = this.otrosTitulosDao.reorderSelection(filterOtrosTitulos, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<OtrosTitulos>(jqGridRequestDto, recordNum, listaOtrosTitulos, reorderSelection);
		}
		return new JQGridResponseDto<OtrosTitulos>(jqGridRequestDto, recordNum, listaOtrosTitulos);   
	}
    
    /**
	 * Searches rows in the OtrosTitulos table.
	 *
	 * @param filterOtrosTitulos OtrosTitulos
	 * @param searchOtrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return List<TableRowDto<OtrosTitulos>>
	 */	
    public List< TableRowDto< OtrosTitulos>> search(OtrosTitulos filterOtrosTitulos, OtrosTitulos searchOtrosTitulos, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.otrosTitulosDao.search(filterOtrosTitulos, searchOtrosTitulos, jqGridRequestDto, startsWith);
	}
    
    /**
	 * Reorder the selection made in OtrosTitulos table.
	 *
	 * @param filterOtrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return Object
	 */	
    public Object reorderSelection(OtrosTitulos filterOtrosTitulos, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.otrosTitulosDao.reorderSelection(filterOtrosTitulos, jqGridRequestDto, startsWith);
	}
    
    /*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */
	 
	/**
	 * Finder method in the hierarchical the OtrosTitulos table.
	 *
	 * @param filterOtrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<JerarquiaDto<OtrosTitulos>>
	 */	
	public JQGridResponseDto<JerarquiaDto<OtrosTitulos>> jerarquia(OtrosTitulos filterOtrosTitulos, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		List<JerarquiaDto<OtrosTitulos>> listaOtrosTitulos =  this.otrosTitulosDao.findAllLikeJerarquia(filterOtrosTitulos, jqGridRequestDto);
		Long recordNum = this.otrosTitulosDao.findAllLikeCountJerarquia(filterOtrosTitulos, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<OtrosTitulos>>(jqGridRequestDto, recordNum, listaOtrosTitulos);
	}
	
	/**
	 * Finder method for siblings rows in the hierarchical the OtrosTitulos table.
	 *
	 * @param filterOtrosTitulos OtrosTitulos
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<OtrosTitulos>>
	 */	
	public JQGridResponseDto<JerarquiaDto<OtrosTitulos>> jerarquiaChildren(OtrosTitulos filterOtrosTitulos, JQGridRequestDto jqGridRequestDto){
		JQGridResponseDto<JerarquiaDto<OtrosTitulos>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<OtrosTitulos>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN, this.otrosTitulosDao.findAllChild(filterOtrosTitulos, jqGridRequestDto));
		return jqGridResponseDto;
	}
	
	
}

