package com.ejie.ab60.service.BEC;

import com.ejie.ab60.dao.BEC.TiposCertificacionDao;
import com.ejie.ab60.model.BEC.TiposCertificacion;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * TiposCertificacionServiceImpl  
 * 
 *  
 */

@Service(value = "tiposCertificacionService")
public class TiposCertificacionServiceImpl implements TiposCertificacionService {

	@Autowired
	private TiposCertificacionDao tiposCertificacionDao;

	/**
	 * Inserts a single row in the TiposCertificacion table.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion
	 * @return TiposCertificacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposCertificacion add(TiposCertificacion tiposCertificacion) {
		return this.tiposCertificacionDao.add(tiposCertificacion);
	}

	/**
	 * Updates a single row in the TiposCertificacion table.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion
	 * @return TiposCertificacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposCertificacion update(TiposCertificacion tiposCertificacion) {
		return this.tiposCertificacionDao.update(tiposCertificacion);
	}

	/**
	 * Finds a single row in the TiposCertificacion table.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion
	 * @return TiposCertificacion
	 */
	public TiposCertificacion find(TiposCertificacion tiposCertificacion) {
		return (TiposCertificacion) this.tiposCertificacionDao.find(tiposCertificacion);
	}

	/**
	 * findCertificaciones
	 * 
	 * @return listaTiposCertificacion
	 */
	@Override
	public List<TiposCertificacion> findCertificaciones(TiposCertificacion tiposCertificacion) {
		return this.tiposCertificacionDao.findCertificaciones(tiposCertificacion);
	}

	/**
	 * Deletes a single row in the TiposCertificacion table.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposCertificacion tiposCertificacion) {
		this.tiposCertificacionDao.remove(tiposCertificacion);
	}

	/**
	 * Finds a list of rows in the TiposCertificacion table.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposCertificacion>
	 */
	public List<TiposCertificacion> findAll(TiposCertificacion tiposCertificacion, JQGridRequestDto jqGridRequestDto) {
		return (List<TiposCertificacion>) this.tiposCertificacionDao.findAll(tiposCertificacion, jqGridRequestDto);
	}

	/**
	 * Finds rows in the TiposCertificacion table using like.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposCertificacion>
	 */
	public List<TiposCertificacion> findAllLike(TiposCertificacion tiposCertificacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<TiposCertificacion>) this.tiposCertificacionDao.findAllLike(tiposCertificacion, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the TiposCertificacion table.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TiposCertificacion filterTiposCertificacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.tiposCertificacionDao.removeMultiple(filterTiposCertificacion, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the TiposCertificacion table.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<TiposCertificacion>
	 */
	public JQGridResponseDto<TiposCertificacion> filter(TiposCertificacion filterTiposCertificacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<TiposCertificacion> listaTiposCertificacion = this.tiposCertificacionDao
				.findAllLike(filterTiposCertificacion, jqGridRequestDto, false);
		Long recordNum = this.tiposCertificacionDao.findAllLikeCount(
				filterTiposCertificacion != null ? filterTiposCertificacion : new TiposCertificacion(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TiposCertificacion>> reorderSelection = this.tiposCertificacionDao
					.reorderSelection(filterTiposCertificacion, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposCertificacion>(jqGridRequestDto, recordNum, listaTiposCertificacion,
					reorderSelection);
		}
		return new JQGridResponseDto<TiposCertificacion>(jqGridRequestDto, recordNum, listaTiposCertificacion);
	}

	/**
	 * Searches rows in the TiposCertificacion table.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param searchTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposCertificacion>>
	 */
	public List<TableRowDto<TiposCertificacion>> search(TiposCertificacion filterTiposCertificacion,
			TiposCertificacion searchTiposCertificacion, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposCertificacionDao.search(filterTiposCertificacion, searchTiposCertificacion, jqGridRequestDto,
				startsWith);
	}

	/**
	 * Reorder the selection made in TiposCertificacion table.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TiposCertificacion filterTiposCertificacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.tiposCertificacionDao.reorderSelection(filterTiposCertificacion, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the TiposCertificacion table.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposCertificacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposCertificacion>> jerarquia(TiposCertificacion filterTiposCertificacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TiposCertificacion>> listaTiposCertificacion = this.tiposCertificacionDao
				.findAllLikeJerarquia(filterTiposCertificacion, jqGridRequestDto);
		Long recordNum = this.tiposCertificacionDao.findAllLikeCountJerarquia(filterTiposCertificacion,
				jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposCertificacion>>(jqGridRequestDto, recordNum,
				listaTiposCertificacion);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the
	 * TiposCertificacion table.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposCertificacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposCertificacion>> jerarquiaChildren(
			TiposCertificacion filterTiposCertificacion, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TiposCertificacion>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposCertificacion>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.tiposCertificacionDao.findAllChild(filterTiposCertificacion, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
