package com.ejie.ab60.service.CTP;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.CTP.AsociacionesSectorialesDao;
import com.ejie.ab60.model.CTP.AsociacionesSectoriales;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AsociacionesSectorialesServiceImpl  
 * 
 *  
 */

@Service(value = "asociacionesSectorialesService")
public class AsociacionesSectorialesServiceImpl implements AsociacionesSectorialesService {

	@Autowired
	private AsociacionesSectorialesDao asociacionesSectorialesDao;

	/**
	 * Inserts a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @return AsociacionesSectoriales
	 */
	@Transactional(rollbackFor = Throwable.class)
	public AsociacionesSectoriales add(AsociacionesSectoriales asociacionesSectoriales) {
		return this.asociacionesSectorialesDao.add(asociacionesSectoriales);
	}

	/**
	 * Updates a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @return AsociacionesSectoriales
	 */
	@Transactional(rollbackFor = Throwable.class)
	public AsociacionesSectoriales update(AsociacionesSectoriales asociacionesSectoriales) {
		return this.asociacionesSectorialesDao.update(asociacionesSectoriales);
	}

	/**
	 * Finds a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @return AsociacionesSectoriales
	 */
	public AsociacionesSectoriales find(AsociacionesSectoriales asociacionesSectoriales) {
		return (AsociacionesSectoriales) this.asociacionesSectorialesDao.find(asociacionesSectoriales);
	}

	/**
	 * Lista de asociones sectoriales para cargar el combo del select
	 */
	@Transactional(rollbackFor = Throwable.class)
	public List<AsociacionesSectoriales> findAsociacionesSectoriales() {
		return (List<AsociacionesSectoriales>) this.asociacionesSectorialesDao.findAsociacionesSectoriales();
	}

	/**
	 * Deletes a single row in the AsociacionesSectoriales table.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(AsociacionesSectoriales asociacionesSectoriales) {
		this.asociacionesSectorialesDao.remove(asociacionesSectoriales);
	}

	/**
	 * Finds a list of rows in the AsociacionesSectoriales table.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<AsociacionesSectoriales>
	 */
	public List<AsociacionesSectoriales> findAll(AsociacionesSectoriales asociacionesSectoriales,
			JQGridRequestDto jqGridRequestDto) {
		return (List<AsociacionesSectoriales>) this.asociacionesSectorialesDao.findAll(asociacionesSectoriales,
				jqGridRequestDto);
	}

	/**
	 * Finds rows in the AsociacionesSectoriales table using like.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<AsociacionesSectoriales>
	 */
	public List<AsociacionesSectoriales> findAllLike(AsociacionesSectoriales asociacionesSectoriales,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<AsociacionesSectoriales>) this.asociacionesSectorialesDao.findAllLike(asociacionesSectoriales,
				jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the AsociacionesSectoriales table.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(AsociacionesSectoriales filterAsociacionesSectoriales, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.asociacionesSectorialesDao.removeMultiple(filterAsociacionesSectoriales, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the AsociacionesSectoriales table.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<AsociacionesSectoriales>
	 */
	public JQGridResponseDto<AsociacionesSectoriales> filter(AsociacionesSectoriales filterAsociacionesSectoriales,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<AsociacionesSectoriales> listaAsociacionesSectoriales = this.asociacionesSectorialesDao
				.findAllLike(filterAsociacionesSectoriales, jqGridRequestDto, false);
		Long recordNum = this.asociacionesSectorialesDao.findAllLikeCount(
				filterAsociacionesSectoriales != null ? filterAsociacionesSectoriales : new AsociacionesSectoriales(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<AsociacionesSectoriales>> reorderSelection = this.asociacionesSectorialesDao
					.reorderSelection(filterAsociacionesSectoriales, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<AsociacionesSectoriales>(jqGridRequestDto, recordNum,
					listaAsociacionesSectoriales, reorderSelection);
		}
		return new JQGridResponseDto<AsociacionesSectoriales>(jqGridRequestDto, recordNum,
				listaAsociacionesSectoriales);
	}

	/**
	 * Searches rows in the AsociacionesSectoriales table.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param searchAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AsociacionesSectoriales>>
	 */
	public List<TableRowDto<AsociacionesSectoriales>> search(AsociacionesSectoriales filterAsociacionesSectoriales,
			AsociacionesSectoriales searchAsociacionesSectoriales, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.asociacionesSectorialesDao.search(filterAsociacionesSectoriales, searchAsociacionesSectoriales,
				jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in AsociacionesSectoriales table.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(AsociacionesSectoriales filterAsociacionesSectoriales,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.asociacionesSectorialesDao.reorderSelection(filterAsociacionesSectoriales, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the AsociacionesSectoriales table.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>>
	 */
	public JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>> jerarquia(
			AsociacionesSectoriales filterAsociacionesSectoriales, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<JerarquiaDto<AsociacionesSectoriales>> listaAsociacionesSectoriales = this.asociacionesSectorialesDao
				.findAllLikeJerarquia(filterAsociacionesSectoriales, jqGridRequestDto);
		Long recordNum = this.asociacionesSectorialesDao.findAllLikeCountJerarquia(filterAsociacionesSectoriales,
				jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>>(jqGridRequestDto, recordNum,
				listaAsociacionesSectoriales);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the
	 * AsociacionesSectoriales table.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>>
	 */
	public JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>> jerarquiaChildren(
			AsociacionesSectoriales filterAsociacionesSectoriales, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.asociacionesSectorialesDao.findAllChild(filterAsociacionesSectoriales, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
