package com.ejie.ab60.service.CTP;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.CTP.ProyectosDao;
import com.ejie.ab60.model.CTP.Proyectos;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ProyectosServiceImpl  
 * 
 *  
 */

@Service(value = "proyectosService")
public class ProyectosServiceImpl implements ProyectosService {

	@Autowired
	private ProyectosDao proyectosDao;

	/**
	 * Inserts a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Proyectos add(Proyectos proyectos) {
		return this.proyectosDao.add(proyectos);
	}

	/**
	 * Updates a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Proyectos update(Proyectos proyectos) {
		return this.proyectosDao.update(proyectos);
	}

	/**
	 * Updates idAsociacion en la tabla in the Proyectos
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Proyectos updateIdAsociacion(Proyectos proyectos) {
		return this.proyectosDao.updateIdAsociacion(proyectos);
	}

	/**
	 * Finds a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @return Proyectos
	 */
	public Proyectos find(Proyectos proyectos) {
		return (Proyectos) this.proyectosDao.find(proyectos);
	}

	/**
	 * Deletes a single row in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Proyectos proyectos) {
		this.proyectosDao.remove(proyectos);
	}

	/**
	 * Finds a list of rows in the Proyectos table.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Proyectos>
	 */
	public List<Proyectos> findAll(Proyectos proyectos, JQGridRequestDto jqGridRequestDto) {
		return (List<Proyectos>) this.proyectosDao.findAll(proyectos, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Proyectos table using like.
	 *
	 * @param proyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Proyectos>
	 */
	public List<Proyectos> findAllLike(Proyectos proyectos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Proyectos>) this.proyectosDao.findAllLike(proyectos, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Proyectos table.
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Proyectos filterProyectos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.proyectosDao.removeMultiple(filterProyectos, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Proyectos table.
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Proyectos>
	 */
	public JQGridResponseDto<Proyectos> filter(Proyectos filterProyectos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<Proyectos> listaProyectos = this.proyectosDao.findAllLike(filterProyectos, jqGridRequestDto, false);
		Long recordNum = this.proyectosDao.findAllLikeCount(filterProyectos != null ? filterProyectos : new Proyectos(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Proyectos>> reorderSelection = this.proyectosDao.reorderSelection(filterProyectos,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Proyectos>(jqGridRequestDto, recordNum, listaProyectos, reorderSelection);
		}
		return new JQGridResponseDto<Proyectos>(jqGridRequestDto, recordNum, listaProyectos);
	}

	/**
	 * Searches rows in the Proyectos table.
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param searchProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Proyectos>>
	 */
	public List<TableRowDto<Proyectos>> search(Proyectos filterProyectos, Proyectos searchProyectos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.proyectosDao.search(filterProyectos, searchProyectos, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Proyectos table.
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Proyectos filterProyectos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.proyectosDao.reorderSelection(filterProyectos, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Proyectos table.
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Proyectos>>
	 */
	public JQGridResponseDto<JerarquiaDto<Proyectos>> jerarquia(Proyectos filterProyectos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Proyectos>> listaProyectos = this.proyectosDao.findAllLikeJerarquia(filterProyectos,
				jqGridRequestDto);
		Long recordNum = this.proyectosDao.findAllLikeCountJerarquia(filterProyectos, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Proyectos>>(jqGridRequestDto, recordNum, listaProyectos);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Proyectos table.
	 *
	 * @param filterProyectos
	 *            Proyectos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Proyectos>>
	 */
	public JQGridResponseDto<JerarquiaDto<Proyectos>> jerarquiaChildren(Proyectos filterProyectos,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Proyectos>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Proyectos>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.proyectosDao.findAllChild(filterProyectos, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
