package com.ejie.ab60.service.CTP;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.CTP.SolicitantesDao;
import com.ejie.ab60.model.CTP.Solicitantes;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * SolicitantesServiceImpl  
 * 
 *  
 */

@Service(value = "solicitantesService")
public class SolicitantesServiceImpl implements SolicitantesService {

	@Autowired
	private SolicitantesDao solicitantesDao;

	/**
	 * Inserts a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return Solicitantes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Solicitantes add(Solicitantes solicitantes) {
		return this.solicitantesDao.add(solicitantes);
	}

	/**
	 * Updates a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return Solicitantes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Solicitantes update(Solicitantes solicitantes) {
		return this.solicitantesDao.update(solicitantes);
	}

	/**
	 * Finds a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @return Solicitantes
	 */
	public Solicitantes find(Solicitantes solicitantes) {
		return (Solicitantes) this.solicitantesDao.find(solicitantes);
	}

	/**
	 * Deletes a single row in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Solicitantes solicitantes) {
		this.solicitantesDao.remove(solicitantes);
	}

	/**
	 * Finds a list of rows in the Solicitantes table.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Solicitantes>
	 */
	public List<Solicitantes> findAll(Solicitantes solicitantes, JQGridRequestDto jqGridRequestDto) {
		return (List<Solicitantes>) this.solicitantesDao.findAll(solicitantes, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Solicitantes table using like.
	 *
	 * @param solicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Solicitantes>
	 */
	public List<Solicitantes> findAllLike(Solicitantes solicitantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<Solicitantes>) this.solicitantesDao.findAllLike(solicitantes, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Solicitantes table.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Solicitantes filterSolicitantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.solicitantesDao.removeMultiple(filterSolicitantes, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Solicitantes table.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Solicitantes>
	 */
	public JQGridResponseDto<Solicitantes> filter(Solicitantes filterSolicitantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<Solicitantes> listaSolicitantes = this.solicitantesDao.findAllLike(filterSolicitantes, jqGridRequestDto,
				false);
		Long recordNum = this.solicitantesDao
				.findAllLikeCount(filterSolicitantes != null ? filterSolicitantes : new Solicitantes(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Solicitantes>> reorderSelection = this.solicitantesDao.reorderSelection(filterSolicitantes,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Solicitantes>(jqGridRequestDto, recordNum, listaSolicitantes,
					reorderSelection);
		}
		return new JQGridResponseDto<Solicitantes>(jqGridRequestDto, recordNum, listaSolicitantes);
	}

	/**
	 * Searches rows in the Solicitantes table.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param searchSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Solicitantes>>
	 */
	public List<TableRowDto<Solicitantes>> search(Solicitantes filterSolicitantes, Solicitantes searchSolicitantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.solicitantesDao.search(filterSolicitantes, searchSolicitantes, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Solicitantes table.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Solicitantes filterSolicitantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.solicitantesDao.reorderSelection(filterSolicitantes, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Solicitantes table.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Solicitantes>>
	 */
	public JQGridResponseDto<JerarquiaDto<Solicitantes>> jerarquia(Solicitantes filterSolicitantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Solicitantes>> listaSolicitantes = this.solicitantesDao
				.findAllLikeJerarquia(filterSolicitantes, jqGridRequestDto);
		Long recordNum = this.solicitantesDao.findAllLikeCountJerarquia(filterSolicitantes, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Solicitantes>>(jqGridRequestDto, recordNum, listaSolicitantes);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Solicitantes
	 * table.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Solicitantes>>
	 */
	public JQGridResponseDto<JerarquiaDto<Solicitantes>> jerarquiaChildren(Solicitantes filterSolicitantes,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Solicitantes>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Solicitantes>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.solicitantesDao.findAllChild(filterSolicitantes, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
