package com.ejie.ab60.service.DEC;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.DEC.ActAsociacionDao;
import com.ejie.ab60.model.DEC.ActAsociacion;
import com.ejie.ab60.model.DEC.AsociacionesComerciantes;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ActAsociacionServiceImpl  
 * 
 *  
 */

@Service(value = "actAsociacionService")
public class ActAsociacionServiceImpl implements ActAsociacionService {

	@Autowired
	private ActAsociacionDao actAsociacionDao;

	/**
	 * Finds a single row in the ActAsociacion table.
	 *
	 * @param actAsociacion
	 *            ActAsociacion
	 * @return ActAsociacion
	 */
	public ActAsociacion find(ActAsociacion actAsociacion) {
		return (ActAsociacion) this.actAsociacionDao.find(actAsociacion);
	}

	/**
	 * Deletes a single row in the ActAsociacion table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Integer idRelExpActSub) {
		this.actAsociacionDao.remove(idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the ActAsociacion table.
	 *
	 * @param actAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ActAsociacion>
	 */
	public List<ActAsociacion> findAll(ActAsociacion actAsociacion, JQGridRequestDto jqGridRequestDto) {
		return (List<ActAsociacion>) this.actAsociacionDao.findAll(actAsociacion, jqGridRequestDto);
	}

	/**
	 * Finds rows in the ActAsociacion table using like.
	 *
	 * @param actAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ActAsociacion>
	 */
	public List<ActAsociacion> findAllLike(ActAsociacion actAsociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<ActAsociacion>) this.actAsociacionDao.findAllLike(actAsociacion, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the ActAsociacion table.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(ActAsociacion filterActAsociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.actAsociacionDao.removeMultiple(filterActAsociacion, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the ActAsociacion table.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<ActAsociacion>
	 */
	public JQGridResponseDto<ActAsociacion> filter(ActAsociacion filterActAsociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<ActAsociacion> listaActAsociacion = this.actAsociacionDao.findAllLike(filterActAsociacion,
				jqGridRequestDto, false);
		Long recordNum = this.actAsociacionDao
				.findAllLikeCount(filterActAsociacion != null ? filterActAsociacion : new ActAsociacion(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<ActAsociacion>> reorderSelection = this.actAsociacionDao
					.reorderSelection(filterActAsociacion, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<ActAsociacion>(jqGridRequestDto, recordNum, listaActAsociacion,
					reorderSelection);
		}
		return new JQGridResponseDto<ActAsociacion>(jqGridRequestDto, recordNum, listaActAsociacion);
	}

	/**
	 * Searches rows in the ActAsociacion table.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param searchActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ActAsociacion>>
	 */
	public List<TableRowDto<ActAsociacion>> search(ActAsociacion filterActAsociacion, ActAsociacion searchActAsociacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.actAsociacionDao.search(filterActAsociacion, searchActAsociacion, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in ActAsociacion table.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(ActAsociacion filterActAsociacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.actAsociacionDao.reorderSelection(filterActAsociacion, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the ActAsociacion table.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<ActAsociacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<ActAsociacion>> jerarquia(ActAsociacion filterActAsociacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<ActAsociacion>> listaActAsociacion = this.actAsociacionDao
				.findAllLikeJerarquia(filterActAsociacion, jqGridRequestDto);
		Long recordNum = this.actAsociacionDao.findAllLikeCountJerarquia(filterActAsociacion, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<ActAsociacion>>(jqGridRequestDto, recordNum, listaActAsociacion);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the ActAsociacion
	 * table.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<ActAsociacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<ActAsociacion>> jerarquiaChildren(ActAsociacion filterActAsociacion,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<ActAsociacion>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<ActAsociacion>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.actAsociacionDao.findAllChild(filterActAsociacion, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
