package com.ejie.ab60.service.DEC;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.DEC.AsociacionesComerciantesDao;
import com.ejie.ab60.model.DEC.AsociacionesComerciantes;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AsociacionesComerciantesServiceImpl  
 * 
 *  
 */

@Service(value = "asociacionesComerciantesService")
public class AsociacionesComerciantesServiceImpl implements AsociacionesComerciantesService {

	@Autowired
	private AsociacionesComerciantesDao asociacionesComerciantesDao;

	/**
	 * Inserts a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @return AsociacionesComerciantes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public AsociacionesComerciantes add(AsociacionesComerciantes asociacionesComerciantes) {
		return this.asociacionesComerciantesDao.add(asociacionesComerciantes);
	}

	/**
	 * Updates a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @return AsociacionesComerciantes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public AsociacionesComerciantes update(AsociacionesComerciantes asociacionesComerciantes) {
		return this.asociacionesComerciantesDao.update(asociacionesComerciantes);
	}

	/**
	 * Finds a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @return AsociacionesComerciantes
	 */
	public AsociacionesComerciantes find(AsociacionesComerciantes asociacionesComerciantes) {
		return (AsociacionesComerciantes) this.asociacionesComerciantesDao.find(asociacionesComerciantes);
	}

	/**
	 * Deletes a single row in the AsociacionesComerciantes table.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(AsociacionesComerciantes asociacionesComerciantes) {
		this.asociacionesComerciantesDao.remove(asociacionesComerciantes);
	}

	/**
	 * Finds a list of rows in the AsociacionesComerciantes table.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<AsociacionesComerciantes>
	 */
	public List<AsociacionesComerciantes> findAll(AsociacionesComerciantes asociacionesComerciantes,
			JQGridRequestDto jqGridRequestDto) {
		return (List<AsociacionesComerciantes>) this.asociacionesComerciantesDao.findAll(asociacionesComerciantes,
				jqGridRequestDto);
	}

	/**
	 * Finds rows in the AsociacionesComerciantes table using like.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<AsociacionesComerciantes>
	 */
	public List<AsociacionesComerciantes> findAllLike(AsociacionesComerciantes asociacionesComerciantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<AsociacionesComerciantes>) this.asociacionesComerciantesDao.findAllLike(asociacionesComerciantes,
				jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the AsociacionesComerciantes table.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(AsociacionesComerciantes filterAsociacionesComerciantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.asociacionesComerciantesDao.removeMultiple(filterAsociacionesComerciantes, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the AsociacionesComerciantes table.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<AsociacionesComerciantes>
	 */
	public JQGridResponseDto<AsociacionesComerciantes> filter(AsociacionesComerciantes filterAsociacionesComerciantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<AsociacionesComerciantes> listaAsociacionesComerciantes = this.asociacionesComerciantesDao
				.findAllLike(filterAsociacionesComerciantes, jqGridRequestDto, false);
		Long recordNum = this.asociacionesComerciantesDao.findAllLikeCount(filterAsociacionesComerciantes != null
				? filterAsociacionesComerciantes : new AsociacionesComerciantes(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<AsociacionesComerciantes>> reorderSelection = this.asociacionesComerciantesDao
					.reorderSelection(filterAsociacionesComerciantes, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<AsociacionesComerciantes>(jqGridRequestDto, recordNum,
					listaAsociacionesComerciantes, reorderSelection);
		}
		return new JQGridResponseDto<AsociacionesComerciantes>(jqGridRequestDto, recordNum,
				listaAsociacionesComerciantes);
	}

	/**
	 * Searches rows in the AsociacionesComerciantes table.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param searchAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<AsociacionesComerciantes>>
	 */
	public List<TableRowDto<AsociacionesComerciantes>> search(AsociacionesComerciantes filterAsociacionesComerciantes,
			AsociacionesComerciantes searchAsociacionesComerciantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.asociacionesComerciantesDao.search(filterAsociacionesComerciantes, searchAsociacionesComerciantes,
				jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in AsociacionesComerciantes table.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(AsociacionesComerciantes filterAsociacionesComerciantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.asociacionesComerciantesDao.reorderSelection(filterAsociacionesComerciantes, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the AsociacionesComerciantes table.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>>
	 */
	public JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>> jerarquia(
			AsociacionesComerciantes filterAsociacionesComerciantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<JerarquiaDto<AsociacionesComerciantes>> listaAsociacionesComerciantes = this.asociacionesComerciantesDao
				.findAllLikeJerarquia(filterAsociacionesComerciantes, jqGridRequestDto);
		Long recordNum = this.asociacionesComerciantesDao.findAllLikeCountJerarquia(filterAsociacionesComerciantes,
				jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>>(jqGridRequestDto, recordNum,
				listaAsociacionesComerciantes);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the
	 * AsociacionesComerciantes table.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>>
	 */
	public JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>> jerarquiaChildren(
			AsociacionesComerciantes filterAsociacionesComerciantes, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.asociacionesComerciantesDao.findAllChild(filterAsociacionesComerciantes, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
