package com.ejie.ab60.service.DIV;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.DIV.AccionesDao;
import com.ejie.ab60.model.DIV.Acciones;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AccionesServiceImpl  
 * 
 *  
 */

@Service(value = "accionesService")
public class AccionesServiceImpl implements AccionesService {

	@Autowired
	private AccionesDao accionesDao;

	/**
	 * Inserts a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return Acciones
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Acciones add(Acciones acciones) {
		return this.accionesDao.add(acciones);
	}

	/**
	 * Updates a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return Acciones
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Acciones update(Acciones acciones) {
		return this.accionesDao.update(acciones);
	}

	/**
	 * Finds a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @return Acciones
	 */
	public Acciones find(Acciones acciones) {
		return (Acciones) this.accionesDao.find(acciones);
	}

	/**
	 * Deletes a single row in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Acciones acciones) {
		this.accionesDao.remove(acciones);
	}

	/**
	 * Finds a list of rows in the Acciones table.
	 *
	 * @param acciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Acciones>
	 */
	public List<Acciones> findAll(Acciones acciones, JQGridRequestDto jqGridRequestDto) {
		return (List<Acciones>) this.accionesDao.findAll(acciones, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Acciones table using like.
	 *
	 * @param acciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Acciones>
	 */
	public List<Acciones> findAllLike(Acciones acciones, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Acciones>) this.accionesDao.findAllLike(acciones, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Acciones table.
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Acciones filterAcciones, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.accionesDao.removeMultiple(filterAcciones, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Acciones table.
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Acciones>
	 */
	public JQGridResponseDto<Acciones> filter(Acciones filterAcciones, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<Acciones> listaAcciones = this.accionesDao.findAllLike(filterAcciones, jqGridRequestDto, false);
		Long recordNum = this.accionesDao.findAllLikeCount(filterAcciones != null ? filterAcciones : new Acciones(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Acciones>> reorderSelection = this.accionesDao.reorderSelection(filterAcciones,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Acciones>(jqGridRequestDto, recordNum, listaAcciones, reorderSelection);
		}
		return new JQGridResponseDto<Acciones>(jqGridRequestDto, recordNum, listaAcciones);
	}

	/**
	 * Searches rows in the Acciones table.
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param searchAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Acciones>>
	 */
	public List<TableRowDto<Acciones>> search(Acciones filterAcciones, Acciones searchAcciones,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.accionesDao.search(filterAcciones, searchAcciones, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Acciones table.
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Acciones filterAcciones, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.accionesDao.reorderSelection(filterAcciones, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Acciones table.
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Acciones>>
	 */
	public JQGridResponseDto<JerarquiaDto<Acciones>> jerarquia(Acciones filterAcciones,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Acciones>> listaAcciones = this.accionesDao.findAllLikeJerarquia(filterAcciones,
				jqGridRequestDto);
		Long recordNum = this.accionesDao.findAllLikeCountJerarquia(filterAcciones, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Acciones>>(jqGridRequestDto, recordNum, listaAcciones);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Acciones table.
	 *
	 * @param filterAcciones
	 *            Acciones
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Acciones>>
	 */
	public JQGridResponseDto<JerarquiaDto<Acciones>> jerarquiaChildren(Acciones filterAcciones,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Acciones>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Acciones>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.accionesDao.findAllChild(filterAcciones, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
