package com.ejie.ab60.service.MEC;

import java.math.BigDecimal;
import java.util.List;

import org.springframework.ui.Model;

import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.justificacion.RelFacActSubvencionables;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * FacturasService  
 * 
 *  
 */

public interface FacturasService {

	/**
	 * Finds el ultimo id de la tabla in the Facturas table.
	 *
	 * 
	 * @return Facturas
	 * 
	 */
	Facturas findUltimoId();

	/**
	 * Updates a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas update(Facturas facturas);

	/**
	 * Updates a Importe admitidor row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas updateImporte(Facturas facturas);

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	Facturas find(Facturas facturas);

	/**
	 * Sumatorio de importe admitido de la tabla de facturas, por expediente y
	 * relacion subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return facturas
	 */
	Facturas findFacturasPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion);

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<Facturas>
	 */
	Facturas findFacturasPorExpediente(Integer idExpediente);

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List<Facturas>
	 */
	List<Facturas> findFacturasPorRelExpActSub(Integer idRelExpActSub);

	/**
	 * Deletes a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 */
	void remove(Facturas facturas);

	/**
	 * Metodo que saca la modal de facturas relacionadas con Actu Sub
	 * 
	 * @param idCriterio
	 * @param idExpediente
	 * @return String
	 */

	String cargarModal(Integer idExpedientes, Integer expedienteValidado, Integer idCriterio, Model model);

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Facturas Bean resultante del proceso de creacion.
	 */

	Facturas add(Integer idRelacion, Integer idExpediente, Integer idCriterio, Facturas facturas, Usuario usuario);

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Facturas Bean resultante del proceso de creacion.
	 */

	Facturas addJustificacion(Integer idRelacion, Integer idExpediente, Integer idCriterio, Facturas facturas,
			Usuario usuario);

	/**
	 * Deletes a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 */

	Facturas removeFacturas(Integer idFactura, Integer idRelacion, Integer idExpediente, Integer idCriterio,
			Integer origen, Usuario usuario);

	/**
	 * Deletes a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 */

	Facturas removeFacturasJustificacion(Integer idFactura, Integer idRelacion, Integer idExpediente, Usuario usuario);

	/**
	 * Metodo para modicar el importe de admitido, cuando le damos al boton de
	 * admitir todo
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	void editImporte(Integer idRelacion, Integer idExpediente, Integer idCriterio, Usuario usuario);

	/**
	 * Metodo para modicar el importe de admitido, cuando le damos al boton de
	 * admitir todo en la justificacion
	 *
	 * @param idExpediente
	 *            Integer
	 * @return Facturas Bean resultante de la modificacion.
	 */
	void editImporteJustificacion(List<RelFacActSubvencionables> relFacActSubvencionablesList, Usuario usuario);

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */

	Facturas editFactura(Integer idRelacion, Integer idExpediente, Integer idCriterio, Facturas facturas,
			Integer origen, Usuario usuario);

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */

	Facturas editFacturaJustificacion(Integer idRelacion, Integer idExpediente, Facturas facturas, Usuario usuario);

	/**
	 * Finds a list of rows in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Facturas>
	 */
	List<Facturas> findAll(Facturas facturas, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Facturas table using like.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Facturas>
	 */
	List<Facturas> findAllLike(Facturas facturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Facturas>
	 */
	JQGridResponseDto<Facturas> filter(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches rows in the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param searchFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Facturas>>
	 */
	List<TableRowDto<Facturas>> search(Facturas filterFacturas, Facturas searchFacturas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Facturas>>
	 */
	JQGridResponseDto<JerarquiaDto<Facturas>> jerarquia(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Finder method for siblings rows in the hierarchical the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Facturas>>
	 */
	JQGridResponseDto<JerarquiaDto<Facturas>> jerarquiaChildren(Facturas filterFacturas,
			JQGridRequestDto jqGridRequestDto);

	JQGridResponseDto<Facturas> filterMarcarInspeccionable(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto,
			boolean b);

	JQGridResponseDto<Facturas> filterEMCO(Facturas filterConceptos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	Facturas editFacturaEMCO(Integer idRelacion, Integer idExpediente, Integer idCriterio, Facturas factura,
			Integer origen, Usuario usuario, Integer idActSubPadre, Integer idActSubHijo);

	Facturas addFacturaEMCO(Integer idRelacion, Facturas factura, Usuario usuario, Integer idExpediente,
			Integer idActSub, Integer idActSubPadre, Integer idActSubHijo);

	BigDecimal sumaFacturasEMCO(Integer idRelacion);

	Facturas removeFacturasEMCO(Integer idRelacion, Integer idFactura, Usuario usuario, Integer idExpediente,
			Integer idActSub, Integer idActSubHijo, Integer idActSubPadre);

	void editImporteEMCO(Integer idRelacion, Integer idExpediente, Usuario usuario);

	JQGridResponseDto<Facturas> filterMarcarInspeccionableEMCO(Facturas filterFacturas,
			JQGridRequestDto jqGridRequestDto, boolean b);

	void updatearImportesDatosProyecto(Integer idExpediente, Usuario usuario, RelExpActSub relExpActSubAux2);
}
