package com.ejie.ab60.service.MEC;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map.Entry;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.dao.MEC.FacturasDao;
import com.ejie.ab60.dao.MEC.RelFacMotDenDao;
import com.ejie.ab60.dao.MEC.RelFacMotMinDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelActSubMotDenDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelActSubMotMinDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelExpActSubDao;
import com.ejie.ab60.dao.estudioTecnico.EstudioTecnicoDao;
import com.ejie.ab60.dao.justificacion.JustificacionDao;
import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.MEC.RelFacMotDen;
import com.ejie.ab60.model.MEC.RelFacMotMin;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotDen;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotMin;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.justificacion.Justificacion;
import com.ejie.ab60.model.justificacion.RelFacActSubvencionables;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.util.UtilDate;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * FacturasServiceImpl  
 * 
 *  
 */

@Service(value = "facturasService")
public class FacturasServiceImpl implements FacturasService {

	private static final Logger logger = LoggerFactory.getLogger(FacturasServiceImpl.class);
	@Autowired
	private FacturasDao facturasDao;

	@Autowired
	private RelExpActSubDao relExpActSubDao;
	@Autowired
	private RelFacMotMinDao relFacMotMinDao;
	@Autowired
	private RelFacMotDenDao relFacMotDenDao;
	@Autowired
	private RelActSubMotDenDao relActSubMotDenDao;
	@Autowired
	private RelActSubMotMinDao relActSubMotMinDao;
	@Autowired
	private EstudioTecnicoDao estudioTecnicoDao;
	@Autowired
	private JustificacionDao justificacionDao;

	@Autowired
	private RelExpActSubService relExpActSubService;

	/**
	 * Finds el ultimo id de la tabla in the Facturas table.
	 *
	 * 
	 * @return Facturas
	 */
	public Facturas findUltimoId() {
		return this.facturasDao.findUltimoId();
	}

	/**
	 * Updates a Importe admitidor row in the Facturas table
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Facturas updateImporte(Facturas facturas) {
		return this.facturasDao.updateImporte(facturas);
	}

	/**
	 * Update single row de la tabla Facturas
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Facturas update(Facturas facturas) {
		return this.facturasDao.update(facturas);
	}

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @return Facturas
	 */
	public Facturas find(Facturas facturas) {
		return (Facturas) this.facturasDao.find(facturas);
	}

	/**
	 * Sumatorio de importe admitido de la tabla de facturas, por expediente y
	 * relacion subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * @return facturas
	 */
	public Facturas findFacturasPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion) {
		return (Facturas) this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
	}

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<Facturas>
	 */
	public Facturas findFacturasPorExpediente(Integer idExpediente) {
		return (Facturas) this.facturasDao.findFacturasPorExpediente(idExpediente);

	}

	/**
	 * Finds a single row in the Facturas table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List<Facturas>
	 */
	public List<Facturas> findFacturasPorRelExpActSub(Integer idRelExpActSub) {
		return (List<Facturas>) this.facturasDao.findFacturasPorRelExpActSub(idRelExpActSub);

	}

	/**
	 * Deletes a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Facturas facturas) {
		this.facturasDao.remove(facturas);
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Facturas Bean resultante del proceso de creacion.
	 */
	@Transactional(rollbackFor = Throwable.class)
	public @ResponseBody Facturas add(Integer idRelacion, Integer idExpediente, Integer idCriterio, Facturas facturas,
			Usuario usuario) {

		RelExpActSub relExpActSub = new RelExpActSub();

		RelExpActSub relExpActSubId = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();

		Date fecha = new Date();
		relExpActSub.setUsuarioRegistro(usuario.getNombreUsuario());
		facturas.setFechaRegistro(fecha);
		facturas.setUsuarioRegistro(usuario.getNombreUsuario());
		// No tengo el idFactura par insertar los motivos de denegacion o
		// minoracion por idFactura
		Facturas facturaId = facturasDao.findUltimoId();
		facturas.setIdFactura(facturaId.getIdFactura());
		if (0 == idRelacion) {
			relExpActSubId = relExpActSubService.findUltimoId(idExpediente, idCriterio);
			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setIdActSub(idCriterio);
			relExpActSub.setFechaRegistro(fecha);
			relExpActSub.setUsuarioRegistro(usuario.getNombreUsuario());
			relExpActSub.setImportePresentado(facturas.getImporte());
			relExpActSub.setImporteAdmitido(facturas.getImporteAdmitido());

			estudioTecnico.setImporteDisponible(facturas.getImporte());
			estudioTecnico.setImporteAdmitido(facturas.getImporteAdmitido());

			idRelacion = relExpActSubId.getIdRelExpActSub();
			relExpActSub.setIdRelExpActSub(relExpActSubId.getIdRelExpActSub());

			RelExpActSub ultimaRelacionExistente = relExpActSubService.findLastId(idExpediente, idCriterio);
			if (!ultimaRelacionExistente.getIdRelExpActSub().equals(idRelacion)) {
				relExpActSub = relExpActSubService.add(relExpActSub);
			}
			facturas.setRelExpActSub(relExpActSub);

		} else {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente,
					facturas.getRelExpActSub().getIdActSub());
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();

			// Si la relación no está creada la creamos
			if (idRelacion == 0) {
				RelExpActSub relExpActSubNew = new RelExpActSub();
				// relExpActSubNew.setIdActSub(facturas.getRelExpActSub().getIdActSub());
				relExpActSubNew.setActSubvencionable(new ActSubvencionable(facturas.getRelExpActSub().getIdActSub()));
				relExpActSubNew.setIdExpediente(idExpediente);
				relExpActSubNew.setImportePresentado(facturas.getImporte());
				relExpActSubNew.setImporteAdmitido(facturas.getImporteAdmitido());
				relExpActSubNew.setObservacionesCastellano(facturas.getObservacionesCastellano());
				relExpActSubNew.setObservacionesEuskera(facturas.getObservacionesEuskera());
				relExpActSubNew.setInspeccionable(facturas.getInspeccionable());
				relExpActSubNew.setUsuarioRegistro(usuario.getNombreUsuario());

				relExpActSubNew = this.relExpActSubDao.anyadirRelacion(relExpActSubNew);
				idRelacion = relExpActSubNew.getIdRelExpActSub();
			}

			relExpActSub.setIdRelExpActSub(idRelacion);
			facturas.setRelExpActSub(relExpActSub);
		}

		facturas.setFechaFacturaStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaFacturaStr()));
		facturas.setFechaPagadoStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaPagadoStr()));

		Facturas facturasAux = this.facturasDao.add(facturas);
		FacturasServiceImpl.logger.info("[POST] : Facturas insertado correctamente");

		// insertamos las denegaciones y minoraciones
		relFacMotDen.setIdFactura(facturasAux.getIdFactura());
		relFacMotDenDao.remove(relFacMotDen);
		FacturasServiceImpl.logger.info("[Remove lista de motivos de denegacion respecto a una factura] "
				+ facturas.getComboFacturaDenegacion().size());
		for (int i = 0; i < facturas.getComboFacturaDenegacion().size(); i++) {
			relFacMotDen.setIdFactura(facturasAux.getIdFactura());
			relFacMotDen.setIdMotivoDenegacion(
					Long.parseLong(facturas.getComboFacturaDenegacion().get(i).getComboFacturaDenegacion()));
			relFacMotDen.setFechaRegistro(new Date());
			relFacMotDen.setUsuarioRegistro(usuario.getNombreUsuario());
			FacturasServiceImpl.logger.info(
					"[obtener lista de id de comboFacturaDenegacion] " + facturas.getComboFacturaDenegacion().size());
			relFacMotDenDao.add(relFacMotDen);

		}

		relFacMotMin.setIdFactura(facturasAux.getIdFactura());
		relFacMotMinDao.remove(relFacMotMin);
		FacturasServiceImpl.logger.info("[Remove lista de motivos de minoracion respecto a una factura] "
				+ facturas.getComboFacturaMinoracion().size());
		for (int i = 0; i < facturas.getComboFacturaMinoracion().size(); i++) {

			relFacMotMin.setIdFactura(facturasAux.getIdFactura());
			relFacMotMin.setIdMotivoMinoracion(
					Long.parseLong(facturas.getComboFacturaMinoracion().get(i).getComboFacturaMinoracion()));
			relFacMotMin.setFechaRegistro(new Date());
			relFacMotMin.setUsuarioRegistro(usuario.getNombreUsuario());
			FacturasServiceImpl.logger.info(
					"[obtener lista de id de comboFacturaDenegacion] " + facturas.getComboFacturaMinoracion().size());
			relFacMotMinDao.add(relFacMotMin);

		}

		// SUMMANOS TODOS LOS IMPORTES DE FACTURAS

		Facturas facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
		if (null != facturasSum) {
			if (null != facturasSum.getImporte()) {
				relExpActSub.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
			} else {

				relExpActSub.setImportePresentado(null);
				estudioTecnico.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != facturasSum.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturasSum.getImporteAdmitido());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnico.setImporteAdmitido(null);
			}

		}
		relExpActSub.setFechaUltmodificacion(fecha);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setSubvencionCalculada(null);
		relExpActSub.setPorcentaje(null);
		// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
		relExpActSubService.updateImportePresentadoAdmtido(relExpActSub);

		// relExpActSubService.updateImporteSubvencionCalculada(relExpActSub);

		FacturasServiceImpl.logger.info("[POST] :RealExpActSub  updateado correctamente");

		// actualizamos importes de expediente en datos proyecto

		RelExpActSub relExpActSubAux2 = new RelExpActSub();

		// // sumar el importe admitido de la tabla relexpactsub del expediente
		relExpActSubAux2 = relExpActSubService.sumTotales(idExpediente);
		//
		updatearImportesDatosProyecto(idExpediente, usuario, estudioTecnico, fecha, relExpActSubAux2);

		return facturasAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Facturas Bean resultante del proceso de creacion.
	 */
	@Transactional(rollbackFor = Throwable.class)
	public @ResponseBody Facturas addJustificacion(Integer idRelacion, Integer idExpediente, Integer idCriterio,
			Facturas facturas, Usuario usuario) {

		Date fecha = new Date();

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idRelacion);
		relExpActSub.setUsuarioRegistro(usuario.getNombreUsuario());
		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setFechaUltmodificacion(fecha);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setSubvencionCalculada(null);
		relExpActSub.setPorcentaje(null);

		facturas.setFechaRegistro(fecha);
		facturas.setUsuarioRegistro(usuario.getNombreUsuario());
		// No tengo el idFactura par insertar los motivos de denegacion o
		// minoracion por idFactura
		Facturas facturaId = facturasDao.findUltimoId();
		facturas.setIdFactura(facturaId.getIdFactura());
		facturas.setRelExpActSub(relExpActSub);
		facturas.setFechaFacturaStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaFacturaStr()));
		facturas.setFechaPagadoStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaPagadoStr()));
		Facturas facturasAux = this.facturasDao.add(facturas);
		FacturasServiceImpl.logger.info("[POST] : Facturas insertado correctamente");
		this.actualizarDenegacionMinoracion(facturas, usuario.getNombreUsuario());

		this.actualizarImportesPorActuacion(relExpActSub);
		FacturasServiceImpl.logger.info("[POST] :RealExpActSub  updateado correctamente");

		// actualizamos importes de expediente en datos proyecto
		relExpActSub = relExpActSubService.sumTotalesJus(idExpediente);
		updatearImportesDatosProyecto(idExpediente, usuario, relExpActSub);

		return facturasAux;
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Facturas editFacturaJustificacion(Integer idRelacion, Integer idExpediente, Facturas facturas,
			Usuario usuario) {

		Date fecha = new Date();

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idRelacion);
		relExpActSub.setUsuarioRegistro(usuario.getNombreUsuario());
		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setFechaUltmodificacion(fecha);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setSubvencionCalculada(null);
		relExpActSub.setPorcentaje(null);
		FacturasServiceImpl.logger.info("[POST] :RealExpActSub  updateado correctamente");

		facturas.setFechaUltmodificacion(fecha);
		facturas.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		facturas.setRelExpActSub(relExpActSub);

		facturas.setFechaFacturaStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaFacturaStr()));
		facturas.setFechaPagadoStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaPagadoStr()));

		this.facturasDao.update(facturas);

		this.actualizarDenegacionMinoracion(facturas, usuario.getNombreUsuario());
		this.actualizarImportesPorActuacion(relExpActSub);

		FacturasServiceImpl.logger.info("[POST] : Facturas insertado correctamente");

		// actualizamos importes de expediente en datos proyecto
		RelExpActSub relExpActSubAux = this.relExpActSubService.sumTotalesJus(idExpediente);
		updatearImportesDatosProyecto(idExpediente, usuario, relExpActSubAux);

		return facturas;
	}

	@Transactional(rollbackFor = Throwable.class)
	public Facturas removeFacturasJustificacion(Integer idFactura, Integer idRelacion, Integer idExpediente,
			Usuario usuario) {

		Date fecha = new Date();
		Facturas facturas = new Facturas();
		RelExpActSub relExpActSub = new RelExpActSub();
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();

		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setIdRelExpActSub(idRelacion);

		relFacMotDen.setIdFactura(idFactura);
		relFacMotDenDao.remove(relFacMotDen);
		relFacMotMin.setIdFactura(idFactura);
		relFacMotMinDao.remove(relFacMotMin);
		// relExpActSubDao.remove(relExpActSub);

		facturas.setIdFactura(idFactura);
		this.facturasDao.remove(facturas);

		relExpActSub.setIdRelExpActSub(idRelacion);
		relExpActSub.setUsuarioRegistro(usuario.getNombreUsuario());
		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setFechaUltmodificacion(fecha);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setSubvencionCalculada(null);
		relExpActSub.setPorcentaje(null);

		this.actualizarImportesPorActuacion(relExpActSub);
		FacturasServiceImpl.logger.info("[POST] :RealExpActSub  updateado correctamente");

		// actualizamos importes de expediente en datos proyecto
		relExpActSub = relExpActSubService.sumTotalesJus(idExpediente);
		updatearImportesDatosProyecto(idExpediente, usuario, relExpActSub);

		return facturas;
	}

	/**
	 * Metodo para modicar el importe de admitido, cuando le damos al boton de
	 * admitir todo
	 * 
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void editImporteJustificacion(List<RelFacActSubvencionables> relFacActSubvencionablesList, Usuario usuario) {

		HashMap<Integer, RelExpActSub> relExpActSubHashMap = new HashMap<Integer, RelExpActSub>();
		// Se recorren todas las facturas del expediente y se actualiza el
		// importe admitido con el presentado.
		Facturas factura;
		Integer key = 0;
		for (int index = 0; index < relFacActSubvencionablesList.size(); index++) {
			factura = relFacActSubvencionablesList.get(index).getFactura();
			// si tienen motivos de denegacion el campo del
			// importe admitido es cero.
			if (factura.getComboFacturaDenegacion().isEmpty()) {
				factura.setImporteAdmitido(factura.getImporte());
			} else {
				factura.setImporteAdmitido(new BigDecimal(0));
			}
			factura.setFechaUltmodificacion(new Date());
			factura.setUsuarioUltmodificacion(usuario.getNombreUsuario());

			facturasDao.updateImporte(factura);
			FacturasServiceImpl.logger.info("[PUT] : Importe en Factura actualizado correctamente");

			// se añade el objeto al hash para poder actualizar despues por
			// actuacion suvencionable
			key = factura.getRelExpActSub().getIdRelExpActSub();
			if (!relExpActSubHashMap.containsKey(key)) {
				relExpActSubHashMap.put(key, factura.getRelExpActSub());
			}
		}

		for (Entry<Integer, RelExpActSub> entry : relExpActSubHashMap.entrySet()) {
			this.actualizarImportesPorActuacion(entry.getValue());
		}

		// actualizamos importes de expediente en datos proyecto
		Integer idExpediente = relFacActSubvencionablesList.get(0).getIdExpediente();
		RelExpActSub relExpActSubAux = this.relExpActSubService.sumTotalesJus(idExpediente);
		updatearImportesDatosProyecto(idExpediente, usuario, relExpActSubAux);

	}

	/**
	 * Metodo para modicar el importe de admitido, cuando le damos al boton de
	 * admitir todo
	 * 
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void editImporte(Integer idRelacion, Integer idExpediente, Integer idCriterio, Usuario usuario) {

		RelExpActSub relExpActSub = new RelExpActSub();
		Date fecha = new Date();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		Facturas factura = new Facturas();

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idCriterio);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}

		List<Facturas> facturasList = facturasDao.findFacturasPorRelExpActSub(idRelacion);
		for (int index = 0; index < facturasList.size(); index++) {
			factura.setIdFactura(facturasList.get(index).getIdFactura());
			factura.setImporte(facturasList.get(index).getImporte());
			factura.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			factura.setFechaUltmodificacion(fecha);
			facturasDao.updateImporte(factura);
			FacturasServiceImpl.logger.info("[PUT] : Importe en Factura actualizado correctamente");
		}

		FacturasServiceImpl.logger.info("[GET - findBy_PK] : Obtener Sumatorio de facturas por expediente");
		Facturas facturas = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);

		if (null != facturas) {

			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			if (null != facturas.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturas.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(BigDecimal.ZERO);
			}

			relExpActSub.setIdRelExpActSub(idRelacion);
			relExpActSub.setSubvencionCalculada(null);
			relExpActSub.setPorcentaje(null);
			relExpActSub = this.relExpActSubDao.updateImporte(relExpActSub);
			FacturasServiceImpl.logger.info("[GET - findBy_PK] : Update Importe admitido en relExpActSub");

			// actualizamos importes de expediente en datos proyecto
			RelExpActSub relExpActSubAux2 = new RelExpActSub();
			// // sumar el importe admitido de la tabla relexpactsub del
			// expediente
			relExpActSubAux2 = relExpActSubDao.sumTotales(idExpediente);
			//
			updatearImportesDatosProyecto(idExpediente, usuario, estudioTecnico, fecha, relExpActSubAux2);
		}
	}

	private void actualizarImportesPorActuacion(RelExpActSub relExpActSub) {

		Facturas facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(relExpActSub.getIdExpediente(),
				relExpActSub.getIdRelExpActSub());
		if (null != facturasSum) {
			if (null != facturasSum.getImporte()) {
				relExpActSub.setImporteJustPresentado(facturasSum.getImporte());
			} else {
				relExpActSub.setImporteJustPresentado(null);
			}
			if (null != facturasSum.getImporteAdmitido()) {
				relExpActSub.setImporteJustAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteJustAdmitido(null);
			}
		} else { // si no encuentra facturas para la actuacion subvencionable
			relExpActSub.setImporteJustPresentado(null);
			relExpActSub.setImporteJustAdmitido(null);
		}

		relExpActSubService.updateImporteJusPresentadoAdmtido(relExpActSub);
	}

	private void updatearImportesDatosProyecto(Integer idExpediente, Usuario usuario, EstudioTecnico estudioTecnico,
			Date fecha, RelExpActSub relExpActSubAux2) {
		// // Actualiazamos importe admitido de expediente
		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		//
		if (null == relExpActSubAux2.getImporteAdmitido()) {
			estudioTecnico.setImporteAdmitido(null);
		} else {
			estudioTecnico.setImporteAdmitido(relExpActSubAux2.getImporteAdmitido());
		}
		if (null == relExpActSubAux2.getImportePresentado()) {
			estudioTecnico.setImportePresentado(null);
		} else {
			estudioTecnico.setImportePresentado(relExpActSubAux2.getImportePresentado());
		}
		estudioTecnicoDao.updateImporte(estudioTecnico);
		FacturasServiceImpl.logger.info("[POST] :Estudio tecico  updateado correctamente");
	}

	private void actualizarDenegacionMinoracion(Facturas facturas, String nombreUsuario) {

		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();

		// insertamos las denegaciones y minoraciones
		relFacMotDen.setIdFactura(facturas.getIdFactura());

		try {
			relFacMotDenDao.remove(relFacMotDen);
		} catch (Exception e) {
			FacturasServiceImpl.logger.info(" VA POR EL CATCH");
		}
		FacturasServiceImpl.logger.info("[Remove lista de motivos de denegacion respecto a una factura] "
				+ facturas.getComboFacturaDenegacion().size());
		for (int i = 0; i < facturas.getComboFacturaDenegacion().size(); i++) {
			relFacMotDen.setIdFactura(facturas.getIdFactura());
			relFacMotDen.setIdMotivoDenegacion(
					Long.parseLong(facturas.getComboFacturaDenegacion().get(i).getComboFacturaDenegacion()));
			relFacMotDen.setFechaRegistro(new Date());
			relFacMotDen.setUsuarioRegistro(nombreUsuario);
			FacturasServiceImpl.logger.info(
					"[obtener lista de id de comboFacturaDenegacion] " + facturas.getComboFacturaDenegacion().size());
			relFacMotDenDao.add(relFacMotDen);

		}

		relFacMotMin.setIdFactura(facturas.getIdFactura());
		relFacMotMinDao.remove(relFacMotMin);
		FacturasServiceImpl.logger.info("[Remove lista de motivos de minoracion respecto a una factura] "
				+ facturas.getComboFacturaMinoracion().size());
		for (int i = 0; i < facturas.getComboFacturaMinoracion().size(); i++) {

			relFacMotMin.setIdFactura(facturas.getIdFactura());
			relFacMotMin.setIdMotivoMinoracion(
					Long.parseLong(facturas.getComboFacturaMinoracion().get(i).getComboFacturaMinoracion()));
			relFacMotMin.setFechaRegistro(new Date());
			relFacMotMin.setUsuarioRegistro(nombreUsuario);
			FacturasServiceImpl.logger.info(
					"[obtener lista de id de comboFacturaDenegacion] " + facturas.getComboFacturaMinoracion().size());
			relFacMotMinDao.add(relFacMotMin);

		}

	}

	public void updatearImportesDatosProyecto(Integer idExpediente, Usuario usuario, RelExpActSub relExpActSubAux2) {
		// // Actualiazamos importe admitido de expediente
		Justificacion justificacion = new Justificacion();

		justificacion.setIdExpediente(idExpediente);
		justificacion.setFechaUltmodificacion(new Date());
		justificacion.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		justificacion.setImporteJusCalculado(null);
		//
		if (null == relExpActSubAux2.getImporteJustAdmitido()) {
			justificacion.setImporteJusAdmitido(null);
		} else {
			justificacion.setImporteJusAdmitido(relExpActSubAux2.getImporteJustAdmitido());
		}
		if (null == relExpActSubAux2.getImporteJustPresentado()) {
			justificacion.setSubvencionJustificada(null);
		} else {
			justificacion.setSubvencionJustificada(relExpActSubAux2.getImporteJustPresentado());
		}
		justificacionDao.updateImporte(justificacion);
		FacturasServiceImpl.logger.info("[POST] :Estudio tecico  updateado correctamente");
	}

	/**
	 * Deletes a single row in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Facturas removeFacturas(Integer idFactura, Integer idRelacion, Integer idExpediente, Integer idCriterio,
			Integer origen, Usuario usuario) {

		Date fecha = new Date();
		Facturas facturas = new Facturas();
		Facturas facturasSum = new Facturas();
		RelExpActSub relExpActSub = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();

		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idCriterio);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}
		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setIdRelExpActSub(idRelacion);

		relFacMotDen.setIdFactura(idFactura);
		relFacMotDenDao.remove(relFacMotDen);
		relFacMotMin.setIdFactura(idFactura);
		relFacMotMinDao.remove(relFacMotMin);

		facturas.setIdFactura(idFactura);
		this.facturasDao.remove(facturas);

		List<Facturas> listaFacturass = facturasDao.findFacturasPorRelExpActSub(idRelacion);
		if (listaFacturass == null || listaFacturass.size() == 0) {
			// Primero borramos relacion de motivos de minoracion
			relActSubMotMin.setIdRelExpActSub(idRelacion);
			relActSubMotMinDao.remove(relActSubMotMin, origen);
			// Primero borramos relacion de motivos de denegacion
			relActSubMotDen.setIdRelExpActSub(idRelacion);
			relActSubMotDenDao.remove(relActSubMotDen, origen);
			// despues borramos la relacion
			relExpActSubDao.remove(relExpActSub);

			// Actualizar expediente.
			facturasSum = facturasDao.findFacturasPorExpediente(idExpediente);
			if (null == facturasSum) {

				estudioTecnico.setImportePresentado(null);
				estudioTecnico.setImporteAdmitido(null);

			} else {
				// actualizamos importes de expediente
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			}

		} else {
			facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
			if (null != facturasSum.getImporte()) {
				relExpActSub.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
			} else {

				relExpActSub.setImportePresentado(null);
				estudioTecnico.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != facturasSum.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturasSum.getImporteAdmitido());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnico.setImporteAdmitido(null);
			}
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpActSub.setPorcentaje(null);
			relExpActSub.setSubvencionCalculada(null);
			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
			relExpActSubDao.updateImportePresentadoAdmtido(relExpActSub);
			estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());

		}

		// actualizamos importes de expediente en datos proyecto
		RelExpActSub relExpActSubAux2 = new RelExpActSub();
		// // sumar el importe admitido de la tabla relexpactsub del expediente
		relExpActSubAux2 = relExpActSubDao.sumTotales(idExpediente);
		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		//
		if (null == relExpActSubAux2.getImporteAdmitido()) {
			estudioTecnico.setImporteAdmitido(null);
		} else {
			estudioTecnico.setImporteAdmitido(relExpActSubAux2.getImporteAdmitido());
		}
		if (null == relExpActSubAux2.getImportePresentado()) {
			estudioTecnico.setImportePresentado(null);
		} else {
			estudioTecnico.setImportePresentado(relExpActSubAux2.getImportePresentado());
		}
		estudioTecnicoDao.updateImporte(estudioTecnico);

		return facturas;

	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Facturas editFactura(Integer idRelacion, Integer idExpediente, Integer idCriterio, Facturas facturas,
			Integer origen, Usuario usuario) {
		RelExpActSub relExpActSub = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		Date fecha = new Date();
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();
		boolean cambioActSub = false;
		Integer idRelacionOld = idRelacion;

		facturas.setFechaUltmodificacion(fecha);
		facturas.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		facturas.setFechaFacturaStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaFacturaStr()));
		facturas.setFechaPagadoStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaPagadoStr()));

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idCriterio);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		} else {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente,
					facturas.getRelExpActSub().getIdActSub());
			if (idRelacion == ultimaRelacionExistente.getIdRelExpActSub()) {
				cambioActSub = false;
			} else {
				cambioActSub = true;
			}

			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}
		// buscar el ultimo de
		// insertamos las denegaciones y minoraciones
		relFacMotDen.setIdFactura(facturas.getIdFactura());
		relFacMotDenDao.remove(relFacMotDen);

		for (int i = 0; i < facturas.getComboFacturaDenegacion().size(); i++) {
			relFacMotDen.setIdFactura(facturas.getIdFactura());
			relFacMotDen.setIdMotivoDenegacion(
					Long.parseLong(facturas.getComboFacturaDenegacion().get(i).getComboFacturaDenegacion()));
			relFacMotDen.setFechaRegistro(new Date());
			relFacMotDen.setUsuarioRegistro(usuario.getNombreUsuario());

			relFacMotDenDao.add(relFacMotDen);

		}

		relFacMotMin.setIdFactura(facturas.getIdFactura());
		relFacMotMinDao.remove(relFacMotMin);

		for (int i = 0; i < facturas.getComboFacturaMinoracion().size(); i++) {

			// relActSubMotDenService.add(relActSubMotDen);
			relFacMotMin.setIdFactura(facturas.getIdFactura());
			relFacMotMin.setIdMotivoMinoracion(
					Long.parseLong(facturas.getComboFacturaMinoracion().get(i).getComboFacturaMinoracion()));
			relFacMotMin.setFechaRegistro(new Date());
			relFacMotMin.setUsuarioRegistro(usuario.getNombreUsuario());

			relFacMotMinDao.add(relFacMotMin);

		}

		// Si la relación no está creada la creamos
		if (idRelacion == 0) {
			RelExpActSub relExpActSubNew = new RelExpActSub();
			// relExpActSubNew.setIdActSub(facturas.getRelExpActSub().getIdActSub());
			relExpActSubNew.setActSubvencionable(new ActSubvencionable(facturas.getRelExpActSub().getIdActSub()));
			relExpActSubNew.setIdExpediente(idExpediente);
			relExpActSubNew.setImportePresentado(facturas.getImporte());
			relExpActSubNew.setImporteAdmitido(facturas.getImporteAdmitido());
			relExpActSubNew.setObservacionesCastellano(facturas.getObservacionesCastellano());
			relExpActSubNew.setObservacionesEuskera(facturas.getObservacionesEuskera());
			relExpActSubNew.setInspeccionable(facturas.getInspeccionable());
			relExpActSubNew.setUsuarioRegistro(usuario.getNombreUsuario());

			relExpActSubNew = this.relExpActSubDao.anyadirRelacion(relExpActSubNew);
			idRelacion = relExpActSubNew.getIdRelExpActSub();
		}

		relExpActSub.setIdRelExpActSub(idRelacion);
		facturas.getRelExpActSub().setIdRelExpActSub(idRelacion);

		Facturas facturasAux = this.facturasDao.update(facturas);

		// Actualizo los importes totales al cambiar de actuación
		// subvencionable
		if (cambioActSub) {
			Facturas facturasOK = new Facturas();
			facturasOK = this.facturasDao.getImportesTotales(idRelacionOld);

			RelExpActSub relExpActSubOK = new RelExpActSub();
			relExpActSubOK.setImportePresentado(facturasOK.getImporte());
			relExpActSubOK.setImporteAdmitido(facturasOK.getImporteAdmitido());
			relExpActSubOK.setSubvencionCalculada(null);
			relExpActSubOK.setPorcentaje(null);

			relExpActSubOK.setIdExpediente(idExpediente);
			relExpActSubOK.setIdRelExpActSub(idRelacionOld);

			relExpActSubOK.setFechaUltmodificacion(fecha);
			relExpActSubOK.setUsuarioUltmodificacion(usuario.getNombreUsuario());

			relExpActSubDao.updateImportePresentadoAdmtido(relExpActSubOK);
		}

		// SUMMANOS TODOS LOS IMPORTES DE FACTURAS
		Facturas facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
		if (facturasSum != null) {
			if (null != facturasSum.getImporte()) {
				relExpActSub.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
			} else {
				relExpActSub.setImportePresentado(null);
				estudioTecnico.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != facturasSum.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturasSum.getImporteAdmitido());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnico.setImporteAdmitido(null);
			}

			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());

			relExpActSub.setSubvencionCalculada(null);
			relExpActSub.setPorcentaje(null);
			relExpActSub.setIdActSub(facturas.getRelExpActSub().getIdActSub());
			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
			relExpActSubDao.updateImportePresentadoAdmtido(relExpActSub);

			// actualizamos importes de expediente en datos proyecto

			RelExpActSub relExpActSubAux2 = new RelExpActSub();

			// // sumar el importe admitido de la tabla relexpactsub del
			// expediente
			relExpActSubAux2 = relExpActSubDao.sumTotales(idExpediente);
			//
			// // Actualiazamos importe admitido de expediente
			estudioTecnico.setIdExpediente(idExpediente);
			estudioTecnico.setFechaUltmodificacion(fecha);
			estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			estudioTecnico.setSubvencionCalculada(null);
			estudioTecnico.setSubvencionResuelta(null);
			//
			if (null == relExpActSubAux2.getImporteAdmitido()) {
				estudioTecnico.setImporteAdmitido(null);
			} else {
				estudioTecnico.setImporteAdmitido(relExpActSubAux2.getImporteAdmitido());
			}
			if (null == relExpActSubAux2.getImportePresentado()) {
				estudioTecnico.setImportePresentado(null);
			} else {
				estudioTecnico.setImportePresentado(relExpActSubAux2.getImportePresentado());
			}
			estudioTecnicoDao.updateImporte(estudioTecnico);

		}

		List<Facturas> listaFacturass = facturasDao.findFacturasPorRelExpActSub(idRelacionOld);
		if (listaFacturass == null || listaFacturass.size() == 0) {
			// Primero borramos relacion de motivos de minoracion
			RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
			relActSubMotMin.setIdRelExpActSub(idRelacionOld);
			relActSubMotMinDao.remove(relActSubMotMin, origen);
			// Primero borramos relacion de motivos de denegacion
			RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
			relActSubMotDen.setIdRelExpActSub(idRelacionOld);
			relActSubMotDenDao.remove(relActSubMotDen, origen);
			// despues borramos la relacion

			relExpActSub.setIdRelExpActSub(idRelacionOld);
			relExpActSubDao.remove(relExpActSub);

		}

		return facturasAux;

	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Facturas editFacturaEMCO(Integer idRelacion, Integer idExpediente, Integer idCriterio, Facturas facturas,
			Integer origen, Usuario usuario, Integer idActSubPadre, Integer idActSubHijo) {
		RelExpActSub relExpActSub = new RelExpActSub();
		RelExpActSub relExpActSubAux = new RelExpActSub();

		EstudioTecnico estudioTecnico = new EstudioTecnico();
		EstudioTecnico estudioTecnicoAux = new EstudioTecnico();
		Date fecha = new Date();
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();
		boolean cambioActSub = false;
		Integer idRelacionOld = idRelacion;

		facturas.setFechaUltmodificacion(fecha);
		facturas.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		facturas.setFechaFacturaStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaFacturaStr()));
		facturas.setFechaPagadoStr(UtilDate.convertirStringEnStringFormateado(facturas.getFechaPagadoStr()));

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idCriterio);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		} else {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente,
					facturas.getRelExpActSub().getIdActSub());
			if (idRelacion.toString().equals(ultimaRelacionExistente.getIdRelExpActSub().toString())) {
				cambioActSub = false;
			} else {
				cambioActSub = true;
			}

			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}
		// buscar el ultimo de
		// insertamos las denegaciones y minoraciones
		relFacMotDen.setIdFactura(facturas.getIdFactura());
		relFacMotDenDao.remove(relFacMotDen);

		for (int i = 0; i < facturas.getComboFacturaDenegacion().size(); i++) {
			relFacMotDen.setIdFactura(facturas.getIdFactura());
			relFacMotDen.setIdMotivoDenegacion(
					Long.parseLong(facturas.getComboFacturaDenegacion().get(i).getComboFacturaDenegacion()));
			relFacMotDen.setFechaRegistro(new Date());
			relFacMotDen.setUsuarioRegistro(usuario.getNombreUsuario());

			relFacMotDenDao.add(relFacMotDen);

		}

		relFacMotMin.setIdFactura(facturas.getIdFactura());
		relFacMotMinDao.remove(relFacMotMin);

		for (int i = 0; i < facturas.getComboFacturaMinoracion().size(); i++) {

			// relActSubMotDenService.add(relActSubMotDen);
			relFacMotMin.setIdFactura(facturas.getIdFactura());
			relFacMotMin.setIdMotivoMinoracion(
					Long.parseLong(facturas.getComboFacturaMinoracion().get(i).getComboFacturaMinoracion()));
			relFacMotMin.setFechaRegistro(new Date());
			relFacMotMin.setUsuarioRegistro(usuario.getNombreUsuario());

			relFacMotMinDao.add(relFacMotMin);

		}

		// Si la relación no está creada la creamos
		if (idRelacion == 0) {
			RelExpActSub relExpActSubNew = new RelExpActSub();
			// relExpActSubNew.setIdActSub(facturas.getRelExpActSub().getIdActSub());
			relExpActSubNew.setActSubvencionable(new ActSubvencionable(facturas.getRelExpActSub().getIdActSub()));
			relExpActSubNew.setIdExpediente(idExpediente);
			relExpActSubNew.setImportePresentado(facturas.getImporte());
			relExpActSubNew.setImporteAdmitido(facturas.getImporteAdmitido());
			relExpActSubNew.setObservacionesCastellano(facturas.getObservacionesCastellano());
			relExpActSubNew.setObservacionesEuskera(facturas.getObservacionesEuskera());
			relExpActSubNew.setInspeccionable(facturas.getInspeccionable());
			relExpActSubNew.setUsuarioRegistro(usuario.getNombreUsuario());

			relExpActSubNew = this.relExpActSubDao.anyadirRelacion(relExpActSubNew);
			idRelacion = relExpActSubNew.getIdRelExpActSub();

			RelExpActSub relExpActSubHijoNew = new RelExpActSub();
			relExpActSubHijoNew.setActSubvencionable(new ActSubvencionable(facturas.getRelExpActSub().getIdActSub()));
			relExpActSubHijoNew.setIdExpediente(idExpediente);
			relExpActSubHijoNew.setImportePresentado(facturas.getImporte());
			relExpActSubHijoNew.setImporteAdmitido(facturas.getImporteAdmitido());
			relExpActSubHijoNew.setObservacionesCastellano(facturas.getObservacionesCastellano());
			relExpActSubHijoNew.setObservacionesEuskera(facturas.getObservacionesEuskera());
			relExpActSubHijoNew.setInspeccionable(facturas.getInspeccionable());
			relExpActSubHijoNew.setUsuarioRegistro(usuario.getNombreUsuario());

			Boolean existeRelacionPadre = this.relExpActSubDao.existeRelacionPadre(relExpActSubHijoNew);

			if (!existeRelacionPadre) {
				Integer nuevoPadre = this.relExpActSubDao
						.findRelExpActSubEmpreHijoEMCO(relExpActSubHijoNew.getActSubvencionable().getIdActSub());
				relExpActSubHijoNew.setActSubvencionable(new ActSubvencionable(nuevoPadre));
				relExpActSubHijoNew = this.relExpActSubDao.anyadirRelacion(relExpActSubHijoNew);
			}
		}

		relExpActSub.setIdRelExpActSub(idRelacion);
		relExpActSubAux.setIdRelExpActSub(idRelacion);
		facturas.getRelExpActSub().setIdRelExpActSub(idRelacion);

		SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");

		facturas.setFechaFacturaStr(UtilDate.convertirStringEnStringFormateado(sdf.format(facturas.getFechaFactura())));
		facturas.setFechaPagadoStr(UtilDate.convertirStringEnStringFormateado(sdf.format(facturas.getFechaPagado())));

		Facturas facturasAux = this.facturasDao.updateEMCO(facturas);

		// Actualizo los importes totales al cambiar de actuación
		// subvencionable
		if (cambioActSub) {
			Facturas facturasOK = new Facturas();
			facturasOK = this.facturasDao.getImportesTotales(idRelacionOld);

			RelExpActSub relExpActSubOK = new RelExpActSub();
			relExpActSubOK.setImportePresentado(facturasOK.getImporte());
			relExpActSubOK.setImporteAdmitido(facturasOK.getImporteAdmitido());
			relExpActSubOK.setSubvencionCalculada(null);
			relExpActSubOK.setPorcentaje(null);

			relExpActSubOK.setIdExpediente(idExpediente);
			relExpActSubOK.setIdRelExpActSub(idRelacionOld);

			relExpActSubOK.setFechaUltmodificacion(fecha);
			relExpActSubOK.setUsuarioUltmodificacion(usuario.getNombreUsuario());

			relExpActSubDao.updateImportePresentadoAdmtido(relExpActSubOK);

		}

		// SUMMANOS TODOS LOS IMPORTES DE FACTURAS
		Facturas facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
		Facturas facturasSumAux = this.facturasDao.findFacturasPorExpedientePorIdActSub(idExpediente, idActSubHijo);

		if (facturasSum != null && facturasSumAux != null) {
			if (null != facturasSum.getImporte()) {
				relExpActSub.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
			} else {
				relExpActSub.setImportePresentado(null);
				estudioTecnico.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != facturasSum.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturasSum.getImporteAdmitido());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnico.setImporteAdmitido(null);
			}

			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());

			relExpActSub.setSubvencionCalculada(null);
			relExpActSub.setPorcentaje(null);
			relExpActSub.setIdActSub(facturas.getRelExpActSub().getIdActSub());
			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
			this.relExpActSubService.updateRelExpActSubEmpreEMCO(idRelacion, idActSubHijo, relExpActSub, idExpediente);

			if (null != facturasSumAux.getImporte()) {
				relExpActSubAux.setImportePresentado(facturasSumAux.getImporte());
				estudioTecnicoAux.setImportePresentado(facturasSumAux.getImporte());
			} else {
				relExpActSubAux.setImportePresentado(null);
				estudioTecnicoAux.setImportePresentado(null);
			}
			relExpActSubAux.setIdExpediente(idExpediente);
			if (null != facturasSumAux.getImporteAdmitido()) {
				relExpActSubAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
				estudioTecnicoAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
			} else {
				relExpActSubAux.setImporteAdmitido(null);
				estudioTecnicoAux.setImporteAdmitido(null);
			}

			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE PADRE
			this.relExpActSubService.updateRelExpActSubPadreEMCO(idRelacion, idActSubHijo, relExpActSubAux,
					idExpediente);

			if (cambioActSub) {

				idActSubHijo = this.relExpActSubService.findNuevoIdActSubHijo(idRelacion);

				facturasSumAux = this.facturasDao.findFacturasPorExpedientePorIdActSub(idExpediente, idActSubHijo);

				if (null != facturasSumAux.getImporte()) {
					relExpActSubAux.setImportePresentado(facturasSumAux.getImporte());
					estudioTecnicoAux.setImportePresentado(facturasSumAux.getImporte());
				} else {
					relExpActSubAux.setImportePresentado(null);
					estudioTecnicoAux.setImportePresentado(null);
				}
				relExpActSubAux.setIdExpediente(idExpediente);
				if (null != facturasSumAux.getImporteAdmitido()) {
					relExpActSubAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
					estudioTecnicoAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
				} else {
					relExpActSubAux.setImporteAdmitido(null);
					estudioTecnicoAux.setImporteAdmitido(null);
				}

				// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE PADRE
				this.relExpActSubService.updateRelExpActSubPadreEMCO(idRelacion, idActSubHijo, relExpActSubAux,
						idExpediente);

			}

			// actualizamos importes de expediente en datos proyecto

			RelExpActSub relExpActSubAux2 = new RelExpActSub();

			// // sumar el importe admitido de la tabla relexpactsub del
			// expediente

			relExpActSubAux2 = this.relExpActSubService.sumaImportesFacturasEMCO(idExpediente, idActSubPadre);

			//
			// // Actualiazamos importe admitido de expediente
			estudioTecnico.setIdExpediente(idExpediente);
			estudioTecnico.setFechaUltmodificacion(fecha);
			estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			estudioTecnico.setSubvencionCalculada(null);
			estudioTecnico.setSubvencionResuelta(null);
			//
			if (null == relExpActSubAux2.getImporteAdmitido()) {
				estudioTecnico.setImporteAdmitido(null);
			} else {
				estudioTecnico.setImporteAdmitido(relExpActSubAux2.getImporteAdmitido());
			}
			if (null == relExpActSubAux2.getImportePresentado()) {
				estudioTecnico.setImportePresentado(null);
			} else {
				estudioTecnico.setImportePresentado(relExpActSubAux2.getImportePresentado());
			}

			estudioTecnicoDao.updateImporte(estudioTecnico);

			// actualizamos importes de expediente en abuelo
			this.relExpActSubService.updateRelExpActSubAbueloEMCO(estudioTecnico, idActSubPadre);
		}

		List<Facturas> listaFacturass = facturasDao.findFacturasPorRelExpActSub(idRelacionOld);
		if (listaFacturass == null || listaFacturass.size() == 0) {
			// Primero borramos relacion de motivos de minoracion
			RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
			relActSubMotMin.setIdRelExpActSub(idRelacionOld);
			relActSubMotMinDao.remove(relActSubMotMin, origen);
			// Primero borramos relacion de motivos de denegacion
			RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
			relActSubMotDen.setIdRelExpActSub(idRelacionOld);
			relActSubMotDenDao.remove(relActSubMotDen, origen);
			// despues borramos la relacion

			relExpActSub.setIdRelExpActSub(idRelacionOld);
			relExpActSubDao.remove(relExpActSub);

		}

		return facturasAux;

	}

	/**
	 * Finds a list of rows in the Facturas table.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Facturas>
	 */
	public List<Facturas> findAll(Facturas facturas, JQGridRequestDto jqGridRequestDto) {
		return (List<Facturas>) this.facturasDao.findAll(facturas, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Facturas table using like.
	 *
	 * @param facturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Facturas>
	 */
	public List<Facturas> findAllLike(Facturas facturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Facturas>) this.facturasDao.findAllLike(facturas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.facturasDao.removeMultiple(filterFacturas, jqGridRequestDto, startsWith);
	}

	/**
	 * Metodo que saca la modal de facturas relacionadas con Actu Sub
	 * 
	 * @param idCriterio
	 * @param idExpediente
	 * @return String
	 */
	@Transactional(rollbackFor = Throwable.class)
	public String cargarModal(Integer idExpedientes, Integer expedienteValidado, Integer idCriterio, Model model) {
		String idsMotivosMinoracionSeleccionados = "";
		String idsMotivosDenegacionselecionados = "";
		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
		String idioma = LocaleContextHolder.getLocale().getLanguage();
		Integer origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_ACT_SUBV;
		RelExpActSub relExpActSub = relExpActSubService.findRelPorExpedientePorCriterio(idExpedientes, idCriterio);

		model.addAttribute("criterio", idCriterio);
		model.addAttribute("expediente", idExpedientes);
		model.addAttribute("lenguaje", idioma);
		model.addAttribute("expedienteValidado", expedienteValidado);
		if (null == relExpActSub) {
			relExpActSub = new RelExpActSub();
			relExpActSub.setIdRelExpActSub(0);
			relExpActSub.setIdActSub(idCriterio);
		}
		relActSubMotMin.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		relActSubMotDen.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		List<RelActSubMotMin> relActSubMotMinList = relActSubMotMinDao
				.findIdsMotivosMinoraciones(relExpActSub.getIdRelExpActSub(), origenMotivosMinoracion);
		List<RelActSubMotDen> relActSubMotDenList = relActSubMotDenDao
				.findIdsMotivosDenegaciones(relExpActSub.getIdRelExpActSub());

		if (relActSubMotMinList.size() > 0) {
			for (int indice = 0; indice < relActSubMotMinList.size(); indice++) {
				idsMotivosMinoracionSeleccionados += Long
						.toString(relActSubMotMinList.get(indice).getIdMotivoMinoracion());
				if ((indice + 1) != relActSubMotMinList.size()) {
					idsMotivosMinoracionSeleccionados += ",";
				}
			}
			model.addAttribute("idsMotivosMinoracionSeleccionados", idsMotivosMinoracionSeleccionados);
			model.addAttribute("relActSubMotMinLis", relActSubMotMinList);
		}
		if (relActSubMotDenList.size() > 0) {
			for (int i = 0; i < relActSubMotDenList.size(); i++) {
				idsMotivosDenegacionselecionados += Long.toString(relActSubMotDenList.get(i).getIdMotivoDenegacion());
				if ((i + 1) != relActSubMotDenList.size()) {
					idsMotivosDenegacionselecionados += ",";
				}
			}
			model.addAttribute("idsMotivosDenegacionselecionados", idsMotivosDenegacionselecionados);
			model.addAttribute("relActSubMotDenList", relActSubMotDenList);
		}
		model.addAttribute("datosRelExpActSub", relExpActSub);
		return "facturas";

	}

	/**
	 * Filter method in the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Facturas>
	 */
	public JQGridResponseDto<Facturas> filter(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		Integer idRelacion = filterFacturas.getRelExpActSub().getIdRelExpActSub();
		RelExpActSub relExpActSub = new RelExpActSub();

		if (null != idRelacion && 0 == idRelacion) {
			RelExpActSub lastId = relExpActSubDao.findLastId(filterFacturas.getRelExpActSub().getIdExpediente(),
					filterFacturas.getRelExpActSub().getIdActSub());
			if (null != lastId.getIdRelExpActSub()) {
				relExpActSub.setIdRelExpActSub(lastId.getIdRelExpActSub());
				filterFacturas.setRelExpActSub(relExpActSub);

			}
		}
		List<Facturas> listaFacturass = this.facturasDao
				.findFacturasPorRelExpActSub(filterFacturas.getRelExpActSub().getIdRelExpActSub());
		Long recordNum = this.facturasDao.findAllLikeCount(filterFacturas != null ? filterFacturas : new Facturas(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Facturas>> reorderSelection = this.facturasDao.reorderSelection(filterFacturas,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Facturas>(jqGridRequestDto, recordNum, listaFacturass, reorderSelection);
		}
		return new JQGridResponseDto<Facturas>(jqGridRequestDto, recordNum, listaFacturass);
	}

	/**
	 * Filter method in the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Facturas>
	 */
	public JQGridResponseDto<Facturas> filterEMCO(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		Integer idRelacion = filterFacturas.getRelExpActSub().getIdRelExpActSub();
		RelExpActSub relExpActSub = new RelExpActSub();

		if (null != idRelacion && 0 == idRelacion) {
			RelExpActSub lastId = relExpActSubDao.findLastId(filterFacturas.getRelExpActSub().getIdExpediente(),
					filterFacturas.getRelExpActSub().getIdActSub());
			if (null != lastId.getIdRelExpActSub()) {
				relExpActSub.setIdRelExpActSub(lastId.getIdRelExpActSub());
				filterFacturas.setRelExpActSub(relExpActSub);

			}
		}
		List<Facturas> listaFacturass = this.facturasDao
				.findFacturasPorRelExpActSub(filterFacturas.getRelExpActSub().getIdRelExpActSub());
		Long recordNum = this.facturasDao.findAllLikeCount(filterFacturas != null ? filterFacturas : new Facturas(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Facturas>> reorderSelection = this.facturasDao.reorderSelection(filterFacturas,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Facturas>(jqGridRequestDto, recordNum, listaFacturass, reorderSelection);
		}
		return new JQGridResponseDto<Facturas>(jqGridRequestDto, recordNum, listaFacturass);
	}

	/**
	 * Searches rows in the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param searchFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Facturas>>
	 */
	public List<TableRowDto<Facturas>> search(Facturas filterFacturas, Facturas searchFacturas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.facturasDao.search(filterFacturas, searchFacturas, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Facturas filterFacturas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.facturasDao.reorderSelection(filterFacturas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Facturas>>
	 */
	public JQGridResponseDto<JerarquiaDto<Facturas>> jerarquia(Facturas filterFacturas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Facturas>> listaFacturas = this.facturasDao.findAllLikeJerarquia(filterFacturas,
				jqGridRequestDto);
		Long recordNum = this.facturasDao.findAllLikeCountJerarquia(filterFacturas, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Facturas>>(jqGridRequestDto, recordNum, listaFacturas);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Facturas table.
	 *
	 * @param filterFacturas
	 *            Facturas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Facturas>>
	 */
	public JQGridResponseDto<JerarquiaDto<Facturas>> jerarquiaChildren(Facturas filterFacturas,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Facturas>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Facturas>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.facturasDao.findAllChild(filterFacturas, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public JQGridResponseDto<Facturas> filterMarcarInspeccionable(Facturas filterFacturas,
			JQGridRequestDto jqGridRequestDto, boolean b) {

		List<Facturas> listaFacturass = this.facturasDao
				.findFacturasMarcarInspeccionable(filterFacturas.getRelExpActSub().getIdExpediente());

		Long recordNum = this.facturasDao.findAllLikeCount(filterFacturas != null ? filterFacturas : new Facturas(),
				false);

		return new JQGridResponseDto<Facturas>(jqGridRequestDto, recordNum, listaFacturass);
	}

	@Override
	public JQGridResponseDto<Facturas> filterMarcarInspeccionableEMCO(Facturas filterFacturas,
			JQGridRequestDto jqGridRequestDto, boolean b) {

		List<Facturas> listaFacturass = this.facturasDao
				.findFacturasMarcarInspeccionableEMCO(filterFacturas.getRelExpActSub().getIdExpediente());

		Long recordNum = this.facturasDao.findAllLikeCount(filterFacturas != null ? filterFacturas : new Facturas(),
				false);

		return new JQGridResponseDto<Facturas>(jqGridRequestDto, recordNum, listaFacturass);
	}

	@Override
	public Facturas addFacturaEMCO(Integer idRelacion, Facturas factura, Usuario usuario, Integer idExpediente,
			Integer idCriterio, Integer idActSubPadre, Integer idActSubHijo) {
		RelExpActSub relExpActSub = new RelExpActSub();
		RelExpActSub relExpActSubAux = new RelExpActSub();
		RelExpActSub relExpActSubId = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		EstudioTecnico estudioTecnicoAux = new EstudioTecnico();
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();

		Date fecha = new Date();
		relExpActSub.setUsuarioRegistro(usuario.getNombreUsuario());
		relExpActSubAux.setUsuarioRegistro(usuario.getNombreUsuario());
		factura.setFechaRegistro(fecha);
		factura.setUsuarioRegistro(usuario.getNombreUsuario());
		// No tengo el idFactura par insertar los motivos de denegacion o
		// minoracion por idFactura
		Facturas facturaId = facturasDao.findUltimoId();
		factura.setIdFactura(facturaId.getIdFactura());
		if (0 == idRelacion) {
			relExpActSubId = relExpActSubService.findUltimoId(idExpediente, idCriterio);
			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setIdActSub(idCriterio);
			relExpActSub.setFechaRegistro(fecha);
			relExpActSub.setUsuarioRegistro(usuario.getNombreUsuario());
			relExpActSub.setImportePresentado(factura.getImporte());
			relExpActSub.setImporteAdmitido(factura.getImporteAdmitido());

			estudioTecnico.setImporteDisponible(factura.getImporte());
			estudioTecnico.setImporteAdmitido(factura.getImporteAdmitido());

			estudioTecnicoAux.setImporteDisponible(factura.getImporte());
			estudioTecnicoAux.setImporteAdmitido(factura.getImporteAdmitido());

			idRelacion = relExpActSubId.getIdRelExpActSub();
			relExpActSub.setIdRelExpActSub(relExpActSubId.getIdRelExpActSub());

			RelExpActSub ultimaRelacionExistente = relExpActSubService.findLastId(idExpediente, idCriterio);
			if (!ultimaRelacionExistente.getIdRelExpActSub().equals(idRelacion)) {
				relExpActSub = relExpActSubService.add(relExpActSub);
			}
			factura.setRelExpActSub(relExpActSub);

		} else {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente,
					factura.getRelExpActSub().getIdActSub());
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();

			// Si la relación no está creada la creamos
			if (idRelacion == 0) {
				RelExpActSub relExpActSubNew = new RelExpActSub();
				// relExpActSubNew.setIdActSub(facturas.getRelExpActSub().getIdActSub());
				relExpActSubNew.setActSubvencionable(new ActSubvencionable(factura.getRelExpActSub().getIdActSub()));
				relExpActSubNew.setIdExpediente(idExpediente);
				relExpActSubNew.setImportePresentado(factura.getImporte());
				relExpActSubNew.setImporteAdmitido(factura.getImporteAdmitido());
				relExpActSubNew.setObservacionesCastellano(factura.getObservacionesCastellano());
				relExpActSubNew.setObservacionesEuskera(factura.getObservacionesEuskera());
				relExpActSubNew.setInspeccionable(factura.getInspeccionable());
				relExpActSubNew.setUsuarioRegistro(usuario.getNombreUsuario());

				relExpActSubNew = this.relExpActSubDao.anyadirRelacion(relExpActSubNew);
				idRelacion = relExpActSubNew.getIdRelExpActSub();

				RelExpActSub relExpActSubHijoNew = new RelExpActSub();
				relExpActSubHijoNew
						.setActSubvencionable(new ActSubvencionable(factura.getRelExpActSub().getIdActSub()));
				relExpActSubHijoNew.setIdExpediente(idExpediente);
				relExpActSubHijoNew.setImportePresentado(factura.getImporte());
				relExpActSubHijoNew.setImporteAdmitido(factura.getImporteAdmitido());
				relExpActSubHijoNew.setObservacionesCastellano(factura.getObservacionesCastellano());
				relExpActSubHijoNew.setObservacionesEuskera(factura.getObservacionesEuskera());
				relExpActSubHijoNew.setInspeccionable(factura.getInspeccionable());
				relExpActSubHijoNew.setUsuarioRegistro(usuario.getNombreUsuario());

				Boolean existeRelacionPadre = this.relExpActSubDao.existeRelacionPadre(relExpActSubHijoNew);

				if (!existeRelacionPadre) {
					Integer nuevoPadre = this.relExpActSubDao
							.findRelExpActSubEmpreHijoEMCO(relExpActSubHijoNew.getActSubvencionable().getIdActSub());
					relExpActSubHijoNew.setActSubvencionable(new ActSubvencionable(nuevoPadre));
					relExpActSubHijoNew = this.relExpActSubDao.anyadirRelacion(relExpActSubHijoNew);
				}
			}

			relExpActSub.setIdRelExpActSub(idRelacion);
			factura.setRelExpActSub(relExpActSub);
		}

		SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");

		factura.setFechaFacturaStr(UtilDate.convertirStringEnStringFormateado(sdf.format(factura.getFechaFactura())));
		factura.setFechaPagadoStr(UtilDate.convertirStringEnStringFormateado(sdf.format(factura.getFechaPagado())));

		Facturas facturasAux = this.facturasDao.add(factura);
		FacturasServiceImpl.logger.info("[POST] : Facturas insertado correctamente");

		// insertamos las denegaciones y minoraciones
		relFacMotDen.setIdFactura(facturasAux.getIdFactura());
		relFacMotDenDao.remove(relFacMotDen);
		FacturasServiceImpl.logger.info("[Remove lista de motivos de denegacion respecto a una factura] "
				+ factura.getComboFacturaDenegacion().size());
		for (int i = 0; i < factura.getComboFacturaDenegacion().size(); i++) {
			relFacMotDen.setIdFactura(facturasAux.getIdFactura());
			relFacMotDen.setIdMotivoDenegacion(
					Long.parseLong(factura.getComboFacturaDenegacion().get(i).getComboFacturaDenegacion()));
			relFacMotDen.setFechaRegistro(new Date());
			relFacMotDen.setUsuarioRegistro(usuario.getNombreUsuario());
			FacturasServiceImpl.logger.info(
					"[obtener lista de id de comboFacturaDenegacion] " + factura.getComboFacturaDenegacion().size());
			relFacMotDenDao.add(relFacMotDen);

		}

		relFacMotMin.setIdFactura(facturasAux.getIdFactura());
		relFacMotMinDao.remove(relFacMotMin);
		FacturasServiceImpl.logger.info("[Remove lista de motivos de minoracion respecto a una factura] "
				+ factura.getComboFacturaMinoracion().size());
		for (int i = 0; i < factura.getComboFacturaMinoracion().size(); i++) {

			relFacMotMin.setIdFactura(facturasAux.getIdFactura());
			relFacMotMin.setIdMotivoMinoracion(
					Long.parseLong(factura.getComboFacturaMinoracion().get(i).getComboFacturaMinoracion()));
			relFacMotMin.setFechaRegistro(new Date());
			relFacMotMin.setUsuarioRegistro(usuario.getNombreUsuario());
			FacturasServiceImpl.logger.info(
					"[obtener lista de id de comboFacturaDenegacion] " + factura.getComboFacturaMinoracion().size());
			relFacMotMinDao.add(relFacMotMin);

		}

		// SUMMANOS TODOS LOS IMPORTES DE FACTURAS

		Facturas facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
		Facturas facturasSumAux = this.facturasDao.findFacturasPorExpedientePorIdActSub(idExpediente, idActSubHijo);
		if (null != facturasSum && facturasSumAux != null) {
			if (null != facturasSum.getImporte()) {
				relExpActSub.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
			} else {

				relExpActSub.setImportePresentado(null);
				estudioTecnico.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != facturasSum.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturasSum.getImporteAdmitido());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnico.setImporteAdmitido(null);
			}

			if (null != facturasSumAux.getImporte()) {
				relExpActSubAux.setImportePresentado(facturasSumAux.getImporte());
				estudioTecnicoAux.setImportePresentado(facturasSumAux.getImporte());
			} else {
				relExpActSubAux.setImportePresentado(null);
				estudioTecnicoAux.setImportePresentado(null);
			}
			relExpActSubAux.setIdExpediente(idExpediente);
			if (null != facturasSumAux.getImporteAdmitido()) {
				relExpActSubAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
				estudioTecnicoAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
			} else {
				relExpActSubAux.setImporteAdmitido(null);
				estudioTecnicoAux.setImporteAdmitido(null);
			}

		}
		relExpActSub.setFechaUltmodificacion(fecha);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setSubvencionCalculada(null);
		relExpActSub.setPorcentaje(null);
		// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
		relExpActSubService.updateImportePresentadoAdmtido(relExpActSub);
		this.relExpActSubService.updateRelExpActSubPadreEMCO(idRelacion, idActSubHijo, relExpActSubAux, idExpediente);

		// relExpActSubService.updateImporteSubvencionCalculada(relExpActSub);

		FacturasServiceImpl.logger.info("[POST] :RealExpActSub  updateado correctamente");

		// actualizamos importes de expediente en datos proyecto

		RelExpActSub relExpActSubAux2 = new RelExpActSub();

		// // sumar el importe admitido de la tabla relexpactsub del expediente
		relExpActSubAux2 = this.relExpActSubService.sumaImportesFacturasEMCO(idExpediente, idActSubPadre);
		//
		updatearImportesDatosProyecto(idExpediente, usuario, estudioTecnico, fecha, relExpActSubAux2);
		this.relExpActSubService.updateRelExpActSubAbueloEMCO(estudioTecnico, idActSubPadre);

		return facturasAux;

	}

	@Override
	public BigDecimal sumaFacturasEMCO(Integer idRelacion) {
		return this.facturasDao.sumaFacturasEMCO(idRelacion);
	}

	@Override
	public Facturas removeFacturasEMCO(Integer idRelacion, Integer idFactura, Usuario usuario, Integer idExpediente,
			Integer idActSub, Integer idActSubHijo, Integer idActSubPadre) {
		Date fecha = new Date();
		Facturas facturas = new Facturas();
		Facturas facturasSum = new Facturas();
		RelExpActSub relExpActSub = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		RelExpActSub relExpActSubAux = new RelExpActSub();
		EstudioTecnico estudioTecnicoAux = new EstudioTecnico();
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		RelFacMotDen relFacMotDen = new RelFacMotDen();

		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idActSub);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}

		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setIdRelExpActSub(idRelacion);

		relFacMotDen.setIdFactura(idFactura);
		relFacMotDenDao.remove(relFacMotDen);
		relFacMotMin.setIdFactura(idFactura);
		relFacMotMinDao.remove(relFacMotMin);

		facturas.setIdFactura(idFactura);
		this.facturasDao.remove(facturas);

		List<Facturas> listaFacturass = facturasDao.findFacturasPorRelExpActSub(idRelacion);
		if (listaFacturass == null || listaFacturass.size() == 0) {
			// Primero borramos relacion de motivos de minoracion
			relActSubMotMin.setIdRelExpActSub(idRelacion);
			relActSubMotMinDao.remove(relActSubMotMin, Constantes.ORIGEN_DENEGACION_MINORACION_FACTURAS);
			// Primero borramos relacion de motivos de denegacion
			relActSubMotDen.setIdRelExpActSub(idRelacion);
			relActSubMotDenDao.remove(relActSubMotDen, Constantes.ORIGEN_DENEGACION_MINORACION_FACTURAS);

			facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
			if (null != facturasSum) {
				relExpActSub.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
			} else {

				relExpActSub.setImportePresentado(null);
				estudioTecnico.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != facturasSum) {
				relExpActSub.setImporteAdmitido(facturasSum.getImporteAdmitido());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnico.setImporteAdmitido(null);
			}
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpActSub.setPorcentaje(null);
			relExpActSub.setSubvencionCalculada(null);
			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
			relExpActSubDao.updateImportePresentadoAdmtido(relExpActSub);

			// Actualizar expediente.
			Facturas facturasSumAux = this.facturasDao.findFacturasPorExpedientePorIdActSub(idExpediente, idActSubHijo);

			if (null != facturasSumAux) {
				relExpActSubAux.setImportePresentado(facturasSumAux.getImporte());
				estudioTecnicoAux.setImportePresentado(facturasSumAux.getImporte());
			} else {

				relExpActSubAux.setImportePresentado(null);
				estudioTecnicoAux.setImportePresentado(null);
			}
			relExpActSubAux.setIdExpediente(idExpediente);
			if (null != facturasSumAux) {
				relExpActSubAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
				estudioTecnicoAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnicoAux.setImporteAdmitido(null);
			}
			relExpActSubAux.setFechaUltmodificacion(fecha);
			relExpActSubAux.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpActSubAux.setPorcentaje(null);
			relExpActSubAux.setSubvencionCalculada(null);
			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
			this.relExpActSubService.updateRelExpActSubPadreEMCO(idRelacion, idActSubHijo, relExpActSubAux,
					idExpediente);

		} else {
			facturasSum = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
			if (null != facturasSum.getImporte()) {
				relExpActSub.setImportePresentado(facturasSum.getImporte());
				estudioTecnico.setImportePresentado(facturasSum.getImporte());
			} else {

				relExpActSub.setImportePresentado(null);
				estudioTecnico.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != facturasSum.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturasSum.getImporteAdmitido());
				estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnico.setImporteAdmitido(null);
			}
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpActSub.setPorcentaje(null);
			relExpActSub.setSubvencionCalculada(null);
			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
			relExpActSubDao.updateImportePresentadoAdmtido(relExpActSub);
			estudioTecnico.setImporteAdmitido(facturasSum.getImporteAdmitido());

			Facturas facturasSumAux = this.facturasDao.findFacturasPorExpedientePorIdActSub(idExpediente, idActSubHijo);

			if (null != facturasSumAux.getImporte()) {
				relExpActSubAux.setImportePresentado(facturasSumAux.getImporte());
				estudioTecnicoAux.setImportePresentado(facturasSumAux.getImporte());
			} else {

				relExpActSubAux.setImportePresentado(null);
				estudioTecnicoAux.setImportePresentado(null);
			}
			relExpActSubAux.setIdExpediente(idExpediente);
			if (null != facturasSumAux.getImporteAdmitido()) {
				relExpActSubAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
				estudioTecnicoAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
				estudioTecnicoAux.setImporteAdmitido(null);
			}
			relExpActSubAux.setFechaUltmodificacion(fecha);
			relExpActSubAux.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpActSubAux.setPorcentaje(null);
			relExpActSubAux.setSubvencionCalculada(null);
			// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
			this.relExpActSubService.updateRelExpActSubPadreEMCO(idRelacion, idActSubHijo, relExpActSubAux,
					idExpediente);
			estudioTecnicoAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());

		}

		// actualizamos importes de expediente en datos proyecto
		RelExpActSub relExpActSubAux2 = new RelExpActSub();
		// // sumar el importe admitido de la tabla relexpactsub del expediente
		relExpActSubAux2 = this.relExpActSubService.sumaImportesFacturasEMCO(idExpediente, idActSubPadre);
		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		//
		if (null == relExpActSubAux2.getImporteAdmitido()) {
			estudioTecnico.setImporteAdmitido(null);
		} else {
			estudioTecnico.setImporteAdmitido(relExpActSubAux2.getImporteAdmitido());
		}
		if (null == relExpActSubAux2.getImportePresentado()) {
			estudioTecnico.setImportePresentado(null);
		} else {
			estudioTecnico.setImportePresentado(relExpActSubAux2.getImportePresentado());
		}
		estudioTecnicoDao.updateImporte(estudioTecnico);
		this.relExpActSubService.updateRelExpActSubAbueloEMCO(estudioTecnico, idActSubPadre);

		return facturas;
	}

	@Override
	public void editImporteEMCO(Integer idRelacion, Integer idExpediente, Usuario usuario) {
		RelExpActSub relExpActSub = new RelExpActSub();
		RelExpActSub relExpActSubAux = new RelExpActSub();
		Date fecha = new Date();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		Facturas factura = new Facturas();

		Integer idCriterio = this.relExpActSubDao.findIdCriterio(idRelacion, idExpediente);

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idCriterio);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}

		List<Facturas> facturasList = facturasDao.findFacturasPorRelExpActSub(idRelacion);
		for (int index = 0; index < facturasList.size(); index++) {
			factura.setIdFactura(facturasList.get(index).getIdFactura());
			factura.setImporte(facturasList.get(index).getImporte());
			factura.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			factura.setFechaUltmodificacion(fecha);
			facturasDao.updateImporte(factura);
			FacturasServiceImpl.logger.info("[PUT] : Importe en Factura actualizado correctamente");
		}

		Integer idActSubHijo = this.relExpActSubService.findRelExpActSubEmpreHijoEMCO(idCriterio);
		Integer idActSubPadre = this.relExpActSubService.findRelExpActSubEmprePadreEMCO(idActSubHijo);

		FacturasServiceImpl.logger.info("[GET - findBy_PK] : Obtener Sumatorio de facturas por expediente");
		Facturas facturas = this.facturasDao.findFacturasPorExpedientePorRelacion(idExpediente, idRelacion);
		Facturas facturasSumAux = this.facturasDao.findFacturasPorExpedientePorIdActSub(idExpediente, idActSubHijo);

		if (null != facturas && facturasSumAux != null) {

			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			if (null != facturas.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(facturas.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(BigDecimal.ZERO);
			}

			relExpActSub.setIdRelExpActSub(idRelacion);
			relExpActSub.setSubvencionCalculada(null);
			relExpActSub.setPorcentaje(null);
			relExpActSub = this.relExpActSubDao.updateImporte(relExpActSub);

			relExpActSubAux.setIdExpediente(idExpediente);
			relExpActSubAux.setFechaUltmodificacion(fecha);
			relExpActSubAux.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			if (null != facturasSumAux.getImporteAdmitido()) {
				relExpActSubAux.setImporteAdmitido(facturasSumAux.getImporteAdmitido());
			} else {
				relExpActSubAux.setImporteAdmitido(BigDecimal.ZERO);
			}

			relExpActSubAux.setIdRelExpActSub(idRelacion);
			relExpActSubAux.setSubvencionCalculada(null);
			relExpActSubAux.setPorcentaje(null);
			this.relExpActSubService.updateRelExpActSubAdmitidoPadreEMCO(idRelacion, idActSubHijo, relExpActSubAux,
					idExpediente);
			FacturasServiceImpl.logger.info("[GET - findBy_PK] : Update Importe admitido en relExpActSub");

			// actualizamos importes de expediente en datos proyecto
			RelExpActSub relExpActSubAux2 = new RelExpActSub();
			// // sumar el importe admitido de la tabla relexpactsub del
			// expediente
			relExpActSubAux2 = this.relExpActSubService.sumaImportesFacturasEMCO(idExpediente, idActSubPadre);
			//
			updatearImportesDatosProyecto(idExpediente, usuario, estudioTecnico, fecha, relExpActSubAux2);
			updatearImportesDatosProyectoEMCO(idExpediente, usuario, estudioTecnico, fecha, relExpActSubAux2,
					idActSubPadre);
		}
	}

	private void updatearImportesDatosProyectoEMCO(Integer idExpediente, Usuario usuario, EstudioTecnico estudioTecnico,
			Date fecha, RelExpActSub relExpActSubAux2, Integer idActSubPadre) {
		// // Actualiazamos importe admitido de expediente
		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		//
		if (null == relExpActSubAux2.getImporteAdmitido()) {
			estudioTecnico.setImporteAdmitido(null);
		} else {
			estudioTecnico.setImporteAdmitido(relExpActSubAux2.getImporteAdmitido());
		}
		if (null == relExpActSubAux2.getImportePresentado()) {
			estudioTecnico.setImportePresentado(null);
		} else {
			estudioTecnico.setImportePresentado(relExpActSubAux2.getImportePresentado());
		}
		this.relExpActSubService.updateRelExpActSubAbueloEMCO(estudioTecnico, idActSubPadre);
		FacturasServiceImpl.logger.info("[POST] :Estudio tecico  updateado correctamente");
	}
}
