package com.ejie.ab60.service.MEC;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.MEC.IaeDao;
import com.ejie.ab60.model.MEC.Iae;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * IaeServiceImpl  
 * 
 *  
 */

@Service(value = "iaeService")
public class IaeServiceImpl implements IaeService {

	@Autowired
	private IaeDao iaeDao;

	/**
	 * Inserts a single row in the Iae table.
	 *
	 * @param iae
	 *            Iae
	 * @return Iae
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Iae add(Iae iae) {
		return this.iaeDao.add(iae);
	}

	/**
	 * Updates a single row in the Iae table.
	 *
	 * @param iae
	 *            Iae
	 * @return Iae
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Iae update(Iae iae) {
		return this.iaeDao.update(iae);
	}

	/**
	 * Finds a single row in the Iae table.
	 *
	 * @param iae
	 *            Iae
	 * @return Iae
	 */
	public Iae find(Iae iae) {
		return (Iae) this.iaeDao.find(iae);
	}

	/**
	 * Deletes a single row in the Iae table.
	 *
	 * @param iae
	 *            Iae
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Iae iae) {
		this.iaeDao.remove(iae);
	}

	/**
	 * Finds a list of rows in the Iae table.
	 *
	 * @param iae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Iae>
	 */
	public List<Iae> findAll(Iae iae, JQGridRequestDto jqGridRequestDto) {
		return (List<Iae>) this.iaeDao.findAll(iae, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Iae table using like.
	 *
	 * @param iae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Iae>
	 */
	public List<Iae> findAllLike(Iae iae, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Iae>) this.iaeDao.findAllLike(iae, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Iae table.
	 *
	 * @param filterIae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Iae filterIae, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.iaeDao.removeMultiple(filterIae, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Iae table.
	 *
	 * @param filterIae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Iae>
	 */
	public JQGridResponseDto<Iae> filter(Iae filterIae, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<Iae> listaIae = this.iaeDao.findAllLike(filterIae, jqGridRequestDto, false);
		Long recordNum = this.iaeDao.findAllLikeCount(filterIae != null ? filterIae : new Iae(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Iae>> reorderSelection = this.iaeDao.reorderSelection(filterIae, jqGridRequestDto,
					startsWith);
			return new JQGridResponseDto<Iae>(jqGridRequestDto, recordNum, listaIae, reorderSelection);
		}
		return new JQGridResponseDto<Iae>(jqGridRequestDto, recordNum, listaIae);
	}

	/**
	 * Searches rows in the Iae table.
	 *
	 * @param filterIae
	 *            Iae
	 * @param searchIae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Iae>>
	 */
	public List<TableRowDto<Iae>> search(Iae filterIae, Iae searchIae, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.iaeDao.search(filterIae, searchIae, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Iae table.
	 *
	 * @param filterIae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Iae filterIae, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.iaeDao.reorderSelection(filterIae, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Iae table.
	 *
	 * @param filterIae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Iae>>
	 */
	public JQGridResponseDto<JerarquiaDto<Iae>> jerarquia(Iae filterIae, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<JerarquiaDto<Iae>> listaIae = this.iaeDao.findAllLikeJerarquia(filterIae, jqGridRequestDto);
		Long recordNum = this.iaeDao.findAllLikeCountJerarquia(filterIae, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Iae>>(jqGridRequestDto, recordNum, listaIae);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Iae table.
	 *
	 * @param filterIae
	 *            Iae
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Iae>>
	 */
	public JQGridResponseDto<JerarquiaDto<Iae>> jerarquiaChildren(Iae filterIae, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Iae>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Iae>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.iaeDao.findAllChild(filterIae, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
