package com.ejie.ab60.service.MEC;

import java.util.List;

import com.ejie.ab60.model.MEC.Participantes;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ParticipantesService  
 * 
 *  
 */

public interface ParticipantesService {

	/**
	 * Inserts a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return Participantes
	 */
	Participantes add(Participantes participantes);

	/**
	 * Updates a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @return Participantes
	 */
	Participantes update(Participantes participantes);

	/**
	 * Busca la lista de participantes para la comunidad de bienes ,del
	 * solicitante titular
	 *
	 * @param idTercero
	 *            Integer
	 * @return List<Participantes> Participantes
	 */
	List<Participantes> find(Integer idTercero);

	/**
	 * Busca participante de la comunidad de bienes del solicitante titular
	 *
	 * @param idParticipante
	 *            Integer
	 * @return Participantes participantes
	 */

	Participantes findParticipante(Integer idParticipante);

	/**
	 * Deletes a single row in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 */
	void remove(Participantes participantes);

	/**
	 * Finds a list of rows in the Participantes table.
	 *
	 * @param participantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Participantes>
	 */
	List<Participantes> findAll(Participantes participantes, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in Participantes using like.
	 *
	 * @param participantes
	 *            Participantes
	 * @return List<Participantes>
	 */
	List<Participantes> findAllLike(Participantes participantes, Expedientes expediente);

	/**
	 * Finds rows in the Participantes table using like.
	 *
	 * @param participantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Participantes>
	 */
	List<Participantes> findAllLike(Participantes participantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Participantes table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the Participantes table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Participantes>
	 */
	JQGridResponseDto<Participantes> filter(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches rows in the Participantes table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param searchParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Participantes>>
	 */
	List<TableRowDto<Participantes>> search(Participantes filterParticipantes, Participantes searchParticipantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in Participantes table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(Participantes filterParticipantes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Participantes table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Participantes>>
	 */
	JQGridResponseDto<JerarquiaDto<Participantes>> jerarquia(Participantes filterParticipantes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Finder method for siblings rows in the hierarchical the Participantes
	 * table.
	 *
	 * @param filterParticipantes
	 *            Participantes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Participantes>>
	 */
	JQGridResponseDto<JerarquiaDto<Participantes>> jerarquiaChildren(Participantes filterParticipantes,
			JQGridRequestDto jqGridRequestDto);

}
