package com.ejie.ab60.service.OTC;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.OTC.ZonasDao;
import com.ejie.ab60.model.OTC.Zonas;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ZonasServiceImpl  
 * 
 *  
 */

@Service(value = "zonasService")
public class ZonasServiceImpl implements ZonasService {

	@Autowired
	private ZonasDao zonasDao;

	/**
	 * Inserts a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @return Zonas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Zonas add(Zonas zonas) {
		return this.zonasDao.add(zonas);
	}

	/**
	 * Updates a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @return Zonas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Zonas update(Zonas zonas) {
		return this.zonasDao.update(zonas);
	}

	/**
	 * Finds a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @return Zonas
	 */
	public Zonas find(Zonas zonas) {
		return (Zonas) this.zonasDao.find(zonas);
	}

	/**
	 * Deletes a single row in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Zonas zonas) {
		this.zonasDao.remove(zonas);
	}

	/**
	 * Finds a list of rows in the Zonas table.
	 *
	 * @param zonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Zonas>
	 */
	public List<Zonas> findAll(Zonas zonas, JQGridRequestDto jqGridRequestDto) {
		return (List<Zonas>) this.zonasDao.findAll(zonas, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Zonas table using like.
	 *
	 * @param zonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Zonas>
	 */
	public List<Zonas> findAllLike(Zonas zonas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Zonas>) this.zonasDao.findAllLike(zonas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Zonas filterZonas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.zonasDao.removeMultiple(filterZonas, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Zonas>
	 */
	public JQGridResponseDto<Zonas> filter(Zonas filterZonas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<Zonas> listaZonas = this.zonasDao.findAllLike(filterZonas, jqGridRequestDto, false);
		Long recordNum = this.zonasDao.findAllLikeCount(filterZonas != null ? filterZonas : new Zonas(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Zonas>> reorderSelection = this.zonasDao.reorderSelection(filterZonas, jqGridRequestDto,
					startsWith);
			return new JQGridResponseDto<Zonas>(jqGridRequestDto, recordNum, listaZonas, reorderSelection);
		}
		return new JQGridResponseDto<Zonas>(jqGridRequestDto, recordNum, listaZonas);
	}

	/**
	 * Searches rows in the Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param searchZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Zonas>>
	 */
	public List<TableRowDto<Zonas>> search(Zonas filterZonas, Zonas searchZonas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.zonasDao.search(filterZonas, searchZonas, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Zonas filterZonas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.zonasDao.reorderSelection(filterZonas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Zonas>>
	 */
	public JQGridResponseDto<JerarquiaDto<Zonas>> jerarquia(Zonas filterZonas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<JerarquiaDto<Zonas>> listaZonas = this.zonasDao.findAllLikeJerarquia(filterZonas, jqGridRequestDto);
		Long recordNum = this.zonasDao.findAllLikeCountJerarquia(filterZonas, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Zonas>>(jqGridRequestDto, recordNum, listaZonas);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Zonas table.
	 *
	 * @param filterZonas
	 *            Zonas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Zonas>>
	 */
	public JQGridResponseDto<JerarquiaDto<Zonas>> jerarquiaChildren(Zonas filterZonas,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Zonas>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Zonas>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.zonasDao.findAllChild(filterZonas, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
