package com.ejie.ab60.service.PTT;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.PTT.CompetitividadDao;
import com.ejie.ab60.model.PTT.Competitividad;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * CompetitividadServiceImpl  
 * 
 *  
 */

@Service(value = "competitividadService")
public class CompetitividadServiceImpl implements CompetitividadService {

	@Autowired
	private CompetitividadDao competitividadDao;

	/**
	 * Inserts a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return Competitividad
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Competitividad add(Competitividad competitividad) {
		return this.competitividadDao.add(competitividad);
	}

	/**
	 * Updates a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return Competitividad
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Competitividad update(Competitividad competitividad) {
		return this.competitividadDao.update(competitividad);
	}

	/**
	 * Finds a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @return Competitividad
	 */
	public Competitividad find(Competitividad competitividad) {
		return (Competitividad) this.competitividadDao.find(competitividad);
	}

	/**
	 * Deletes a single row in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Competitividad competitividad) {
		this.competitividadDao.remove(competitividad);
	}

	/**
	 * Finds a list of rows in the Competitividad table.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Competitividad>
	 */
	public List<Competitividad> findAll(Competitividad competitividad, JQGridRequestDto jqGridRequestDto) {
		return (List<Competitividad>) this.competitividadDao.findAll(competitividad, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Competitividad table using like.
	 *
	 * @param competitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Competitividad>
	 */
	public List<Competitividad> findAllLike(Competitividad competitividad, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<Competitividad>) this.competitividadDao.findAllLike(competitividad, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Competitividad table.
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Competitividad filterCompetitividad, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.competitividadDao.removeMultiple(filterCompetitividad, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Competitividad table.
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Competitividad>
	 */
	public JQGridResponseDto<Competitividad> filter(Competitividad filterCompetitividad,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<Competitividad> listaCompetitividad = this.competitividadDao.findAllLike(filterCompetitividad,
				jqGridRequestDto, false);
		Long recordNum = this.competitividadDao
				.findAllLikeCount(filterCompetitividad != null ? filterCompetitividad : new Competitividad(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Competitividad>> reorderSelection = this.competitividadDao
					.reorderSelection(filterCompetitividad, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Competitividad>(jqGridRequestDto, recordNum, listaCompetitividad,
					reorderSelection);
		}
		return new JQGridResponseDto<Competitividad>(jqGridRequestDto, recordNum, listaCompetitividad);
	}

	/**
	 * Searches rows in the Competitividad table.
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param searchCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Competitividad>>
	 */
	public List<TableRowDto<Competitividad>> search(Competitividad filterCompetitividad,
			Competitividad searchCompetitividad, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.competitividadDao.search(filterCompetitividad, searchCompetitividad, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Competitividad table.
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Competitividad filterCompetitividad, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.competitividadDao.reorderSelection(filterCompetitividad, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Competitividad table.
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Competitividad>>
	 */
	public JQGridResponseDto<JerarquiaDto<Competitividad>> jerarquia(Competitividad filterCompetitividad,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Competitividad>> listaCompetitividad = this.competitividadDao
				.findAllLikeJerarquia(filterCompetitividad, jqGridRequestDto);
		Long recordNum = this.competitividadDao.findAllLikeCountJerarquia(filterCompetitividad, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Competitividad>>(jqGridRequestDto, recordNum, listaCompetitividad);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Competitividad
	 * table.
	 *
	 * @param filterCompetitividad
	 *            Competitividad
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Competitividad>>
	 */
	public JQGridResponseDto<JerarquiaDto<Competitividad>> jerarquiaChildren(Competitividad filterCompetitividad,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Competitividad>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Competitividad>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.competitividadDao.findAllChild(filterCompetitividad, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
