package com.ejie.ab60.service.PTT;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.PTT.ContratacionesPersonalDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelExpActSubDao;
import com.ejie.ab60.model.PTT.ContratacionesPersonal;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ContratacionesPersonalServiceImpl  
 * 
 *  
 */

@Service(value = "contratacionesPersonalService")
public class ContratacionesPersonalServiceImpl implements ContratacionesPersonalService {

	@Autowired
	private ContratacionesPersonalDao contratacionesPersonalDao;

	@Autowired
	private RelExpActSubDao relExpActSubDao;

	/**
	 * Inserts a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal
	 * @return ContratacionesPersonal
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ContratacionesPersonal add(ContratacionesPersonal contratacionesPersonal) {
		return this.contratacionesPersonalDao.add(contratacionesPersonal);
	}

	/**
	 * Updates a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal
	 * @return ContratacionesPersonal
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ContratacionesPersonal update(ContratacionesPersonal contratacionesPersonal) {
		return this.contratacionesPersonalDao.update(contratacionesPersonal);
	}

	/**
	 * Finds a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal
	 * @return ContratacionesPersonal
	 */
	public ContratacionesPersonal find(ContratacionesPersonal contratacionesPersonal) {
		return (ContratacionesPersonal) this.contratacionesPersonalDao.find(contratacionesPersonal);
	}

	/**
	 * Finds a single row in the ContratacionesPersonal table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List<ContratacionesPersonal>
	 */
	public List<ContratacionesPersonal> findContratacionesPersonalPorRelExpActSub(Integer idRelExpActSub) {
		return (List<ContratacionesPersonal>) this.contratacionesPersonalDao
				.findContratacionesPersonalPorRelExpActSub(idRelExpActSub);

	}

	/**
	 * Deletes a single row in the ContratacionesPersonal table.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(ContratacionesPersonal contratacionesPersonal) {
		this.contratacionesPersonalDao.remove(contratacionesPersonal);
	}

	/**
	 * Removes a single row in the ContratacionesPersonal table.
	 *
	 * @param idRelExpActSub
	 *            Integer
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Throwable.class)
	public void removeByIdRelExpActSub(Integer idRelExpActSub) {
		this.contratacionesPersonalDao.removeByIdRelExpActSub(idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the ContratacionesPersonal table.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ContratacionesPersonal>
	 */
	public List<ContratacionesPersonal> findAll(ContratacionesPersonal contratacionesPersonal,
			JQGridRequestDto jqGridRequestDto) {
		return (List<ContratacionesPersonal>) this.contratacionesPersonalDao.findAll(contratacionesPersonal,
				jqGridRequestDto);
	}

	/**
	 * Finds rows in the ContratacionesPersonal table using like.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ContratacionesPersonal>
	 */
	public List<ContratacionesPersonal> findAllLike(ContratacionesPersonal contratacionesPersonal,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<ContratacionesPersonal>) this.contratacionesPersonalDao.findAllLike(contratacionesPersonal,
				jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the ContratacionesPersonal table.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(ContratacionesPersonal filterContratacionesPersonal, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.contratacionesPersonalDao.removeMultiple(filterContratacionesPersonal, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the ContratacionesPersonal table.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<ContratacionesPersonal>
	 */
	public JQGridResponseDto<ContratacionesPersonal> filter(ContratacionesPersonal filterContratacionesPersonal,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {

		Integer idRelacion = filterContratacionesPersonal.getRelExpActSub().getIdRelExpActSub();
		if (null != idRelacion && 0 == idRelacion) {
			RelExpActSub lastId = relExpActSubDao.findLastId(filterContratacionesPersonal.getIdExpediente(),
					filterContratacionesPersonal.getIdActSub());
			if (null != lastId.getIdRelExpActSub()) {
				filterContratacionesPersonal.getRelExpActSub().setIdRelExpActSub(lastId.getIdRelExpActSub());
				filterContratacionesPersonal.setIdRelExpActSub(lastId.getIdRelExpActSub());
			}
		}

		List<ContratacionesPersonal> listaContratacionesPersonal = this.contratacionesPersonalDao
				.findContratacionesPersonalPorRelExpActSub(
						filterContratacionesPersonal.getRelExpActSub().getIdRelExpActSub());
		Long recordNum = this.contratacionesPersonalDao.findAllLikeCount(
				filterContratacionesPersonal != null ? filterContratacionesPersonal : new ContratacionesPersonal(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<ContratacionesPersonal>> reorderSelection = this.contratacionesPersonalDao
					.reorderSelection(filterContratacionesPersonal, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<ContratacionesPersonal>(jqGridRequestDto, recordNum,
					listaContratacionesPersonal, reorderSelection);
		}
		return new JQGridResponseDto<ContratacionesPersonal>(jqGridRequestDto, recordNum, listaContratacionesPersonal);
	}

	/**
	 * Searches rows in the ContratacionesPersonal table.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param searchContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ContratacionesPersonal>>
	 */
	public List<TableRowDto<ContratacionesPersonal>> search(ContratacionesPersonal filterContratacionesPersonal,
			ContratacionesPersonal searchContratacionesPersonal, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.contratacionesPersonalDao.search(filterContratacionesPersonal, searchContratacionesPersonal,
				jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in ContratacionesPersonal table.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(ContratacionesPersonal filterContratacionesPersonal,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.contratacionesPersonalDao.reorderSelection(filterContratacionesPersonal, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the ContratacionesPersonal table.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>>
	 */
	public JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>> jerarquia(
			ContratacionesPersonal filterContratacionesPersonal, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<JerarquiaDto<ContratacionesPersonal>> listaContratacionesPersonal = this.contratacionesPersonalDao
				.findAllLikeJerarquia(filterContratacionesPersonal, jqGridRequestDto);
		Long recordNum = this.contratacionesPersonalDao.findAllLikeCountJerarquia(filterContratacionesPersonal,
				jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>>(jqGridRequestDto, recordNum,
				listaContratacionesPersonal);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the
	 * ContratacionesPersonal table.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>>
	 */
	public JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>> jerarquiaChildren(
			ContratacionesPersonal filterContratacionesPersonal, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.contratacionesPersonalDao.findAllChild(filterContratacionesPersonal, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
