package com.ejie.ab60.service.PTT;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.PTT.ModalidadesContratoDao;
import com.ejie.ab60.model.PTT.ModalidadesContrato;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ModalidadesContratoServiceImpl  
 * 
 *  
 */

@Service(value = "modalidadesContratoService")
public class ModalidadesContratoServiceImpl implements ModalidadesContratoService {

	@Autowired
	private ModalidadesContratoDao modalidadesContratoDao;

	/**
	 * Finds a list of rows in the ModalidadesContrato table.
	 *
	 * 
	 * @return List<ModalidadesContrato>
	 */
	public List<ModalidadesContrato> findModalidadesContrato() {
		return (List<ModalidadesContrato>) this.modalidadesContratoDao.findModalidadesContrato();
	}

	/**
	 * Inserts a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato
	 * @return ModalidadesContrato
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ModalidadesContrato add(ModalidadesContrato modalidadesContrato) {
		return this.modalidadesContratoDao.add(modalidadesContrato);
	}

	/**
	 * Updates a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato
	 * @return ModalidadesContrato
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ModalidadesContrato update(ModalidadesContrato modalidadesContrato) {
		return this.modalidadesContratoDao.update(modalidadesContrato);
	}

	/**
	 * Finds a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato
	 * @return ModalidadesContrato
	 */
	public ModalidadesContrato find(ModalidadesContrato modalidadesContrato) {
		return (ModalidadesContrato) this.modalidadesContratoDao.find(modalidadesContrato);
	}

	/**
	 * Deletes a single row in the ModalidadesContrato table.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(ModalidadesContrato modalidadesContrato) {
		this.modalidadesContratoDao.remove(modalidadesContrato);
	}

	/**
	 * Finds a list of rows in the ModalidadesContrato table.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ModalidadesContrato>
	 */
	public List<ModalidadesContrato> findAll(ModalidadesContrato modalidadesContrato,
			JQGridRequestDto jqGridRequestDto) {
		return (List<ModalidadesContrato>) this.modalidadesContratoDao.findAll(modalidadesContrato, jqGridRequestDto);
	}

	/**
	 * Finds rows in the ModalidadesContrato table using like.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ModalidadesContrato>
	 */
	public List<ModalidadesContrato> findAllLike(ModalidadesContrato modalidadesContrato,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<ModalidadesContrato>) this.modalidadesContratoDao.findAllLike(modalidadesContrato,
				jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the ModalidadesContrato table.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(ModalidadesContrato filterModalidadesContrato, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.modalidadesContratoDao.removeMultiple(filterModalidadesContrato, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the ModalidadesContrato table.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<ModalidadesContrato>
	 */
	public JQGridResponseDto<ModalidadesContrato> filter(ModalidadesContrato filterModalidadesContrato,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<ModalidadesContrato> listaModalidadesContrato = this.modalidadesContratoDao
				.findAllLike(filterModalidadesContrato, jqGridRequestDto, false);
		Long recordNum = this.modalidadesContratoDao.findAllLikeCount(
				filterModalidadesContrato != null ? filterModalidadesContrato : new ModalidadesContrato(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<ModalidadesContrato>> reorderSelection = this.modalidadesContratoDao
					.reorderSelection(filterModalidadesContrato, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<ModalidadesContrato>(jqGridRequestDto, recordNum, listaModalidadesContrato,
					reorderSelection);
		}
		return new JQGridResponseDto<ModalidadesContrato>(jqGridRequestDto, recordNum, listaModalidadesContrato);
	}

	/**
	 * Searches rows in the ModalidadesContrato table.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param searchModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ModalidadesContrato>>
	 */
	public List<TableRowDto<ModalidadesContrato>> search(ModalidadesContrato filterModalidadesContrato,
			ModalidadesContrato searchModalidadesContrato, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.modalidadesContratoDao.search(filterModalidadesContrato, searchModalidadesContrato,
				jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in ModalidadesContrato table.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(ModalidadesContrato filterModalidadesContrato, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.modalidadesContratoDao.reorderSelection(filterModalidadesContrato, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the ModalidadesContrato table.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<ModalidadesContrato>>
	 */
	public JQGridResponseDto<JerarquiaDto<ModalidadesContrato>> jerarquia(ModalidadesContrato filterModalidadesContrato,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<ModalidadesContrato>> listaModalidadesContrato = this.modalidadesContratoDao
				.findAllLikeJerarquia(filterModalidadesContrato, jqGridRequestDto);
		Long recordNum = this.modalidadesContratoDao.findAllLikeCountJerarquia(filterModalidadesContrato,
				jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<ModalidadesContrato>>(jqGridRequestDto, recordNum,
				listaModalidadesContrato);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the
	 * ModalidadesContrato table.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<ModalidadesContrato>>
	 */
	public JQGridResponseDto<JerarquiaDto<ModalidadesContrato>> jerarquiaChildren(
			ModalidadesContrato filterModalidadesContrato, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<ModalidadesContrato>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<ModalidadesContrato>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.modalidadesContratoDao.findAllChild(filterModalidadesContrato, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
