package com.ejie.ab60.service.PTT;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.PTT.PersonasContratadasDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelExpActSubDao;
import com.ejie.ab60.model.PTT.ContratacionesPersonal;
import com.ejie.ab60.model.PTT.PersonasContratadas;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PersonasContratadasServiceImpl  
 * 
 *  
 */

@Service(value = "personasContratadasService")
public class PersonasContratadasServiceImpl implements PersonasContratadasService {

	@Autowired
	private PersonasContratadasDao personasContratadasDao;

	@Autowired
	private RelExpActSubDao relExpActSubDao;

	/**
	 * Inserts a single row in the PersonasContratadas table.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas
	 * @return PersonasContratadas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public PersonasContratadas add(PersonasContratadas personasContratadas) {
		return this.personasContratadasDao.add(personasContratadas);
	}

	/**
	 * Updates a single row in the PersonasContratadas table.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas
	 * @return PersonasContratadas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public PersonasContratadas update(PersonasContratadas personasContratadas) {
		return this.personasContratadasDao.update(personasContratadas);
	}

	/**
	 * Finds a single row in the PersonasContratadas table.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas
	 * @return PersonasContratadas
	 */
	public PersonasContratadas find(PersonasContratadas personasContratadas) {
		return (PersonasContratadas) this.personasContratadasDao.find(personasContratadas);
	}

	/**
	 * Finds a single row in the PersonasContratadas table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List<PersonasContratadas>
	 */
	public List<PersonasContratadas> findPersonasContratadasPorRelExpActSub(Integer idRelExpActSub) {
		return (List<PersonasContratadas>) this.personasContratadasDao
				.findPersonasContratadasPorRelExpActSub(idRelExpActSub);

	}

	/**
	 * Deletes a single row in the PersonasContratadas table.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(PersonasContratadas personasContratadas) {
		this.personasContratadasDao.remove(personasContratadas);
	}

	/**
	 * Removes a single row in the PersonasContratadas table.
	 *
	 * @param idRelExpActSub
	 *            Integer
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Throwable.class)
	public void removeByIdRelExpActSub(Integer idRelExpActSub) {
		this.personasContratadasDao.removeByIdRelExpActSub(idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the PersonasContratadas table.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PersonasContratadas>
	 */
	public List<PersonasContratadas> findAll(PersonasContratadas personasContratadas,
			JQGridRequestDto jqGridRequestDto) {
		return (List<PersonasContratadas>) this.personasContratadasDao.findAll(personasContratadas, jqGridRequestDto);
	}

	/**
	 * Finds rows in the PersonasContratadas table using like.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PersonasContratadas>
	 */
	public List<PersonasContratadas> findAllLike(PersonasContratadas personasContratadas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<PersonasContratadas>) this.personasContratadasDao.findAllLike(personasContratadas,
				jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the PersonasContratadas table.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(PersonasContratadas filterPersonasContratadas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.personasContratadasDao.removeMultiple(filterPersonasContratadas, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the PersonasContratadas table.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<PersonasContratadas>
	 */
	public JQGridResponseDto<PersonasContratadas> filter(PersonasContratadas filterPersonasContratadas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {

		Integer idRelacion = filterPersonasContratadas.getRelExpActSub().getIdRelExpActSub();
		if (null != idRelacion && 0 == idRelacion) {
			RelExpActSub lastId = relExpActSubDao.findLastId(filterPersonasContratadas.getIdExpediente(),
					filterPersonasContratadas.getIdActSub());
			if (null != lastId.getIdRelExpActSub()) {
				filterPersonasContratadas.getRelExpActSub().setIdRelExpActSub(lastId.getIdRelExpActSub());
				filterPersonasContratadas.setIdRelExpActSub(lastId.getIdRelExpActSub());
			}
		}
		List<PersonasContratadas> listaPersonasContratadas = this.personasContratadasDao
				.findPersonasContratadasPorRelExpActSub(
						filterPersonasContratadas.getRelExpActSub().getIdRelExpActSub());
		Long recordNum = this.personasContratadasDao.findAllLikeCount(
				filterPersonasContratadas != null ? filterPersonasContratadas : new PersonasContratadas(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<PersonasContratadas>> reorderSelection = this.personasContratadasDao
					.reorderSelection(filterPersonasContratadas, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<PersonasContratadas>(jqGridRequestDto, recordNum, listaPersonasContratadas,
					reorderSelection);
		}
		return new JQGridResponseDto<PersonasContratadas>(jqGridRequestDto, recordNum, listaPersonasContratadas);
	}

	/**
	 * Searches rows in the PersonasContratadas table.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param searchPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PersonasContratadas>>
	 */
	public List<TableRowDto<PersonasContratadas>> search(PersonasContratadas filterPersonasContratadas,
			PersonasContratadas searchPersonasContratadas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.personasContratadasDao.search(filterPersonasContratadas, searchPersonasContratadas,
				jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in PersonasContratadas table.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(PersonasContratadas filterPersonasContratadas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.personasContratadasDao.reorderSelection(filterPersonasContratadas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the PersonasContratadas table.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<PersonasContratadas>>
	 */
	public JQGridResponseDto<JerarquiaDto<PersonasContratadas>> jerarquia(PersonasContratadas filterPersonasContratadas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<PersonasContratadas>> listaPersonasContratadas = this.personasContratadasDao
				.findAllLikeJerarquia(filterPersonasContratadas, jqGridRequestDto);
		Long recordNum = this.personasContratadasDao.findAllLikeCountJerarquia(filterPersonasContratadas,
				jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<PersonasContratadas>>(jqGridRequestDto, recordNum,
				listaPersonasContratadas);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the
	 * PersonasContratadas table.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<PersonasContratadas>>
	 */
	public JQGridResponseDto<JerarquiaDto<PersonasContratadas>> jerarquiaChildren(
			PersonasContratadas filterPersonasContratadas, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<PersonasContratadas>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<PersonasContratadas>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.personasContratadasDao.findAllChild(filterPersonasContratadas, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
