package com.ejie.ab60.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.RelExpInsDao;
import com.ejie.ab60.model.RelExpIns;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpInsServiceImpl  
 * 
 *  
 */

@Service(value = "relExpInsService")
public class RelExpInsServiceImpl implements RelExpInsService {

	/**
	 * Finds a single row in the RelExpIns table.
	 *
	 * @param relExpIns
	 *            RelExpIns
	 * @return RelExpIns
	 */
	public RelExpIns findTipoInspeccion(RelExpIns relExpIns) {
		return (RelExpIns) this.relExpInsDao.find(relExpIns);
	}

	@Autowired
	private RelExpInsDao relExpInsDao;

	/**
	 * Inserts a single row in the RelExpIns table.
	 *
	 * @param relExpIns
	 *            RelExpIns
	 * @return RelExpIns
	 */
	@Transactional(rollbackFor = Throwable.class)
	public RelExpIns add(RelExpIns relExpIns) {
		return this.relExpInsDao.add(relExpIns);
	}

	/**
	 * Updates a single row in the RelExpIns table.
	 *
	 * @param relExpIns
	 *            RelExpIns
	 * @return RelExpIns
	 */
	@Transactional(rollbackFor = Throwable.class)
	public RelExpIns update(RelExpIns relExpIns) {
		return this.relExpInsDao.update(relExpIns);
	}

	/**
	 * Finds a single row in the RelExpIns table.
	 *
	 * @param relExpIns
	 *            RelExpIns
	 * @return RelExpIns
	 */
	public RelExpIns find(RelExpIns relExpIns) {
		return (RelExpIns) this.relExpInsDao.find(relExpIns);
	}

	public RelExpIns findByIdExpediente(RelExpIns relExpIns) {
		return (RelExpIns) this.relExpInsDao.findByIdExpediente(relExpIns);
	}

	@Override
	public RelExpIns findByIdentificadorInspeccion(RelExpIns relExpIns) {
		return this.relExpInsDao.findByIdentificadorInspeccion(relExpIns);
	}

	@Override
	public RelExpIns findByIdInspeccion(RelExpIns relExpIns) {
		return this.relExpInsDao.findByIdInspeccion(relExpIns);
	}

	/**
	 * Deletes a single row in the RelExpIns table.
	 *
	 * @param relExpIns
	 *            RelExpIns
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(RelExpIns relExpIns) {
		this.relExpInsDao.remove(relExpIns);
	}

	/**
	 * Finds a list of rows in the RelExpIns table.
	 *
	 * @param relExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpIns>
	 */
	public List<RelExpIns> findAll(RelExpIns relExpIns, JQGridRequestDto jqGridRequestDto) {
		return (List<RelExpIns>) this.relExpInsDao.findAll(relExpIns, jqGridRequestDto);
	}

	/**
	 * Finds rows in the RelExpIns table using like.
	 *
	 * @param relExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpIns>
	 */
	public List<RelExpIns> findAllLike(RelExpIns relExpIns, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<RelExpIns>) this.relExpInsDao.findAllLike(relExpIns, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the RelExpIns table.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(RelExpIns filterRelExpIns, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.relExpInsDao.removeMultiple(filterRelExpIns, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the RelExpIns table.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<RelExpIns>
	 */
	public JQGridResponseDto<RelExpIns> filter(RelExpIns filterRelExpIns, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<RelExpIns> listaRelExpIns = this.relExpInsDao.findAllLike(filterRelExpIns, jqGridRequestDto, false);
		Long recordNum = this.relExpInsDao.findAllLikeCount(filterRelExpIns != null ? filterRelExpIns : new RelExpIns(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<RelExpIns>> reorderSelection = this.relExpInsDao.reorderSelection(filterRelExpIns,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<RelExpIns>(jqGridRequestDto, recordNum, listaRelExpIns, reorderSelection);
		}
		return new JQGridResponseDto<RelExpIns>(jqGridRequestDto, recordNum, listaRelExpIns);
	}

	/**
	 * Searches rows in the RelExpIns table.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param searchRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpIns>>
	 */
	public List<TableRowDto<RelExpIns>> search(RelExpIns filterRelExpIns, RelExpIns searchRelExpIns,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.relExpInsDao.search(filterRelExpIns, searchRelExpIns, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in RelExpIns table.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(RelExpIns filterRelExpIns, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.relExpInsDao.reorderSelection(filterRelExpIns, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the RelExpIns table.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<RelExpIns>>
	 */
	public JQGridResponseDto<JerarquiaDto<RelExpIns>> jerarquia(RelExpIns filterRelExpIns,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<RelExpIns>> listaRelExpIns = this.relExpInsDao.findAllLikeJerarquia(filterRelExpIns,
				jqGridRequestDto);
		Long recordNum = this.relExpInsDao.findAllLikeCountJerarquia(filterRelExpIns, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<RelExpIns>>(jqGridRequestDto, recordNum, listaRelExpIns);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the RelExpIns table.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<RelExpIns>>
	 */
	public JQGridResponseDto<JerarquiaDto<RelExpIns>> jerarquiaChildren(RelExpIns filterRelExpIns,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<RelExpIns>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<RelExpIns>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.relExpInsDao.findAllChild(filterRelExpIns, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public Integer obtenerID(String identificadorInspeccion) {
		return this.relExpInsDao.obtenerID(identificadorInspeccion);
	}

}
