package com.ejie.ab60.service.calculoAyuda;

import java.sql.Types;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.SqlInOutParameter;
import org.springframework.jdbc.core.SqlOutParameter;
import org.springframework.jdbc.core.SqlParameter;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.stereotype.Service;

import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.util.DBUtils;

@Service(value = "calculoAyudaService")
public class CalculoAyudaServiceImpl implements CalculoAyudaService {

	private JdbcTemplate jdbcTemplate;

	@Autowired
	private ConvocatoriasService convocatoriasService;

	private static final Logger logger = LoggerFactory.getLogger(CalculoAyudaServiceImpl.class);

	/**
	 * 
	 * Necesario para llamar al pl-sql
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource()
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * llamamos al pl-sql para calcular la ayuda
	 *
	 * @param Integer
	 *            idConvocatoria
	 * @return string outMessage
	 */
	public String calculoAyuda(Integer idConvocatorias, Integer idExpediente, int inFase) {

		Convocatorias convocatoria = new Convocatorias();

		CalculoAyudaServiceImpl.logger.info("Inicio calculoAyuda");
		CalculoAyudaServiceImpl.logger.info("Convocatoria: " + idConvocatorias);

		/**********************************************************************
		 * SE INVOCA AL PL/SQL DE CARGA
		 **********************************************************************/

		/**
		 * Primero obtenemos de la tabla configuracion el nombre del pl/sql
		 */
		convocatoria = convocatoriasService.findNombrePLSQL(idConvocatorias);
		convocatoria.setIdConvocatoria(idConvocatorias);
		String nombrePlSql = convocatoria.getPlsqlCalculo();
		CalculoAyudaServiceImpl.logger.info(" nombrePlSql: " + nombrePlSql);

		SqlParameter[] parameters = {

				new SqlInOutParameter("IN_ID_EXPEDIENTE", Types.VARCHAR),
				new SqlInOutParameter("IN_FASE", Types.VARCHAR),

				new SqlOutParameter("OUT_AVISO", Types.VARCHAR) };

		MapSqlParameterSource parameterSource = new MapSqlParameterSource();

		parameterSource.addValue("IN_ID_EXPEDIENTE", idExpediente);
		parameterSource.addValue("IN_FASE", inFase);

		Map<String, Object> m = null;
		String mensage = "";
		try {
			m = DBUtils.callPLSQLCalculoAyuda(this.jdbcTemplate, nombrePlSql, parameters, parameterSource);
			mensage = m.get("OUT_AVISO").toString();

		} catch (Exception e) {

			CalculoAyudaServiceImpl.logger.error("Error en el procesamiento del carga del calculo de ayuda:"
					+ convocatoria.getIdConvocatoria() + "-" + e.getMessage());
		}

		CalculoAyudaServiceImpl.logger.info("String devuelto por pl/sql = " + mensage);
		return mensage;

	}
}
