package com.ejie.ab60.service.convocatorias;

import java.util.List;

import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ConvocatoriasService  
 * 
 *  
 */

public interface ConvocatoriasService {

	/**
	 * Inserts a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias add(Convocatorias convocatorias);

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias update(Convocatorias convocatorias);

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias updateFaseActiva(Convocatorias convocatorias);

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias find(Convocatorias convocatorias);

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias findFaseActiva(Convocatorias convocatorias);

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias findWithProcedimiento(Integer idProcedimiento);

	/**
	 * Encuentra el nombre del pl-sql de calculo de ayuda correspondiente a cada
	 * convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */
	Convocatorias findNombrePLSQL(Integer idConvocatorias);

	/**
	 * Encuentra el nombre del pl-sql de REPARTO de ayuda correspondiente a cada
	 * convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */

	Convocatorias findNombrePLSQLReparto(Integer idConvocatoria);

	/**
	 * Encuentra el nombre del pl-sql de ANULAR REPARTO de ayuda correspondiente
	 * a cada convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */

	Convocatorias findNombrePLSQLAnularReparto(Integer idConvocatoria);

	/**
	 * Updates Importe_Disponible en Convocatorias table.
	 *
	 * @param idConvocatorias
	 *            Integer
	 * @return Convocatorias
	 */
	Convocatorias updateImporteDisponible(Convocatorias convocatorias);

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias findProc(Convocatorias convocatorias);

	/**
	 * Convo combo.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	Convocatorias tipoConvo(Convocatorias convocatorias);

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param faseActiva
	 *            Integer
	 * @param idProcedimiento
	 *            Integer
	 * @param usuario
	 *            Usuario
	 */
	Convocatorias aplicarCorte(Integer idConvocatoria, Integer faseActiva, Integer idProcedimiento, Usuario usuario);

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param faseActiva
	 *            Integer
	 * @param idProcedimiento
	 *            Integer
	 * @param usuario
	 *            Usuario
	 */
	Convocatorias deshacerCorte(Integer idConvocatoria, Integer faseActiva, Integer idProcedimiento, Usuario usuario);

	/**
	 * Deletes a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 */
	void remove(Convocatorias convocatorias);

	/**
	 * Finds a list of rows in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Convocatorias>
	 */
	List<Convocatorias> findAll(Convocatorias convocatorias, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Convocatorias table using like.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Convocatorias>
	 */
	List<Convocatorias> findAllLike(Convocatorias convocatorias, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Convocatorias filterConvocatorias, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Convocatorias>
	 */
	JQGridResponseDto<Convocatorias> filter(Convocatorias filterConvocatorias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches rows in the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param searchConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Convocatorias>>
	 */
	List<TableRowDto<Convocatorias>> search(Convocatorias filterConvocatorias, Convocatorias searchConvocatorias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(Convocatorias filterConvocatorias, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Convocatorias>>
	 */
	JQGridResponseDto<JerarquiaDto<Convocatorias>> jerarquia(Convocatorias filterConvocatorias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Finder method for siblings rows in the hierarchical the Convocatorias
	 * table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Convocatorias>>
	 */
	JQGridResponseDto<JerarquiaDto<Convocatorias>> jerarquiaChildren(Convocatorias filterConvocatorias,
			JQGridRequestDto jqGridRequestDto);

	void updateFechas(Convocatorias convocatoria);

	Convocatorias findByIdExpediente(Integer idExpediente);

}
