package com.ejie.ab60.service.convocatorias;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.dao.BEC.PuntuacionesDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.ActSubvencionableDao;
import com.ejie.ab60.dao.convocatorias.ConvocatoriasDao;
import com.ejie.ab60.dao.estudioTecnico.EstudioTecnicoDao;
import com.ejie.ab60.model.BEC.Fases;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * ConvocatoriasServiceImpl  
 * 
 *  
 */

@Service(value = "convocatoriasService")
public class ConvocatoriasServiceImpl implements ConvocatoriasService {

	private static final Logger logger = LoggerFactory.getLogger(ConvocatoriasServiceImpl.class);

	@Autowired
	private ConvocatoriasDao convocatoriasDao;

	@Autowired
	private PuntuacionesDao puntuacionesDao;

	@Autowired
	private EstudioTecnicoDao estudioTecnicoDao;

	@Autowired
	private ActSubvencionableDao actSubvencionableDao;

	/**
	 * Inserts a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Integer
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Integer findTipoImporte(Convocatorias convocatorias) {
		EstudioTecnico estudioTipoImporte = this.estudioTecnicoDao.findTipoImporte(convocatorias.getIdConvocatoria());
		return estudioTipoImporte.getTipoImporte();
	}

	/**
	 * find tipoImporte
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Convocatorias add(Convocatorias convocatorias) {
		return this.convocatoriasDao.add(convocatorias);
	}

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Convocatorias update(Convocatorias convocatorias) {
		if (convocatorias.getIdTipoAyuda() == Constantes.TIPO_AYUDA_BEC) {
			return this.convocatoriasDao.updateBEC(convocatorias);
		} else {

			///////////////////////////////////////////////
			///////////////// GUARDAR FECHAS////////////////
			convocatoriasDao.updateFechas(convocatorias);
			///////////////////////////////////////////////

			// buscamos el tipo de importe de la tabla de convocatorias para
			// saber si el importe disponible lo tenemos en la tabla de
			// convocatorias (0) o en la de acciones subencionables (1)
			EstudioTecnico estudioTipoImporte = this.estudioTecnicoDao
					.findTipoImporte(convocatorias.getIdConvocatoria());
			if (0 == estudioTipoImporte.getTipoImporte()) {
				Convocatorias convocatoriaBDD = convocatoriasDao.find(convocatorias);
				if (null != convocatoriaBDD.getImporte()) {
					convocatorias.setImporteDisponible(convocatorias.getImporte());
					if ((convocatoriaBDD.getImporte().equals(convocatoriaBDD.getImporteDisponible()))) {
						// si el importe de base de datos tiene valor y es igual
						// al
						// importe
						// disponible, entonces se puede cambiar al no haberse
						// repartido
						// dinero
						convocatoriasDao.updateImportes(convocatorias);
					} else {
						// devolvemos el objeto vacio para indicarle a la
						// presentacion
						// que pinte un error al no poderse cambiar el importe
						// de la
						// convocatoria
						return new Convocatorias();
					}
				} else {
					// si el importe es null en base de datos se informan con el
					// mismo
					// valor tanto el importe como el importe disponible
					convocatorias.setImporteDisponible(convocatorias.getImporte());
					convocatoriasDao.updateImportes(convocatorias);
				}
			} else if (1 == estudioTipoImporte.getTipoImporte()) {
				// hay que cambiar en la tabla de acciones subvencionables
				List<ActSubvencionable> listaAccionesSubvencionables = convocatorias.getActSubvencionables();
				/*
				 * for (ActSubvencionable actSubvencionable :
				 * listaAccionesSubvencionables) { // recuperamos la accion
				 * subvencionable de la bbdd List<ActSubvencionable>
				 * listaActSubvencionableBBDD = actSubvencionableDao
				 * .findImporteImporteDisponibleActSub(actSubvencionable.
				 * getIdActSub()); if (!listaActSubvencionableBBDD.isEmpty()) {
				 * ActSubvencionable actSubvencionableBBDD =
				 * listaActSubvencionableBBDD.get(0); if
				 * (!(actSubvencionableBBDD.getImporte()
				 * .equals(actSubvencionableBBDD.getImporteDisponible()))) { //
				 * si se ha empezado a repaartir el dinero,enviamos // un
				 * mensaje de error return new Convocatorias(); } } }
				 */
				// if (convocatorias.getActualizarImportes()) {
				BigDecimal importeNuevoConvocatoria = BigDecimal.ZERO;
				for (ActSubvencionable actSubvencionable : listaAccionesSubvencionables) {
					// recuperamos la accion subvencionable de la bbdd
					List<ActSubvencionable> listaActSubvencionableBBDD = actSubvencionableDao
							.findImporteImporteDisponibleActSub(actSubvencionable.getIdActSub());
					if (!listaActSubvencionableBBDD.isEmpty()) {
						ActSubvencionable actSubvencionableBBDD = listaActSubvencionableBBDD.get(0);
						if (null == actSubvencionableBBDD.getImporteDisponible() || actSubvencionableBBDD.getImporte()
								.equals(actSubvencionableBBDD.getImporteDisponible())) {
							// si no se ha empezado a repartir el dinero, se
							// puede actualizar el importe de la accion
							// subvencionable
							actSubvencionable.setImporteDisponible(actSubvencionable.getImporte());
							actSubvencionableDao.updateImporte(actSubvencionable);
							// si se ha actualizado el importe disponible de
							// las
							// acciones subvencionables, actualizamos
							// tambien el
							// importe de la convocatoria con la suma de
							// todos
							// los importes de las acciones subvencionables
							importeNuevoConvocatoria = importeNuevoConvocatoria.add(actSubvencionable.getImporte());
						}
					}
				}

				// }
				if (convocatorias.getActualizarImportes()) {
					convocatorias.setImporteDisponible(convocatorias.getImporte());
					convocatoriasDao.updateImportes(convocatorias);
				}

			}
			return this.convocatoriasDao.update(convocatorias);
		}
	}

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Convocatorias updateFaseActiva(Convocatorias convocatorias) {
		return this.convocatoriasDao.updateFaseActiva(convocatorias);
	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias find(Convocatorias convocatorias) {
		Convocatorias resultado = new Convocatorias();
		// buscamos el tipo de importe de la tabla de convocatorias para
		// saber si el importe disponible lo tenemos en la tabla de
		// convocatorias (0) o en la de acciones subencionables (1)
		EstudioTecnico estudioTipoImporte = this.estudioTecnicoDao.findTipoImporte(convocatorias.getIdConvocatoria());
		resultado = this.convocatoriasDao.find(convocatorias);
		if (1 == estudioTipoImporte.getTipoImporte()) {
			List<ActSubvencionable> listaAccionesSubencionables = actSubvencionableDao
					.findImporteActSubvencionable(convocatorias.getIdConvocatoria());
			resultado.setActSubvencionables(listaAccionesSubencionables);
		}
		return resultado;
	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias findFaseActiva(Convocatorias convocatorias) {
		return (Convocatorias) this.convocatoriasDao.findFaseActiva(convocatorias);
	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias findWithProcedimiento(Integer idProcedimiento) {
		return (Convocatorias) this.convocatoriasDao.findWithProcedimiento(idProcedimiento);
	}

	/**
	 * Encuentra el nombre del pl-sql de calculo de ayuda correspondiente a cada
	 * convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */
	public Convocatorias findNombrePLSQL(Integer idConvocatorias) {
		logger.info("Inicio findnombrePLSQL con idConvocatoria = " + idConvocatorias);
		return (Convocatorias) this.convocatoriasDao.findNombrePLSQL(idConvocatorias);
	}

	/**
	 * Encuentra el nombre del pl-sql de REPARTO de ayuda correspondiente a cada
	 * convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */

	public Convocatorias findNombrePLSQLReparto(Integer idConvocatoria) {
		logger.info("Inicio findnombrePLSQL con idConvocatoria = " + idConvocatoria);
		return (Convocatorias) this.convocatoriasDao.findNombrePLSQLReparto(idConvocatoria);

	}

	/**
	 * Encuentra el nombre del pl-sql de ANULAR REPARTO de ayuda correspondiente
	 * a cada convocatoria
	 *
	 * @param Integer
	 *            idConvocatorias
	 * @return convocatorias
	 */

	public Convocatorias findNombrePLSQLAnularReparto(Integer idConvocatoria) {
		logger.info("Inicio findnombrePLSQL con idConvocatoria = " + idConvocatoria);
		return (Convocatorias) this.convocatoriasDao.findNombrePLSQLAnularReparto(idConvocatoria);

	}

	/**
	 * Updates Importe_Disponible en Convocatorias table.
	 *
	 * @param idConvocatorias
	 *            Integer
	 * @return Convocatorias
	 */
	public Convocatorias updateImporteDisponible(Convocatorias convocatorias) {

		logger.info("updateImporteDisponible  con idConvocatoria = " + convocatorias.getIdConvocatoria());
		return (Convocatorias) this.convocatoriasDao.updateImporteDisponible(convocatorias);

	}

	/**
	 * Finds a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias findProc(Convocatorias convocatorias) {
		return (Convocatorias) this.convocatoriasDao.findProc(convocatorias);
	}

	/**
	 * Convo combo.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @return Convocatorias
	 */
	public Convocatorias tipoConvo(Convocatorias convocatorias) {
		return (Convocatorias) this.convocatoriasDao.tipoConvo(convocatorias);
	}

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param faseActiva
	 *            Integer
	 * @param idProcedimiento
	 *            Integer
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Convocatorias aplicarCorte(Integer idConvocatoria, Integer faseActiva, Integer idProcedimiento,
			Usuario usuario) {
		Convocatorias convocatorias = new Convocatorias();
		convocatorias.setFechaUltmodificacion(new Date());
		convocatorias.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		convocatorias.setIdConvocatoria(idConvocatoria);

		Puntuaciones puntuaciones = new Puntuaciones();
		Procedimientos procedimientos = new Procedimientos();
		Expedientes expedientes = new Expedientes();
		List<Puntuaciones> puntuacionesList = new ArrayList<Puntuaciones>();
		List<Puntuaciones> puntuacionesListSuplentes = new ArrayList<Puntuaciones>();
		Puntuaciones puntuacionesAux = new Puntuaciones();
		Fases fases = new Fases();
		switch (faseActiva) {
		case 1:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_2);
			procedimientos.setIdProcedimiento(idProcedimiento);
			expedientes.setProcedimientos(procedimientos);
			puntuaciones.setExpedientes(expedientes);

			puntuacionesList = puntuacionesDao.findExpedientesParaConocimientos(puntuaciones, idConvocatoria);

			fases.setIdFase(Long.valueOf(Constantes.ID_FASE1));
			puntuacionesAux.setFases(fases);

			break;
		case 2:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_3);
			procedimientos.setIdProcedimiento(idProcedimiento);
			expedientes.setProcedimientos(procedimientos);
			puntuaciones.setExpedientes(expedientes);

			puntuacionesList = puntuacionesDao.findExpedientesParaCurso(puntuaciones, idConvocatoria);

			fases.setIdFase(Long.valueOf(Constantes.ID_FASE2));
			puntuacionesAux.setFases(fases);

			break;
		case 3:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_4);
			procedimientos.setIdProcedimiento(idProcedimiento);
			expedientes.setProcedimientos(procedimientos);
			puntuaciones.setExpedientes(expedientes);

			puntuacionesList = puntuacionesDao.findExpedientesParaBecarios(puntuaciones, idConvocatoria);

			fases.setIdFase(Long.valueOf(Constantes.ID_FASE3));
			puntuacionesAux.setFases(fases);

			break;
		case 4:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_5);
			this.convocatoriasDao.updateFaseActiva(convocatorias);
			break;
		default:
			break;
		}

		if (convocatorias.getFaseActiva() != null) {
			if (convocatorias.getFaseActiva() != Constantes.FASE_ACTIVA_5) {
				Puntuaciones puntuacionesFase = new Puntuaciones();
				this.convocatoriasDao.updateFaseActiva(convocatorias);

				puntuacionesAux.setFechaUltmodificacion(new Date());
				puntuacionesAux.setUsuarioUltmodificacion(usuario.getNombreUsuario());

				if (null != puntuacionesList) {
					for (int i = 0; i < puntuacionesList.size(); i++) {
						Integer idExpediente = puntuacionesList.get(i).getExpedientes().getIdExpediente();
						Expedientes expedientesAux = new Expedientes();
						expedientesAux.setIdExpediente(idExpediente);
						puntuacionesAux.setExpedientes(expedientesAux);
						puntuacionesFase = puntuacionesDao.updateFasePuntuacion(puntuacionesAux);
					}
				}
				if (puntuacionesFase.getFases().getIdFase() == Constantes.ID_FASE3) {
					puntuacionesListSuplentes = puntuacionesDao.findExpedientesParaSuplentes(puntuaciones,
							idConvocatoria);
					Puntuaciones puntuacionesSuplentes = new Puntuaciones();
					puntuacionesSuplentes.setFechaUltmodificacion(new Date());
					puntuacionesSuplentes.setUsuarioUltmodificacion(usuario.getNombreUsuario());

					Fases fasesSuplentes = new Fases();
					fasesSuplentes.setIdFase(Long.valueOf(Constantes.ID_FASE4));
					puntuacionesSuplentes.setFases(fasesSuplentes);

					if (null != puntuacionesListSuplentes) {
						for (int i = 0; i < puntuacionesListSuplentes.size(); i++) {
							Integer idExpediente = puntuacionesListSuplentes.get(i).getExpedientes().getIdExpediente();
							Expedientes expedientesAuxSuplentes = new Expedientes();
							expedientesAuxSuplentes.setIdExpediente(idExpediente);
							puntuacionesSuplentes.setExpedientes(expedientesAuxSuplentes);
							this.puntuacionesDao.updateFasePuntuacion(puntuacionesSuplentes);
						}
					}
				}
			}
		}
		return convocatorias;
	}

	/**
	 * Updates a single row in the Convocatorias table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param faseActiva
	 *            Integer
	 * @param idProcedimiento
	 *            Integer
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Convocatorias deshacerCorte(Integer idConvocatoria, Integer faseActiva, Integer idProcedimiento,
			Usuario usuario) {
		Convocatorias convocatorias = new Convocatorias();
		convocatorias.setFechaUltmodificacion(new Date());
		convocatorias.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		convocatorias.setIdConvocatoria(idConvocatoria);
		Puntuaciones puntuaciones = new Puntuaciones();
		Procedimientos procedimientos = new Procedimientos();
		Expedientes expedientes = new Expedientes();

		List<Puntuaciones> puntuacionesList = new ArrayList<Puntuaciones>();
		Puntuaciones puntuacionesAux = new Puntuaciones();
		Fases fases = new Fases();

		switch (faseActiva) {
		case 2:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_1);

			procedimientos.setIdProcedimiento(idProcedimiento);
			expedientes.setProcedimientos(procedimientos);
			puntuaciones.setExpedientes(expedientes);
			puntuacionesList = puntuacionesDao.findFaseConocimientos(puntuaciones);

			fases.setIdFase(null);
			puntuacionesAux.setFases(fases);

			break;
		case 3:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_2);

			procedimientos.setIdProcedimiento(idProcedimiento);
			expedientes.setProcedimientos(procedimientos);
			puntuaciones.setExpedientes(expedientes);
			puntuacionesList = puntuacionesDao.findFaseCurso(puntuaciones);

			fases.setIdFase(Long.valueOf(Constantes.ID_FASE1));
			puntuacionesAux.setFases(fases);

			break;
		case 4:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_3);

			procedimientos.setIdProcedimiento(idProcedimiento);
			expedientes.setProcedimientos(procedimientos);
			puntuaciones.setExpedientes(expedientes);

			puntuacionesList = puntuacionesDao.findFaseBecasBecariosSuplentes(puntuaciones);

			fases.setIdFase(Long.valueOf(Constantes.ID_FASE2));
			puntuacionesAux.setFases(fases);

			break;
		case 5:
			convocatorias.setFaseActiva(Constantes.FASE_ACTIVA_4);
			break;
		default:
			break;
		}

		if (convocatorias.getFaseActiva() != null) {
			this.convocatoriasDao.updateFaseActiva(convocatorias);

			if (null != puntuacionesList) {
				for (int i = 0; i < puntuacionesList.size(); i++) {
					Integer idExpediente = puntuacionesList.get(i).getExpedientes().getIdExpediente();
					Expedientes expedientesAux = new Expedientes();
					expedientesAux.setIdExpediente(idExpediente);
					puntuacionesAux.setExpedientes(expedientesAux);

					this.puntuacionesDao.updateFasePuntuacion(puntuacionesAux);
				}
			}
		}

		return convocatorias;
	}

	/**
	 * Deletes a single row in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Convocatorias convocatorias) {
		this.convocatoriasDao.remove(convocatorias);
	}

	/**
	 * Finds a list of rows in the Convocatorias table.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Convocatorias>
	 */
	public List<Convocatorias> findAll(Convocatorias convocatorias, JQGridRequestDto jqGridRequestDto) {
		return (List<Convocatorias>) this.convocatoriasDao.findAll(convocatorias, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Convocatorias table using like.
	 *
	 * @param convocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Convocatorias>
	 */
	public List<Convocatorias> findAllLike(Convocatorias convocatorias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<Convocatorias>) this.convocatoriasDao.findAllLike(convocatorias, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Convocatorias filterConvocatorias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.convocatoriasDao.removeMultiple(filterConvocatorias, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Convocatorias>
	 */
	public JQGridResponseDto<Convocatorias> filter(Convocatorias filterConvocatorias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<Convocatorias> listaConvocatorias = this.convocatoriasDao.findAllLike(filterConvocatorias,
				jqGridRequestDto, false);
		Long recordNum = this.convocatoriasDao
				.findAllLikeCount(filterConvocatorias != null ? filterConvocatorias : new Convocatorias(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Convocatorias>> reorderSelection = this.convocatoriasDao
					.reorderSelection(filterConvocatorias, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Convocatorias>(jqGridRequestDto, recordNum, listaConvocatorias,
					reorderSelection);
		}
		return new JQGridResponseDto<Convocatorias>(jqGridRequestDto, recordNum, listaConvocatorias);
	}

	/**
	 * Searches rows in the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param searchConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Convocatorias>>
	 */
	public List<TableRowDto<Convocatorias>> search(Convocatorias filterConvocatorias, Convocatorias searchConvocatorias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.convocatoriasDao.search(filterConvocatorias, searchConvocatorias, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Convocatorias filterConvocatorias, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.convocatoriasDao.reorderSelection(filterConvocatorias, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Convocatorias table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Convocatorias>>
	 */
	public JQGridResponseDto<JerarquiaDto<Convocatorias>> jerarquia(Convocatorias filterConvocatorias,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Convocatorias>> listaConvocatorias = this.convocatoriasDao
				.findAllLikeJerarquia(filterConvocatorias, jqGridRequestDto);
		Long recordNum = this.convocatoriasDao.findAllLikeCountJerarquia(filterConvocatorias, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Convocatorias>>(jqGridRequestDto, recordNum, listaConvocatorias);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Convocatorias
	 * table.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Convocatorias>>
	 */
	public JQGridResponseDto<JerarquiaDto<Convocatorias>> jerarquiaChildren(Convocatorias filterConvocatorias,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Convocatorias>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Convocatorias>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.convocatoriasDao.findAllChild(filterConvocatorias, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public void updateFechas(Convocatorias convocatoria) {
		convocatoriasDao.updateFechas(convocatoria);
	}

	@Override
	public Convocatorias findByIdExpediente(Integer idExpediente) {
		return this.convocatoriasDao.findByIdExpediente(idExpediente);
	}

}
