package com.ejie.ab60.service.convocatorias;

import com.ejie.ab60.dao.convocatorias.DatosContablesDao;
import com.ejie.ab60.model.convocatorias.DatosContables;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * DatosContablesServiceImpl  
 * 
 *  
 */

@Service(value = "datosContablesService")
public class DatosContablesServiceImpl implements DatosContablesService {

	@Autowired
	private DatosContablesDao datosContablesDao;

	/**
	 * Inserts a single row in the DatosContables table.
	 *
	 * @param datosContables
	 *            DatosContables
	 * @return DatosContables
	 */
	@Transactional(rollbackFor = Throwable.class)
	public DatosContables add(DatosContables datosContables) {
		return this.datosContablesDao.add(datosContables);
	}

	/**
	 * Updates a single row in the DatosContables table.
	 *
	 * @param datosContables
	 *            DatosContables
	 * @return DatosContables
	 */
	@Transactional(rollbackFor = Throwable.class)
	public DatosContables update(DatosContables datosContables) {
		return this.datosContablesDao.update(datosContables);
	}

	/**
	 * Finds a single row in the DatosContables table.
	 *
	 * @param datosContables
	 *            DatosContables
	 * @return DatosContables
	 */
	public DatosContables find(DatosContables datosContables) {
		return (DatosContables) this.datosContablesDao.find(datosContables);
	}

	/**
	 * Finds a single row in the DatosContables table.
	 *
	 * @param datosContables
	 *            DatosContables
	 * @return DatosContables
	 */
	public DatosContables findbyConvocatoria(DatosContables datosContables) {
		return (DatosContables) this.datosContablesDao.findbyConvocatoria(datosContables);
	}

	/**
	 * Deletes a single row in the DatosContables table.
	 *
	 * @param datosContables
	 *            DatosContables
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(DatosContables datosContables) {
		this.datosContablesDao.remove(datosContables);
	}

	/**
	 * Finds a list of rows in the DatosContables table.
	 *
	 * @param datosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<DatosContables>
	 */
	public List<DatosContables> findAll(DatosContables datosContables, JQGridRequestDto jqGridRequestDto) {
		return (List<DatosContables>) this.datosContablesDao.findAll(datosContables, jqGridRequestDto);
	}

	/**
	 * Finds rows in the DatosContables table using like.
	 *
	 * @param datosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<DatosContables>
	 */
	public List<DatosContables> findAllLike(DatosContables datosContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<DatosContables>) this.datosContablesDao.findAllLike(datosContables, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(DatosContables filterDatosContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.datosContablesDao.removeMultiple(filterDatosContables, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<DatosContables>
	 */
	public JQGridResponseDto<DatosContables> filter(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<DatosContables> listaDatosContables = this.datosContablesDao.findAllLike(filterDatosContables,
				jqGridRequestDto, false);
		Long recordNum = this.datosContablesDao
				.findAllLikeCount(filterDatosContables != null ? filterDatosContables : new DatosContables(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<DatosContables>> reorderSelection = this.datosContablesDao
					.reorderSelection(filterDatosContables, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<DatosContables>(jqGridRequestDto, recordNum, listaDatosContables,
					reorderSelection);
		}
		return new JQGridResponseDto<DatosContables>(jqGridRequestDto, recordNum, listaDatosContables);
	}

	/**
	 * Searches rows in the DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param searchDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosContables>>
	 */
	public List<TableRowDto<DatosContables>> search(DatosContables filterDatosContables,
			DatosContables searchDatosContables, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.datosContablesDao.search(filterDatosContables, searchDatosContables, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(DatosContables filterDatosContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.datosContablesDao.reorderSelection(filterDatosContables, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the DatosContables table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<DatosContables>>
	 */
	public JQGridResponseDto<JerarquiaDto<DatosContables>> jerarquia(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<DatosContables>> listaDatosContables = this.datosContablesDao
				.findAllLikeJerarquia(filterDatosContables, jqGridRequestDto);
		Long recordNum = this.datosContablesDao.findAllLikeCountJerarquia(filterDatosContables, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<DatosContables>>(jqGridRequestDto, recordNum, listaDatosContables);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the DatosContables
	 * table.
	 *
	 * @param filterDatosContables
	 *            DatosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<DatosContables>>
	 */
	public JQGridResponseDto<JerarquiaDto<DatosContables>> jerarquiaChildren(DatosContables filterDatosContables,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<DatosContables>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<DatosContables>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.datosContablesDao.findAllChild(filterDatosContables, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
