package com.ejie.ab60.service.convocatorias;

import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.convocatorias.IdiomasDao;
import com.ejie.ab60.model.Idiomas;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;

/**
 * IdiomasServiceImpl  
 * 
 *  
 */

@Service(value = "idiomasService")
public class IdiomasServiceImpl implements IdiomasService {

	@Autowired
	private IdiomasDao idiomasDao;

	/**
	 * Inserts a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Idiomas add(Idiomas idiomas) {
		return this.idiomasDao.add(idiomas);
	}

	/**
	 * Updates a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Idiomas update(Idiomas idiomas) {
		return this.idiomasDao.update(idiomas);
	}

	/**
	 * Finds a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @return Idiomas
	 */
	public Idiomas find(Idiomas idiomas) {
		return (Idiomas) this.idiomasDao.find(idiomas);
	}

	/**
	 * Deletes a single row in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Idiomas idiomas) {
		this.idiomasDao.remove(idiomas);
	}

	/**
	 * Finds a list of rows in the Idiomas table.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Idiomas>
	 */
	public List<Idiomas> findAll(Idiomas idiomas, JQGridRequestDto jqGridRequestDto) {
		return (List<Idiomas>) this.idiomasDao.findAll(idiomas, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Idiomas table using like.
	 *
	 * @param idiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Idiomas>
	 */
	public List<Idiomas> findAllLike(Idiomas idiomas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Idiomas>) this.idiomasDao.findAllLike(idiomas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.idiomasDao.removeMultiple(filterIdiomas, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Idiomas>
	 */
	public JQGridResponseDto<Idiomas> filter(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<Idiomas> listaIdiomas = this.idiomasDao.findAllLike(filterIdiomas, jqGridRequestDto, false);
		Long recordNum = this.idiomasDao.findAllLikeCount(filterIdiomas != null ? filterIdiomas : new Idiomas(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Idiomas>> reorderSelection = this.idiomasDao.reorderSelection(filterIdiomas,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Idiomas>(jqGridRequestDto, recordNum, listaIdiomas, reorderSelection);
		}
		return new JQGridResponseDto<Idiomas>(jqGridRequestDto, recordNum, listaIdiomas);
	}

	/**
	 * Searches rows in the Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param searchIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Idiomas>>
	 */
	public List<TableRowDto<Idiomas>> search(Idiomas filterIdiomas, Idiomas searchIdiomas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.idiomasDao.search(filterIdiomas, searchIdiomas, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.idiomasDao.reorderSelection(filterIdiomas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Idiomas>>
	 */
	public JQGridResponseDto<JerarquiaDto<Idiomas>> jerarquia(Idiomas filterIdiomas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<JerarquiaDto<Idiomas>> listaIdiomas = this.idiomasDao.findAllLikeJerarquia(filterIdiomas,
				jqGridRequestDto);
		Long recordNum = this.idiomasDao.findAllLikeCountJerarquia(filterIdiomas, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Idiomas>>(jqGridRequestDto, recordNum, listaIdiomas);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Idiomas table.
	 *
	 * @param filterIdiomas
	 *            Idiomas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Idiomas>>
	 */
	public JQGridResponseDto<JerarquiaDto<Idiomas>> jerarquiaChildren(Idiomas filterIdiomas,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Idiomas>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Idiomas>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.idiomasDao.findAllChild(filterIdiomas, jqGridRequestDto));
		return jqGridResponseDto;
	}

	/**
	 * Finds a list of rows in the Idiomas table.
	 *
	 * 
	 * @return List<Idiomas>
	 */
	public List<Idiomas> findIdioma() {
		return (List<Idiomas>) this.idiomasDao.findIdioma();
	}

}
