package com.ejie.ab60.service.convocatorias;

import com.ejie.ab60.dao.convocatorias.TiposAyudaDao;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

import java.sql.Types;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.SqlInOutParameter;
import org.springframework.jdbc.core.SqlParameter;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.convocatorias.TiposAyuda;
import com.ejie.ab60.util.DBUtils;

/**
 * TiposAyudaServiceImpl  
 * 
 *  
 */

@Service(value = "tiposAyudaService")
public class TiposAyudaServiceImpl implements TiposAyudaService {

	private static final Logger logger = LoggerFactory.getLogger(TiposAyudaServiceImpl.class);

	private JdbcTemplate jdbcTemplate;

	@Autowired
	private TiposAyudaDao tiposAyudaDao;

	/**
	 * 
	 * Necesario para llamar al pl-sql
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource()
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the TiposAyuda table.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda
	 * @return TiposAyuda
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposAyuda add(TiposAyuda tiposAyuda) {
		return this.tiposAyudaDao.add(tiposAyuda);
	}

	/**
	 * Updates a single row in the TiposAyuda table.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda
	 * @return TiposAyuda
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposAyuda update(TiposAyuda tiposAyuda) {
		return this.tiposAyudaDao.update(tiposAyuda);
	}

	/**
	 * Finds a single row in the TiposAyuda table.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda
	 * @return TiposAyuda
	 */
	public TiposAyuda find(TiposAyuda tiposAyuda) {
		return (TiposAyuda) this.tiposAyudaDao.find(tiposAyuda);
	}

	public TiposAyuda findPLSQL(TiposAyuda tiposAyuda) {
		return (TiposAyuda) this.tiposAyudaDao.findPLSQL(tiposAyuda);
	}

	/**
	 * Deletes a single row in the TiposAyuda table.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposAyuda tiposAyuda) {
		this.tiposAyudaDao.remove(tiposAyuda);
	}

	/**
	 * Finds a list of rows in the TiposAyuda table.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposAyuda>
	 */
	public List<TiposAyuda> findAll(TiposAyuda tiposAyuda, JQGridRequestDto jqGridRequestDto) {
		return (List<TiposAyuda>) this.tiposAyudaDao.findAll(tiposAyuda, jqGridRequestDto);
	}

	/**
	 * Finds rows in the TiposAyuda table using like.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposAyuda>
	 */
	public List<TiposAyuda> findAllLike(TiposAyuda tiposAyuda, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<TiposAyuda>) this.tiposAyudaDao.findAllLike(tiposAyuda, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the TiposAyuda table.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TiposAyuda filterTiposAyuda, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.tiposAyudaDao.removeMultiple(filterTiposAyuda, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the TiposAyuda table.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<TiposAyuda>
	 */
	public JQGridResponseDto<TiposAyuda> filter(TiposAyuda filterTiposAyuda, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<TiposAyuda> listaTiposAyuda = this.tiposAyudaDao.findAllLike(filterTiposAyuda, jqGridRequestDto, false);
		Long recordNum = this.tiposAyudaDao
				.findAllLikeCount(filterTiposAyuda != null ? filterTiposAyuda : new TiposAyuda(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TiposAyuda>> reorderSelection = this.tiposAyudaDao.reorderSelection(filterTiposAyuda,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposAyuda>(jqGridRequestDto, recordNum, listaTiposAyuda, reorderSelection);
		}
		return new JQGridResponseDto<TiposAyuda>(jqGridRequestDto, recordNum, listaTiposAyuda);
	}

	/**
	 * Searches rows in the TiposAyuda table.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param searchTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposAyuda>>
	 */
	public List<TableRowDto<TiposAyuda>> search(TiposAyuda filterTiposAyuda, TiposAyuda searchTiposAyuda,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposAyudaDao.search(filterTiposAyuda, searchTiposAyuda, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in TiposAyuda table.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TiposAyuda filterTiposAyuda, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposAyudaDao.reorderSelection(filterTiposAyuda, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the TiposAyuda table.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposAyuda>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposAyuda>> jerarquia(TiposAyuda filterTiposAyuda,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TiposAyuda>> listaTiposAyuda = this.tiposAyudaDao.findAllLikeJerarquia(filterTiposAyuda,
				jqGridRequestDto);
		Long recordNum = this.tiposAyudaDao.findAllLikeCountJerarquia(filterTiposAyuda, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposAyuda>>(jqGridRequestDto, recordNum, listaTiposAyuda);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the TiposAyuda table.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposAyuda>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposAyuda>> jerarquiaChildren(TiposAyuda filterTiposAyuda,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TiposAyuda>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposAyuda>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.tiposAyudaDao.findAllChild(filterTiposAyuda, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public String copiaConvocatoria(Convocatorias copiaConvocatoria) {

		/**********************************************************************
		 * SE INVOCA AL PL/SQL DE CARGA
		 **********************************************************************/

		/**
		 * Primero obtenemos de la tabla configuracion el nombre del pl/sql
		 */

		TiposAyuda tiposAyuda = new TiposAyuda();
		tiposAyuda.setIdTipoAyuda(copiaConvocatoria.getIdTipoAyuda().longValue());
		tiposAyuda = this.findPLSQL(tiposAyuda);

		SqlParameter[] parameters = {

				new SqlInOutParameter("IN_ID_PROCEDIMIENTO", Types.VARCHAR),
				new SqlInOutParameter("IN_COD_PROCEDURE_ID", Types.VARCHAR),
				new SqlInOutParameter("IN_ANYO_CONVOCATORIA", Types.VARCHAR) };

		MapSqlParameterSource parameterSource = new MapSqlParameterSource();

		parameterSource.addValue("IN_ID_PROCEDIMIENTO", copiaConvocatoria.getIdProcedimiento());
		parameterSource.addValue("IN_COD_PROCEDURE_ID", copiaConvocatoria.getCodProcedureId());
		parameterSource.addValue("IN_ANYO_CONVOCATORIA", copiaConvocatoria.getAnyoConvocatoria());

		String mensage = "";

		try {
			DBUtils.callPLSQLCopiaConvocatoria(this.jdbcTemplate, tiposAyuda.getPlsqlCopiaConvocatoria(), parameters,
					parameterSource);

			mensage = "correcto";

		} catch (Exception e) {
			TiposAyudaServiceImpl.logger.info("[copia combocatoria] : Error - " + e);
			mensage = "error";
		}

		return mensage;
	}

}
