package com.ejie.ab60.service.convocatorias;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.convocatorias.TiposConvocatoriaDao;
import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposConvocatoriaServiceImpl  
 * 
 *  
 */

@Service(value = "tiposConvocatoriaService")
public class TiposConvocatoriaServiceImpl implements TiposConvocatoriaService {

	@Autowired
	private TiposConvocatoriaDao tiposConvocatoriaDao;

	/**
	 * Inserts a single row in the TiposConvocatoria table.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposConvocatoria add(TiposConvocatoria tiposConvocatoria) {
		return this.tiposConvocatoriaDao.add(tiposConvocatoria);
	}

	/**
	 * Updates a single row in the TiposConvocatoria table.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposConvocatoria update(TiposConvocatoria tiposConvocatoria) {
		return this.tiposConvocatoriaDao.update(tiposConvocatoria);
	}

	/**
	 * Finds a single row in the TiposConvocatoria table.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	public TiposConvocatoria find(TiposConvocatoria tiposConvocatoria) {
		return (TiposConvocatoria) this.tiposConvocatoriaDao.find(tiposConvocatoria);
	}

	/**
	 * Finds a single row in the TiposConvocatoria table.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria
	 * @return TiposConvocatoria
	 */
	public TiposConvocatoria findNoConcursal(TiposConvocatoria tiposConvocatoria) {
		return (TiposConvocatoria) this.tiposConvocatoriaDao.findNoConcursal(tiposConvocatoria);
	}

	/**
	 * Deletes a single row in the TiposConvocatoria table.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposConvocatoria tiposConvocatoria) {
		this.tiposConvocatoriaDao.remove(tiposConvocatoria);
	}

	/**
	 * Finds a list of rows in the TiposConvocatoria table.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposConvocatoria>
	 */
	public List<TiposConvocatoria> findAll(TiposConvocatoria tiposConvocatoria, JQGridRequestDto jqGridRequestDto) {
		return (List<TiposConvocatoria>) this.tiposConvocatoriaDao.findAll(tiposConvocatoria, jqGridRequestDto);
	}

	/**
	 * Finds rows in the TiposConvocatoria table using like.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposConvocatoria>
	 */
	public List<TiposConvocatoria> findAllLike(TiposConvocatoria tiposConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<TiposConvocatoria>) this.tiposConvocatoriaDao.findAllLike(tiposConvocatoria, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TiposConvocatoria filterTiposConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.tiposConvocatoriaDao.removeMultiple(filterTiposConvocatoria, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<TiposConvocatoria>
	 */
	public JQGridResponseDto<TiposConvocatoria> filter(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<TiposConvocatoria> listaTiposConvocatoria = this.tiposConvocatoriaDao.findAllLike(filterTiposConvocatoria,
				jqGridRequestDto, false);
		Long recordNum = this.tiposConvocatoriaDao.findAllLikeCount(
				filterTiposConvocatoria != null ? filterTiposConvocatoria : new TiposConvocatoria(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TiposConvocatoria>> reorderSelection = this.tiposConvocatoriaDao
					.reorderSelection(filterTiposConvocatoria, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposConvocatoria>(jqGridRequestDto, recordNum, listaTiposConvocatoria,
					reorderSelection);
		}
		return new JQGridResponseDto<TiposConvocatoria>(jqGridRequestDto, recordNum, listaTiposConvocatoria);
	}

	/**
	 * Searches rows in the TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param searchTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposConvocatoria>>
	 */
	public List<TableRowDto<TiposConvocatoria>> search(TiposConvocatoria filterTiposConvocatoria,
			TiposConvocatoria searchTiposConvocatoria, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposConvocatoriaDao.search(filterTiposConvocatoria, searchTiposConvocatoria, jqGridRequestDto,
				startsWith);
	}

	/**
	 * Reorder the selection made in TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TiposConvocatoria filterTiposConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.tiposConvocatoriaDao.reorderSelection(filterTiposConvocatoria, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the TiposConvocatoria table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposConvocatoria>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposConvocatoria>> jerarquia(TiposConvocatoria filterTiposConvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TiposConvocatoria>> listaTiposConvocatoria = this.tiposConvocatoriaDao
				.findAllLikeJerarquia(filterTiposConvocatoria, jqGridRequestDto);
		Long recordNum = this.tiposConvocatoriaDao.findAllLikeCountJerarquia(filterTiposConvocatoria, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposConvocatoria>>(jqGridRequestDto, recordNum,
				listaTiposConvocatoria);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the TiposConvocatoria
	 * table.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposConvocatoria>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposConvocatoria>> jerarquiaChildren(
			TiposConvocatoria filterTiposConvocatoria, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TiposConvocatoria>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposConvocatoria>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.tiposConvocatoriaDao.findAllChild(filterTiposConvocatoria, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
