package com.ejie.ab60.service.criteriosPuntuacion;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.criteriosPuntuacion.CriteriosPuntuacionDao;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * CriteriosPuntuacionServiceImpl  
 * 
 *  
 */

@Service(value = "criteriosPuntuacionService")
public class CriteriosPuntuacionServiceImpl implements CriteriosPuntuacionService {

	@Autowired
	private CriteriosPuntuacionDao criteriosPuntuacionDao;

	/**
	 * Inserts a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public CriteriosPuntuacion add(CriteriosPuntuacion criteriosPuntuacion) {
		return this.criteriosPuntuacionDao.add(criteriosPuntuacion);
	}

	/**
	 * Updates a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public CriteriosPuntuacion update(CriteriosPuntuacion criteriosPuntuacion) {
		return this.criteriosPuntuacionDao.update(criteriosPuntuacion);
	}

	/**
	 * Finds a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @return CriteriosPuntuacion
	 */
	public CriteriosPuntuacion find(CriteriosPuntuacion criteriosPuntuacion) {
		return (CriteriosPuntuacion) this.criteriosPuntuacionDao.find(criteriosPuntuacion);
	}

	/**
	 * Lista de texto de criterios de puntuacion CriteriosPuntuacion table.
	 *
	 * @param Integer
	 *            idconvocatoria
	 * @return List<CriteriosPuntuacion>
	 * 
	 */
	public List<CriteriosPuntuacion> findTextoCriterio(Integer idconvocatoria) {
		return (List<CriteriosPuntuacion>) this.criteriosPuntuacionDao.findTextoCriterio(idconvocatoria);
	}

	/**
	 * Lista de texto de criterios de puntuacion CriteriosPuntuacion table.
	 *
	 * @param Integer
	 *            idconvocatoria
	 * @return List<CriteriosPuntuacion>
	 * 
	 */
	public List<CriteriosPuntuacion> findTextoCriterioBEC(Integer idconvocatoria) {
		return (List<CriteriosPuntuacion>) this.criteriosPuntuacionDao.findTextoCriterioBEC(idconvocatoria);
	}

	/**
	 * Deletes a single row in the CriteriosPuntuacion table.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(CriteriosPuntuacion criteriosPuntuacion) {
		this.criteriosPuntuacionDao.remove(criteriosPuntuacion);
	}

	/**
	 * Finds a list of rows in the CriteriosPuntuacion table.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<CriteriosPuntuacion>
	 */
	public List<CriteriosPuntuacion> findAll(CriteriosPuntuacion criteriosPuntuacion,
			JQGridRequestDto jqGridRequestDto) {
		return (List<CriteriosPuntuacion>) this.criteriosPuntuacionDao.findAll(criteriosPuntuacion, jqGridRequestDto);
	}

	/**
	 * Finds rows in the CriteriosPuntuacion table using like.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<CriteriosPuntuacion>
	 */
	public List<CriteriosPuntuacion> findAllLike(CriteriosPuntuacion criteriosPuntuacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<CriteriosPuntuacion>) this.criteriosPuntuacionDao.findAllLike(criteriosPuntuacion,
				jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the CriteriosPuntuacion table.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(CriteriosPuntuacion filterCriteriosPuntuacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.criteriosPuntuacionDao.removeMultiple(filterCriteriosPuntuacion, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the CriteriosPuntuacion table.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<CriteriosPuntuacion>
	 */
	public JQGridResponseDto<CriteriosPuntuacion> filter(CriteriosPuntuacion filterCriteriosPuntuacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<CriteriosPuntuacion> listaCriteriosPuntuacion = this.criteriosPuntuacionDao
				.findAllLike(filterCriteriosPuntuacion, jqGridRequestDto, false);
		Long recordNum = this.criteriosPuntuacionDao.findAllLikeCount(
				filterCriteriosPuntuacion != null ? filterCriteriosPuntuacion : new CriteriosPuntuacion(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<CriteriosPuntuacion>> reorderSelection = this.criteriosPuntuacionDao
					.reorderSelection(filterCriteriosPuntuacion, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<CriteriosPuntuacion>(jqGridRequestDto, recordNum, listaCriteriosPuntuacion,
					reorderSelection);
		}
		return new JQGridResponseDto<CriteriosPuntuacion>(jqGridRequestDto, recordNum, listaCriteriosPuntuacion);
	}

	/**
	 * Searches rows in the CriteriosPuntuacion table.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param searchCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<CriteriosPuntuacion>>
	 */
	public List<TableRowDto<CriteriosPuntuacion>> search(CriteriosPuntuacion filterCriteriosPuntuacion,
			CriteriosPuntuacion searchCriteriosPuntuacion, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.criteriosPuntuacionDao.search(filterCriteriosPuntuacion, searchCriteriosPuntuacion,
				jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in CriteriosPuntuacion table.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(CriteriosPuntuacion filterCriteriosPuntuacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.criteriosPuntuacionDao.reorderSelection(filterCriteriosPuntuacion, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the CriteriosPuntuacion table.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>> jerarquia(CriteriosPuntuacion filterCriteriosPuntuacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<CriteriosPuntuacion>> listaCriteriosPuntuacion = this.criteriosPuntuacionDao
				.findAllLikeJerarquia(filterCriteriosPuntuacion, jqGridRequestDto);
		Long recordNum = this.criteriosPuntuacionDao.findAllLikeCountJerarquia(filterCriteriosPuntuacion,
				jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>>(jqGridRequestDto, recordNum,
				listaCriteriosPuntuacion);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the
	 * CriteriosPuntuacion table.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>> jerarquiaChildren(
			CriteriosPuntuacion filterCriteriosPuntuacion, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.criteriosPuntuacionDao.findAllChild(filterCriteriosPuntuacion, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
