package com.ejie.ab60.service.criteriosPuntuacion;

import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.criteriosPuntuacion.RelExpCriPunDao;
import com.ejie.ab60.model.criteriosPuntuacion.RelExpCriPun;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.tramita.services.PifServiceImpl;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpCriPunServiceImpl  
 * 
 *  
 */

@Service(value = "relExpCriPunService")
public class RelExpCriPunServiceImpl implements RelExpCriPunService {

	private static final Logger logger = LoggerFactory.getLogger(PifServiceImpl.class);

	@Autowired
	private RelExpCriPunDao relExpCriPunDao;

	/**
	 * Inserts a single row in the RelExpCriPun table.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	@Transactional(rollbackFor = Throwable.class)
	public RelExpCriPun add(RelExpCriPun relExpCriPun) {
		return this.relExpCriPunDao.add(relExpCriPun);
	}

	/**
	 * Updates a single row in the RelExpCriPun table.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	@Transactional(rollbackFor = Throwable.class)
	public RelExpCriPun update(RelExpCriPun relExpCriPun, Usuario usuario) throws Exception {
		try {
			relExpCriPun.setFechaUltmodificacion(new Date());
			relExpCriPun.setUsuarioUltmodificacion(usuario.getNombreUsuario());

			relExpCriPun = this.relExpCriPunDao.update(relExpCriPun);
		} catch (Exception e) {
			logger.error("Error actualizando la puntuacion admitida: " + e.getMessage());
			throw new Exception("Error actualizando la puntuacion admitida", e);
		}
		return relExpCriPun;
	}

	/**
	 * Updates a single row in the RelExpCriPun table.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	@Transactional(rollbackFor = Throwable.class)
	public RelExpCriPun updatePuntuacionAdmitida(RelExpCriPun relExpCriPun, Integer idExpediente, Usuario usuario)
			throws Exception {
		try {
			relExpCriPun.setFechaUltmodificacion(new Date());
			relExpCriPun.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpCriPun.setIdExpediente(idExpediente);

			relExpCriPun = this.relExpCriPunDao.updatePuntuacionAdmitida(relExpCriPun);

		} catch (Exception e) {
			logger.error("Error actualizando las puntuaciones admitidas: " + e.getMessage());
			throw new Exception("Error actualizando las puntuaciones admitidas", e);
		}
		return relExpCriPun;
	}

	/**
	 * Finds a single row in the RelExpCriPun table.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	public RelExpCriPun find(RelExpCriPun relExpCriPun) {
		return (RelExpCriPun) this.relExpCriPunDao.find(relExpCriPun);
	}

	/**
	 * Finds a single row in the RelExpCriPun table.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 * @return RelExpCriPun
	 */
	public RelExpCriPun findPuntTeorica(RelExpCriPun relExpCriPun) {
		return (RelExpCriPun) this.relExpCriPunDao.findPuntTeorica(relExpCriPun);
	}

	/**
	 * Deletes a single row in the RelExpCriPun table.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(RelExpCriPun relExpCriPun) {
		this.relExpCriPunDao.remove(relExpCriPun);
	}

	/**
	 * Deletes a single row in the RelExpCriPun table.
	 *
	 * @param Integer
	 *            IdExpediente
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeCriteriosPorExpediente(Integer IdExpediente) {
		this.relExpCriPunDao.removeCriteriosPorExpediente(IdExpediente);
	}

	/**
	 * Finds a list of rows in the RelExpCriPun table.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpCriPun>
	 */
	public List<RelExpCriPun> findAll(RelExpCriPun relExpCriPun, JQGridRequestDto jqGridRequestDto) {
		return (List<RelExpCriPun>) this.relExpCriPunDao.findAll(relExpCriPun, jqGridRequestDto);
	}

	/**
	 * Finds rows in the RelExpCriPun table using like.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpCriPun>
	 */
	public List<RelExpCriPun> findAllLike(RelExpCriPun relExpCriPun, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<RelExpCriPun>) this.relExpCriPunDao.findAllLike(relExpCriPun, jqGridRequestDto, startsWith);
	}

	/**
	 * Lista de id de criterios de puntuacion de la RelExpCriPun table.
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<RelExpCriPun>
	 * 
	 */
	public List<RelExpCriPun> findIdsCriterio(Integer idExpediente) {
		return (List<RelExpCriPun>) this.relExpCriPunDao.findIdsCriterio(idExpediente);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the RelExpCriPun table.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(RelExpCriPun filterRelExpCriPun, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.relExpCriPunDao.removeMultiple(filterRelExpCriPun, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the RelExpCriPun table.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<RelExpCriPun>
	 */
	public JQGridResponseDto<RelExpCriPun> filter(RelExpCriPun filterRelExpCriPun, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// List<RelExpCriPun> listaRelExpCriPun =
		// this.relExpCriPunDao.findAllLike(filterRelExpCriPun,
		// jqGridRequestDto,false);
		List<RelExpCriPun> listaRelExpCriPun = this.relExpCriPunDao.findDescCriterio(
				filterRelExpCriPun.getIdExpediente(),
				filterRelExpCriPun.getCriteriosPuntuacion().getConvocatorias().getIdConvocatoria());
		Long recordNum = this.relExpCriPunDao
				.findAllLikeCount(filterRelExpCriPun != null ? filterRelExpCriPun : new RelExpCriPun(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<RelExpCriPun>> reorderSelection = this.relExpCriPunDao.reorderSelection(filterRelExpCriPun,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<RelExpCriPun>(jqGridRequestDto, recordNum, listaRelExpCriPun,
					reorderSelection);
		}
		return new JQGridResponseDto<RelExpCriPun>(jqGridRequestDto, recordNum, listaRelExpCriPun);
	}

	/**
	 * Searches rows in the RelExpCriPun table.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param searchRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpCriPun>>
	 */
	public List<TableRowDto<RelExpCriPun>> search(RelExpCriPun filterRelExpCriPun, RelExpCriPun searchRelExpCriPun,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.relExpCriPunDao.search(filterRelExpCriPun, searchRelExpCriPun, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in RelExpCriPun table.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(RelExpCriPun filterRelExpCriPun, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.relExpCriPunDao.reorderSelection(filterRelExpCriPun, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the RelExpCriPun table.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<RelExpCriPun>>
	 */
	public JQGridResponseDto<JerarquiaDto<RelExpCriPun>> jerarquia(RelExpCriPun filterRelExpCriPun,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<RelExpCriPun>> listaRelExpCriPun = this.relExpCriPunDao
				.findAllLikeJerarquia(filterRelExpCriPun, jqGridRequestDto);
		Long recordNum = this.relExpCriPunDao.findAllLikeCountJerarquia(filterRelExpCriPun, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<RelExpCriPun>>(jqGridRequestDto, recordNum, listaRelExpCriPun);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the RelExpCriPun
	 * table.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<RelExpCriPun>>
	 */
	public JQGridResponseDto<JerarquiaDto<RelExpCriPun>> jerarquiaChildren(RelExpCriPun filterRelExpCriPun,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<RelExpCriPun>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<RelExpCriPun>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.relExpCriPunDao.findAllChild(filterRelExpCriPun, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
