package com.ejie.ab60.service.criteriosPuntuacion;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.criteriosPuntuacion.TiposCriterioDao;
import com.ejie.ab60.model.criteriosPuntuacion.TiposCriterio;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposCriterioServiceImpl  
 * 
 *  
 */

@Service(value = "tiposCriterioService")
public class TiposCriterioServiceImpl implements TiposCriterioService {

	@Autowired
	private TiposCriterioDao tiposCriterioDao;

	/**
	 * Inserts a single row in the TiposCriterio table.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio
	 * @return TiposCriterio
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposCriterio add(TiposCriterio tiposCriterio) {
		return this.tiposCriterioDao.add(tiposCriterio);
	}

	/**
	 * Updates a single row in the TiposCriterio table.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio
	 * @return TiposCriterio
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposCriterio update(TiposCriterio tiposCriterio) {
		return this.tiposCriterioDao.update(tiposCriterio);
	}

	/**
	 * Finds a single row in the TiposCriterio table.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio
	 * @return TiposCriterio
	 */
	public TiposCriterio find(TiposCriterio tiposCriterio) {
		return (TiposCriterio) this.tiposCriterioDao.find(tiposCriterio);
	}

	/**
	 * Deletes a single row in the TiposCriterio table.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposCriterio tiposCriterio) {
		this.tiposCriterioDao.remove(tiposCriterio);
	}

	/**
	 * Finds a list of rows in the TiposCriterio table.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposCriterio>
	 */
	public List<TiposCriterio> findAll(TiposCriterio tiposCriterio, JQGridRequestDto jqGridRequestDto) {
		return (List<TiposCriterio>) this.tiposCriterioDao.findAll(tiposCriterio, jqGridRequestDto);
	}

	/**
	 * Finds rows in the TiposCriterio table using like.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposCriterio>
	 */
	public List<TiposCriterio> findAllLike(TiposCriterio tiposCriterio, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<TiposCriterio>) this.tiposCriterioDao.findAllLike(tiposCriterio, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the TiposCriterio table.
	 *
	 * @param filterTiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TiposCriterio filterTiposCriterio, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.tiposCriterioDao.removeMultiple(filterTiposCriterio, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the TiposCriterio table.
	 *
	 * @param filterTiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<TiposCriterio>
	 */
	public JQGridResponseDto<TiposCriterio> filter(TiposCriterio filterTiposCriterio, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<TiposCriterio> listaTiposCriterio = this.tiposCriterioDao.findAllLike(filterTiposCriterio,
				jqGridRequestDto, false);
		Long recordNum = this.tiposCriterioDao
				.findAllLikeCount(filterTiposCriterio != null ? filterTiposCriterio : new TiposCriterio(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TiposCriterio>> reorderSelection = this.tiposCriterioDao
					.reorderSelection(filterTiposCriterio, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposCriterio>(jqGridRequestDto, recordNum, listaTiposCriterio,
					reorderSelection);
		}
		return new JQGridResponseDto<TiposCriterio>(jqGridRequestDto, recordNum, listaTiposCriterio);
	}

	/**
	 * Searches rows in the TiposCriterio table.
	 *
	 * @param filterTiposCriterio
	 *            TiposCriterio
	 * @param searchTiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposCriterio>>
	 */
	public List<TableRowDto<TiposCriterio>> search(TiposCriterio filterTiposCriterio, TiposCriterio searchTiposCriterio,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposCriterioDao.search(filterTiposCriterio, searchTiposCriterio, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in TiposCriterio table.
	 *
	 * @param filterTiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TiposCriterio filterTiposCriterio, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.tiposCriterioDao.reorderSelection(filterTiposCriterio, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the TiposCriterio table.
	 *
	 * @param filterTiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposCriterio>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposCriterio>> jerarquia(TiposCriterio filterTiposCriterio,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TiposCriterio>> listaTiposCriterio = this.tiposCriterioDao
				.findAllLikeJerarquia(filterTiposCriterio, jqGridRequestDto);
		Long recordNum = this.tiposCriterioDao.findAllLikeCountJerarquia(filterTiposCriterio, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposCriterio>>(jqGridRequestDto, recordNum, listaTiposCriterio);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the TiposCriterio
	 * table.
	 *
	 * @param filterTiposCriterio
	 *            TiposCriterio
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposCriterio>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposCriterio>> jerarquiaChildren(TiposCriterio filterTiposCriterio,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TiposCriterio>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposCriterio>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.tiposCriterioDao.findAllChild(filterTiposCriterio, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
