package com.ejie.ab60.service.estudioTecnico;

import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * ConceptosService  
 * 
 *  
 */

public interface ConceptosService {

	/**
	 * Inserts a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos add(Conceptos conceptos);

	/**
	 * Inserts a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos add(Integer idRelacion, Integer idExpediente, Integer idActSubPadre, Integer idActSub,
			Conceptos conceptos, Usuario usuario);

	/**
	 * Updates a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos update(Conceptos conceptos);

	/**
	 * Updates a Importe admitido row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos updateImporte(Conceptos conceptos);

	/**
	 * Boton de admitir todo, pasa el valos del importe al importe admitido
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	void editImporte(Integer idRelacion, Integer idExpediente, Integer idActSub, Integer idActSubPadre,
			Usuario usuario);

	/**
	 * Updates a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos edit(Integer idRelacion, Integer idActSubPadre, Integer idExpediente, Integer idCriterio,
			Conceptos conceptos, Usuario usuario);

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	Conceptos find(Conceptos conceptos);

	/**
	 * Sumatorio de importe admitido de la tabla de conceptos, por expediente y
	 * relacion subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return conceptos
	 */
	Conceptos findConceptosPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion);

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<Conceptos>
	 */
	Conceptos findConceptosPorExpediente(Integer idExpediente);

	/**
	 * Sumatorio de importe admitido de la tabla de conceptos por relacion
	 * subvencionable
	 *
	 * @param Integer
	 *            idRelacion
	 * 
	 * @return conceptos
	 */
	Conceptos findSumConceptosPorRelExpActSub(Integer idRelacion);

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List<Conceptos>
	 */
	List<Conceptos> findConceptosPorRelExpActSub(Integer idRelExpActSub);

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param Conceptos
	 *            conceptos
	 * @return Conceptos
	 */
	Conceptos getSumatorioConceptos(Integer idExpediente, Integer idRelacion, Integer idCriterio, Usuario usuario);

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param Conceptos
	 *            conceptos
	 * @return Conceptos
	 */
	Conceptos getSumatorioConceptos(Integer idExpediente, Integer idRelacion, Usuario usuario);

	/**
	 * Deletes a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 */
	void remove(Conceptos conceptos);

	/**
	 * Deletes a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 */
	Conceptos remove(Integer idRelacion, Integer idExpediente, Integer idConcepto, Integer idActSub,
			Integer idActSubPadre, Usuario usuario);

	/**
	 * Finds a list of rows in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Conceptos>
	 */
	List<Conceptos> findAll(Conceptos conceptos, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Conceptos table using like.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Conceptos>
	 */
	List<Conceptos> findAllLike(Conceptos conceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Conceptos>
	 */
	JQGridResponseDto<Conceptos> filter(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches rows in the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param searchConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Conceptos>>
	 */
	List<TableRowDto<Conceptos>> search(Conceptos filterConceptos, Conceptos searchConceptos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Conceptos>>
	 */
	JQGridResponseDto<JerarquiaDto<Conceptos>> jerarquia(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Finder method for siblings rows in the hierarchical the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Conceptos>>
	 */
	JQGridResponseDto<JerarquiaDto<Conceptos>> jerarquiaChildren(Conceptos filterConceptos,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * removeByIdRelExpActSub
	 *
	 * @param idRelExpActSub
	 *            Integer
	 */
	void removeByIdRelExpActSub(Integer idRelExpActSub);

	Conceptos removeCovidT(Integer idRelacion, Integer idExpediente, Integer idConcepto, Integer idActSub,
			Integer idActSubPadre, Usuario usuario);

}
