package com.ejie.ab60.service.estudioTecnico;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.dao.OtrosIngresosDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.ActSubvencionableDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelActSubMotDenDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelActSubMotMinDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelExpActSubDao;
import com.ejie.ab60.dao.estudioTecnico.ConceptosDao;
import com.ejie.ab60.dao.estudioTecnico.EstudioTecnicoDao;
import com.ejie.ab60.model.OtrosIngresos;
import com.ejie.ab60.model.DEC.RelMunAsoCom;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotDen;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotMin;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.DEC.RelMunAsoComService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ConceptosServiceImpl  
 * 
 *  
 */

@Service(value = "conceptosService")
public class ConceptosServiceImpl implements ConceptosService {

	private static final Logger logger = LoggerFactory.getLogger(ConceptosServiceImpl.class);

	@Autowired
	private ConceptosDao conceptosDao;

	@Autowired
	private RelExpActSubDao relExpActSubDao;

	@Autowired
	private RelExpActSubService relExpActSubService;

	@Autowired
	private EstudioTecnicoDao estudioTecnicoDao;

	@Autowired
	private ActSubvencionableDao actSubvencionableDao;

	@Autowired
	private RelMunAsoComService relMunAsoComService;

	@Autowired
	private ConvocatoriasService convocatoriasService;

	@Autowired
	private RelActSubMotMinDao relActSubMotMinDao;

	@Autowired
	private RelActSubMotDenDao relActSubMotDenDao;

	@Autowired
	private OtrosIngresosDao otrosIngresosDao;

	/**
	 * Inserts a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Conceptos add(Conceptos conceptos) {
		return this.conceptosDao.add(conceptos);
	}

	/**
	 * Inserts a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Conceptos add(Integer idRelacion, Integer idExpediente, Integer idActSubPadre, Integer idActSub,
			Conceptos conceptos, Usuario usuario) {

		Integer idAgrupacionActSubPadre = 0;

		if ((null != idActSubPadre) && (0 != (int) idActSubPadre)) {

			idAgrupacionActSubPadre = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSubPadre);
		}

		Integer idAgrupacionActSub = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSub);

		RelExpActSub relExpActSub = new RelExpActSub();
		RelExpActSub relExpActSubAux = new RelExpActSub();
		RelExpActSub relExpActSubId = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();

		Date fecha = new Date();

		conceptos.setFechaRegistro(fecha);
		conceptos.setUsuarioRegistro(usuario.getNombreUsuario());

		if (0 == idRelacion) {
			relExpActSubId = relExpActSubService.findUltimoId(idExpediente, idActSub);
			relExpActSubAux.setIdExpediente(idExpediente);
			relExpActSubAux.setIdActSub(idActSub);
			relExpActSubAux.setFechaRegistro(fecha);
			relExpActSubAux.setUsuarioRegistro(usuario.getNombreUsuario());
			relExpActSubAux.setImportePresentado(conceptos.getImportePresentado());
			relExpActSubAux.setImporteAdmitido(conceptos.getImporteAdmitido());
			// relExpActSubAux.setIdRelExpActSub(idRelacion);

			estudioTecnico.setImporteDisponible(conceptos.getImportePresentado());
			estudioTecnico.setImporteAdmitido(conceptos.getImporteAdmitido());

			idRelacion = relExpActSubId.getIdRelExpActSub();
			relExpActSubAux.setIdRelExpActSub(relExpActSubId.getIdRelExpActSub());

			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idActSub);
			if (!ultimaRelacionExistente.getIdRelExpActSub().equals(idRelacion)) {
				relExpActSub = relExpActSubDao.add(relExpActSubAux);
			}
			conceptos.setRelExpActSub(relExpActSub);

		}

		relExpActSub.setIdRelExpActSub(idRelacion);
		conceptos.setRelExpActSub(relExpActSub);
		Conceptos conceptosAux = this.conceptosDao.add(conceptos);
		conceptosAux.setIdRelExpActSub(idRelacion);
		conceptosAux.getRelExpActSub().setIdRelExpActSub(idRelacion);
		ConceptosServiceImpl.logger.info("[POST] : Conceptos insertado correctamente");

		Conceptos conceptosSum = this.conceptosDao.findConceptosPorExpedientePorRelacion(idExpediente, idRelacion);
		RelExpActSub relAux = actulizarImportesRelExpActSub(idRelacion, idExpediente, conceptosSum, usuario,
				relExpActSub, fecha);
		estudioTecnico.setImporteAdmitido(relAux.getImporteAdmitido());
		estudioTecnico.setImportePresentado(relAux.getImportePresentado());

		if (idActSubPadre > 0) {
			if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Pertenencia_Redes) {
				// Update los importes en el padre
				RelExpActSub relExpActSubSuma = this.relExpActSubDao.sumEstudioActuacion(idExpediente, idActSubPadre);
				relExpActSubSuma.setIdExpediente(idExpediente);
				relExpActSubSuma.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				this.relExpActSubDao.updateImportePorIdActSub(relExpActSubSuma, idActSubPadre);
				// actualizo los importes de la subvencion calculada y
				// porcentaje a null
				RelExpActSub relExpActSubCalculada = new RelExpActSub();
				relExpActSubCalculada.setIdExpediente(idExpediente);
				relExpActSubCalculada.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				relExpActSubCalculada.setFechaUltmodificacion(new Date());
				relExpActSubDao.updateImporteSubvencionCalculada(relExpActSubCalculada);

				// Sumo para los totales de la tabla 5
				relExpActSubSuma = relExpActSubDao.findRelExpActHijosPorExpediente(idExpediente);
				estudioTecnico.setImporteAdmitido(relExpActSubSuma.getImporteAdmitido());
				estudioTecnico.setImportePresentado(relExpActSubSuma.getImportePresentado());
			} else if (idAgrupacionActSubPadre == Constantes.ID_AGRUPACION_DEC_Asociacion) {

				// Update los importes en la relacion que corresponda
				RelExpActSub relExpActSubSuma = this.relExpActSubDao.sumEstudioActuacion(idExpediente, idActSubPadre);
				relExpActSubSuma.setIdExpediente(idExpediente);
				relExpActSubSuma.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				this.relExpActSubDao.updateImportePorIdActSub(relExpActSubSuma, idActSubPadre);

				RelExpActSub subvencionPorcentaje = new RelExpActSub();
				subvencionPorcentaje.setIdExpediente(idExpediente);
				this.relExpActSubDao.updateSubvencionPorcentaje(subvencionPorcentaje);

				// Update los importes en datos proyecto(estudio tecnico)
				estudioTecnico.setImportePresentado(relExpActSubSuma.getImportePresentado());
				estudioTecnico.setImporteAdmitido(relExpActSubSuma.getImporteAdmitido());

			} else { // EMET (Competitividad)
				RelExpActSub rel = updatearImportesRelacionPadre(idExpediente, idActSubPadre, usuario, relExpActSub,
						fecha);
				estudioTecnico.setImporteAdmitido(rel.getImporteAdmitido());
				estudioTecnico.setImportePresentado(rel.getImportePresentado());
			}
		} else { // CTP, COVIDT, COVIDM y EMET (Emprencimiento)
			RelExpActSub relExpActSubSum = this.relExpActSubDao.sumImportesConceptos(idExpediente);
			estudioTecnico.setImporteAdmitido(relExpActSubSum.getImporteAdmitido());
			estudioTecnico.setImportePresentado(relExpActSubSum.getImportePresentado());
		}

		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		estudioTecnicoDao.updateImporte(estudioTecnico);

		return conceptosAux;

	}

	/**
	 * Updates a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Conceptos update(Conceptos conceptos) {
		return this.conceptosDao.update(conceptos);
	}

	/**
	 * Updates a Importe admitido row in the Conceptos table
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Conceptos updateImporte(Conceptos conceptos) {
		return this.conceptosDao.updateImporte(conceptos);
	}

	/**
	 * Updates a row in the Conceptos table
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void editImporte(Integer idRelacion, Integer idExpediente, Integer idActSub, Integer idActSubPadre,
			Usuario usuario) {
		RelExpActSub relExpActSub = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		Date fecha = new Date();
		Conceptos concepto = new Conceptos();

		Integer idAgrupacionActSubPadre = 0;
		if ((null != idActSubPadre) && (0 != (int) idActSubPadre)) {

			idAgrupacionActSubPadre = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSubPadre);
		}

		Integer idAgrupacionActSub = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSub);

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idActSub);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}
		relExpActSub.setIdRelExpActSub(idRelacion);

		RelMunAsoCom relMunAsoCom = new RelMunAsoCom();
		relMunAsoCom = this.relMunAsoComService.findById(idExpediente);

		Convocatorias convocatoria = new Convocatorias();
		convocatoria = convocatoriasService.findByIdExpediente(idExpediente);

		List<Conceptos> conceptosList = conceptosDao.findConceptosPorRelExpActSub(idRelacion);
		for (int index = 0; index < conceptosList.size(); index++) {
			concepto.setIdConcepto(conceptosList.get(index).getIdConcepto());

			if (relMunAsoCom != null && relMunAsoCom.getExentoIva() != null) {
				if (convocatoria.getIdConvocatoria() != Constantes.DEC_2018
						&& relMunAsoCom.getExentoIva() == Constantes.MAGIC_NUMBER_1) {
					concepto.setImportePresentado(conceptosList.get(index).getImportePresentado());
				} else if (convocatoria.getIdConvocatoria() != Constantes.DEC_2018
						&& relMunAsoCom.getExentoIva() == Constantes.MAGIC_NUMBER_0) {
					concepto.setImportePresentado(conceptosList.get(index).getImporteSinIva());
				} else {
					concepto.setImportePresentado(conceptosList.get(index).getImportePresentado());
				}
			} else {
				concepto.setImportePresentado(conceptosList.get(index).getImportePresentado());
			}

			concepto.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			concepto.setFechaUltmodificacion(fecha);
			conceptosDao.updateImporte(concepto);
			ConceptosServiceImpl.logger.info("[PUT] : Importe en Conceptos actualizado correctamente");
		}
		ConceptosServiceImpl.logger.info("[GET - findBy_PK] : Obtener Sumatorio de facturas por expediente");
		Conceptos conceptos = this.conceptosDao.findConceptosPorExpedientePorRelacion(idExpediente, idRelacion);
		if (null != conceptos) {

			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			if (null != conceptos.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(conceptos.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(BigDecimal.ZERO);
			}

			relExpActSub.setIdRelExpActSub(idRelacion);
			relExpActSub = this.relExpActSubDao.updateImporte(relExpActSub);
			ConceptosServiceImpl.logger.info("[GET - findBy_PK] : Update Importe admitido en relExpActSub");

			if (idActSubPadre > 0) {
				if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion
						|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Pertenencia_Redes) {
					// Update los importes en el padre
					RelExpActSub relExpActSubSuma = this.relExpActSubDao.sumEstudioActuacion(idExpediente,
							idActSubPadre);
					relExpActSubSuma.setIdExpediente(idExpediente);
					relExpActSubSuma.setUsuarioUltmodificacion(usuario.getNombreUsuario());
					this.relExpActSubDao.updateImportePorIdActSub(relExpActSubSuma, idActSubPadre);
					// actualizo los importes de la subvencion calculada y
					// porcentaje a null
					RelExpActSub relExpActSubCalculada = new RelExpActSub();
					relExpActSubCalculada.setIdExpediente(idExpediente);
					relExpActSubCalculada.setUsuarioUltmodificacion(usuario.getNombreUsuario());
					relExpActSubCalculada.setFechaUltmodificacion(new Date());
					relExpActSubDao.updateImporteSubvencionCalculada(relExpActSubCalculada);
					// Sumo para los totales de la tabla 5
					relExpActSubSuma = relExpActSubDao.findRelExpActHijosPorExpediente(idExpediente);
					estudioTecnico.setImporteAdmitido(relExpActSubSuma.getImporteAdmitido());
					estudioTecnico.setImportePresentado(relExpActSubSuma.getImportePresentado());

				} else if (idAgrupacionActSubPadre == Constantes.ID_AGRUPACION_DEC_Asociacion) {
					// Update los importes en la relacion que corresponda
					RelExpActSub relExpActSubSuma = this.relExpActSubDao.sumEstudioActuacion(idExpediente,
							idActSubPadre);
					relExpActSubSuma.setIdExpediente(idExpediente);
					relExpActSubSuma.setUsuarioUltmodificacion(usuario.getNombreUsuario());
					this.relExpActSubDao.updateImportePorIdActSub(relExpActSubSuma, idActSubPadre);

					// Update los importes en datos proyecto(estudio tecnico)
					estudioTecnico.setImportePresentado(relExpActSubSuma.getImportePresentado());
					estudioTecnico.setImporteAdmitido(relExpActSubSuma.getImporteAdmitido());
				} else {
					RelExpActSub rel = updatearImportesRelacionPadre(idExpediente, idActSubPadre, usuario, relExpActSub,
							fecha);
					estudioTecnico.setImporteAdmitido(rel.getImporteAdmitido());
					estudioTecnico.setImportePresentado(rel.getImportePresentado());
				}
			} else if (Constantes.COVIDT_2020.equals(convocatoria.getIdConvocatoria())
					|| Constantes.COVIDM_2020.equals(convocatoria.getIdConvocatoria())) {
				RelExpActSub relExpActSubSum = this.relExpActSubDao.sumImportesConceptos(idExpediente);
				estudioTecnico.setImporteAdmitido(relExpActSubSum.getImporteAdmitido());
				estudioTecnico.setImportePresentado(relExpActSubSum.getImportePresentado());
			} else {

				// actualizo expediente
				estudioTecnico.setImportePresentado(conceptos.getImportePresentado());
				estudioTecnico.setImporteAdmitido(conceptos.getImporteAdmitido());
			}
			estudioTecnico.setIdExpediente(idExpediente);
			estudioTecnico.setFechaUltmodificacion(fecha);
			estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			estudioTecnicoDao.updateImporte(estudioTecnico);

		}

	}

	/**
	 * Updates a row in the Conceptos table
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Conceptos edit(Integer idRelacion, Integer idActSubPadre, Integer idExpediente, Integer idActSub,
			Conceptos conceptos, Usuario usuario) {
		RelExpActSub relExpActSub = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		Date fecha = new Date();

		Integer idAgrupacionActSubPadre = 0;

		if ((null != idActSubPadre) && (0 != (int) idActSubPadre)) {

			idAgrupacionActSubPadre = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSubPadre);
		}

		Integer idAgrupacionActSub = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSub);

		conceptos.setFechaUltmodificacion(fecha);
		conceptos.setUsuarioUltmodificacion(usuario.getNombreUsuario());

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idActSub);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}
		relExpActSub.setIdRelExpActSub(idRelacion);
		conceptos.setIdRelExpActSub(idRelacion);
		conceptos = this.conceptosDao.update(conceptos);
		ConceptosServiceImpl.logger.info("[PUT] : Conceptos actualizado correctamente");

		List<RelExpActSub> exento = this.relExpActSubService.findExentoPorExpediente(idExpediente);

		if (exento.size() == 0) {
			relExpActSub.setExento(1);
		} else {
			relExpActSub.setExento(exento.get(0).getExento());
		}

		// Sumamos los conceptos
		Conceptos conceptosSum = this.conceptosDao.findConceptosPorExpedientePorRelacion(idExpediente, idRelacion);
		RelExpActSub relAux = actulizarImportesRelExpActSub(idRelacion, idExpediente, conceptosSum, usuario,
				relExpActSub, fecha);
		estudioTecnico.setImporteAdmitido(relAux.getImporteAdmitido());
		estudioTecnico.setImportePresentado(relAux.getImportePresentado());

		if (idActSubPadre > 0) {
			if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Pertenencia_Redes) {
				// Update los importes en el padre
				RelExpActSub relExpActSubSuma = relExpActSubDao.sumEstudioActuacion(idExpediente, idActSubPadre);
				relExpActSubSuma.setIdExpediente(idExpediente);
				relExpActSubSuma.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				relExpActSubDao.updateImportePorIdActSub(relExpActSubSuma, idActSubPadre);
				// actualizo los importes de la subvencion calculada y
				// porcentaje a null
				RelExpActSub relExpActSubCalculada = new RelExpActSub();
				relExpActSubCalculada.setIdExpediente(idExpediente);
				relExpActSubCalculada.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				relExpActSubCalculada.setFechaUltmodificacion(new Date());
				relExpActSubDao.updateImporteSubvencionCalculada(relExpActSubCalculada);

				// Sumo para los totales de la tabla 5
				relExpActSubSuma = relExpActSubDao.findRelExpActHijosPorExpediente(idExpediente);
				estudioTecnico.setImporteAdmitido(relExpActSubSuma.getImporteAdmitido());
				estudioTecnico.setImportePresentado(relExpActSubSuma.getImportePresentado());

			} else if (idAgrupacionActSubPadre == Constantes.ID_AGRUPACION_DEC_Asociacion) {
				RelExpActSub subvencionPorcentaje = new RelExpActSub();
				subvencionPorcentaje.setIdExpediente(idExpediente);
				this.relExpActSubDao.updateSubvencionPorcentaje(subvencionPorcentaje);

				List<RelExpActSub> listaImportes = this.relExpActSubDao.importesPorExento(idExpediente,
						relExpActSub.getExento());

				if (listaImportes.size() != 0) {

					Float presentado = (float) 0;

					for (RelExpActSub relexpactsub : listaImportes) {
						presentado = presentado
								+ relexpactsub.getImportePresentado().setScale(2, RoundingMode.DOWN).floatValue();
					}

					BigDecimal presentadoTotal = new BigDecimal(presentado);

					estudioTecnico.setImportePresentado(presentadoTotal);
				}

			} else { // EMET (Competitividad)
				RelExpActSub rel = updatearImportesRelacionPadre(idExpediente, idActSubPadre, usuario, relExpActSub,
						fecha);
				estudioTecnico.setImporteAdmitido(rel.getImporteAdmitido());
				estudioTecnico.setImportePresentado(rel.getImportePresentado());
			}
		} else { // CTP, COVIDT, COVIDM y EMET (Emprendimiento)
			RelExpActSub relExpActSubSum = this.relExpActSubDao.sumImportesConceptos(idExpediente);
			estudioTecnico.setImporteAdmitido(relExpActSubSum.getImporteAdmitido());
			estudioTecnico.setImportePresentado(relExpActSubSum.getImportePresentado());
		}

		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		estudioTecnicoDao.updateImporte(estudioTecnico);

		return conceptos;

	}

	private RelExpActSub updatearImportesRelacionPadre(Integer idExpediente, Integer idActSubPadre, Usuario usuario,
			RelExpActSub relExpActSub, Date fecha) {
		RelExpActSub relExpSumHijos = this.relExpActSubDao.findRelExpActHijosPorExpediente(idExpediente);
		if (null != relExpSumHijos) {
			if (null != relExpSumHijos.getImportePresentado()) {
				relExpActSub.setImportePresentado(relExpSumHijos.getImportePresentado());
			} else {
				relExpActSub.setImportePresentado(null);
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != relExpSumHijos.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(relExpSumHijos.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
			}
		}
		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setIdActSub(idActSubPadre);
		relExpActSub.setFechaUltmodificacion(fecha);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		// updateamos la RelExpeActSubPadre
		return relExpActSubDao.updateImportePresentadoAdmtidoPadre(relExpActSub);

	}

	private RelExpActSub actulizarImportesRelExpActSub(Integer idRelacion, Integer idExpediente, Conceptos conceptosSum,
			Usuario usuario, RelExpActSub relExpActSub, Date fecha) {

		List<RelExpActSub> relExpActSubAux = this.relExpActSubDao.findExentoPorExpediente(idExpediente);

		// SUMMANOS TODOS LOS IMPORTES DE CONCEPTOS
		if (null != conceptosSum) {

			if (relExpActSubAux.size() == 0) {
				RelExpActSub relExpAct = new RelExpActSub();
				relExpAct.setExento(1);
				relExpActSubAux.add(relExpAct);
			}

			if (relExpActSubAux.get(0).getExento() == 0) {
				if (null != conceptosSum.getImporteSinIva()) {
					relExpActSub.setImportePresentado(conceptosSum.getImporteSinIva());
				} else {
					relExpActSub.setImportePresentado(null);
				}
			} else {
				if (null != conceptosSum.getImportePresentado()) {
					relExpActSub.setImportePresentado(conceptosSum.getImportePresentado());
				} else {
					relExpActSub.setImportePresentado(null);
				}
			}
			relExpActSub.setIdExpediente(idExpediente);
			if (null != conceptosSum.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(conceptosSum.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
			}
		}
		relExpActSub.setFechaUltmodificacion(fecha);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setSubvencionCalculada(null);
		relExpActSub.setPorcentaje(null);

		// ACTUALIZAMOS importes de RELACION ACCION SUBVENCIONABLE
		return relExpActSubDao.updateImportePresentadoAdmtido(relExpActSub);
	}

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	public Conceptos find(Conceptos conceptos) {
		return (Conceptos) this.conceptosDao.find(conceptos);
	}

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	public Conceptos getSumatorioConceptos(Integer idExpediente, Integer idRelacion, Integer idCriterio,
			Usuario usuario) {

		Date fecha = new Date();
		Conceptos conceptos = new Conceptos();
		RelExpActSub relExpActSub = new RelExpActSub();

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idCriterio);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}

		ConceptosServiceImpl.logger.info("[GET - findBy_PK] : Obtener Sumatorio de conceptos por expediente");
		conceptos = this.conceptosDao.findConceptosPorExpedientePorRelacion(idExpediente, idRelacion);

		if (null != conceptos) {

			ConceptosServiceImpl.logger.info("[GET - findBy_PK] : Obtener sumatorio de importes por expediente");
			relExpActSub = relExpActSubDao.sumTotales(idExpediente);

			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setIdRelExpActSub(idRelacion);
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());

			if (null != relExpActSub.getImporteAdmitido()) {
				relExpActSub.setImporteAdmitido(conceptos.getImporteAdmitido());
			} else {
				relExpActSub.setImporteAdmitido(null);
			}

			ConceptosServiceImpl.logger.info("[GET - findBy_PK] : Update Importe admitido en relExpActSub");
			relExpActSub = this.relExpActSubDao.updateImporte(relExpActSub);
		}

		return conceptos;
	}

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @return Conceptos
	 */
	public Conceptos getSumatorioConceptos(Integer idExpediente, Integer idRelacion, Usuario usuario) {
		Conceptos conceptos = new Conceptos();
		RelExpActSub relExpActSub = new RelExpActSub();

		conceptos = this.conceptosDao.findSumConceptosPorRelExpActSub(idRelacion);
		ConceptosServiceImpl.logger.info("[GET - findBy_PK] : Obtener Sumatorio de conceptos por expediente");

		if (conceptos != null && conceptos.getImporteAdmitido() != null) {
			Date fecha = new Date();
			// Integer idExpediente = initForm.getIdExpediente();

			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpActSub.setImporteAdmitido(conceptos.getImporteAdmitido());
			relExpActSub.setIdRelExpActSub(idRelacion);
			relExpActSub = this.relExpActSubDao.updateImporte(relExpActSub);
			ConceptosServiceImpl.logger.info("[GET - findBy_PK] : Update Importe admitido en relExpActSub");

		}

		return conceptos;

	}

	/**
	 * Sumatorio de importe admitido de la tabla de conceptos, por expediente y
	 * relacion subvencionable
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idRelacion
	 * @return conceptos
	 */
	public Conceptos findConceptosPorExpedientePorRelacion(Integer idExpediente, Integer idRelacion) {
		return (Conceptos) this.conceptosDao.findConceptosPorExpedientePorRelacion(idExpediente, idRelacion);
	}

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<Conceptos>
	 */
	public Conceptos findConceptosPorExpediente(Integer idExpediente) {
		return (Conceptos) this.conceptosDao.findConceptosPorExpediente(idExpediente);

	}

	/**
	 * Sumatorio de importe admitido de la tabla de conceptos por relacion
	 * subvencionable
	 *
	 * @param Integer
	 *            idRelacion
	 * @return conceptos
	 */
	public Conceptos findSumConceptosPorRelExpActSub(Integer idRelacion) {
		return (Conceptos) this.conceptosDao.findSumConceptosPorRelExpActSub(idRelacion);
	}

	/**
	 * Finds a single row in the Conceptos table.
	 *
	 * @param Integer
	 *            idRelExpActSub
	 * @return List<Conceptos>
	 */
	public List<Conceptos> findConceptosPorRelExpActSub(Integer idRelExpActSub) {
		return (List<Conceptos>) this.conceptosDao.findConceptosPorRelExpActSub(idRelExpActSub);

	}

	/**
	 * Deletes a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Conceptos conceptos) {
		this.conceptosDao.remove(conceptos);
	}

	/**
	 * Deletes a single row in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Conceptos remove(Integer idRelacion, Integer idExpediente, Integer idConcepto, Integer idActSub,
			Integer idActSubPadre, Usuario usuario) {

		RelExpActSub relExpActSub = new RelExpActSub();
		// RelActSubSubact relActSubSubact = new RelActSubSubact();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		Date fecha = new Date();

		Integer idAgrupacionActSubPadre = 0;
		if ((null != idActSubPadre) && (0 != (int) idActSubPadre)) {

			idAgrupacionActSubPadre = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSubPadre);
		}
		Integer idAgrupacionActSub = actSubvencionableDao.obtenerIdentificadorAgrupacion(idActSub);

		Conceptos conceptos = new Conceptos();
		Conceptos conceptosSum = new Conceptos();

		if (0 == idRelacion) {
			RelExpActSub ultimaRelacionExistente = relExpActSubDao.findLastId(idExpediente, idActSub);
			idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
		}
		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setIdRelExpActSub(idRelacion);
		relExpActSub.setIdActSub(idActSub);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setFechaUltmodificacion(fecha);
		conceptos.setIdConcepto(idConcepto);
		this.conceptosDao.remove(conceptos);
		ConceptosServiceImpl.logger.info("[DELETE] : Conceptos borrado  correctamente");

		List<Conceptos> listaConceptoss = conceptosDao.findConceptosPorRelExpActSub(idRelacion);
		if (listaConceptoss.size() == 0) {
			if (idAgrupacionActSub == Constantes.ID_AGRUPACION_CTP_Apoyo_Creacion
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_CTP_Actuaciones_Destinadas
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_CTP_Apoyo_Eventos
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_EMET_Emprendimiento
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_EMET_Competitividad
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_EMET_Competitividad_Innovacion
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_EMET_Competitividad_Calidad
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_EMET_Competitividad_Oferta) {

				relExpActSub.setImporteAdmitido(null);
				relExpActSub.setImportePresentado(null);
				relExpActSub.setPorcentaje(null);
				relExpActSub.setSubvencionCalculada(null);
				relExpActSubDao.updateImportePresentadoAdmtidoPadre(relExpActSub);
				ConceptosServiceImpl.logger.info(
						"[DELETE] : Relacion  updateada  correctamente, poner a null los importes si la act es 22,19,21,20");

			} else if (idAgrupacionActSubPadre == Constantes.ID_AGRUPACION_DEC_Asociacion) {
				relExpActSub.setImporteAdmitido(null);
				relExpActSub.setImportePresentado(null);
				relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				relExpActSub.setFechaUltmodificacion(new Date());
				relExpActSubDao.updateImportePresentadoAdmtido(relExpActSub);
				relExpActSub.setIdActSub(idActSubPadre);
				relExpActSubDao.updateImportePresentadoAdmtidoPadre(relExpActSub);
				RelExpActSub subvencionPorcentaje = new RelExpActSub();
				subvencionPorcentaje.setIdExpediente(idExpediente);
				this.relExpActSubDao.updateSubvencionPorcentaje(subvencionPorcentaje);
			} else {
				if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion
						|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Pertenencia_Redes) {
					relExpActSub.setImporteAdmitido(null);
					relExpActSub.setImportePresentado(null);
					relExpActSub.setIdExpediente(idExpediente);
					relExpActSub.setIdRelExpActSub(idRelacion);
					relExpActSub.setFechaUltmodificacion(fecha);
					relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
					relExpActSubDao.updateImportePresentadoAdmtido(relExpActSub);
				}
				// } else {
				// relExpActSubDao.remove(relExpActSub);
				// }
				if (idActSubPadre > 0) {
					if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion
							|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Pertenencia_Redes) {
						// Update los importes en el padre
						RelExpActSub relExpActSubSuma = this.relExpActSubDao.sumEstudioActuacion(idExpediente,
								idActSubPadre);
						relExpActSubSuma.setIdExpediente(idExpediente);
						relExpActSubSuma.setUsuarioUltmodificacion(usuario.getNombreUsuario());
						this.relExpActSubDao.updateImportePorIdActSub(relExpActSubSuma, idActSubPadre);
						// actualizo los importes de la subvencion calculada y
						// porcentaje a null
						RelExpActSub relExpActSubCalculada = new RelExpActSub();
						relExpActSubCalculada.setIdExpediente(idExpediente);
						relExpActSubCalculada.setUsuarioUltmodificacion(usuario.getNombreUsuario());
						relExpActSubCalculada.setFechaUltmodificacion(new Date());
						relExpActSubDao.updateImporteSubvencionCalculada(relExpActSubCalculada);

						// Sumo para los totales de la tabla 5
						relExpActSubSuma = relExpActSubDao.findRelExpActHijosPorExpediente(idExpediente);
						estudioTecnico.setImporteAdmitido(relExpActSubSuma.getImporteAdmitido());
						estudioTecnico.setImportePresentado(relExpActSubSuma.getImportePresentado());
					} else {
						updatearImportesRelacionPadre(idExpediente, idActSubPadre, usuario, relExpActSub, fecha);
					}

					ConceptosServiceImpl.logger.info("[DELETE] : actualizzamos valor del padre");
				}
				ConceptosServiceImpl.logger.info("[DELETE] : Relacion  borrado correctamente");
			}
			// Actualizar expediente.
			conceptosSum = conceptosDao.findConceptosPorExpediente(idExpediente);
			if (null == conceptosSum) {
				estudioTecnico.setImportePresentado(null);
				estudioTecnico.setImporteAdmitido(null);
			}
			///////////////////////////////////////////////////////////////
			/*
			 * else { // actualizamos importes de expediente
			 * estudioTecnico.setImportePresentado(conceptosSum.
			 * getImportePresentado());
			 * estudioTecnico.setImporteAdmitido(conceptosSum.
			 * getImporteAdmitido()); }
			 */
			//////////////////////////////////////////////////////////////
		} else {
			conceptosSum = this.conceptosDao.findConceptosPorExpedientePorRelacion(idExpediente, idRelacion);
			RelExpActSub relAux = actulizarImportesRelExpActSub(idRelacion, idExpediente, conceptosSum, usuario,
					relExpActSub, fecha);
			estudioTecnico.setImporteAdmitido(relAux.getImporteAdmitido());
			estudioTecnico.setImportePresentado(relAux.getImportePresentado());

			if (idActSubPadre > 0) {
				if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion
						|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Pertenencia_Redes) {
					// Update los importes en el padre
					RelExpActSub relExpActSubSuma = this.relExpActSubDao.sumEstudioActuacion(idExpediente,
							idActSubPadre);
					relExpActSubSuma.setIdExpediente(idExpediente);
					relExpActSubSuma.setUsuarioUltmodificacion(usuario.getNombreUsuario());
					this.relExpActSubDao.updateImportePorIdActSub(relExpActSubSuma, idActSubPadre);

					// actualizo los importes de la subvencion calculada y
					// porcentaje a null
					RelExpActSub relExpActSubCalculada = new RelExpActSub();
					relExpActSubCalculada.setIdExpediente(idExpediente);
					relExpActSubCalculada.setUsuarioUltmodificacion(usuario.getNombreUsuario());
					relExpActSubCalculada.setFechaUltmodificacion(new Date());
					relExpActSubDao.updateImporteSubvencionCalculada(relExpActSubCalculada);
					// Sumo para los totales de la tabla 5
					relExpActSubSuma = relExpActSubDao.findRelExpActHijosPorExpediente(idExpediente);
					estudioTecnico.setImporteAdmitido(relExpActSubSuma.getImporteAdmitido());
					estudioTecnico.setImportePresentado(relExpActSubSuma.getImportePresentado());
				} else {
					RelExpActSub rel = updatearImportesRelacionPadre(idExpediente, idActSubPadre, usuario, relExpActSub,
							fecha);
					estudioTecnico.setImporteAdmitido(rel.getImporteAdmitido());
					estudioTecnico.setImportePresentado(rel.getImportePresentado());
				}
			}

		}

		// actualizamos importes de expediente
		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		estudioTecnicoDao.updateImporte(estudioTecnico);

		return conceptos;

	}

	/**
	 * removeByIdRelExpActSub
	 *
	 * @param idRelExpActSub
	 *            Integer
	 */
	@Override
	@Transactional(rollbackFor = Throwable.class)
	public void removeByIdRelExpActSub(Integer idRelExpActSub) {
		this.conceptosDao.removeByIdRelExpActSub(idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the Conceptos table.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Conceptos>
	 */
	public List<Conceptos> findAll(Conceptos conceptos, JQGridRequestDto jqGridRequestDto) {
		return (List<Conceptos>) this.conceptosDao.findAll(conceptos, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Conceptos table using like.
	 *
	 * @param conceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Conceptos>
	 */
	public List<Conceptos> findAllLike(Conceptos conceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Conceptos>) this.conceptosDao.findAllLike(conceptos, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.conceptosDao.removeMultiple(filterConceptos, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Conceptos>
	 */
	public JQGridResponseDto<Conceptos> filter(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		Integer idRelacion = filterConceptos.getRelExpActSub().getIdRelExpActSub();
		if (null != idRelacion && 0 == idRelacion) {
			RelExpActSub lastId = relExpActSubDao.findLastId(filterConceptos.getIdExpediente(),
					filterConceptos.getIdActSub());
			if (null != lastId.getIdRelExpActSub()) {
				filterConceptos.getRelExpActSub().setIdRelExpActSub(lastId.getIdRelExpActSub());
				filterConceptos.setIdRelExpActSub(lastId.getIdRelExpActSub());
			}
		}
		List<Conceptos> listaConceptoss = this.conceptosDao
				.findConceptosPorRelExpActSub(filterConceptos.getRelExpActSub().getIdRelExpActSub());
		Long recordNum = this.conceptosDao.findAllLikeCount(filterConceptos != null ? filterConceptos : new Conceptos(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Conceptos>> reorderSelection = this.conceptosDao.reorderSelection(filterConceptos,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Conceptos>(jqGridRequestDto, recordNum, listaConceptoss, reorderSelection);
		}
		return new JQGridResponseDto<Conceptos>(jqGridRequestDto, recordNum, listaConceptoss);
	}

	/**
	 * Searches rows in the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param searchConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Conceptos>>
	 */
	public List<TableRowDto<Conceptos>> search(Conceptos filterConceptos, Conceptos searchConceptos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.conceptosDao.search(filterConceptos, searchConceptos, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Conceptos filterConceptos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.conceptosDao.reorderSelection(filterConceptos, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Conceptos>>
	 */
	public JQGridResponseDto<JerarquiaDto<Conceptos>> jerarquia(Conceptos filterConceptos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Conceptos>> listaConceptos = this.conceptosDao.findAllLikeJerarquia(filterConceptos,
				jqGridRequestDto);
		Long recordNum = this.conceptosDao.findAllLikeCountJerarquia(filterConceptos, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Conceptos>>(jqGridRequestDto, recordNum, listaConceptos);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Conceptos table.
	 *
	 * @param filterConceptos
	 *            Conceptos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Conceptos>>
	 */
	public JQGridResponseDto<JerarquiaDto<Conceptos>> jerarquiaChildren(Conceptos filterConceptos,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Conceptos>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Conceptos>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.conceptosDao.findAllChild(filterConceptos, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public Conceptos removeCovidT(Integer idRelacion, Integer idExpediente, Integer idConcepto, Integer idActSub,
			Integer idActSubPadre, Usuario usuario) {

		Date fecha = new Date();
		RelExpActSub relExpActSub = new RelExpActSub();
		EstudioTecnico estudioTecnico = new EstudioTecnico();
		int countConceptos = this.conceptosDao.findCountByRelExpActSub(idRelacion);
		Conceptos concepto = new Conceptos();
		concepto.setIdConcepto(idConcepto);
		this.conceptosDao.remove(concepto);

		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setIdRelExpActSub(idRelacion);
		relExpActSub.setIdActSub(idActSub);
		relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		relExpActSub.setFechaUltmodificacion(fecha);

		Conceptos conceptosSum = this.conceptosDao.findConceptosPorExpedientePorRelacion(idExpediente, idRelacion);
		actulizarImportesRelExpActSub(idRelacion, idExpediente, conceptosSum, usuario, relExpActSub, fecha);

		RelExpActSub relExpActSubSum = this.relExpActSubDao.sumImportesConceptos(idExpediente);
		estudioTecnico.setImporteAdmitido(relExpActSubSum.getImporteAdmitido());
		estudioTecnico.setImportePresentado(relExpActSubSum.getImportePresentado());

		// actualizamos importes de expediente
		estudioTecnico.setIdExpediente(idExpediente);
		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		estudioTecnico.setSubvencionCalculada(null);
		estudioTecnico.setSubvencionResuelta(null);
		estudioTecnicoDao.updateImporte(estudioTecnico);

		if (countConceptos == 1) {
			List<RelActSubMotMin> listaMotivosMinoracion = this.relActSubMotMinDao
					.findIdsMotivosMinoraciones(idRelacion, Constantes.ORIGEN_INSPECCION_ESTUDIO_TECNICO);
			List<RelActSubMotDen> listaMotivosDenegacion = this.relActSubMotDenDao
					.findIdsMotivosDenegaciones(idRelacion);
			if (listaMotivosDenegacion.isEmpty() && listaMotivosMinoracion.isEmpty()) {
				OtrosIngresos otrosIngresos = new OtrosIngresos();
				otrosIngresos.setIdRelExpActSub(idRelacion);
				otrosIngresos.setFase(Constantes.FASE_SOLICITUD);
				otrosIngresos = this.otrosIngresosDao.findByIdRelExpActSub(otrosIngresos);
				if (otrosIngresos != null && otrosIngresos.getImporte() == null) {
					this.otrosIngresosDao.remove(otrosIngresos);
					RelExpActSub relExpActSubAux = new RelExpActSub();
					relExpActSubAux.setIdRelExpActSub(idRelacion);
					relExpActSubAux = this.relExpActSubDao.findNotasObservaciones(relExpActSubAux);
					if (relExpActSubAux.getNotas() == null && relExpActSubAux.getObservacionesCastellano() == null
							&& relExpActSubAux.getObservacionesEuskera() == null) {
						this.relExpActSubDao.remove(relExpActSubAux);
					}
				}
			}
		}

		return concepto;
	}

}
