package com.ejie.ab60.service.estudioTecnico;

import com.ejie.ab60.dao.estudioTecnico.ErroresCalculoDao;
import com.ejie.ab60.model.estudioTecnico.ErroresCalculo;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * ErroresCalculoServiceImpl  
 * 
 *  
 */

@Service(value = "erroresCalculoService")
public class ErroresCalculoServiceImpl implements ErroresCalculoService {

	@Autowired
	private ErroresCalculoDao erroresCalculoDao;

	/**
	 * Inserts a single row in the ErroresCalculo table.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo
	 * @return ErroresCalculo
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ErroresCalculo add(ErroresCalculo erroresCalculo) {
		return this.erroresCalculoDao.add(erroresCalculo);
	}

	/**
	 * Updates a single row in the ErroresCalculo table.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo
	 * @return ErroresCalculo
	 */
	@Transactional(rollbackFor = Throwable.class)
	public ErroresCalculo update(ErroresCalculo erroresCalculo) {
		return this.erroresCalculoDao.update(erroresCalculo);
	}

	/**
	 * Finds a single row in the ErroresCalculo table.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo
	 * @return ErroresCalculo
	 */
	public ErroresCalculo find(ErroresCalculo erroresCalculo) {
		return (ErroresCalculo) this.erroresCalculoDao.find(erroresCalculo);
	}

	/**
	 * Deletes a single row in the ErroresCalculo table.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(ErroresCalculo erroresCalculo) {
		this.erroresCalculoDao.remove(erroresCalculo);
	}

	/**
	 * Finds a list of rows in the ErroresCalculo table.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<ErroresCalculo>
	 */
	public List<ErroresCalculo> findAll(ErroresCalculo erroresCalculo, JQGridRequestDto jqGridRequestDto) {
		return (List<ErroresCalculo>) this.erroresCalculoDao.findAll(erroresCalculo, jqGridRequestDto);
	}

	/**
	 * Finds rows in the ErroresCalculo table using like.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ErroresCalculo>
	 */
	public List<ErroresCalculo> findAllLike(ErroresCalculo erroresCalculo, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<ErroresCalculo>) this.erroresCalculoDao.findAllLike(erroresCalculo, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the ErroresCalculo table.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(ErroresCalculo filterErroresCalculo, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.erroresCalculoDao.removeMultiple(filterErroresCalculo, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the ErroresCalculo table.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<ErroresCalculo>
	 */
	public JQGridResponseDto<ErroresCalculo> filter(ErroresCalculo filterErroresCalculo,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<ErroresCalculo> listaErroresCalculo = this.erroresCalculoDao.findAllLike(filterErroresCalculo,
				jqGridRequestDto, false);
		Long recordNum = this.erroresCalculoDao
				.findAllLikeCount(filterErroresCalculo != null ? filterErroresCalculo : new ErroresCalculo(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<ErroresCalculo>> reorderSelection = this.erroresCalculoDao
					.reorderSelection(filterErroresCalculo, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<ErroresCalculo>(jqGridRequestDto, recordNum, listaErroresCalculo,
					reorderSelection);
		}
		return new JQGridResponseDto<ErroresCalculo>(jqGridRequestDto, recordNum, listaErroresCalculo);
	}

	/**
	 * Searches rows in the ErroresCalculo table.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param searchErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<ErroresCalculo>>
	 */
	public List<TableRowDto<ErroresCalculo>> search(ErroresCalculo filterErroresCalculo,
			ErroresCalculo searchErroresCalculo, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.erroresCalculoDao.search(filterErroresCalculo, searchErroresCalculo, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in ErroresCalculo table.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(ErroresCalculo filterErroresCalculo, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.erroresCalculoDao.reorderSelection(filterErroresCalculo, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the ErroresCalculo table.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<ErroresCalculo>>
	 */
	public JQGridResponseDto<JerarquiaDto<ErroresCalculo>> jerarquia(ErroresCalculo filterErroresCalculo,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<ErroresCalculo>> listaErroresCalculo = this.erroresCalculoDao
				.findAllLikeJerarquia(filterErroresCalculo, jqGridRequestDto);
		Long recordNum = this.erroresCalculoDao.findAllLikeCountJerarquia(filterErroresCalculo, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<ErroresCalculo>>(jqGridRequestDto, recordNum, listaErroresCalculo);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the ErroresCalculo
	 * table.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<ErroresCalculo>>
	 */
	public JQGridResponseDto<JerarquiaDto<ErroresCalculo>> jerarquiaChildren(ErroresCalculo filterErroresCalculo,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<ErroresCalculo>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<ErroresCalculo>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.erroresCalculoDao.findAllChild(filterErroresCalculo, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
