package com.ejie.ab60.service.estudioTecnico;

import java.util.List;

import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * EstudioTecnicoService  
 * 
 *  
 */

public interface EstudioTecnicoService {

	/**
	 * Inserts a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico add(EstudioTecnico estudioTecnico);

	/**
	 * Updates a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico update(EstudioTecnico estudioTecnico);

	/**
	 * Update importes de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateImporte(EstudioTecnico estudioTecnico);

	/**
	 * Update importeAdmitido de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateImporteAdmitido(EstudioTecnico datosproyecto);

	/**
	 * Update SUBVENCION_RESUELTA de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateSubvencionResuelta(EstudioTecnico datosproyecto);

	/**
	 * Update Habilitar subvencion resuelta de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateHabilitar(EstudioTecnico datosproyecto);

	/**
	 * Cambiar valor al campo expedienteValidado si validamos expediente.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico updateExpedienteValidado(EstudioTecnico datosproyecto);

	/**
	 * Finds a single row in the EstudioTecnico table. PARA CTP
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */

	EstudioTecnico findCTP(EstudioTecnico datosproyecto);

	/**
	 * Finds a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico find(EstudioTecnico estudioTecnico);

	/**
	 * Metod para hacer un update de estudio tecnico
	 * 
	 * @param tercero
	 * @return EstudioTecnico Bean resultante del proceso de creacion
	 */
	EstudioTecnico saveEstudioTecnico(EstudioTecnico estudioTecnico, Usuario usuario, Integer idExpediente,
			Integer idConvocatoria);

	/**
	 * Validamos que esten los datos de datos de estudio rellenados y calculamos
	 * Calculamos la subvencion resuelta
	 * 
	 * 
	 * @param idExpediente
	 *            Integer
	 * @param idConvocatoria
	 *            Integer
	 * 
	 * 
	 */
	EstudioTecnico pasarValidacion(Integer idExpediente, Integer idConvocatoria, Usuario usuario);

	/**
	 * Select de todos los importes de Estudio de tecnico
	 *
	 * @param idExpediente
	 *            Integer
	 * @return EstudioTecnico
	 */
	EstudioTecnico refescarImportes(Integer idExpediente);

	/**
	 * Finds datos de ayuda de la EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	EstudioTecnico findDatosProyecto(EstudioTecnico estudioTecnico);

	/**
	 * Devolvemos un mensaje de los expedientes validados filtrado por
	 * convocatoria
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @return String
	 */
	String listExpedientesValidados(Integer idConvocatoria, Integer idActSub);

	/**
	 * Devolvemos un mensaje de la lista de expedientes filtrados por
	 * convocatoria, para poder poner la sub_resuelta a null
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @return List<Expedientes>
	 * @throws Exception
	 */
	void anularReparto(Integer idConvocatoria, Integer idExpediente) throws Exception;

	/**
	 * Recogemos SUBVENCION_RESUELTA, restando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */

	EstudioTecnico calcularSubvencionResuelta(Integer idExpediente, Integer idConvocatoria);

	/**
	 * retornamos SUBVENCION_RESUELTA, sumando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	EstudioTecnico retonarSubvencionResuelta(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Buscar SUBVENCION_RESUELTA de la tabla EstudioTecnico
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */

	EstudioTecnico findSubvencionResuelta(Integer idExpediente, Integer idConvocatoria);

	/**
	 * Deletes a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 */
	void remove(EstudioTecnico estudioTecnico);

	/**
	 * Devuelve los totales de un expediente
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return EstudioTecnico
	 */

	EstudioTecnico findTotales(Integer IdExpediente);

	/**
	 * Finds a list of rows in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<EstudioTecnico>
	 */
	List<EstudioTecnico> findAll(EstudioTecnico estudioTecnico, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the EstudioTecnico table using like.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<EstudioTecnico>
	 */
	List<EstudioTecnico> findAllLike(EstudioTecnico estudioTecnico, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<EstudioTecnico>
	 */
	JQGridResponseDto<EstudioTecnico> filter(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches rows in the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param searchEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	List<TableRowDto<EstudioTecnico>> search(EstudioTecnico filterEstudioTecnico, EstudioTecnico searchEstudioTecnico,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<EstudioTecnico>>
	 */
	JQGridResponseDto<JerarquiaDto<EstudioTecnico>> jerarquia(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Finder method for siblings rows in the hierarchical the EstudioTecnico
	 * table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<EstudioTecnico>>
	 */
	JQGridResponseDto<JerarquiaDto<EstudioTecnico>> jerarquiaChildren(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * retornamos SUBVENCION_RESUELTA, sumando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6006T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @return EstudioTecnico
	 */
	EstudioTecnico retornarSubvencionResueltaPorAccionSubencionable(Integer idExpediente);

	EstudioTecnico obtenerImporteDisponiblePorAccionSubencionable(Integer idExpediente);

}
