package com.ejie.ab60.service.estudioTecnico;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.sql.Types;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.SqlInOutParameter;
import org.springframework.jdbc.core.SqlParameter;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.dao.CTP.ProyectosDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelExpActSubDao;
import com.ejie.ab60.dao.criteriosPuntuacion.RelExpCriPunDao;
import com.ejie.ab60.dao.estudioTecnico.EstudioTecnicoDao;
import com.ejie.ab60.dao.expedientes.ExpedientesDao;
import com.ejie.ab60.model.CTP.AsociacionesSectoriales;
import com.ejie.ab60.model.CTP.Proyectos;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.ab60.model.criteriosPuntuacion.RelExpCriPun;
import com.ejie.ab60.model.estudioTecnico.DatosTerOmic;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.actuacionesSubvencionables.ActSubvencionableService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.repartoAyuda.RepartoAyudaService;
import com.ejie.ab60.util.DBUtils;
import com.ejie.ab60.util.UtilDate;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * EstudioTecnicoServiceImpl  
 * 
 *  
 */

@Service(value = "estudioTecnicoService")
public class EstudioTecnicoServiceImpl implements EstudioTecnicoService {

	private static final Logger logger = LoggerFactory.getLogger(EstudioTecnicoService.class);

	@Autowired
	private EstudioTecnicoDao estudioTecnicoDao;

	@Autowired
	private RepartoAyudaService repartoAyudaService;

	@Autowired
	private ConvocatoriasService convocatoriasService;
	@Autowired
	private RelExpActSubDao relExpActSubDao;

	@Autowired
	private RelExpActSubService relExpActSubService;
	@Autowired
	private RelExpCriPunDao relExpCriPunDao;

	@Autowired
	private ProyectosDao proyectosDao;

	@Autowired
	private ActSubvencionableService actSubvencionableService;

	private JdbcTemplate jdbcTemplate;

	@Autowired
	private ExpedientesDao expedientesDao;

	@Autowired
	private DatosTerOmicService datosTerOmicService;

	/**
	 * 
	 * Necesario para llamar al pl-sql
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource()
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(rollbackFor = Throwable.class)
	public EstudioTecnico add(EstudioTecnico estudioTecnico) {
		return this.estudioTecnicoDao.add(estudioTecnico);
	}

	/**
	 * Updates a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(rollbackFor = Throwable.class)
	public EstudioTecnico update(EstudioTecnico estudioTecnico) {
		return this.estudioTecnicoDao.update(estudioTecnico);
	}

	/**
	 * Update importes de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(rollbackFor = Throwable.class)
	public EstudioTecnico updateImporte(EstudioTecnico estudioTecnico) {
		return this.estudioTecnicoDao.updateImporte(estudioTecnico);
	}

	/**
	 * Update SUBVENCION_RESUELTA de Estudio de tecnicor
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateSubvencionResuelta(EstudioTecnico datosproyecto) {
		return this.estudioTecnicoDao.updateSubvencionResuelta(datosproyecto);
	}

	/**
	 * Update Habilitar subvencion resuelta de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateHabilitar(EstudioTecnico datosproyecto) {
		return this.estudioTecnicoDao.updateHabilitar(datosproyecto);
	}

	/**
	 * Cambiar valor al campo expedienteValidado si validamos expediente.
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico updateExpedienteValidado(EstudioTecnico datosproyecto) {
		return this.estudioTecnicoDao.updateExpedienteValidado(datosproyecto);
	}

	/**
	 * Update importeAdmitido de Estudio de tecnico
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(rollbackFor = Throwable.class)
	public EstudioTecnico updateImporteAdmitido(EstudioTecnico estudioTecnico) {
		return this.estudioTecnicoDao.updateImporteAdmitido(estudioTecnico);
	}

	/**
	 * Finds a single row in the EstudioTecnico table. PARA CTP
	 *
	 * @param datosproyecto
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */

	public EstudioTecnico findCTP(EstudioTecnico estudioTecnico) {
		return (EstudioTecnico) this.estudioTecnicoDao.findCTP(estudioTecnico);
	}

	/**
	 * Finds a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	public EstudioTecnico find(EstudioTecnico estudioTecnico) {
		EstudioTecnico resultado = new EstudioTecnico();
		// buscamos el tipo de importe de la tabla de convocatorias para
		// saber si el importe disponible lo tenemos en la tabla de
		// convocatorias (0) o en la de acciones subencionables (1)
		EstudioTecnico estudioTipoImporte = this.estudioTecnicoDao.findTipoImporte(estudioTecnico.getIdConvocatoria());
		resultado = (EstudioTecnico) this.estudioTecnicoDao.find(estudioTecnico);
		if (1 == estudioTipoImporte.getTipoImporte()) {
			EstudioTecnico estudioTecnicoImporteDisponible = this
					.obtenerImporteDisponiblePorAccionSubencionable(estudioTecnico.getIdExpediente());
			resultado.setImporteDisponible(estudioTecnicoImporteDisponible.getImporteDisponible());
		}
		return resultado;
	}

	/**
	 * Metod para hacer un update de estudio tecnico
	 * 
	 * @param tercero
	 * @return EstudioTecnico Bean resultante del proceso de creacion
	 * @throws Exception
	 */
	public EstudioTecnico saveEstudioTecnico(EstudioTecnico estudioTecnico, Usuario usuario, Integer idExpediente,
			Integer idConvocatoria) {
		Date fecha = new Date();
		Proyectos proyectos = estudioTecnico.getProyectos();

		if (estudioTecnico.getBandera() != 0) {
			estudioTecnico.setSubvencionCalculada(null);
			estudioTecnico.setSubvencionResuelta(null);

			// Borarremos todo lo que haya referente a es idExpediente
			relExpCriPunDao.removeCriteriosPorExpediente(idExpediente);
			if (estudioTecnico.getCriterios() != null) {
				EstudioTecnicoServiceImpl.logger.info("[obtener lista de criterios] ");

				List<CriteriosPuntuacion> lcriterios = new ArrayList<CriteriosPuntuacion>();
				CriteriosPuntuacion crit = null;

				for (Integer criterio : estudioTecnico.getCriterios()) {
					crit = new CriteriosPuntuacion();
					crit.setIdCriterio(criterio);
					lcriterios.add(crit);
				}

				RelExpCriPun relExpCriPun = null;
				for (int i = 0; i < lcriterios.size(); i++) {
					// crear un objeto
					relExpCriPun = new RelExpCriPun();
					relExpCriPun.setIdExpediente(idExpediente);
					relExpCriPun.setCriteriosPuntuacion(lcriterios.get(i));
					relExpCriPun.setFechaRegistro(fecha);

					relExpCriPun.setUsuarioRegistro(usuario.getNombreUsuario());
					relExpCriPunDao.add(relExpCriPun);

					EstudioTecnicoServiceImpl.logger.info("[Anyadir criterios] ");
				}

			}
			// quitar sub calculada de relexpactsub
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(idExpediente);
			relExpActSub.setFechaUltmodificacion(fecha);
			relExpActSub.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			relExpActSub.setSubvencionCalculada(null);
			relExpActSub.setPorcentaje(null);

			relExpActSub = this.relExpActSubDao.updateImporteSubvencionCalculada(relExpActSub);
			EstudioTecnicoServiceImpl.logger
					.info("[POST - filter] : Updatear subvencion calculada y porcenataje en  RelExpActSubs");

		}
		if (null != proyectos && null != proyectos.getAsociacionesSectoriales()) {
			proyectos.setFechaUltmodificacion(fecha);
			proyectos.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			proyectos.setIdExpediente(idExpediente);
			AsociacionesSectoriales asociacionesSectoriales = proyectos.getAsociacionesSectoriales();

			asociacionesSectoriales
					.setIdAsociacion(estudioTecnico.getProyectos().getAsociacionesSectoriales().getIdAsociacion());
			proyectos.setAsociacionesSectoriales(asociacionesSectoriales);
			proyectosDao.updateIdAsociacion(proyectos);

		}
		if (estudioTecnico.getTecnicosResponsables() != null
				&& estudioTecnico.getTecnicosResponsables().getIdTecnicoResponsable() == 0) {
			estudioTecnico.getTecnicosResponsables().setIdTecnicoResponsable(null);
		}
		if (estudioTecnico.getMotivosDesestimacion() != null
				&& estudioTecnico.getMotivosDesestimacion().getIdMotivoDesestimacion() == 0) {
			estudioTecnico.getMotivosDesestimacion().setIdMotivoDesestimacion(null);
		}
		if (estudioTecnico.getTiposResultado() != null && estudioTecnico.getTiposResultado().getIdResultado() == 0) {
			estudioTecnico.getTiposResultado().setIdResultado(null);
		}

		estudioTecnico.setFechaUltmodificacion(fecha);
		estudioTecnico.setUsuarioUltmodificacion(usuario.getNombreUsuario());

		estudioTecnico
				.setFechaInformeStr(UtilDate.convertirStringEnStringFormateado(estudioTecnico.getFechaInformeStr()));

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);
		convocatoria = convocatoriasService.find(convocatoria);

		if (convocatoria.getIdTipoAyuda() == Constantes.TIPO_AYUDA_OMIC) {
			// Updatear Datos_ter_omic
			if (estudioTecnico.getDatosTerOmic() == null) {
				estudioTecnico.setDatosTerOmic(new DatosTerOmic());
			} else if (estudioTecnico.getDatosTerOmic().getIdDatosOmic() == null) {
				estudioTecnico.getDatosTerOmic().setIdExpediente(idExpediente);
				estudioTecnico.getDatosTerOmic().setFechaRegistro(new Date());
				estudioTecnico.getDatosTerOmic().setUsuarioRegistro(usuario.getNombreUsuario());
				estudioTecnico.setDatosTerOmic(this.datosTerOmicService.add(estudioTecnico.getDatosTerOmic()));
			} else {
				estudioTecnico.getDatosTerOmic().setIdExpediente(idExpediente);
				estudioTecnico.getDatosTerOmic().setFechaUltmodificacion(new Date());
				estudioTecnico.getDatosTerOmic().setUsuarioUltmodificacion(usuario.getNombreUsuario());
				estudioTecnico
						.setDatosTerOmic(this.datosTerOmicService.updateByExpediente(estudioTecnico.getDatosTerOmic()));
			}
		}

		if (convocatoria.getIdTipoAyuda() == Constantes.TIPO_AYUDA_DEC) {
			if (estudioTecnico.getExeptoHidden() != null && estudioTecnico.getExeptoHidden() != 2) {
				estudioTecnicoDao.updateExepto(estudioTecnico.getIdExpediente(), estudioTecnico.getExeptoHidden());

				List<RelExpActSub> listaImportes = this.relExpActSubDao.importesPorExento(idExpediente,
						estudioTecnico.getExeptoHidden());

				if (listaImportes.size() != 0) {

					Float presentado = (float) 0;

					for (RelExpActSub relexpactsub : listaImportes) {
						presentado = presentado
								+ relexpactsub.getImportePresentado().setScale(2, RoundingMode.DOWN).floatValue();
					}

					BigDecimal presentadoTotal = new BigDecimal(presentado);

					estudioTecnico.setImportePresentado(presentadoTotal);
				}
			}
		}

		this.update(estudioTecnico);

		EstudioTecnicoServiceImpl.logger.info("[Updatear expediente] ");

		if ((null != estudioTecnico.getTiposResultado() && null != estudioTecnico.getTiposResultado().getIdResultado())
				&& (Constantes.IDRESULTADO_DESESTIMADA == estudioTecnico.getTiposResultado().getIdResultado())) {

			try {
				relExpActSubService.ponerImportesNulosACero(idExpediente, idConvocatoria, usuario);
			} catch (Exception e) {
				EstudioTecnicoServiceImpl.logger.error("save estudioTecnico " + e);
			}
		}
		return estudioTecnico;

	}

	/**
	 * Validamos que esten los datos de datos de estudio rellenados y calculamos
	 * Calculamos la subvencion resuelta
	 * 
	 * 
	 * @param idExpediente
	 *            Integer
	 * @param idConvocatoria
	 *            Integer
	 * 
	 * 
	 */
	@Transactional(rollbackFor = Throwable.class)
	public EstudioTecnico pasarValidacion(Integer idExpediente, Integer idConvocatoria, Usuario usuario) {

		EstudioTecnico estudioTecnico = new EstudioTecnico();
		EstudioTecnico estudioTecnicoAux = new EstudioTecnico();
		EstudioTecnico estudioTecnicoAux2 = new EstudioTecnico();
		Convocatorias convocatorias = new Convocatorias();
		ActSubvencionable accionSubencionable = new ActSubvencionable();
		estudioTecnico.setIdExpediente(idExpediente);
		// [VALIDAR - findBy_PK] : Obtener datos del EstudioTecnico por
		// idExpediente
		estudioTecnico = this.findDatosProyecto(estudioTecnico);
		if (null != estudioTecnico.getFechaInforme() || 0 != estudioTecnico.getIdTecnicoResponsable()) {
			Date fecha = new Date();
			// Obtener datos del EstudioTecnico por idExpediente y por
			// idConvocatoria

			// buscamos el tipo de importe de la tabla de convocatorias para
			// saber si el importe disponible lo tenemos en la tabla de
			// convocatorias (0) o en la de acciones subencionables (1)
			EstudioTecnico estudioTipoImporte = this.estudioTecnicoDao.findTipoImporte(idConvocatoria);

			if (null != estudioTipoImporte && 0 == estudioTipoImporte.getTipoImporte()) {
				// importe disponible lo tenemos en la tabla de convocatorias
				estudioTecnicoAux2 = this.calcularSubvencionResuelta(idExpediente, idConvocatoria);

				// [VALIDAR - calcularSubvencionResuelta] : Find Subvencion
				// Resuelta del convocatoria por idExpediente y por
				// idConvocatoria
				convocatorias.setIdConvocatoria(idConvocatoria);
				convocatorias.setFechaUltmodificacion(fecha);
				convocatorias.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				calculoSubvencion(estudioTecnico, estudioTecnicoAux, estudioTecnicoAux2, convocatorias,
						accionSubencionable);

				estudioTecnicoAux.setIdExpediente(idExpediente);
				estudioTecnicoAux.setFechaUltmodificacion(fecha);
				estudioTecnicoAux.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				estudioTecnicoAux.setExpedienteValidado(1);
				estudioTecnicoAux.setCargarSolSub(Constantes.NO_CARGAR_SOL_SUB);

				// [VALIDAR - updateImporteDisponible] : updateImporteDisponible
				// en convocatorias tabla por idExpediente y por idConvocatoria
				convocatorias = convocatoriasService.updateImporteDisponible(convocatorias);

				// [VALIDAR - updateSubvencionResuelta] : update
				// SubvencionResuelta en datos de proeyecto tabla por
				// idExpediente
				estudioTecnico = this.updateSubvencionResuelta(estudioTecnicoAux);
				estudioTecnico.setImporteDisponible(convocatorias.getImporteDisponible());
			} else if (null != estudioTipoImporte && 1 == estudioTipoImporte.getTipoImporte()) {
				// importe disponible lo tenemos en la tabla de acciones
				// subencionables

				estudioTecnicoAux2 = this.calcularSubvencionResueltaPorAccionSubencionable(idExpediente);

				if (null != estudioTecnicoAux2 && null != estudioTecnicoAux2.getActSubvencionable()) {
					accionSubencionable.setIdActSub(estudioTecnicoAux2.getActSubvencionable().getIdActSub());
				}
				convocatorias.setIdConvocatoria(idConvocatoria);
				convocatorias.setFechaUltmodificacion(fecha);
				convocatorias.setUsuarioUltmodificacion(usuario.getNombreUsuario());

				accionSubencionable.setFechaUltmodificacion(fecha);
				accionSubencionable.setUsuarioUltmodificacion(usuario.getNombreUsuario());

				calculoSubvencion(estudioTecnico, estudioTecnicoAux, estudioTecnicoAux2, convocatorias,
						accionSubencionable);
				// [VALIDAR - updateImporteDisponible] : updateImporteDisponible
				// en accionSubencionable tabla por idExpediente y por
				// accionSubencionable
				accionSubencionable = actSubvencionableService.updateImporteDisponible(accionSubencionable);

				estudioTecnicoAux.setIdExpediente(idExpediente);
				estudioTecnicoAux.setFechaUltmodificacion(fecha);
				estudioTecnicoAux.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				estudioTecnicoAux.setExpedienteValidado(1);
				estudioTecnicoAux.setCargarSolSub(Constantes.NO_CARGAR_SOL_SUB);

				estudioTecnico = this.updateSubvencionResuelta(estudioTecnicoAux);
				estudioTecnico.setImporteDisponible(accionSubencionable.getImporteDisponible());

				convocatorias.setImporteDisponible(estudioTecnicoAux2.getImporteFinalConvocatoria());
				convocatoriasService.updateImporteDisponible(convocatorias);
			}
		}
		return estudioTecnico;
	}

	/**
	 * Select de todos los importes de Estudio de tecnico
	 *
	 * @param idExpediente
	 *            Integer
	 * @return EstudioTecnico
	 */
	public EstudioTecnico refescarImportes(Integer idExpediente) {
		return (EstudioTecnico) this.estudioTecnicoDao.refescarImportes(idExpediente);
	}

	/**
	 * Finds datos de ayuda de la EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico findDatosProyecto(EstudioTecnico estudioTecnico) {
		return (EstudioTecnico) this.estudioTecnicoDao.findDatosProyecto(estudioTecnico);

	}

	/**
	 * Devolvemos un mensaje de los expedientes validados filtrado por
	 * convocatoria
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @return msj
	 *
	 *         String
	 *
	 */
	@Transactional(readOnly = true)
	public String listExpedientesValidados(Integer idConvocatoria, Integer idActSub) {

		String msj = "";
		/*
		 * List<EstudioTecnico> listaExpedientes =
		 * this.estudioTecnicoDao.findListExpedientesValidados(idConvocatoria);
		 * EstudioTecnicoServiceImpl.logger
		 * .info("[GET - listExpedientesValidados] : Obtener listado de expedientes de esta convocatoria"
		 * + idConvocatoria); for (int indice = 0; indice <
		 * listaExpedientes.size(); indice++) { if
		 * (listaExpedientes.get(indice).getExpedienteValidado() == 0 ||
		 * listaExpedientes.get(indice).getExpedienteValidado() == null) { msj =
		 * Constantes.EXPEDIENTESNOVALIDADOS; break; } else {
		 * 
		 * msj = Constantes.EXPEDIENTESVALIDADOS; }
		 * 
		 * }
		 */
		// if (msj == Constantes.EXPEDIENTESVALIDADOS) {
		// llamar a pl-reparto
		EstudioTecnicoServiceImpl.logger.info("[GET - llamarPLSQL] : Obtener PL DE REPARTO DE AYUDA");
		msj = repartoAyudaService.repartoAyuda(idConvocatoria, idActSub);
		// }
		return msj;
	}

	/**
	 * llamada al PL de anular reparto
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param usuario
	 *            Usuario
	 * @param idExpediente
	 *            Integer
	 * @param idActSub
	 *            Integer
	 * 
	 * @throws Exception
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void anularReparto(Integer idConvocatoria, Integer idActSub) throws Exception {

		Convocatorias convocatoria = convocatoriasService.findNombrePLSQLAnularReparto(idConvocatoria);
		String nombrePlSql = convocatoria.getPlsqlReparto();
		EstudioTecnicoServiceImpl.logger.info("nombrePlSql: " + nombrePlSql);

		SqlParameter[] parameters = { new SqlInOutParameter("IN_ID_PROCEDIMIENTO", Types.VARCHAR),
				new SqlInOutParameter("IN_ID_ACT_SUB", Types.VARCHAR) };

		MapSqlParameterSource parameterSource = new MapSqlParameterSource();

		parameterSource.addValue("IN_ID_PROCEDIMIENTO", convocatoria.getIdProcedimiento());
		parameterSource.addValue("IN_ID_ACT_SUB", (idActSub == 0) ? null : idActSub);

		try {
			DBUtils.callPLSQLRepartoAyuda(this.jdbcTemplate, nombrePlSql, parameters, parameterSource);

		} catch (Exception e) {
			EstudioTecnicoServiceImpl.logger.error(
					"Error en el procesamiento del carga del anular reparto:" + idConvocatoria + "-" + e.getMessage());
			throw new Exception("Error en el proceso del PL/SQL de reparto");
		}
	}

	/**
	 * Recogemos SUBVENCION_RESUELTA, restando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico calcularSubvencionResuelta(Integer idExpediente, Integer idConvocatoria) {
		return (EstudioTecnico) this.estudioTecnicoDao.calcularSubvencionResuelta(idExpediente, idConvocatoria);
	}

	/**
	 * Recogemos SUBVENCION_RESUELTA, restando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6006T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico calcularSubvencionResueltaPorAccionSubencionable(Integer idExpediente) {
		return (EstudioTecnico) this.estudioTecnicoDao.calcularSubvencionResueltaPorAccionSubencionable(idExpediente);
	}

	@Transactional(readOnly = true)
	public EstudioTecnico obtenerImporteDisponiblePorAccionSubencionable(Integer idExpediente) {
		return (EstudioTecnico) this.estudioTecnicoDao.obtenerImporteDisponiblePorAccionSubencionable(idExpediente);
	}

	/**
	 * retornamos SUBVENCION_RESUELTA, sumando el importe de subvencion
	 * calculada del IMPORTE_DISPONIBLE en la tabla AB6001T00
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico retonarSubvencionResuelta(Integer idExpediente, Integer idConvocatoria) {
		return (EstudioTecnico) this.estudioTecnicoDao.retonarSubvencionResuelta(idExpediente, idConvocatoria);
	}

	/**
	 * Buscar SUBVENCION_RESUELTA de la tabla EstudioTecnico
	 * 
	 * @param Integer
	 *            IdExpediente
	 * @param Integer
	 *            IdConvocatoria
	 * @return EstudioTecnico
	 */
	@Transactional(readOnly = true)
	public EstudioTecnico findSubvencionResuelta(Integer idExpediente, Integer idConvocatoria) {
		return (EstudioTecnico) this.estudioTecnicoDao.findSubvencionResuelta(idExpediente, idConvocatoria);
	}

	/**
	 * Devuelve los totales de un expediente
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return EstudioTecnico
	 */

	public EstudioTecnico findTotales(Integer IdExpediente) {
		return (EstudioTecnico) this.estudioTecnicoDao.findTotales(IdExpediente);

	}

	/**
	 * Deletes a single row in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(EstudioTecnico estudioTecnico) {
		this.estudioTecnicoDao.remove(estudioTecnico);
	}

	/**
	 * Finds a list of rows in the EstudioTecnico table.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<EstudioTecnico>
	 */
	public List<EstudioTecnico> findAll(EstudioTecnico estudioTecnico, JQGridRequestDto jqGridRequestDto) {
		return (List<EstudioTecnico>) this.estudioTecnicoDao.findAll(estudioTecnico, jqGridRequestDto);
	}

	/**
	 * Finds rows in the EstudioTecnico table using like.
	 *
	 * @param estudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<EstudioTecnico>
	 */
	public List<EstudioTecnico> findAllLike(EstudioTecnico estudioTecnico, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<EstudioTecnico>) this.estudioTecnicoDao.findAllLike(estudioTecnico, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.estudioTecnicoDao.removeMultiple(filterEstudioTecnico, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<EstudioTecnico>
	 */
	public JQGridResponseDto<EstudioTecnico> filter(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<EstudioTecnico> listaEstudioTecnico = this.estudioTecnicoDao.findAllLike(filterEstudioTecnico,
				jqGridRequestDto, false);
		Long recordNum = this.estudioTecnicoDao
				.findAllLikeCount(filterEstudioTecnico != null ? filterEstudioTecnico : new EstudioTecnico(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<EstudioTecnico>> reorderSelection = this.estudioTecnicoDao
					.reorderSelection(filterEstudioTecnico, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<EstudioTecnico>(jqGridRequestDto, recordNum, listaEstudioTecnico,
					reorderSelection);
		}
		return new JQGridResponseDto<EstudioTecnico>(jqGridRequestDto, recordNum, listaEstudioTecnico);
	}

	/**
	 * Searches rows in the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param searchEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<EstudioTecnico>>
	 */
	public List<TableRowDto<EstudioTecnico>> search(EstudioTecnico filterEstudioTecnico,
			EstudioTecnico searchEstudioTecnico, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.estudioTecnicoDao.search(filterEstudioTecnico, searchEstudioTecnico, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(EstudioTecnico filterEstudioTecnico, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.estudioTecnicoDao.reorderSelection(filterEstudioTecnico, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the EstudioTecnico table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<EstudioTecnico>>
	 */
	public JQGridResponseDto<JerarquiaDto<EstudioTecnico>> jerarquia(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<EstudioTecnico>> listaEstudioTecnico = this.estudioTecnicoDao
				.findAllLikeJerarquia(filterEstudioTecnico, jqGridRequestDto);
		Long recordNum = this.estudioTecnicoDao.findAllLikeCountJerarquia(filterEstudioTecnico, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<EstudioTecnico>>(jqGridRequestDto, recordNum, listaEstudioTecnico);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the EstudioTecnico
	 * table.
	 *
	 * @param filterEstudioTecnico
	 *            EstudioTecnico
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<EstudioTecnico>>
	 */
	public JQGridResponseDto<JerarquiaDto<EstudioTecnico>> jerarquiaChildren(EstudioTecnico filterEstudioTecnico,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<EstudioTecnico>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<EstudioTecnico>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.estudioTecnicoDao.findAllChild(filterEstudioTecnico, jqGridRequestDto));
		return jqGridResponseDto;
	}

	private void calculoSubvencion(EstudioTecnico estudioTecnico, EstudioTecnico estudioTecnicoAux,
			EstudioTecnico estudioTecnicoAux2, Convocatorias convocatorias, ActSubvencionable accionSubencionable) {
		if (null != estudioTecnicoAux2.getImporteFinal()) {
			int i1 = estudioTecnicoAux2.getImporteFinal().signum();
			if (i1 == -1) {
				if (estudioTecnicoAux2.getImporteDisponible().compareTo(BigDecimal.ZERO) == 0) {
					convocatorias.setImporteDisponible(BigDecimal.ZERO);
					accionSubencionable.setImporteDisponible(BigDecimal.ZERO);
					estudioTecnicoAux.setIdResultado(2);
					estudioTecnicoAux.setIdMotivoDesestimacion(7);
					estudioTecnicoAux.setSubvencionResuelta(BigDecimal.ZERO);
				} else {
					EstudioTecnicoServiceImpl.logger.info("[VALIDAR - calcularSubvencionResuelta] :Resta negativa ");
					convocatorias.setImporteDisponible(BigDecimal.ZERO);
					accionSubencionable.setImporteDisponible(BigDecimal.ZERO);
					estudioTecnicoAux.setIdResultado(1);
					estudioTecnicoAux.setSubvencionResuelta(estudioTecnicoAux2.getImporteDisponible());
				}
			} else if (estudioTecnicoAux2.getImporteDisponible() == null) {
				convocatorias.setImporteDisponible(null);
				accionSubencionable.setImporteDisponible(null);
				estudioTecnicoAux.setIdResultado(2);
				estudioTecnicoAux.setIdMotivoDesestimacion(7);
				estudioTecnicoAux.setSubvencionResuelta(BigDecimal.ZERO);
			} else {
				convocatorias.setImporteDisponible(estudioTecnicoAux2.getImporteFinal());
				accionSubencionable.setImporteDisponible(estudioTecnicoAux2.getImporteFinal());
				estudioTecnicoAux.setIdResultado(estudioTecnico.getIdResultado());
				if (estudioTecnico.getIdMotivoDesestimacion() == 0) {
					estudioTecnico.setIdMotivoDesestimacion(null);
				}
				estudioTecnicoAux.setIdMotivoDesestimacion(estudioTecnico.getIdMotivoDesestimacion());
				estudioTecnicoAux.setSubvencionResuelta(estudioTecnicoAux2.getSubvencionCalculada());
			}
		} else {
			convocatorias.setImporteDisponible(BigDecimal.ZERO);
			accionSubencionable.setImporteDisponible(BigDecimal.ZERO);
			estudioTecnicoAux.setIdResultado(2);
			estudioTecnicoAux.setIdMotivoDesestimacion(7);
			estudioTecnicoAux.setSubvencionResuelta(BigDecimal.ZERO);
		}
	}

	@Override
	public EstudioTecnico retornarSubvencionResueltaPorAccionSubencionable(Integer idExpediente) {
		return (EstudioTecnico) this.estudioTecnicoDao.retornarSubvencionResueltaPorAccionSubencionable(idExpediente);
	}

}
