package com.ejie.ab60.service.estudioTecnico;

import com.ejie.ab60.dao.estudioTecnico.HorariosDao;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.Horarios;

/**
 * HorariosServiceImpl  
 * 
 *  
 */

@Service(value = "horariosService")
public class HorariosServiceImpl implements HorariosService {

	@Autowired
	private HorariosDao horariosDao;

	/**
	 * Inserts a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return Horarios
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Horarios add(Horarios horarios) {
		return this.horariosDao.add(horarios);
	}

	/**
	 * Updates a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return Horarios
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Horarios update(Horarios horarios) {
		return this.horariosDao.update(horarios);
	}

	/**
	 * Finds a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @return Horarios
	 */
	public Horarios find(Horarios horarios) {
		return (Horarios) this.horariosDao.find(horarios);
	}

	/**
	 * Deletes a single row in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Horarios horarios) {
		this.horariosDao.remove(horarios);
	}

	/**
	 * Finds a list of rows in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Horarios>
	 */
	public List<Horarios> findAll(Horarios horarios, JQGridRequestDto jqGridRequestDto) {
		return (List<Horarios>) this.horariosDao.findAll(horarios, jqGridRequestDto);
	}

	/**
	 * Finds a list of rows in the Horarios table.
	 *
	 * @param horarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Horarios>
	 */
	public List<Horarios> findByPoblacion(Integer idPoblacion, Integer idConvocatoria) {
		return (List<Horarios>) this.horariosDao.findByPoblacion(idPoblacion, idConvocatoria);
	}

	/**
	 * Finds rows in the Horarios table using like.
	 *
	 * @param horarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Horarios>
	 */
	public List<Horarios> findAllLike(Horarios horarios, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<Horarios>) this.horariosDao.findAllLike(horarios, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Horarios table.
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Horarios filterHorarios, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.horariosDao.removeMultiple(filterHorarios, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Horarios table.
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Horarios>
	 */
	public JQGridResponseDto<Horarios> filter(Horarios filterHorarios, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<Horarios> listaHorarios = this.horariosDao.findAllLike(filterHorarios, jqGridRequestDto, false);
		Long recordNum = this.horariosDao.findAllLikeCount(filterHorarios != null ? filterHorarios : new Horarios(),
				false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Horarios>> reorderSelection = this.horariosDao.reorderSelection(filterHorarios,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Horarios>(jqGridRequestDto, recordNum, listaHorarios, reorderSelection);
		}
		return new JQGridResponseDto<Horarios>(jqGridRequestDto, recordNum, listaHorarios);
	}

	/**
	 * Searches rows in the Horarios table.
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param searchHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Horarios>>
	 */
	public List<TableRowDto<Horarios>> search(Horarios filterHorarios, Horarios searchHorarios,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.horariosDao.search(filterHorarios, searchHorarios, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Horarios table.
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Horarios filterHorarios, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.horariosDao.reorderSelection(filterHorarios, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Horarios table.
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Horarios>>
	 */
	public JQGridResponseDto<JerarquiaDto<Horarios>> jerarquia(Horarios filterHorarios,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Horarios>> listaHorarios = this.horariosDao.findAllLikeJerarquia(filterHorarios,
				jqGridRequestDto);
		Long recordNum = this.horariosDao.findAllLikeCountJerarquia(filterHorarios, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Horarios>>(jqGridRequestDto, recordNum, listaHorarios);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Horarios table.
	 *
	 * @param filterHorarios
	 *            Horarios
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Horarios>>
	 */
	public JQGridResponseDto<JerarquiaDto<Horarios>> jerarquiaChildren(Horarios filterHorarios,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Horarios>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Horarios>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.horariosDao.findAllChild(filterHorarios, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
