package com.ejie.ab60.service.estudioTecnico;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.estudioTecnico.MotivosDenegacionDao;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * MotivosDenegacionServiceImpl  
 * 
 *  
 */

@Service(value = "motivosDenegacionService")
public class MotivosDenegacionServiceImpl implements MotivosDenegacionService {

	@Autowired
	private MotivosDenegacionDao motivosDenegacionDao;

	/**
	 * Inserts a single row in the MotivosDenegacion table.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion
	 * @return MotivosDenegacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public MotivosDenegacion add(MotivosDenegacion motivosDenegacion) {
		MotivosDenegacion motivosdenegacionAux = motivosDenegacion;
		motivosdenegacionAux = this.motivosDenegacionDao.add(motivosDenegacion);
		return motivosdenegacionAux;
	}

	/**
	 * Updates a single row in the MotivosDenegacion table.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion
	 * @return MotivosDenegacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public MotivosDenegacion update(MotivosDenegacion motivosDenegacion) {
		return this.motivosDenegacionDao.update(motivosDenegacion);
	}

	/**
	 * Finds a single row in the MotivosDenegacion table.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion
	 * @return MotivosDenegacion
	 */
	public MotivosDenegacion find(MotivosDenegacion motivosDenegacion) {
		return (MotivosDenegacion) this.motivosDenegacionDao.find(motivosDenegacion);
	}

	/**
	 * Deletes a single row in the MotivosDenegacion table.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(MotivosDenegacion motivosDenegacion) {
		this.motivosDenegacionDao.remove(motivosDenegacion);
	}

	/**
	 * Finds a list of rows in the MotivosDenegacion table.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<MotivosDenegacion>
	 */
	public List<MotivosDenegacion> findAll(MotivosDenegacion motivosDenegacion, JQGridRequestDto jqGridRequestDto) {
		return (List<MotivosDenegacion>) this.motivosDenegacionDao.findAll(motivosDenegacion, jqGridRequestDto);
	}

	/**
	 * Finds rows in the MotivosDenegacion table using like.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<MotivosDenegacion>
	 */
	public List<MotivosDenegacion> findAllLike(MotivosDenegacion motivosDenegacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<MotivosDenegacion>) this.motivosDenegacionDao.findAllLike(motivosDenegacion, jqGridRequestDto,
				startsWith);
	}

	/**
	 * Finds a list of rows in the MotivosDenegacion table.
	 *
	 * 
	 * @return List<MotivosDenegacion>
	 */
	public List<MotivosDenegacion> findDenegacionActSubvencionable(Integer idConvocatoria, Integer origen,
			Integer idRelExpActSub) {
		return this.motivosDenegacionDao.findDenegacionActSubvencionable(idConvocatoria, origen, idRelExpActSub);
	}

	/**
	 * Finds a list of rows in the MotivosDenegacion table.
	 *
	 * 
	 * @return List<MotivosDenegacion>
	 */
	public List<MotivosDenegacion> findDenegacionFacturas(Integer idConvocatoria, Integer origen, Integer idFactura) {
		return this.motivosDenegacionDao.findDenegacionFacturas(idConvocatoria, origen, idFactura);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the MotivosDenegacion table.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(MotivosDenegacion filterMotivosDenegacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.motivosDenegacionDao.removeMultiple(filterMotivosDenegacion, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the MotivosDenegacion table.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<MotivosDenegacion>
	 */
	public JQGridResponseDto<MotivosDenegacion> filter(MotivosDenegacion filterMotivosDenegacion,
			JQGridRequestDto jqGridRequestDto) {
		List<MotivosDenegacion> listaMotivosDenegacion = this.motivosDenegacionDao.findAll(filterMotivosDenegacion,
				jqGridRequestDto);
		Long recordNum = this.motivosDenegacionDao
				.findAllCount(filterMotivosDenegacion != null ? filterMotivosDenegacion : new MotivosDenegacion());

		return new JQGridResponseDto<MotivosDenegacion>(jqGridRequestDto, recordNum, listaMotivosDenegacion);
	}

	/**
	 * Searches rows in the MotivosDenegacion table.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param searchMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<MotivosDenegacion>>
	 */
	public List<TableRowDto<MotivosDenegacion>> search(MotivosDenegacion filterMotivosDenegacion,
			MotivosDenegacion searchMotivosDenegacion, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.motivosDenegacionDao.search(filterMotivosDenegacion, searchMotivosDenegacion, jqGridRequestDto,
				startsWith);
	}

	/**
	 * Reorder the selection made in MotivosDenegacion table.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(MotivosDenegacion filterMotivosDenegacion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.motivosDenegacionDao.reorderSelection(filterMotivosDenegacion, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the MotivosDenegacion table.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<MotivosDenegacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<MotivosDenegacion>> jerarquia(MotivosDenegacion filterMotivosDenegacion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<MotivosDenegacion>> listaMotivosDenegacion = this.motivosDenegacionDao
				.findAllLikeJerarquia(filterMotivosDenegacion, jqGridRequestDto);
		Long recordNum = this.motivosDenegacionDao.findAllLikeCountJerarquia(filterMotivosDenegacion, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<MotivosDenegacion>>(jqGridRequestDto, recordNum,
				listaMotivosDenegacion);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the MotivosDenegacion
	 * table.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<MotivosDenegacion>>
	 */
	public JQGridResponseDto<JerarquiaDto<MotivosDenegacion>> jerarquiaChildren(
			MotivosDenegacion filterMotivosDenegacion, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<MotivosDenegacion>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<MotivosDenegacion>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.motivosDenegacionDao.findAllChild(filterMotivosDenegacion, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
