package com.ejie.ab60.service.estudioTecnico;

import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.estudioTecnico.OtrasAyudasDao;
import com.ejie.ab60.model.estudioTecnico.OtrasAyudas;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * OtrasAyudasServiceImpl  
 * 
 *  
 */

@Service(value = "otrasAyudasService")
public class OtrasAyudasServiceImpl implements OtrasAyudasService {

	private static final Logger logger = LoggerFactory.getLogger(OtrasAyudasServiceImpl.class);

	@Autowired
	private OtrasAyudasDao otrasAyudasDao;

	/**
	 * Inserts a single row in the OtrasAyudas table.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas
	 * @return OtrasAyudas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public OtrasAyudas add(OtrasAyudas otrasAyudas) {
		return this.otrasAyudasDao.add(otrasAyudas);
	}

	/**
	 * Inserts a single row in the OtrasAyudas table.
	 *
	 * @param httpRequest
	 *            HttpServletRequest
	 * @param idExpediente
	 *            Integer
	 * @param tipoOtraAyuda
	 *            Integer
	 * @param otrasAyudas
	 *            OtrasAyudas Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return OtrasAyudas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public OtrasAyudas addConFiltro(HttpServletRequest httpRequest, Integer idExpediente, Integer tipoOtraAyuda,
			OtrasAyudas otrasAyudas, Usuario usuario) {

		otrasAyudas.setIdExpediente(idExpediente);
		otrasAyudas.setIdTipoOtraAyuda(tipoOtraAyuda);

		otrasAyudas.setUsuarioRegistro(usuario.getNombreUsuario());
		otrasAyudas.setFechaRegistro(new Date());

		otrasAyudas.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		otrasAyudas.setFechaUltmodificacion(new Date());

		OtrasAyudas otrasAyudasAux = this.otrasAyudasDao.add(otrasAyudas);
		OtrasAyudasServiceImpl.logger.info("[POST] : OtrasAyudas insertado correctamente");
		return otrasAyudasAux;

	}

	/**
	 * Updates a single row in the OtrasAyudas table.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas
	 * @return OtrasAyudas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public OtrasAyudas update(OtrasAyudas otrasAyudas) {
		return this.otrasAyudasDao.update(otrasAyudas);
	}

	/**
	 * Updates a single row in the OtrasAyudas table.
	 *
	 * @param httpRequest
	 *            HttpServletRequest
	 * @param idExpediente
	 *            Integer
	 * @param tipoOtraAyuda
	 *            Integer
	 * @param otrasAyudas
	 *            OtrasAyudas
	 * @return OtrasAyudas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public OtrasAyudas editConFiltro(HttpServletRequest httpRequest, Integer idExpediente, Integer tipoOtraAyuda,
			OtrasAyudas otrasAyudas, Usuario usuario) {

		otrasAyudas.setIdExpediente(idExpediente);
		otrasAyudas.setIdTipoOtraAyuda(tipoOtraAyuda);

		otrasAyudas.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		otrasAyudas.setFechaUltmodificacion(new Date());

		OtrasAyudas otrasAyudasAux = this.otrasAyudasDao.update(otrasAyudas);
		OtrasAyudasServiceImpl.logger.info("[PUT] : OtrasAyudas actualizado correctamente");
		return otrasAyudasAux;

	}

	/**
	 * Finds a single row in the OtrasAyudas table.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas
	 * @return OtrasAyudas
	 */
	public OtrasAyudas find(OtrasAyudas otrasAyudas) {
		return (OtrasAyudas) this.otrasAyudasDao.find(otrasAyudas);
	}

	/**
	 * Deletes a single row in the OtrasAyudas table.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(OtrasAyudas otrasAyudas) {
		this.otrasAyudasDao.remove(otrasAyudas);
	}

	/**
	 * Deletes a single row in the OtrasAyudas table.
	 *
	 * @param idExpediente
	 *            Integer
	 * @param tipoOtraAyuda
	 *            Integer
	 * @param idOtraAyuda
	 *            Integer
	 */
	@Transactional(rollbackFor = Throwable.class)
	public OtrasAyudas remove(Integer idExpediente, Integer tipoOtraAyuda, Integer idOtraAyuda) {
		OtrasAyudas otrasAyudas = new OtrasAyudas();
		otrasAyudas.setIdOtraAyuda(idOtraAyuda);
		this.otrasAyudasDao.remove(otrasAyudas);
		OtrasAyudasServiceImpl.logger.info("[DELETE] : OtrasAyudas borrado correctamente");
		return otrasAyudas;

	}

	/**
	 * Finds a list of rows in the OtrasAyudas table.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<OtrasAyudas>
	 */
	public List<OtrasAyudas> findAll(OtrasAyudas otrasAyudas, JQGridRequestDto jqGridRequestDto) {
		return (List<OtrasAyudas>) this.otrasAyudasDao.findAll(otrasAyudas, jqGridRequestDto);
	}

	/**
	 * Finds rows in the OtrasAyudas table using like.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<OtrasAyudas>
	 */
	public List<OtrasAyudas> findAllLike(OtrasAyudas otrasAyudas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<OtrasAyudas>) this.otrasAyudasDao.findAllLike(otrasAyudas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the OtrasAyudas table.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(OtrasAyudas filterOtrasAyudas, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.otrasAyudasDao.removeMultiple(filterOtrasAyudas, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the OtrasAyudas table.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<OtrasAyudas>
	 */
	public JQGridResponseDto<OtrasAyudas> filter(OtrasAyudas filterOtrasAyudas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<OtrasAyudas> listaOtrasAyudas = this.otrasAyudasDao.findAllLike(filterOtrasAyudas, null, false);
		Long recordNum = this.otrasAyudasDao
				.findAllLikeCount(filterOtrasAyudas != null ? filterOtrasAyudas : new OtrasAyudas(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<OtrasAyudas>> reorderSelection = this.otrasAyudasDao.reorderSelection(filterOtrasAyudas,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<OtrasAyudas>(jqGridRequestDto, recordNum, listaOtrasAyudas, reorderSelection);
		}
		return new JQGridResponseDto<OtrasAyudas>(jqGridRequestDto, recordNum, listaOtrasAyudas);
	}

	/**
	 * Searches rows in the OtrasAyudas table.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param searchOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<OtrasAyudas>>
	 */
	public List<TableRowDto<OtrasAyudas>> search(OtrasAyudas filterOtrasAyudas, OtrasAyudas searchOtrasAyudas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.otrasAyudasDao.search(filterOtrasAyudas, searchOtrasAyudas, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in OtrasAyudas table.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(OtrasAyudas filterOtrasAyudas, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.otrasAyudasDao.reorderSelection(filterOtrasAyudas, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the OtrasAyudas table.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<OtrasAyudas>>
	 */
	public JQGridResponseDto<JerarquiaDto<OtrasAyudas>> jerarquia(OtrasAyudas filterOtrasAyudas,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<OtrasAyudas>> listaOtrasAyudas = this.otrasAyudasDao.findAllLikeJerarquia(filterOtrasAyudas,
				jqGridRequestDto);
		Long recordNum = this.otrasAyudasDao.findAllLikeCountJerarquia(filterOtrasAyudas, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<OtrasAyudas>>(jqGridRequestDto, recordNum, listaOtrasAyudas);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the OtrasAyudas
	 * table.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<OtrasAyudas>>
	 */
	public JQGridResponseDto<JerarquiaDto<OtrasAyudas>> jerarquiaChildren(OtrasAyudas filterOtrasAyudas,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<OtrasAyudas>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<OtrasAyudas>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.otrasAyudasDao.findAllChild(filterOtrasAyudas, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
