package com.ejie.ab60.service.estudioTecnico;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.estudioTecnico.RelTecResConDao;
import com.ejie.ab60.dao.estudioTecnico.TecnicosResponsablesDao;
import com.ejie.ab60.model.estudioTecnico.RelTecResCon;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

/**
 * TecnicosResponsablesServiceImpl  
 * 
 *  
 */

@Service(value = "tecnicosResponsablesService")
public class TecnicosResponsablesServiceImpl implements TecnicosResponsablesService {

	@Autowired
	private TecnicosResponsablesDao tecnicosResponsablesDao;
	@Autowired
	private RelTecResConDao relTecResConDao;

	/**
	 * Inserts a single row in the TecnicosResponsables table.
	 *
	 * @param tecnicosResponsable
	 *            TecnicosResponsables
	 * @return TecnicosResponsables
	 */
	@Override()
	@Transactional(rollbackFor = Throwable.class)
	public TecnicosResponsables add(TecnicosResponsables tecnicosResponsable) {

		TecnicosResponsables tecnicosResponsablesAux = tecnicosResponsable;
		tecnicosResponsablesAux = this.tecnicosResponsablesDao.add(tecnicosResponsable);

		RelTecResCon relTecResCon;
		for (int i = 0; i < tecnicosResponsablesAux.getListRelTecResCon().size(); i++) {
			relTecResCon = new RelTecResCon();

			relTecResCon.setIdConvocatoria(tecnicosResponsablesAux.getListRelTecResCon().get(i).getIdConvocatoria());
			relTecResCon.setIdTecnicoResponsable(tecnicosResponsablesAux.getIdTecnicoResponsable());
			relTecResCon.setFechaRegistro(tecnicosResponsablesAux.getFechaRegistro());
			relTecResCon.setUsuarioRegistro(tecnicosResponsablesAux.getUsuarioRegistro());

			this.relTecResConDao.add(relTecResCon);
		}

		return tecnicosResponsablesAux;
	}

	/**
	 * Updates a single row in the TecnicosResponsables table.
	 *
	 * @param tecnicosResponsables
	 *            TecnicosResponsables
	 * @return TecnicosResponsables
	 */
	@Override()
	@Transactional(rollbackFor = Throwable.class)
	public TecnicosResponsables update(TecnicosResponsables tecnicosResponsables) {
		this.tecnicosResponsablesDao.update(tecnicosResponsables);

		this.relTecResConDao.remove(tecnicosResponsables.getIdTecnicoResponsable());

		RelTecResCon relTecResCon;
		for (int i = 0; i < tecnicosResponsables.getListRelTecResCon().size(); i++) {
			relTecResCon = new RelTecResCon();

			relTecResCon.setIdConvocatoria(tecnicosResponsables.getListRelTecResCon().get(i).getIdConvocatoria());
			relTecResCon.setIdTecnicoResponsable(tecnicosResponsables.getIdTecnicoResponsable());
			relTecResCon.setFechaRegistro(tecnicosResponsables.getFechaUltModificacion());
			relTecResCon.setUsuarioRegistro(tecnicosResponsables.getUsuarioUltModificacion());

			this.relTecResConDao.add(relTecResCon);
		}

		return tecnicosResponsables;
	}

	/**
	 * Finds a single row in the TecnicosResponsables table.
	 *
	 * @param tecnicosResponsables
	 *            TecnicosResponsables
	 * @return TecnicosResponsables
	 */
	public TecnicosResponsables find(TecnicosResponsables tecnicosResponsables) {

		TecnicosResponsables tecnicosResponsablesAux = this.tecnicosResponsablesDao.find(tecnicosResponsables);

		List<RelTecResCon> relTecResConList = relTecResConDao
				.findConvocatoriasPorTecnico(tecnicosResponsablesAux.getIdTecnicoResponsable());

		tecnicosResponsablesAux.setListRelTecResCon(relTecResConList);

		return tecnicosResponsablesAux;
	}

	/**
	 * Finds a list of rows in the TecnicosResponsables table.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param idExpediente
	 *            Integer
	 * @param justificacion
	 *            boolean
	 * 
	 * @return List<TecnicosResponsables>
	 */
	public List<TecnicosResponsables> findTecnico(Integer idConvocatoria, Integer idExpediente, boolean justificacion) {
		return this.tecnicosResponsablesDao.findTecnico(idConvocatoria, idExpediente, justificacion);
	}

	/**
	 * Deletes a single row in the TecnicosResponsables table.
	 *
	 * @param tecnicosResponsables
	 *            TecnicosResponsables
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TecnicosResponsables tecnicosResponsables) {
		this.tecnicosResponsablesDao.remove(tecnicosResponsables);

		this.relTecResConDao.remove(tecnicosResponsables.getIdTecnicoResponsable());
	}

	/**
	 * Finds a list of rows in the TecnicosResponsables table.
	 *
	 * @param tecnicosResponsables
	 *            TecnicosResponsables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TecnicosResponsables>
	 */
	public List<TecnicosResponsables> findAll(TecnicosResponsables tecnicosResponsables,
			JQGridRequestDto jqGridRequestDto) {
		return (List<TecnicosResponsables>) this.tecnicosResponsablesDao.findAll(tecnicosResponsables,
				jqGridRequestDto);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter method in the TecnicosResponsables table.
	 *
	 * @param filterTecnicosResponsables
	 *            TecnicosResponsables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<TecnicosResponsables>
	 */
	public JQGridResponseDto<TecnicosResponsables> filter(TecnicosResponsables filterTecnicosResponsables,
			JQGridRequestDto jqGridRequestDto) {
		List<TecnicosResponsables> listaTecnicosResponsables = this.tecnicosResponsablesDao
				.findAll(filterTecnicosResponsables, jqGridRequestDto);
		Long recordNum = this.tecnicosResponsablesDao.findAllCount(
				filterTecnicosResponsables != null ? filterTecnicosResponsables : new TecnicosResponsables());

		return new JQGridResponseDto<TecnicosResponsables>(jqGridRequestDto, recordNum, listaTecnicosResponsables);

	}

}
