package com.ejie.ab60.service.estudioTecnico;

import com.ejie.ab60.dao.estudioTecnico.TiposGastoDao;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.model.estudioTecnico.TiposGasto;

/**
 * TiposGastoServiceImpl  
 * 
 *  
 */

@Service(value = "tiposGastoService")
public class TiposGastoServiceImpl implements TiposGastoService {

	@Autowired
	private TiposGastoDao tiposGastoDao;

	/**
	 * Inserts a single row in the TiposGasto table.
	 *
	 * @param tiposGasto
	 *            TiposGasto
	 * @return TiposGasto
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposGasto add(TiposGasto tiposGasto) {
		return this.tiposGastoDao.add(tiposGasto);
	}

	/**
	 * Updates a single row in the TiposGasto table.
	 *
	 * @param tiposGasto
	 *            TiposGasto
	 * @return TiposGasto
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposGasto update(TiposGasto tiposGasto) {
		return this.tiposGastoDao.update(tiposGasto);
	}

	/**
	 * Finds a single row in the TiposGasto table.
	 *
	 * @param tiposGasto
	 *            TiposGasto
	 * @return TiposGasto
	 */
	public TiposGasto find(TiposGasto tiposGasto) {
		return (TiposGasto) this.tiposGastoDao.find(tiposGasto);
	}

	/**
	 * Deletes a single row in the TiposGasto table.
	 *
	 * @param tiposGasto
	 *            TiposGasto
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposGasto tiposGasto) {
		this.tiposGastoDao.remove(tiposGasto);
	}

	/**
	 * Finds a list of rows in the TiposGasto table.
	 *
	 * @param tiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposGasto>
	 */
	public List<TiposGasto> findAll(TiposGasto tiposGasto, JQGridRequestDto jqGridRequestDto) {
		return (List<TiposGasto>) this.tiposGastoDao.findAll(tiposGasto, jqGridRequestDto);
	}

	/**
	 * Finds a list of rows in the TiposGasto table filtrado por idActSub. Cada
	 * actuacion subvencionable muestra unos tipos
	 *
	 * @param idCriterio
	 *            Integer
	 * 
	 * @return List<TiposGasto>
	 */
	public List<TiposGasto> findTiposGasto(Integer idCriterio, Integer idConvocatoria) {
		return (List<TiposGasto>) this.tiposGastoDao.findTiposGasto(idCriterio, idConvocatoria);
	}

	/**
	 * Finds rows in the TiposGasto table using like.
	 *
	 * @param tiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposGasto>
	 */
	public List<TiposGasto> findAllLike(TiposGasto tiposGasto, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return (List<TiposGasto>) this.tiposGastoDao.findAllLike(tiposGasto, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.tiposGastoDao.removeMultiple(filterTiposGasto, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<TiposGasto>
	 */
	public JQGridResponseDto<TiposGasto> filter(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<TiposGasto> listaTiposGasto = this.tiposGastoDao.findAllLike(filterTiposGasto, jqGridRequestDto, false);
		Long recordNum = this.tiposGastoDao
				.findAllLikeCount(filterTiposGasto != null ? filterTiposGasto : new TiposGasto(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TiposGasto>> reorderSelection = this.tiposGastoDao.reorderSelection(filterTiposGasto,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposGasto>(jqGridRequestDto, recordNum, listaTiposGasto, reorderSelection);
		}
		return new JQGridResponseDto<TiposGasto>(jqGridRequestDto, recordNum, listaTiposGasto);
	}

	/**
	 * Searches rows in the TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param searchTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposGasto>>
	 */
	public List<TableRowDto<TiposGasto>> search(TiposGasto filterTiposGasto, TiposGasto searchTiposGasto,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposGastoDao.search(filterTiposGasto, searchTiposGasto, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TiposGasto filterTiposGasto, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposGastoDao.reorderSelection(filterTiposGasto, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposGasto>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposGasto>> jerarquia(TiposGasto filterTiposGasto,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TiposGasto>> listaTiposGasto = this.tiposGastoDao.findAllLikeJerarquia(filterTiposGasto,
				jqGridRequestDto);
		Long recordNum = this.tiposGastoDao.findAllLikeCountJerarquia(filterTiposGasto, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposGasto>>(jqGridRequestDto, recordNum, listaTiposGasto);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the TiposGasto table.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposGasto>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposGasto>> jerarquiaChildren(TiposGasto filterTiposGasto,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TiposGasto>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposGasto>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.tiposGastoDao.findAllChild(filterTiposGasto, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
