package com.ejie.ab60.service.expedientes;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.adaptadores.X43ExpedienteElectronicoAdaptadorService;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TBoolean;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolder;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderCompleteQuery;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderList;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderQuery;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderSearchType;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderSearchTypeList;
import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TStringList;
import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.dao.RelExpInsDao;
import com.ejie.ab60.dao.expedientes.ExpedientesDao;
import com.ejie.ab60.model.RelExpIns;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

@SessionAttributes("usuario")
@Service(value = "expedientesService")
public class ExpedientesServiceImpl implements ExpedientesService {

	@Autowired
	private ExpedientesDao expedientesDao;

	@Autowired
	private RelExpInsDao relExpInsDao;

	private final static Logger logger = Logger
			.getLogger(com.ejie.ab60.service.expedientes.ExpedientesServiceImpl.class.getName());

	@Autowired
	private X43ExpedienteElectronicoAdaptadorService expedienteElectronicoWS;

	/**
	 * Inserts a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes add(Expedientes expedientes) {
		return this.expedientesDao.add(expedientes);
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes update(Expedientes expedientes) {
		return this.expedientesDao.update(expedientes);
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes updateFolder(Expedientes expedientes) {
		return this.expedientesDao.updateFolder(expedientes);
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes updateFolderTitle(Expedientes expedientes) {
		return this.expedientesDao.updateFolderTitle(expedientes);
	}

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes find(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.find(expedientes);
	}

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes findProcedureIdPorExpediente(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.findProcedureIdPorExpediente(expedientes);
	}

	/**
	 * Finds a single row in the Expedientes table por Folder ID.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes findByFolderId(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.findByFolderId(expedientes);
	}

	/**
	 * Finds a single row in the Expedientes table por Folder ID.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes findByFolderNumber(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.findByFolderNumber(expedientes);
	}

	/**
	 * Deletes a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Expedientes expedientes) {
		this.expedientesDao.remove(expedientes);
	}

	/**
	 * Finds a list of rows in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Expedientes>
	 */
	public List<Expedientes> findAll(Expedientes expedientes, JQGridRequestDto jqGridRequestDto) {
		return (List<Expedientes>) this.expedientesDao.findAll(expedientes, jqGridRequestDto);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.expedientesDao.removeMultiple(filterExpedientes, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDtor
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Expedientes>
	 */
	public JQGridResponseDto<Expedientes> filterTer(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		List<Expedientes> listaExpedientes = this.expedientesDao.findAllLikeTer(filterExpedientes, jqGridRequestDto,
				false);

		for (Expedientes expediente : listaExpedientes) {

			RelExpIns relExpIns = new RelExpIns();
			relExpIns.setIdExpediente(expediente.getIdExpediente());
			List<RelExpIns> listaRelExpIns = this.relExpInsDao.findIdentificadorInspeccionByIdExpediente(relExpIns);
			List<String> identificadoresInspeccion = new ArrayList<String>();
			List<Integer> idsInspeccion = new ArrayList<Integer>();
			List<Integer> tiposInspeccion = new ArrayList<Integer>();

			for (RelExpIns relExpInsAux : listaRelExpIns) {
				if (relExpInsAux.getIdExpediente().equals(expediente.getIdExpediente())) {
					identificadoresInspeccion.add(relExpInsAux.getIdentificadorInspeccion());
					idsInspeccion.add(relExpInsAux.getIdInspeccion());
					tiposInspeccion.add(relExpInsAux.getTipoInspeccion());
				}
			}

			if (!identificadoresInspeccion.isEmpty() && !idsInspeccion.isEmpty() && !tiposInspeccion.isEmpty()) {
				if (identificadoresInspeccion.size() > 1 && idsInspeccion.size() > 1 && tiposInspeccion.size() > 1) {
					expediente.setIdentificadoresInspeccion(
							identificadoresInspeccion.get(0) + " | " + identificadoresInspeccion.get(1));
					expediente.setIdsInspeccion(idsInspeccion.get(0) + "|" + idsInspeccion.get(1));
					expediente.setTiposInspeccion(tiposInspeccion.get(0) + "|" + tiposInspeccion.get(1));
				} else {
					expediente.setIdentificadoresInspeccion(identificadoresInspeccion.get(0));
					expediente.setIdsInspeccion(String.valueOf(idsInspeccion.get(0)));
					expediente.setTiposInspeccion(String.valueOf(tiposInspeccion.get(0)));
				}
			}

		}

		Long recordNum = this.expedientesDao
				.findAllLikeCountTer(filterExpedientes != null ? filterExpedientes : new Expedientes(), false);

		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Expedientes>> reorderSelection = this.expedientesDao.reorderSelection(filterExpedientes,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientes, reorderSelection);
		}

		return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	/**
	 * Finds rows in the ActSubvencionable table using like.
	 *
	 * @param Expedientes
	 *            expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ActSubvencionable>
	 */
	public List<Expedientes> findAllLikeTer(Expedientes expedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		List<Expedientes> listaExpedientes = this.expedientesDao.findAllLikeTer(expedientes, jqGridRequestDto,
				startsWith);

		for (Expedientes expediente : listaExpedientes) {

			RelExpIns relExpIns = new RelExpIns();
			relExpIns.setIdExpediente(expediente.getIdExpediente());
			List<RelExpIns> listaRelExpIns = this.relExpInsDao.findIdentificadorInspeccionByIdExpediente(relExpIns);
			List<String> identificadoresInspeccion = new ArrayList<String>();

			for (RelExpIns relExpInsAux : listaRelExpIns) {
				if (relExpInsAux.getIdExpediente().equals(expediente.getIdExpediente())) {
					identificadoresInspeccion.add(relExpInsAux.getIdentificadorInspeccion());
				}
			}

			if (!identificadoresInspeccion.isEmpty()) {
				if (identificadoresInspeccion.size() > 1) {
					expediente.setIdentificadoresInspeccion(
							identificadoresInspeccion.get(0) + " | " + identificadoresInspeccion.get(1));
				} else {
					expediente.setIdentificadoresInspeccion(identificadoresInspeccion.get(0));
				}
			}

		}

		return listaExpedientes;
	}

	/**
	 * Método para obtener el Expediente mediante el FOLDER_NUMBER.
	 *
	 * @param String
	 *            folderNumber
	 * 
	 * @return List<Expedientes> Expedientes
	 */

	public List<Expedientes> findExpediente(String folderNumber) {

		return expedientesDao.findLupaExpediente(folderNumber);

	}

	/**
	 * Searches rows in the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param searchExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Expedientes>>
	 */
	public List<TableRowDto<Expedientes>> search(Expedientes filterExpedientes, Expedientes searchExpedientes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.expedientesDao.search(filterExpedientes, searchExpedientes, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.expedientesDao.reorderSelection(filterExpedientes, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Expedientes>>
	 */
	public JQGridResponseDto<JerarquiaDto<Expedientes>> jerarquia(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Expedientes>> listaExpedientes = this.expedientesDao.findAllLikeJerarquia(filterExpedientes,
				jqGridRequestDto);
		Long recordNum = this.expedientesDao.findAllLikeCountJerarquia(filterExpedientes, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Expedientes>>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Expedientes
	 * table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Expedientes>>
	 */
	public JQGridResponseDto<JerarquiaDto<Expedientes>> jerarquiaChildren(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Expedientes>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Expedientes>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.expedientesDao.findAllChild(filterExpedientes, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public List<Expedientes> findAllLike(Expedientes expedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// TODO Auto-generated method stub
		return null;
	}

	/**
	 * llama al WS searchFolders
	 * 
	 * @param folderId
	 * @return TFolderList
	 * @throws Exception
	 */
	@Override
	public TFolderList obtenerInfoPlatea(String folderId) throws Exception {

		logger.info("obtenerInfoPlatea:inicio: folderId: " + folderId);
		String auditUser = Constantes.AUDIT_USER;

		TFolderList resultado = null;
		try {

			TFolderQuery query = new TFolderQuery();
			TFolderCompleteQuery tFolderComplete = new TFolderCompleteQuery();

			TStringList folderIdList = new TStringList();

			folderIdList.getItem().add(folderId);

			TFolderSearchType tFolderSearchType = TFolderSearchType.PARAM_ALL;
			TFolderSearchTypeList tFolderSearchTypeList = new TFolderSearchTypeList();
			tFolderSearchTypeList.getParam().add(tFolderSearchType);
			tFolderComplete.setParamList(tFolderSearchTypeList);

			tFolderComplete.setAuditUser(auditUser);
			tFolderComplete.setFolderIDList(folderIdList);
			tFolderComplete.setInterestedMode(TBoolean.TRUE);

			query.setComplete(tFolderComplete);

			resultado = expedienteElectronicoWS.SearchFolders(query, null);

		} catch (Exception e) {
			logger.info("No esta disponible el SearchFolders");
			resultado = null;
		}
		return resultado;
	}

	/**
	 * Método que actualizar el tiutlo del expediente con el titulo que viene de
	 * Platea (Tramitagune)
	 * 
	 * @param resultado
	 * @param usuario
	 */
	public void actualizarTituloExpediente(TFolderList resultado, Usuario usuario, InitForm initForm) throws Exception {

		logger.info("INICIO actualizarTituloExpediente");

		if (!resultado.getFolder().isEmpty()) {

			// actualizamos en BD
			Expedientes expediente = new Expedientes();
			TFolder expedientPlatea = resultado.getFolder().get(0);
			logger.info("FolderID = " + expedientPlatea.getFolderID());
			expediente.setFolderId(expedientPlatea.getFolderID());
			logger.info("FolderTitle = " + expedientPlatea.getFolderTitle());
			expediente.setTitulo(expedientPlatea.getFolderTitle());
			if (null != usuario.getNombreUsuario() && usuario.getNombreUsuario().length() > 19) {
				logger.info("NombreUsuario = " + usuario.getNombreUsuario().substring(0, 19));
				expediente.setUsuarioRegistro(usuario.getNombreUsuario().substring(0, 19));
			} else {
				logger.info("NombreUsuario = " + usuario.getNombreUsuario());
				expediente.setUsuarioRegistro(usuario.getNombreUsuario());
			}
			this.updateFolderTitle(expediente);
			// actualizamos en el initForm
			initForm.setTituloExpediente(expedientPlatea.getFolderTitle());
		}
		logger.info("FIN actualizarTituloExpediente");
	}

	@Override
	public JQGridResponseDto<Expedientes> filterExpedientesRelacionadosTitular(String documentosTitular,
			Integer idExpediente, JQGridRequestDto jqGridRequestDto) {
		List<Expedientes> listaExpedientesRelacionados = this.expedientesDao
				.findExpedientesRelacionadosTitular(documentosTitular, idExpediente, jqGridRequestDto);

		for (Expedientes expediente : listaExpedientesRelacionados) {

			if (!expediente.isExpedienteHistorico()) {

				RelExpIns relExpIns = new RelExpIns();
				relExpIns.setIdExpediente(expediente.getIdExpediente());
				List<RelExpIns> listaRelExpIns = this.relExpInsDao.findIdentificadorInspeccionByIdExpediente(relExpIns);
				List<String> identificadoresInspeccion = new ArrayList<String>();
				List<Integer> idsInspeccion = new ArrayList<Integer>();

				for (RelExpIns relExpInsAux : listaRelExpIns) {
					if (relExpInsAux.getIdExpediente().equals(expediente.getIdExpediente())) {
						identificadoresInspeccion.add(relExpInsAux.getIdentificadorInspeccion());
						idsInspeccion.add(relExpInsAux.getIdInspeccion());
					}
				}

				if (!identificadoresInspeccion.isEmpty() && !idsInspeccion.isEmpty()) {
					if (identificadoresInspeccion.size() > 1 && idsInspeccion.size() > 1) {
						expediente.setIdentificadoresInspeccion(
								identificadoresInspeccion.get(0) + "|" + identificadoresInspeccion.get(1));
						expediente.setIdsInspeccion(idsInspeccion.get(0) + "|" + idsInspeccion.get(1));
					} else {
						expediente.setIdentificadoresInspeccion(identificadoresInspeccion.get(0));
						expediente.setIdsInspeccion(String.valueOf(idsInspeccion.get(0)));
					}
				}
			}
		}

		Long recordNum = this.expedientesDao.findExpedientesRelacionadosTitularCount(documentosTitular, idExpediente);

		return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientesRelacionados);
	}

	@Override
	public JQGridResponseDto<Expedientes> filterExpedientesRelacionadosUbicacion(String identificadorEstablecimiento,
			Integer idExpediente, JQGridRequestDto jqGridRequestDto) {
		List<Expedientes> listaExpedientesRelacionados = this.expedientesDao
				.findExpedientesRelacionadosUbicacion(identificadorEstablecimiento, idExpediente, jqGridRequestDto);

		for (Expedientes expediente : listaExpedientesRelacionados) {

			if (!expediente.isExpedienteHistorico()) {

				RelExpIns relExpIns = new RelExpIns();
				relExpIns.setIdExpediente(expediente.getIdExpediente());
				List<RelExpIns> listaRelExpIns = this.relExpInsDao.findIdentificadorInspeccionByIdExpediente(relExpIns);
				List<String> identificadoresInspeccion = new ArrayList<String>();
				List<Integer> idsInspeccion = new ArrayList<Integer>();

				for (RelExpIns relExpInsAux : listaRelExpIns) {
					if (relExpInsAux.getIdExpediente().equals(expediente.getIdExpediente())) {
						identificadoresInspeccion.add(relExpInsAux.getIdentificadorInspeccion());
						idsInspeccion.add(relExpInsAux.getIdInspeccion());
					}
				}

				if (!identificadoresInspeccion.isEmpty() && !idsInspeccion.isEmpty()) {
					if (identificadoresInspeccion.size() > 1 && idsInspeccion.size() > 1) {
						expediente.setIdentificadoresInspeccion(
								identificadoresInspeccion.get(0) + "|" + identificadoresInspeccion.get(1));
						expediente.setIdsInspeccion(idsInspeccion.get(0) + "|" + idsInspeccion.get(1));
					} else {
						expediente.setIdentificadoresInspeccion(identificadoresInspeccion.get(0));
						expediente.setIdsInspeccion(String.valueOf(idsInspeccion.get(0)));
					}
				}
			}
		}

		Long recordNum = this.expedientesDao.findExpedientesRelacionadosUbicacionCount(identificadorEstablecimiento,
				idExpediente);

		return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientesRelacionados);
	}

	@Override
	public JQGridResponseDto<Expedientes> filterExpedientesRelacionadosUbicacionRelacionExpediente(
			Integer relacionExpediente, Integer idExpediente, JQGridRequestDto jqGridRequestDto) {
		List<Expedientes> listaExpedientesRelacionados = this.expedientesDao
				.findExpedientesRelacionadosUbicacionRelacionExpediente(relacionExpediente, idExpediente,
						jqGridRequestDto);

		for (Expedientes expediente : listaExpedientesRelacionados) {

			if (!expediente.isExpedienteHistorico()) {

				RelExpIns relExpIns = new RelExpIns();
				relExpIns.setIdExpediente(expediente.getIdExpediente());
				List<RelExpIns> listaRelExpIns = this.relExpInsDao.findIdentificadorInspeccionByIdExpediente(relExpIns);
				List<String> identificadoresInspeccion = new ArrayList<String>();
				List<Integer> idsInspeccion = new ArrayList<Integer>();

				for (RelExpIns relExpInsAux : listaRelExpIns) {
					if (relExpInsAux.getIdExpediente().equals(expediente.getIdExpediente())) {
						identificadoresInspeccion.add(relExpInsAux.getIdentificadorInspeccion());
						idsInspeccion.add(relExpInsAux.getIdInspeccion());
					}
				}

				if (!identificadoresInspeccion.isEmpty() && !idsInspeccion.isEmpty()) {
					if (identificadoresInspeccion.size() > 1 && idsInspeccion.size() > 1) {
						expediente.setIdentificadoresInspeccion(
								identificadoresInspeccion.get(0) + "|" + identificadoresInspeccion.get(1));
						expediente.setIdsInspeccion(idsInspeccion.get(0) + "|" + idsInspeccion.get(1));
					} else {
						expediente.setIdentificadoresInspeccion(identificadoresInspeccion.get(0));
						expediente.setIdsInspeccion(String.valueOf(idsInspeccion.get(0)));
					}
				}
			}
		}

		Long recordNum = this.expedientesDao
				.findExpedientesRelacionadosUbicacionRelacionExpedienteCount(relacionExpediente, idExpediente);

		return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientesRelacionados);
	}

}
