package com.ejie.ab60.service.expedientes;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.dao.expedientes.MarcarInspeccionableDao;
import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.expedientes.MarcarInspeccionable;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;

/**
 * JustificacionServiceImpl  
 * 
 *  
 */

@Service(value = "marcarInspeccionableService")
public class MarcarInspeccionableServiceImpl implements MarcarInspeccionableService {

	@Autowired
	private MarcarInspeccionableDao marcarInspeccionableDao;

	@Override
	public MarcarInspeccionable findInspeccionable(MarcarInspeccionable marcarInspeccionable) {
		return this.marcarInspeccionableDao.findInspeccionable(marcarInspeccionable);
	}

	@Override
	public MarcarInspeccionableAct findInspeccionableAct(MarcarInspeccionableAct marcarInspeccionableAct) {
		return (MarcarInspeccionableAct) this.marcarInspeccionableDao.findInspeccionableAct(marcarInspeccionableAct);
	}

	/**
	 * Actualizar los datos del proyecto con la informción del envío a
	 * inspección
	 * 
	 * @param marcarInspeccionable
	 *            MarcarInspeccionable
	 * @param tipoInspeccion
	 *            Integer
	 * 
	 * @return String
	 */
	@Transactional(rollbackFor = Throwable.class)
	public String guardarMarcarInspeccionable(MarcarInspeccionable marcarInspeccionable, Integer tipoInspeccion,
			String respuesta) {
		try {

			// Actualizar los datos del proyecto
			this.marcarInspeccionableDao.actualizarDatosProyecto(marcarInspeccionable, tipoInspeccion);

			// Actualizar las facturas
			for (int i = 0; i < marcarInspeccionable.getFacturas().size(); i++) {
				this.marcarInspeccionableDao.actualizarFacturas(marcarInspeccionable.getFacturas().get(i));
			}

			return respuesta;

		} catch (Exception ex) {
			return "error";
		}
	}

	/**
	 * Actualizar los datos del proyecto con la informción del envío a
	 * inspección
	 * 
	 * @param marcarInspeccionableAct
	 *            MarcarInspeccionableAct
	 * 
	 * @return String
	 */
	@Transactional(rollbackFor = Throwable.class)
	public String guardarMarcarInspeccionableAct(MarcarInspeccionableAct marcarInspeccionableAct, String respuesta) {
		try {
			// Actualizar los datos del proyecto
			this.marcarInspeccionableDao.actualizarDatosProyectoAct(marcarInspeccionableAct);

			// Actualizar las facturas
			for (Conceptos concepto : marcarInspeccionableAct.getConceptosList()) {
				if (concepto.getIdConcepto() == Constantes.MAGIC_NUMBER_0) {
					// Actualizar REL_EXP_ACT_SUB (AB6023T00)
					this.marcarInspeccionableDao.actualizarActuaciones(concepto.getIdRelExpActSub());
				} else {
					// Actualizar CONCEPTOS (AB6019T00)
					this.marcarInspeccionableDao.actualizarConcepto(concepto.getIdConcepto());
				}

			}
			return respuesta;

		} catch (Exception ex) {
			return "error";
		}
	}

	@Override
	public String findDatosProyectoPorId(Integer idExpediente, Integer tipoInspeccion) {
		return this.marcarInspeccionableDao.findDatosProyectoPorId(idExpediente, tipoInspeccion);
	}
}
