package com.ejie.ab60.service.moduloContable;

import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.dao.convocatorias.AplicacionesPresupuestariasDao;
import com.ejie.ab60.dao.convocatorias.ConvocatoriasDao;
import com.ejie.ab60.dao.moduloContable.DocumentosContablesDao;
import com.ejie.ab60.dao.moduloContable.FicherosContablesDao;
import com.ejie.ab60.model.convocatorias.AplicacionesPresupuestarias;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.moduloContable.DocContables;
import com.ejie.ab60.model.moduloContable.DocumentosContables;
import com.ejie.ab60.model.moduloContable.FicherosContables;
import com.ejie.ab60.model.moduloContable.ModuloContable;
import com.ejie.ab60.model.terceros.TiposDocumento;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * FicherosContablesServiceImpl  
 * 
 *  
 */

@Service(value = "ficherosContablesService")
public class FicherosContablesServiceImpl implements FicherosContablesService {

	@Autowired
	private FicherosContablesDao ficherosContablesDao;

	@Autowired
	private ConvocatoriasDao convocatoriasDao;

	@Autowired
	private DocumentosContablesDao documentosContablesDao;

	@Autowired
	private AplicacionesPresupuestariasDao aplicacionesPresupuestariasDao;

	/**
	 * Inserts a single row in the FicherosContables table.
	 *
	 * @param ficherosContables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	@Transactional(rollbackFor = Throwable.class)
	public FicherosContables add(FicherosContables ficherosContables, Usuario usuario) {
		return this.ficherosContablesDao.add(ficherosContables, usuario);
	}

	/**
	 * Updates a single row in the FicherosContables table.
	 *
	 * @param ficherosContables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	@Transactional(rollbackFor = Throwable.class)
	public FicherosContables update(FicherosContables ficherosContables, Usuario usuario) {
		return this.ficherosContablesDao.update(ficherosContables, usuario);
	}

	/**
	 * Finds a single row in the FicherosContables table.
	 *
	 * @param ficherosContables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	public FicherosContables find(FicherosContables ficherosContables) {
		return (FicherosContables) this.ficherosContablesDao.find(ficherosContables);
	}

	/**
	 * Finds a single row in the FicherosContables table.
	 *
	 * @param ficherosContables
	 *            FicherosContables
	 * @return FicherosContables
	 */
	public FicherosContables findNew(FicherosContables ficherosContables) {
		return (FicherosContables) this.ficherosContablesDao.findNew(ficherosContables);
	}

	/**
	 * Deletes a single row in the FicherosContables table.
	 *
	 * @param ficherosContables
	 *            FicherosContables
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(FicherosContables ficherosContables) {
		this.ficherosContablesDao.remove(ficherosContables);
	}

	/**
	 * Finds a list of rows in the FicherosContables table.
	 *
	 * @param ficherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<FicherosContables>
	 */
	public List<FicherosContables> findAll(FicherosContables ficherosContables, JQGridRequestDto jqGridRequestDto) {
		return (List<FicherosContables>) this.ficherosContablesDao.findAll(ficherosContables, jqGridRequestDto);
	}

	/**
	 * Finds rows in the FicherosContables table using like.
	 *
	 * @param ficherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<FicherosContables>
	 */
	public List<FicherosContables> findAllLike(FicherosContables ficherosContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<FicherosContables>) this.ficherosContablesDao.findAllLike(ficherosContables, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the FicherosContables table.
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(FicherosContables filterFicherosContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.ficherosContablesDao.removeMultiple(filterFicherosContables, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the FicherosContables table.
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<FicherosContables>
	 */
	public JQGridResponseDto<FicherosContables> filter(FicherosContables filterFicherosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<FicherosContables> listaFicherosContables = this.ficherosContablesDao.findAllLike(filterFicherosContables,
				jqGridRequestDto, false);
		Long recordNum = this.ficherosContablesDao.findAllLikeCount(
				filterFicherosContables != null ? filterFicherosContables : new FicherosContables(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<FicherosContables>> reorderSelection = this.ficherosContablesDao
					.reorderSelection(filterFicherosContables, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<FicherosContables>(jqGridRequestDto, recordNum, listaFicherosContables,
					reorderSelection);
		}
		return new JQGridResponseDto<FicherosContables>(jqGridRequestDto, recordNum, listaFicherosContables);
	}

	/**
	 * Searches rows in the FicherosContables table.
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param searchFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<FicherosContables>>
	 */
	public List<TableRowDto<FicherosContables>> search(FicherosContables filterFicherosContables,
			FicherosContables searchFicherosContables, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.ficherosContablesDao.search(filterFicherosContables, searchFicherosContables, jqGridRequestDto,
				startsWith);
	}

	/**
	 * Reorder the selection made in FicherosContables table.
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(FicherosContables filterFicherosContables, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.ficherosContablesDao.reorderSelection(filterFicherosContables, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the FicherosContables table.
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<FicherosContables>>
	 */
	public JQGridResponseDto<JerarquiaDto<FicherosContables>> jerarquia(FicherosContables filterFicherosContables,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<FicherosContables>> listaFicherosContables = this.ficherosContablesDao
				.findAllLikeJerarquia(filterFicherosContables, jqGridRequestDto);
		Long recordNum = this.ficherosContablesDao.findAllLikeCountJerarquia(filterFicherosContables, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<FicherosContables>>(jqGridRequestDto, recordNum,
				listaFicherosContables);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the FicherosContables
	 * table.
	 *
	 * @param filterFicherosContables
	 *            FicherosContables
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<FicherosContables>>
	 */
	public JQGridResponseDto<JerarquiaDto<FicherosContables>> jerarquiaChildren(
			FicherosContables filterFicherosContables, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<FicherosContables>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<FicherosContables>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.ficherosContablesDao.findAllChild(filterFicherosContables, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	@Transactional
	public ModuloContable saveDocumentoDO(ModuloContable moduloContable, Usuario usuario) {

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(moduloContable.getFicherosContables().getIdConvocatoria());
		convocatoria = this.convocatoriasDao.find(convocatoria);

		moduloContable.getFicherosContables().setOrigenMaqueta(convocatoria.getOrigenMaqueta());
		moduloContable.getFicherosContables().setEstado(Constantes.ESTADO_FICHERO_LOT_NO_GENERADO);
		moduloContable.getFicherosContables().setTipoRegistro(String.valueOf(Constantes.TIPO_REGISTRO_1));

		// Creamos el fichero contable
		FicherosContables ficheroContable = this.ficherosContablesDao.add(moduloContable.getFicherosContables(),
				usuario);

		for (DocContables docContable : moduloContable.getListaDocContables()) {

			DocumentosContables documentoContable = new DocumentosContables();

			documentoContable.setIdConvocatoria(moduloContable.getFicherosContables().getIdConvocatoria());
			documentoContable.setIdFicheroContable(ficheroContable.getIdFicheroContable());
			documentoContable.setIdExpediente(docContable.getIdExpediente());
			documentoContable.setFechaDocumentoDO(new Date());
			documentoContable.setTipoRegistro(String.valueOf(Constantes.TIPO_REGISTRO_1));
			documentoContable
					.setTipoDocumento(new TiposDocumento(Long.parseLong(Constantes.TIPO_DOCUMENTO_CONTABLE_DO)));
			documentoContable.setNumeroExpediente(docContable.getExpediente());
			documentoContable.setEjercicioAplPre(docContable.getEjercicioAplPre());
			documentoContable.setAgrupacion(docContable.getAgrupacion());
			documentoContable.setGastoIngreso(docContable.getGastoIngreso());
			documentoContable.setSeccion(docContable.getSeccion());
			documentoContable.setServicio(docContable.getServicio());
			documentoContable.setCentro(docContable.getCentro());
			documentoContable.setTerritorio(docContable.getTerritorio());
			documentoContable.setCac(docContable.getCac());
			documentoContable.setSc(docContable.getSc());
			documentoContable.setPrograma(docContable.getPrograma());
			documentoContable.setPartida(docContable.getPartida());
			documentoContable.setLetraControl(docContable.getLetraControl());
			documentoContable.setEjercicioRefInt(docContable.getEjercicioRefInt());
			documentoContable.setAnyoOrigen(docContable.getAnyoOrigen());
			documentoContable.setNumero(docContable.getNumero());
			documentoContable.setDisponible(docContable.getDisponible());
			documentoContable.setObligacion(docContable.getObligacion());
			if (docContable.getConceptoResumido().length() > 80) {
				documentoContable.setConceptoResumido(docContable.getConceptoResumido().substring(0, 80));
			} else {
				documentoContable.setConceptoResumido(docContable.getConceptoResumido());
			}
			documentoContable.setTercero(docContable.getTercero());
			documentoContable.setImporte(docContable.getImportePago());
			documentoContable.setFechaRegistro(new Date());
			documentoContable.setUsuarioRegistro(usuario.getNombreUsuario());
			documentoContable.setFechaDocumentoDO(new Date());
			documentoContable.setFechaResolucion(docContable.getFechaResolucion());

			moduloContable.setDocContables(this.documentosContablesDao.add(documentoContable));

			// Hacemos update del importe disponible de la aplicación
			// presupuestaria
			AplicacionesPresupuestarias aplicPresu = new AplicacionesPresupuestarias();
			aplicPresu.setIdAplicacionPresupuestaria(docContable.getIdAplicPresu());
			aplicPresu.setImporteDisponible(docContable.getImporteDisponibleApl());

			this.aplicacionesPresupuestariasDao.updateImporteDisponible(aplicPresu);
		}

		return moduloContable;

	}

}
