package com.ejie.ab60.service.pagos;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.dao.pagos.PagosConvocatoriaDao;
import com.ejie.ab60.model.pagos.PagosConvocatoria;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PagosConvocatoriaServiceImpl  
 * 
 *  
 */

@Service(value = "pagosConvocatoriaService")
public class PagosConvocatoriaServiceImpl implements PagosConvocatoriaService {

	@Autowired
	private PagosConvocatoriaDao pagosConvocatoriaDao;

	/**
	 * Inserts a single row in the PagosConvocatoria table.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	@Transactional(rollbackFor = Throwable.class)
	public PagosConvocatoria add(PagosConvocatoria pagosConvocatoria) {
		return this.pagosConvocatoriaDao.add(pagosConvocatoria);
	}

	/**
	 * Updates a single row in the PagosConvocatoria table.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	@Transactional(rollbackFor = Throwable.class)
	public PagosConvocatoria update(PagosConvocatoria pagosConvocatoria) {
		return this.pagosConvocatoriaDao.update(pagosConvocatoria);
	}

	/**
	 * Finds a single row in the PagosConvocatoria table.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria
	 * @return PagosConvocatoria
	 */
	public PagosConvocatoria find(PagosConvocatoria pagosConvocatoria) {
		return (PagosConvocatoria) this.pagosConvocatoriaDao.find(pagosConvocatoria);
	}

	/**
	 * Deletes a single row in the PagosConvocatoria table.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(PagosConvocatoria pagosConvocatoria) {
		this.pagosConvocatoriaDao.remove(pagosConvocatoria);
	}

	/**
	 * Finds a list of rows in the PagosConvocatoria table.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PagosConvocatoria>
	 */
	public List<PagosConvocatoria> findAll(PagosConvocatoria pagosConvocatoria, JQGridRequestDto jqGridRequestDto) {
		return (List<PagosConvocatoria>) this.pagosConvocatoriaDao.findAll(pagosConvocatoria, jqGridRequestDto);
	}

	public List<PagosConvocatoria> findAllPagos(PagosConvocatoria pagosConvocatoria,
			JQGridRequestDto jqGridRequestDto) {
		return (List<PagosConvocatoria>) this.pagosConvocatoriaDao.findAllPagos(pagosConvocatoria, jqGridRequestDto);
	}

	/**
	 * Finds rows in the PagosConvocatoria table using like.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PagosConvocatoria>
	 */
	public List<PagosConvocatoria> findAllLike(PagosConvocatoria pagosConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<PagosConvocatoria>) this.pagosConvocatoriaDao.findAllLike(pagosConvocatoria, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(PagosConvocatoria filterPagosConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.pagosConvocatoriaDao.removeMultiple(filterPagosConvocatoria, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<PagosConvocatoria>
	 */
	public JQGridResponseDto<PagosConvocatoria> filter(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<PagosConvocatoria> listaPagosConvocatoria = this.pagosConvocatoriaDao.findAllLike(filterPagosConvocatoria,
				jqGridRequestDto, false);
		Long recordNum = this.pagosConvocatoriaDao.findAllLikeCount(
				filterPagosConvocatoria != null ? filterPagosConvocatoria : new PagosConvocatoria(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<PagosConvocatoria>> reorderSelection = this.pagosConvocatoriaDao
					.reorderSelection(filterPagosConvocatoria, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<PagosConvocatoria>(jqGridRequestDto, recordNum, listaPagosConvocatoria,
					reorderSelection);
		}
		return new JQGridResponseDto<PagosConvocatoria>(jqGridRequestDto, recordNum, listaPagosConvocatoria);
	}

	/**
	 * Searches rows in the PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param searchPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PagosConvocatoria>>
	 */
	public List<TableRowDto<PagosConvocatoria>> search(PagosConvocatoria filterPagosConvocatoria,
			PagosConvocatoria searchPagosConvocatoria, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.pagosConvocatoriaDao.search(filterPagosConvocatoria, searchPagosConvocatoria, jqGridRequestDto,
				startsWith);
	}

	/**
	 * Reorder the selection made in PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(PagosConvocatoria filterPagosConvocatoria, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.pagosConvocatoriaDao.reorderSelection(filterPagosConvocatoria, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the PagosConvocatoria table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<PagosConvocatoria>>
	 */
	public JQGridResponseDto<JerarquiaDto<PagosConvocatoria>> jerarquia(PagosConvocatoria filterPagosConvocatoria,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<PagosConvocatoria>> listaPagosConvocatoria = this.pagosConvocatoriaDao
				.findAllLikeJerarquia(filterPagosConvocatoria, jqGridRequestDto);
		Long recordNum = this.pagosConvocatoriaDao.findAllLikeCountJerarquia(filterPagosConvocatoria, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<PagosConvocatoria>>(jqGridRequestDto, recordNum,
				listaPagosConvocatoria);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the PagosConvocatoria
	 * table.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<PagosConvocatoria>>
	 */
	public JQGridResponseDto<JerarquiaDto<PagosConvocatoria>> jerarquiaChildren(
			PagosConvocatoria filterPagosConvocatoria, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<PagosConvocatoria>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<PagosConvocatoria>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.pagosConvocatoriaDao.findAllChild(filterPagosConvocatoria, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
