package com.ejie.ab60.service.plantillas;
import com.ejie.ab60.dao.plantillas.TiposPlantillaDao;
import com.ejie.ab60.model.plantillas.TiposPlantilla;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * TiposPlantillaServiceImpl  
 *  
 */

@Service(value = "tiposPlantillaService")
public class TiposPlantillaServiceImpl implements TiposPlantillaService {

	@Autowired
	private TiposPlantillaDao tiposPlantillaDao;

	/**
	 * Inserts a single row in the TiposPlantilla table.
	 *
	 * @param tiposPlantilla TiposPlantilla
	 * @return TiposPlantilla
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposPlantilla add(TiposPlantilla tiposPlantilla) {
		return this.tiposPlantillaDao.add(tiposPlantilla);
	}

	/**
	 * Updates a single row in the TiposPlantilla table.
	 *
	 * @param tiposPlantilla TiposPlantilla
	 * @return TiposPlantilla
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposPlantilla update(TiposPlantilla tiposPlantilla) {
		return this.tiposPlantillaDao.update(tiposPlantilla);
	 }

	/**
	 * Finds a single row in the TiposPlantilla table.
	 *
	 * @param tiposPlantilla TiposPlantilla
	 * @return TiposPlantilla
	 */
	public TiposPlantilla find(TiposPlantilla tiposPlantilla) {
		return (TiposPlantilla) this.tiposPlantillaDao.find(tiposPlantilla);
	}
	
	/**
	 * Deletes a single row in the TiposPlantilla table.
	 *
	 * @param tiposPlantilla TiposPlantilla
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposPlantilla tiposPlantilla) {
		this.tiposPlantillaDao.remove(tiposPlantilla);
	}

	/**
	 * Finds a list of rows in the TiposPlantilla table.
	 *
	 * @param tiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return List<TiposPlantilla>
	 */
	public List<TiposPlantilla> findAll(TiposPlantilla tiposPlantilla, JQGridRequestDto jqGridRequestDto){
		return (List<TiposPlantilla>) this.tiposPlantillaDao.findAll(tiposPlantilla, jqGridRequestDto);
	}
    
	/**
	 * Finds rows in the TiposPlantilla table using like.
	 *
	 * @param tiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
     * @param startsWith Boolean	 
	 * @return List<TiposPlantilla>
	 */
	public List<TiposPlantilla> findAllLike(TiposPlantilla tiposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return (List<TiposPlantilla>) this.tiposPlantillaDao.findAllLike(tiposPlantilla, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */
	 
	/**
	 * Removes rows from the TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 */	
	public void removeMultiple(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		this.tiposPlantillaDao.removeMultiple(filterTiposPlantilla, jqGridRequestDto, startsWith);
	}
        
	/**
	 * Filter method in the TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<TiposPlantilla>
	 */	
	public JQGridResponseDto< TiposPlantilla> filter(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto,  Boolean startsWith){
		List<TiposPlantilla> listaTiposPlantilla =  this.tiposPlantillaDao.findAllLike(filterTiposPlantilla, jqGridRequestDto, false);
		Long recordNum =  this.tiposPlantillaDao.findAllLikeCount(filterTiposPlantilla != null ? filterTiposPlantilla: new TiposPlantilla (),false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds()!=null){
			List< TableRowDto< TiposPlantilla>> reorderSelection = this.tiposPlantillaDao.reorderSelection(filterTiposPlantilla, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposPlantilla>(jqGridRequestDto, recordNum, listaTiposPlantilla, reorderSelection);
		}
		return new JQGridResponseDto<TiposPlantilla>(jqGridRequestDto, recordNum, listaTiposPlantilla);   
	}
    
    /**
	 * Searches rows in the TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param searchTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return List<TableRowDto<TiposPlantilla>>
	 */	
    public List< TableRowDto< TiposPlantilla>> search(TiposPlantilla filterTiposPlantilla, TiposPlantilla searchTiposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.tiposPlantillaDao.search(filterTiposPlantilla, searchTiposPlantilla, jqGridRequestDto, startsWith);
	}
    
    /**
	 * Reorder the selection made in TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return Object
	 */	
    public Object reorderSelection(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		return this.tiposPlantillaDao.reorderSelection(filterTiposPlantilla, jqGridRequestDto, startsWith);
	}
    
    /*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */
	 
	/**
	 * Finder method in the hierarchical the TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @param startsWith Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposPlantilla>>
	 */	
	public JQGridResponseDto<JerarquiaDto<TiposPlantilla>> jerarquia(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto, Boolean startsWith){
		List<JerarquiaDto<TiposPlantilla>> listaTiposPlantilla =  this.tiposPlantillaDao.findAllLikeJerarquia(filterTiposPlantilla, jqGridRequestDto);
		Long recordNum = this.tiposPlantillaDao.findAllLikeCountJerarquia(filterTiposPlantilla, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposPlantilla>>(jqGridRequestDto, recordNum, listaTiposPlantilla);
	}
	
	/**
	 * Finder method for siblings rows in the hierarchical the TiposPlantilla table.
	 *
	 * @param filterTiposPlantilla TiposPlantilla
	 * @param jqGridRequestDto JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposPlantilla>>
	 */	
	public JQGridResponseDto<JerarquiaDto<TiposPlantilla>> jerarquiaChildren(TiposPlantilla filterTiposPlantilla, JQGridRequestDto jqGridRequestDto){
		JQGridResponseDto<JerarquiaDto<TiposPlantilla>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposPlantilla>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN, this.tiposPlantillaDao.findAllChild(filterTiposPlantilla, jqGridRequestDto));
		return jqGridResponseDto;
	}
	
	
}

