package com.ejie.ab60.service.repartoAyuda;

import java.sql.Types;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.SqlInOutParameter;
import org.springframework.jdbc.core.SqlOutParameter;
import org.springframework.jdbc.core.SqlParameter;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.stereotype.Service;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;

import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.util.DBUtils;

@Service(value = "repartoAyudaService")
public class RepartoAyudaServiceImpl implements RepartoAyudaService {

	private JdbcTemplate jdbcTemplate;

	private static final Logger logger = LoggerFactory.getLogger(RepartoAyudaServiceImpl.class);

	@Autowired
	private ConvocatoriasService convocatoriasService;

	/**
	 * 
	 * Necesario para llamar al pl-sql
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource()
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/**
	 * llamamos al pl-sql para reparto de la ayuda
	 *
	 * @param Integer
	 *            idConvocatoria
	 * @return string outMessage
	 */

	public String repartoAyuda(Integer idConvocatoria, Integer idActSub) {
		Convocatorias convocatoria = new Convocatorias();
		RepartoAyudaServiceImpl.logger.info("Inicio reparto Ayuda");
		RepartoAyudaServiceImpl.logger.info("Convocatoria: " + idConvocatoria);

		/**********************************************************************
		 * SE INVOCA AL PL/SQL DE REPARTO
		 **********************************************************************/

		/**
		 * Primero obtenemos de la tabla configuracion el nombre del pl/sql de
		 * reparto y el id procedimiento
		 */
		convocatoria = convocatoriasService.findNombrePLSQLReparto(idConvocatoria);
		String nombrePlSqlReparto = convocatoria.getPlsqlReparto();
		RepartoAyudaServiceImpl.logger.info(" nombrePlSql: " + nombrePlSqlReparto);
		SqlParameter[] parameters = {

				new SqlInOutParameter("IN_ID_PROCEDIMIENTO", Types.VARCHAR),

				new SqlInOutParameter("IN_ID_ACT_SUB", Types.VARCHAR) };

		MapSqlParameterSource parameterSource = new MapSqlParameterSource();

		parameterSource.addValue("IN_ID_PROCEDIMIENTO", convocatoria.getIdProcedimiento());
		parameterSource.addValue("IN_ID_ACT_SUB", (idActSub == 0) ? null : idActSub);

		Map<String, Object> m = null;
		String mensage = "";
		try {
			m = DBUtils.callPLSQLRepartoAyuda(this.jdbcTemplate, nombrePlSqlReparto, parameters, parameterSource);
			mensage = Constantes.EXPEDIENTESVALIDADOSREPARTIDOSAYUDA;

		} catch (Exception e) {

			RepartoAyudaServiceImpl.logger.error("Error en el procesamiento del carga del reparto de ayuda:"
					+ convocatoria.getIdProcedimiento() + "-" + e.getMessage());
		}

		return mensage;
	}

}
