package com.ejie.ab60.service.terceros;

import com.ejie.ab60.model.terceros.DatosTerceros;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;

/**
 * DatosTercerosService  
 * 
 *  
 */

public interface DatosTercerosService {

	/**
	 * Inserts a single row in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	DatosTerceros add(DatosTerceros datosTerceros);

	/**
	 * Finds el ultimo id de la tabla in the DatosTerceros table.
	 *
	 * 
	 * @return datosTerceros Datosterceros
	 */
	DatosTerceros findUltimoId();

	/**
	 * Updates a single row in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	DatosTerceros update(DatosTerceros datosTerceros);

	/**
	 * Deletes a single row in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 */
	void remove(Integer idTercero);

	/**
	 * Finds a list of rows in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<DatosTerceros>
	 */
	List<DatosTerceros> findAll(DatosTerceros datosTerceros, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the DatosTerceros table using like.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<DatosTerceros>
	 */
	List<DatosTerceros> findAllLike(DatosTerceros datosTerceros, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<DatosTerceros>
	 */
	JQGridResponseDto<DatosTerceros> filter(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches rows in the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param searchDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosTerceros>>
	 */
	List<TableRowDto<DatosTerceros>> search(DatosTerceros filterDatosTerceros, DatosTerceros searchDatosTerceros,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<DatosTerceros>>
	 */
	JQGridResponseDto<JerarquiaDto<DatosTerceros>> jerarquia(DatosTerceros filterDatosTerceros,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Finder method for siblings rows in the hierarchical the DatosTerceros
	 * table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<DatosTerceros>>
	 */
	JQGridResponseDto<JerarquiaDto<DatosTerceros>> jerarquiaChildren(DatosTerceros filterDatosTerceros,
			JQGridRequestDto jqGridRequestDto);

	List<DatosTerceros> findTitularExpediente(Integer idExpediente);

}
