package com.ejie.ab60.service.terceros;

import com.ejie.ab60.dao.terceros.DatosTercerosDao;

import com.ejie.ab60.model.terceros.DatosTerceros;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * DatosTercerosServiceImpl  
 * 
 *  
 */

@Service(value = "datosTercerosService")
public class DatosTercerosServiceImpl implements DatosTercerosService {

	@Autowired
	private DatosTercerosDao datosTercerosDao;

	/**
	 * Inserts a single row in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	@Transactional(rollbackFor = Throwable.class)
	public DatosTerceros add(DatosTerceros datosTerceros) {
		return this.datosTercerosDao.add(datosTerceros);
	}

	/**
	 * Finds el ultimo id de la tabla in the DatosTerceros table.
	 *
	 * 
	 * @return datosTerceros Datosterceros
	 */
	public DatosTerceros findUltimoId() {
		return this.datosTercerosDao.findUltimoId();
	}

	/**
	 * Updates a single row in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	@Transactional(rollbackFor = Throwable.class)
	public DatosTerceros update(DatosTerceros datosTerceros) {
		return this.datosTercerosDao.update(datosTerceros);
	}

	/**
	 * Deletes a single row in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Integer idTercero) {
		this.datosTercerosDao.remove(idTercero);
	}

	/**
	 * Finds a list of rows in the DatosTerceros table.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<DatosTerceros>
	 */
	public List<DatosTerceros> findAll(DatosTerceros datosTerceros, JQGridRequestDto jqGridRequestDto) {
		return (List<DatosTerceros>) this.datosTercerosDao.findAll(datosTerceros, jqGridRequestDto);
	}

	/**
	 * Finds rows in the DatosTerceros table using like.
	 *
	 * @param datosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<DatosTerceros>
	 */
	public List<DatosTerceros> findAllLike(DatosTerceros datosTerceros, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<DatosTerceros>) this.datosTercerosDao.findAllLike(datosTerceros, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.datosTercerosDao.removeMultiple(filterDatosTerceros, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<DatosTerceros>
	 */
	public JQGridResponseDto<DatosTerceros> filter(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		List<DatosTerceros> listaDatosTerceros = this.datosTercerosDao.findAllLike(filterDatosTerceros,
				jqGridRequestDto, false);
		Long recordNum = this.datosTercerosDao
				.findAllLikeCount(filterDatosTerceros != null ? filterDatosTerceros : new DatosTerceros(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<DatosTerceros>> reorderSelection = this.datosTercerosDao
					.reorderSelection(filterDatosTerceros, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<DatosTerceros>(jqGridRequestDto, recordNum, listaDatosTerceros,
					reorderSelection);
		}
		return new JQGridResponseDto<DatosTerceros>(jqGridRequestDto, recordNum, listaDatosTerceros);
	}

	/**
	 * Searches rows in the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param searchDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosTerceros>>
	 */
	public List<TableRowDto<DatosTerceros>> search(DatosTerceros filterDatosTerceros, DatosTerceros searchDatosTerceros,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.datosTercerosDao.search(filterDatosTerceros, searchDatosTerceros, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.datosTercerosDao.reorderSelection(filterDatosTerceros, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<DatosTerceros>>
	 */
	public JQGridResponseDto<JerarquiaDto<DatosTerceros>> jerarquia(DatosTerceros filterDatosTerceros,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<DatosTerceros>> listaDatosTerceros = this.datosTercerosDao
				.findAllLikeJerarquia(filterDatosTerceros, jqGridRequestDto);
		Long recordNum = this.datosTercerosDao.findAllLikeCountJerarquia(filterDatosTerceros, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<DatosTerceros>>(jqGridRequestDto, recordNum, listaDatosTerceros);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the DatosTerceros
	 * table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<DatosTerceros>>
	 */
	public JQGridResponseDto<JerarquiaDto<DatosTerceros>> jerarquiaChildren(DatosTerceros filterDatosTerceros,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<DatosTerceros>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<DatosTerceros>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.datosTercerosDao.findAllChild(filterDatosTerceros, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public List<DatosTerceros> findTitularExpediente(Integer idExpediente) {
		return this.datosTercerosDao.findTitularExpediente(idExpediente);
	}

}
