package com.ejie.ab60.service.terceros;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.PathVariable;

import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderList;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.terceros.RelExpTer;
import com.ejie.ab60.model.terceros.VistaDatosExpediente;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpTerService  
 * 
 *  
 */

public interface RelExpTerService {

	/**
	 * Inserts a single row in the RelExpTer table.
	 *
	 * @param relExpTer
	 *            RelExpTer
	 * @return RelExpTer
	 */
	RelExpTer add(RelExpTer relExpTer);

	/**
	 * Updates a single row in the RelExpTer table.
	 *
	 * @param relExpTer
	 *            RelExpTer
	 * @return RelExpTer
	 */
	RelExpTer update(RelExpTer relExpTer);

	/**
	 * Finds a single row in the RelExpTer table.
	 *
	 * @param relExpTer
	 *            RelExpTer
	 * @return RelExpTer
	 */
	RelExpTer find(RelExpTer relExpTer);

	/**
	 * Deletes a single row in the RelExpTer table.
	 *
	 * @param relExpTer
	 *            RelExpTer
	 */
	void remove(RelExpTer relExpTer);

	/**
	 * Finds a list of rows in the RelExpTer table.
	 *
	 * @param relExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpTer>
	 */
	List<RelExpTer> findAll(RelExpTer relExpTer, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the RelExpTer table using like.
	 *
	 * @param relExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpTer>
	 */
	List<RelExpTer> findAllLike(RelExpTer relExpTer, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Obtener lista de participantes de la participacion
	 *
	 * @param resultado
	 *            TFolderList
	 * @param idExpediente
	 *            Integer
	 * @param usuario
	 *            Usuario
	 */
	void actualizarListParticipantesPorParticipacion(TFolderList resultado, Integer idExpediente, Usuario usuario,
			InitForm datosTramitagune);

	/**
	 * Obtener lista de participaciones
	 *
	 * 
	 * 
	 * @param idExpediente
	 *            Integer
	 * @param todosParticipantes
	 *            Boolean
	 * 
	 * @return List<VistaTerceros>
	 * 
	 */
	List<VistaDatosExpediente> findParticipaciones(Integer idExpediente, Boolean todosParticipantes);

	/**
	 * Guardar ubicacion y direccion del solicitante y si es bec tambien la
	 * puntacuion
	 *
	 * @param relExpTerEmp
	 *            RelExpTerEmp Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelExpTerEmp Bean resultante del proceso de creacion.
	 */
	void addDomicilioUbicacionSolicitante(HttpServletRequest request, Model model, Usuario usuario,
			@PathVariable("idTercero") Integer idTercero);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the RelExpTer table.
	 *
	 * @param filterRelExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(RelExpTer filterRelExpTer, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the RelExpTer table.
	 *
	 * @param filterRelExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<RelExpTer>
	 */
	JQGridResponseDto<RelExpTer> filter(RelExpTer filterRelExpTer, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches rows in the RelExpTer table.
	 *
	 * @param filterRelExpTer
	 *            RelExpTer
	 * @param searchRelExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpTer>>
	 */
	List<TableRowDto<RelExpTer>> search(RelExpTer filterRelExpTer, RelExpTer searchRelExpTer,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in RelExpTer table.
	 *
	 * @param filterRelExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(RelExpTer filterRelExpTer, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method for siblings rows in the hierarchical the RelExpTer table.
	 *
	 * @param filterRelExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<RelExpTer>>
	 */
	JQGridResponseDto<JerarquiaDto<RelExpTer>> jerarquiaChildren(RelExpTer filterRelExpTer,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds lista de participantes de la tabla RelExpTer
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @param todosParticipantes
	 *            Boolean
	 * 
	 * @return RelExpTer
	 */
	List<RelExpTer> findParticipantes(Integer idExpediente, Boolean todosParticipantes);
}
