package com.ejie.ab60.service.terceros;

import com.ejie.ab60.dao.terceros.TiposDocumentoDao;
import com.ejie.ab60.model.terceros.TiposDocumento;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * TiposDocumentoServiceImpl  
 * 
 *  
 */

@Service(value = "tiposDocumentoService")
public class TiposDocumentoServiceImpl implements TiposDocumentoService {

	@Autowired
	private TiposDocumentoDao tiposDocumentoDao;

	/**
	 * Inserts a single row in the TiposDocumento table.
	 *
	 * @param tiposDocumento
	 *            TiposDocumento
	 * @return TiposDocumento
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposDocumento add(TiposDocumento tiposDocumento) {
		return this.tiposDocumentoDao.add(tiposDocumento);
	}

	/**
	 * Updates a single row in the TiposDocumento table.
	 *
	 * @param tiposDocumento
	 *            TiposDocumento
	 * @return TiposDocumento
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposDocumento update(TiposDocumento tiposDocumento) {
		return this.tiposDocumentoDao.update(tiposDocumento);
	}

	/**
	 * Finds a single row in the TiposDocumento table.
	 *
	 * @param tiposDocumento
	 *            TiposDocumento
	 * @return TiposDocumento
	 */
	public TiposDocumento find(TiposDocumento tiposDocumento) {
		return (TiposDocumento) this.tiposDocumentoDao.find(tiposDocumento);
	}

	/**
	 * Deletes a single row in the TiposDocumento table.
	 *
	 * @param tiposDocumento
	 *            TiposDocumento
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposDocumento tiposDocumento) {
		this.tiposDocumentoDao.remove(tiposDocumento);
	}

	/**
	 * Finds a list of rows in the TiposDocumento table.
	 *
	 * @param tiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposDocumento>
	 */
	public List<TiposDocumento> findAll(TiposDocumento tiposDocumento, JQGridRequestDto jqGridRequestDto) {
		return (List<TiposDocumento>) this.tiposDocumentoDao.findAll(tiposDocumento, jqGridRequestDto);
	}

	/**
	 * Finds rows in the TiposDocumento table using like.
	 *
	 * @param tiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposDocumento>
	 */
	public List<TiposDocumento> findAllLike(TiposDocumento tiposDocumento, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<TiposDocumento>) this.tiposDocumentoDao.findAllLike(tiposDocumento, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the TiposDocumento table.
	 *
	 * @param filterTiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TiposDocumento filterTiposDocumento, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.tiposDocumentoDao.removeMultiple(filterTiposDocumento, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the TiposDocumento table.
	 *
	 * @param filterTiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<TiposDocumento>
	 */
	public JQGridResponseDto<TiposDocumento> filter(TiposDocumento filterTiposDocumento,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<TiposDocumento> listaTiposDocumento = this.tiposDocumentoDao.findAllLike(filterTiposDocumento,
				jqGridRequestDto, false);
		Long recordNum = this.tiposDocumentoDao
				.findAllLikeCount(filterTiposDocumento != null ? filterTiposDocumento : new TiposDocumento(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TiposDocumento>> reorderSelection = this.tiposDocumentoDao
					.reorderSelection(filterTiposDocumento, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposDocumento>(jqGridRequestDto, recordNum, listaTiposDocumento,
					reorderSelection);
		}
		return new JQGridResponseDto<TiposDocumento>(jqGridRequestDto, recordNum, listaTiposDocumento);
	}

	/**
	 * Searches rows in the TiposDocumento table.
	 *
	 * @param filterTiposDocumento
	 *            TiposDocumento
	 * @param searchTiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposDocumento>>
	 */
	public List<TableRowDto<TiposDocumento>> search(TiposDocumento filterTiposDocumento,
			TiposDocumento searchTiposDocumento, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposDocumentoDao.search(filterTiposDocumento, searchTiposDocumento, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in TiposDocumento table.
	 *
	 * @param filterTiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TiposDocumento filterTiposDocumento, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.tiposDocumentoDao.reorderSelection(filterTiposDocumento, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the TiposDocumento table.
	 *
	 * @param filterTiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposDocumento>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposDocumento>> jerarquia(TiposDocumento filterTiposDocumento,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TiposDocumento>> listaTiposDocumento = this.tiposDocumentoDao
				.findAllLikeJerarquia(filterTiposDocumento, jqGridRequestDto);
		Long recordNum = this.tiposDocumentoDao.findAllLikeCountJerarquia(filterTiposDocumento, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposDocumento>>(jqGridRequestDto, recordNum, listaTiposDocumento);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the TiposDocumento
	 * table.
	 *
	 * @param filterTiposDocumento
	 *            TiposDocumento
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposDocumento>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposDocumento>> jerarquiaChildren(TiposDocumento filterTiposDocumento,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TiposDocumento>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposDocumento>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.tiposDocumentoDao.findAllChild(filterTiposDocumento, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
