package com.ejie.ab60.control.BEC;

import com.ejie.ab60.model.BEC.Caracteristicas;
import com.ejie.ab60.service.BEC.CaracteristicasService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * CaracteristicasController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/caracteristicas")

public class CaracteristicasController {

	private static final Logger logger = LoggerFactory.getLogger(CaracteristicasController.class);

	@Autowired
	private CaracteristicasService caracteristicasService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idCaracteristica
	 *            Long
	 * @return Caracteristicas Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idCaracteristica}", method = RequestMethod.GET)
	public @ResponseBody Caracteristicas get(@PathVariable Long idCaracteristica) {
		Caracteristicas caracteristicas = new Caracteristicas();
		caracteristicas.setIdCaracteristica(idCaracteristica);
		caracteristicas = this.caracteristicasService.find(caracteristicas);
		CaracteristicasController.logger.info("[GET - findBy_PK] : Obtener Caracteristicas por PK");
		return caracteristicas;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterCaracteristicas
	 *            Caracteristicas Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Caracteristicas> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Caracteristicas> getAll(@ModelAttribute Caracteristicas filterCaracteristicas) {
		CaracteristicasController.logger.info("[GET - find_ALL] : Obtener Caracteristicas por filtro");
		return this.caracteristicasService.findAll(filterCaracteristicas, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param caracteristicas
	 *            Caracteristicas Bean que contiene la informacion a modificar.
	 * @return Caracteristicas Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Caracteristicas edit(@RequestBody Caracteristicas caracteristicas) {
		Caracteristicas caracteristicasAux = this.caracteristicasService.update(caracteristicas);
		CaracteristicasController.logger.info("[PUT] : Caracteristicas actualizado correctamente");
		return caracteristicasAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param caracteristicas
	 *            Caracteristicas Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return Caracteristicas Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Caracteristicas add(@RequestBody Caracteristicas caracteristicas) {
		Caracteristicas caracteristicasAux = this.caracteristicasService.add(caracteristicas);
		CaracteristicasController.logger.info("[POST] : Caracteristicas insertado correctamente");
		return caracteristicasAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idCaracteristica
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return Caracteristicas Bean eliminado.
	 */
	@RequestMapping(value = "/{idCaracteristica}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Caracteristicas remove(@PathVariable Long idCaracteristica) {
		Caracteristicas caracteristicas = new Caracteristicas();
		caracteristicas.setIdCaracteristica(idCaracteristica);
		this.caracteristicasService.remove(caracteristicas);
		CaracteristicasController.logger.info("[DELETE] : Caracteristicas borrado correctamente");
		return caracteristicas;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		CaracteristicasController.logger.info("[GET - View] : caracteristicas");
		return "caracteristicas";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterCaracteristicas
	 *            Caracteristicas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Caracteristicas> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Caracteristicas> filter(
			@RequestJsonBody(param = "filter") Caracteristicas filterCaracteristicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CaracteristicasController.logger.info("[POST - filter] : Obtener Caracteristicass");
		return this.caracteristicasService.filter(filterCaracteristicas, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterCaracteristicas
	 *            Caracteristicas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchCaracteristicas
	 *            Caracteristicas Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Caracteristicas> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Caracteristicas>> search(
			@RequestJsonBody(param = "filter") Caracteristicas filterCaracteristicas,
			@RequestJsonBody(param = "search") Caracteristicas searchCaracteristicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CaracteristicasController.logger.info("[POST - search] : Buscar Caracteristicass");
		return this.caracteristicasService.search(filterCaracteristicas, searchCaracteristicas, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterCaracteristicas
	 *            Caracteristicas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") Caracteristicas filterCaracteristicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CaracteristicasController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Caracteristicass");
		this.caracteristicasService.removeMultiple(filterCaracteristicas, jqGridRequestDto, false);
		CaracteristicasController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterCaracteristicas
	 *            Caracteristicas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Caracteristicas>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Caracteristicas>> jerarquia(
			@RequestJsonBody(param = "filter") Caracteristicas filterCaracteristicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CaracteristicasController.logger.info("[POST - jerarquia] : Obtener Caracteristicass jerarquia");
		return this.caracteristicasService.jerarquia(filterCaracteristicas, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterCaracteristicas
	 *            Caracteristicas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Caracteristicas>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Caracteristicas>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Caracteristicas filterCaracteristicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CaracteristicasController.logger.info("[POST - jerarquia] : Obtener Caracteristicass jerarquia - Hijos");
		return this.caracteristicasService.jerarquiaChildren(filterCaracteristicas, jqGridRequestDto);
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<Caracteristicas> init(@PathVariable Integer idConvocatoria) {
		CaracteristicasController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		Caracteristicas caracteristicas = new Caracteristicas();
		caracteristicas.setIdConvocatoria(idConvocatoria);
		return this.caracteristicasService.findAll(caracteristicas, null);

	}

}
