package com.ejie.ab60.control.BEC;

import java.util.List;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.ab60.model.criteriosPuntuacion.RelExpCriPun;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.BEC.CurriculumService;
import com.ejie.ab60.service.BEC.PuntuacionesService;
import com.ejie.ab60.service.calculoAyuda.CalculoAyudaService;
import com.ejie.ab60.service.criteriosPuntuacion.CriteriosPuntuacionService;
import com.ejie.ab60.service.criteriosPuntuacion.RelExpCriPunService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * CurriculumController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/curriculum")

public class CurriculumController {

	private static final Logger logger = LoggerFactory.getLogger(CurriculumController.class);

	@Autowired
	private CurriculumService curriculumService;

	@Autowired
	private PuntuacionesService puntuacionesService;

	@Autowired
	private RelExpCriPunService relExpCriPunService;

	@Autowired
	private CriteriosPuntuacionService criteriosPuntuacionService;

	@Autowired
	private CalculoAyudaService calculoAyudaService;

	@Autowired
	private ProcedimientosService procedimientosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idCurriculum
	 *            Integer
	 * @return Curriculum Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idCurriculum}", method = RequestMethod.GET)
	public @ResponseBody Curriculum get(@PathVariable Integer idCurriculum) {
		Curriculum curriculum = new Curriculum();
		curriculum.setIdCurriculum(idCurriculum);
		curriculum = this.curriculumService.find(curriculum);
		CurriculumController.logger.info("[GET - findBy_PK] : Obtener Curriculum por PK");
		return curriculum;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterCurriculum
	 *            Curriculum Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Curriculum> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Curriculum> getAll(@ModelAttribute Curriculum filterCurriculum) {
		CurriculumController.logger.info("[GET - find_ALL] : Obtener Curriculum por filtro");
		return this.curriculumService.findAll(filterCurriculum, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param curriculum
	 *            Curriculum Bean que contiene la informacion a modificar.
	 * @return Curriculum Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Curriculum edit(@RequestBody Curriculum curriculum) {
		Curriculum curriculumAux = this.curriculumService.update(curriculum);
		CurriculumController.logger.info("[PUT] : Curriculum actualizado correctamente");
		return curriculumAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param curriculum
	 *            Curriculum Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Curriculum Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Curriculum add(@RequestBody Curriculum curriculum) {
		Curriculum curriculumAux = this.curriculumService.add(curriculum);
		CurriculumController.logger.info("[POST] : Curriculum insertado correctamente");
		return curriculumAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idCurriculum
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Curriculum Bean eliminado.
	 */
	@RequestMapping(value = "/{idCurriculum}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Curriculum remove(@PathVariable Integer idCurriculum) {
		Curriculum curriculum = new Curriculum();
		curriculum.setIdCurriculum(idCurriculum);
		this.curriculumService.remove(curriculum);
		CurriculumController.logger.info("[DELETE] : Curriculum borrado correctamente");
		return curriculum;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * @param model
	 *            Model
	 * @param usuario
	 *            Usuario
	 * 
	 * @return ModelAndView
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public ModelAndView mostrar(Model model, Curriculum curriculum,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();
		Integer idExpediente = initForm.getIdExpediente();
		String idioma = LocaleContextHolder.getLocale().getLanguage();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}
		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);
		model.addAttribute("lenguaje", idioma);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		Puntuaciones puntuaciones = new Puntuaciones();
		puntuaciones.setIdExpediente(initForm.getIdExpediente());
		try {
			puntuaciones = puntuacionesService.findAll(puntuaciones, null).get(0);
		} catch (Exception e) {
			CurriculumController.logger.info("[mostrar] : la puntuacion no existe");
		}

		List<RelExpCriPun> relExpCriPunList = relExpCriPunService.findIdsCriterio(idExpediente);
		if (null != relExpCriPunList && !relExpCriPunList.isEmpty()) {
			model.addAttribute("listaIdsCriterios", relExpCriPunList);
		}
		List<CriteriosPuntuacion> lcriterios = criteriosPuntuacionService.findTextoCriterioBEC(idConvocatoria);
		model.addAttribute("listaCriterios", lcriterios);

		Curriculum datosCurriculum = new Curriculum();
		datosCurriculum.setIdExpediente(initForm.getIdExpediente());
		datosCurriculum = curriculumService.findAll(datosCurriculum, null).get(0);
		datosCurriculum.setPuntuaciones(puntuaciones);

		model.addAttribute("curriculum", datosCurriculum);

		return new ModelAndView("curriculum", "model", model);

	}

	/**
	 * save
	 * 
	 * @param idExpediente
	 * @param curriculum
	 * @param usuario
	 * @return
	 */
	@RequestMapping(value = "/save/{idExpediente}", method = RequestMethod.POST)
	public @ResponseBody() Curriculum save(@PathVariable Integer idExpediente, @RequestBody() Curriculum curriculum,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		return curriculumService.save(idExpediente, curriculum, usuario);

	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		CurriculumController.logger.info("[GET - View] : curriculum");
		Curriculum curriculum = new Curriculum();
		model.addAttribute("curriculum", curriculum);
		return "curriculum";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterCurriculum
	 *            Curriculum Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Curriculum> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Curriculum> filter(
			@RequestJsonBody(param = "filter") Curriculum filterCurriculum,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CurriculumController.logger.info("[POST - filter] : Obtener Curriculums");
		return this.curriculumService.filter(filterCurriculum, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterCurriculum
	 *            Curriculum Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchCurriculum
	 *            Curriculum Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Curriculum> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Curriculum>> search(
			@RequestJsonBody(param = "filter") Curriculum filterCurriculum,
			@RequestJsonBody(param = "search") Curriculum searchCurriculum,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CurriculumController.logger.info("[POST - search] : Buscar Curriculums");
		return this.curriculumService.search(filterCurriculum, searchCurriculum, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterCurriculum
	 *            Curriculum Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Curriculum filterCurriculum,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CurriculumController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Curriculums");
		this.curriculumService.removeMultiple(filterCurriculum, jqGridRequestDto, false);
		CurriculumController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterCurriculum
	 *            Curriculum Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Curriculum>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Curriculum>> jerarquia(
			@RequestJsonBody(param = "filter") Curriculum filterCurriculum,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CurriculumController.logger.info("[POST - jerarquia] : Obtener Curriculums jerarquia");
		return this.curriculumService.jerarquia(filterCurriculum, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterCurriculum
	 *            Curriculum Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Curriculum>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Curriculum>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Curriculum filterCurriculum,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CurriculumController.logger.info("[POST - jerarquia] : Obtener Curriculums jerarquia - Hijos");
		return this.curriculumService.jerarquiaChildren(filterCurriculum, jqGridRequestDto);
	}

	/**
	 * Metodo que llama al pl-sql de calcular ayuda
	 *
	 * 
	 * @param idConvocatoria
	 * 
	 * @param idExpediente
	 * @return Msg
	 */
	@RequestMapping(value = "/llamarPLSQL/{idConvocatoria}/{idExpediente}", method = RequestMethod.GET)
	public @ResponseBody() String calcularAyuda(@PathVariable Integer idConvocatoria,
			@PathVariable Integer idExpediente) {

		CurriculumController.logger.info("[GET - llamarPLSQL] : Obtener PL DE AYUDA");
		int inFase = 1;
		String msg = calculoAyudaService.calculoAyuda(idConvocatoria, idExpediente, inFase);
		return msg;

	}
}
