package com.ejie.ab60.control.BEC;

import com.ejie.ab60.model.BEC.Fases;
import com.ejie.ab60.service.BEC.FasesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * FasesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/fases")

public class FasesController {

	private static final Logger logger = LoggerFactory.getLogger(FasesController.class);

	@Autowired
	private FasesService fasesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Metodo que nos trae la lista para cargar el combo de fase
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo", method = RequestMethod.GET)
	public @ResponseBody List<Fases> init() {
		FasesController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.fasesService.findFases();

	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idFase
	 *            Long
	 * @return Fases Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFase}", method = RequestMethod.GET)
	public @ResponseBody Fases get(@PathVariable Long idFase) {
		Fases fases = new Fases();
		fases.setIdFase(idFase);
		fases = this.fasesService.find(fases);
		FasesController.logger.info("[GET - findBy_PK] : Obtener Fases por PK");
		return fases;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterFases
	 *            Fases Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Fases> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Fases> getAll(@ModelAttribute Fases filterFases) {
		FasesController.logger.info("[GET - find_ALL] : Obtener Fases por filtro");
		return this.fasesService.findAll(filterFases, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param fases
	 *            Fases Bean que contiene la informacion a modificar.
	 * @return Fases Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Fases edit(@RequestBody Fases fases) {
		Fases fasesAux = this.fasesService.update(fases);
		FasesController.logger.info("[PUT] : Fases actualizado correctamente");
		return fasesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param fases
	 *            Fases Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Fases Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Fases add(@RequestBody Fases fases) {
		Fases fasesAux = this.fasesService.add(fases);
		FasesController.logger.info("[POST] : Fases insertado correctamente");
		return fasesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idFase
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return Fases Bean eliminado.
	 */
	@RequestMapping(value = "/{idFase}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Fases remove(@PathVariable Long idFase) {
		Fases fases = new Fases();
		fases.setIdFase(idFase);
		this.fasesService.remove(fases);
		FasesController.logger.info("[DELETE] : Fases borrado correctamente");
		return fases;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		FasesController.logger.info("[GET - View] : fases");
		return "fases";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterFases
	 *            Fases Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Fases> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Fases> filter(@RequestJsonBody(param = "filter") Fases filterFases,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FasesController.logger.info("[POST - filter] : Obtener Fasess");
		return this.fasesService.filter(filterFases, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterFases
	 *            Fases Bean que contiene los parametros de filtrado a emplear.
	 * @param searchFases
	 *            Fases Bean que contiene los parametros de busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Fases> Dto que contiene el resultado de la busqueda
	 *         realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Fases>> search(@RequestJsonBody(param = "filter") Fases filterFases,
			@RequestJsonBody(param = "search") Fases searchFases, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FasesController.logger.info("[POST - search] : Buscar Fasess");
		return this.fasesService.search(filterFases, searchFases, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterFases
	 *            Fases Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Fases filterFases,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FasesController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Fasess");
		this.fasesService.removeMultiple(filterFases, jqGridRequestDto, false);
		FasesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterFases
	 *            Fases Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Fases>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Fases>> jerarquia(
			@RequestJsonBody(param = "filter") Fases filterFases, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FasesController.logger.info("[POST - jerarquia] : Obtener Fasess jerarquia");
		return this.fasesService.jerarquia(filterFases, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterFases
	 *            Fases Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Fases>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Fases>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Fases filterFases, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FasesController.logger.info("[POST - jerarquia] : Obtener Fasess jerarquia - Hijos");
		return this.fasesService.jerarquiaChildren(filterFases, jqGridRequestDto);
	}

}
