package com.ejie.ab60.control.BEC;

import com.ejie.ab60.model.BEC.Curriculum;
import com.ejie.ab60.model.BEC.OtrosTitulos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.BEC.OtrosTitulosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

import java.util.Date;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

/**
 * OtrosTitulosController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/otrostitulos")

public class OtrosTitulosController {

	private static final Logger logger = LoggerFactory.getLogger(OtrosTitulosController.class);

	@Autowired
	private OtrosTitulosService otrosTitulosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTituloCurso
	 *            Integer
	 * @return OtrosTitulos Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idCurriculum}/{idTituloCurso}", method = RequestMethod.GET)
	public @ResponseBody OtrosTitulos get(@PathVariable Integer idTituloCurso) {
		OtrosTitulos otrosTitulos = new OtrosTitulos();
		otrosTitulos.setIdTituloCurso(idTituloCurso);
		otrosTitulos = this.otrosTitulosService.find(otrosTitulos);
		OtrosTitulosController.logger.info("[GET - findBy_PK] : Obtener OtrosTitulos por PK");
		return otrosTitulos;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterOtrosTitulos
	 *            OtrosTitulos Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<OtrosTitulos> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<OtrosTitulos> getAll(@ModelAttribute OtrosTitulos filterOtrosTitulos) {
		OtrosTitulosController.logger.info("[GET - find_ALL] : Obtener OtrosTitulos por filtro");
		return this.otrosTitulosService.findAll(filterOtrosTitulos, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param otrosTitulos
	 *            OtrosTitulos Bean que contiene la informacion a modificar.
	 * @return OtrosTitulos Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/{idCurriculum}", method = RequestMethod.PUT)
	public @ResponseBody OtrosTitulos edit(@RequestBody OtrosTitulos otrosTitulos,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		otrosTitulos.setFechaUltmodificacion(new Date());
		otrosTitulos.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		OtrosTitulos otrosTitulosAux = this.otrosTitulosService.update(otrosTitulos);
		OtrosTitulosController.logger.info("[PUT] : OtrosTitulos actualizado correctamente");
		return otrosTitulosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param otrosTitulos
	 *            OtrosTitulos Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return OtrosTitulos Bean resultante del proceso de creacion.
	 */
	@RequestMapping(value = "/{idCurriculum}", method = RequestMethod.POST)
	public @ResponseBody OtrosTitulos add(@RequestBody OtrosTitulos otrosTitulos,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		otrosTitulos.setFechaRegistro(new Date());
		otrosTitulos.setUsuarioRegistro(usuario.getNombreUsuario());
		OtrosTitulos otrosTitulosAux = this.otrosTitulosService.add(otrosTitulos);
		OtrosTitulosController.logger.info("[POST] : OtrosTitulos insertado correctamente");
		return otrosTitulosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTituloCurso
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return OtrosTitulos Bean eliminado.
	 */
	@RequestMapping(value = "/{idCurriculum}/{idTituloCurso}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody OtrosTitulos remove(@PathVariable Integer idTituloCurso) {
		OtrosTitulos otrosTitulos = new OtrosTitulos();
		otrosTitulos.setIdTituloCurso(idTituloCurso);
		this.otrosTitulosService.remove(otrosTitulos);
		OtrosTitulosController.logger.info("[DELETE] : OtrosTitulos borrado correctamente");
		return otrosTitulos;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		OtrosTitulosController.logger.info("[GET - View] : otrostitulos");
		return "otrostitulos";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterOtrosTitulos
	 *            OtrosTitulos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<OtrosTitulos> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/{idCurriculum}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<OtrosTitulos> filter(@PathVariable Integer idCurriculum,
			@RequestJsonBody(param = "filter") OtrosTitulos filterOtrosTitulos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		filterOtrosTitulos.setCurriculum(new Curriculum(idCurriculum));
		OtrosTitulosController.logger.info("[POST - filter] : Obtener OtrosTituloss");
		return this.otrosTitulosService.filter(filterOtrosTitulos, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterOtrosTitulos
	 *            OtrosTitulos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchOtrosTitulos
	 *            OtrosTitulos Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<OtrosTitulos> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<OtrosTitulos>> search(
			@RequestJsonBody(param = "filter") OtrosTitulos filterOtrosTitulos,
			@RequestJsonBody(param = "search") OtrosTitulos searchOtrosTitulos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrosTitulosController.logger.info("[POST - search] : Buscar OtrosTituloss");
		return this.otrosTitulosService.search(filterOtrosTitulos, searchOtrosTitulos, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterOtrosTitulos
	 *            OtrosTitulos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") OtrosTitulos filterOtrosTitulos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrosTitulosController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples OtrosTituloss");
		this.otrosTitulosService.removeMultiple(filterOtrosTitulos, jqGridRequestDto, false);
		OtrosTitulosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterOtrosTitulos
	 *            OtrosTitulos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<OtrosTitulos>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OtrosTitulos>> jerarquia(
			@RequestJsonBody(param = "filter") OtrosTitulos filterOtrosTitulos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrosTitulosController.logger.info("[POST - jerarquia] : Obtener OtrosTituloss jerarquia");
		return this.otrosTitulosService.jerarquia(filterOtrosTitulos, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterOtrosTitulos
	 *            OtrosTitulos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<OtrosTitulos>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OtrosTitulos>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") OtrosTitulos filterOtrosTitulos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrosTitulosController.logger.info("[POST - jerarquia] : Obtener OtrosTituloss jerarquia - Hijos");
		return this.otrosTitulosService.jerarquiaChildren(filterOtrosTitulos, jqGridRequestDto);
	}

}
