package com.ejie.ab60.control.BEC;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.pagos.PagosExpediente;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.BEC.PuntuacionesService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import com.ejie.x38.reports.ReportData;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;

/**
 * PuntuacionesController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/puntuaciones")

public class PuntuacionesController {

	private static final Logger logger = LoggerFactory.getLogger(PuntuacionesController.class);

	@Autowired
	private PuntuacionesService puntuacionesService;

	@Autowired
	private ConvocatoriasService convocatoriasService;

	@Autowired
	private ReloadableResourceBundleMessageSource appMessageSource;

	@Autowired
	private ProcedimientosService procedimientosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idPuntuacion
	 *            Integer
	 * @return Puntuaciones Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idPuntuacion}", method = RequestMethod.GET)
	public @ResponseBody Puntuaciones get(@PathVariable Integer idPuntuacion) {
		Puntuaciones puntuaciones = new Puntuaciones();
		puntuaciones.setIdPuntuacion(idPuntuacion);
		puntuaciones = this.puntuacionesService.find(puntuaciones);
		PuntuacionesController.logger.info("[GET - findBy_PK] : Obtener Puntuaciones por PK");
		return puntuaciones;
	}

	/**
	 * 
	 * @param model
	 * @param puntuaciones
	 * @param initForm
	 * @return
	 */
	@RequestMapping(value = "/conocimientos", method = RequestMethod.POST)
	public ModelAndView mostrarconocimientos(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		Puntuaciones puntuacionesAux = new Puntuaciones();
		puntuaciones.setIdExpediente(initForm.getIdExpediente());
		try {
			puntuacionesAux = puntuacionesService.findConocimientos(puntuaciones);
			if (null == puntuacionesAux) {
				puntuacionesAux = new Puntuaciones();
			}
			model.addAttribute("puntuacionesConocimientos", puntuacionesAux);
		} catch (Exception e) {
			PuntuacionesController.logger.info("[mostrar] : la puntuacion no existe");
		}

		return new ModelAndView("conocimientos");

	}

	/**
	 * saveconocimientos
	 * 
	 * @param idExpediente
	 * @param puntuaciones
	 * @param usuario
	 * @return
	 */
	@RequestMapping(value = "/conocimientos/save/{idExpediente}", method = RequestMethod.POST)
	public @ResponseBody() Puntuaciones saveconocimientos(@PathVariable Integer idExpediente,
			@RequestBody() Puntuaciones puntuaciones, @ModelAttribute(value = "usuario") Usuario usuario) {
		PuntuacionesController.logger.info("[save] : entro a save");
		puntuaciones.setIdExpediente(idExpediente);

		puntuaciones.setFechaRegistro(new Date());
		puntuaciones.setFechaUltmodificacion(new Date());
		puntuaciones.setUsuarioRegistro(usuario.getNombreUsuario());
		puntuaciones.setUsuarioUltmodificacion(usuario.getNombreUsuario());

		// puntuacionesService.updateConocimientos(puntuaciones);

		puntuacionesService.addOrUpdateConocimientos(puntuaciones);
		return puntuaciones;

	}

	/**
	 * savecurso
	 * 
	 * @param idExpediente
	 * @param puntuaciones
	 * @param usuario
	 * @return
	 */
	@RequestMapping(value = "/curso/save/{idExpediente}", method = RequestMethod.POST)
	public @ResponseBody() Puntuaciones savecurso(@PathVariable Integer idExpediente,
			@RequestBody() Puntuaciones puntuaciones, @ModelAttribute(value = "usuario") Usuario usuario) {
		PuntuacionesController.logger.info("[save] : entro a save");
		puntuaciones.setIdExpediente(idExpediente);

		puntuaciones.setFechaRegistro(new Date());
		puntuaciones.setFechaUltmodificacion(new Date());
		puntuaciones.setUsuarioRegistro(usuario.getNombreUsuario());
		puntuaciones.setUsuarioUltmodificacion(usuario.getNombreUsuario());

		// puntuacionesService.updateCurso(puntuaciones);
		puntuacionesService.addOrUpdateCurso(puntuaciones);
		return puntuaciones;

	}

	/**
	 * 
	 * @param model
	 * @param puntuaciones
	 * @param initForm
	 * @return
	 */
	@RequestMapping(value = "/curso", method = RequestMethod.POST)
	public ModelAndView mostrarcurso(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		Puntuaciones puntuacionesAux = new Puntuaciones();
		puntuaciones.setIdExpediente(initForm.getIdExpediente());
		try {
			puntuacionesAux = puntuacionesService.findCurso(puntuaciones);
			if (null == puntuacionesAux) {
				puntuacionesAux = new Puntuaciones();
			}
			model.addAttribute("puntuacionesCurso", puntuacionesAux);
		} catch (Exception e) {
			PuntuacionesController.logger.info("[mostrar] : la puntuacion no existe");
		}

		return new ModelAndView("curso");

	}

	/**
	 * 
	 * @param model
	 * @param puntuaciones
	 * @param initForm
	 * @return
	 */
	@RequestMapping(value = "/resolucion", method = RequestMethod.POST)
	public ModelAndView mostrarresolucion(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		Puntuaciones puntuacionesAux = new Puntuaciones();
		puntuaciones.setIdExpediente(initForm.getIdExpediente());
		try {
			puntuacionesAux = puntuacionesService.findResolucion(puntuaciones);
			if (null == puntuacionesAux) {
				puntuacionesAux = new Puntuaciones();
			}
			model.addAttribute("puntuacionesResolucion", puntuacionesAux);
		} catch (Exception e) {
			PuntuacionesController.logger.info("[mostrar] : la puntuacion no existe");
		}

		return new ModelAndView("resolucion");

	}

	/**
	 * saveresolucion
	 * 
	 * @param idExpediente
	 * @param puntuaciones
	 * @param usuario
	 * @return
	 */
	@RequestMapping(value = "/resolucion/save/{idExpediente}", method = RequestMethod.POST)
	public @ResponseBody() Puntuaciones saveresolucion(@PathVariable Integer idExpediente,
			@RequestBody() Puntuaciones puntuaciones, @ModelAttribute(value = "usuario") Usuario usuario) {
		PuntuacionesController.logger.info("[save] : entro a save");
		puntuaciones.setIdExpediente(idExpediente);

		puntuaciones.setFechaRegistro(new Date());
		puntuaciones.setFechaUltmodificacion(new Date());
		puntuaciones.setUsuarioRegistro(usuario.getNombreUsuario());
		puntuaciones.setUsuarioUltmodificacion(usuario.getNombreUsuario());

		if (puntuaciones.getMotivosDesestimacion() != null
				&& puntuaciones.getMotivosDesestimacion().getIdMotivoDesestimacion() == 0) {
			puntuaciones.getMotivosDesestimacion().setIdMotivoDesestimacion(null);
		}
		if (puntuaciones.getTiposResultado() != null && puntuaciones.getTiposResultado().getIdResultado() == 0) {
			puntuaciones.getTiposResultado().setIdResultado(null);
		}
		if (puntuaciones.getFases() != null && puntuaciones.getFases().getIdFase() == 0) {
			puntuaciones.getFases().setIdFase(null);
		}

		// puntuacionesService.updateCurso(puntuaciones);
		puntuacionesService.addOrUpdateResolucion(puntuaciones);
		return puntuaciones;

	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/faseCurriculum", method = RequestMethod.POST)
	public String mostrarfaseCurriculum(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));

		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		Convocatorias convocatorias = new Convocatorias();
		if (null != initForm.getIdConvocatoria()) {
			convocatorias.setIdConvocatoria(initForm.getIdConvocatoria());
			convocatorias = convocatoriasService.find(convocatorias);
			model.addAttribute("datosConv", convocatorias);
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);
		model.addAttribute("datosFaseCurriculum", puntuaciones);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		PuntuacionesController.logger.info("[GET - View] : faseCurriculum");
		return "faseCurriculum";
	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/faseConocimientos", method = RequestMethod.POST)
	public String mostrarfaseConocimientos(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		Convocatorias convocatorias = new Convocatorias();
		if (null != initForm.getIdConvocatoria()) {
			convocatorias.setIdConvocatoria(initForm.getIdConvocatoria());
			convocatorias = convocatoriasService.find(convocatorias);
			// String fechaResolucion =
			// UtilDate.convertirFechaEnString(convocatorias.getFechaResolucion());
			// convocatorias.setFechaResolucionStr(fechaResolucion);
			model.addAttribute("datosConv", convocatorias);
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);
		model.addAttribute("datosFaseConocimientos", puntuaciones);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		PuntuacionesController.logger.info("[GET - View] : faseConocimientos");
		return "faseConocimientos";
	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/faseCurso", method = RequestMethod.POST)
	public String mostrarfaseCurso(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		Convocatorias convocatorias = new Convocatorias();
		if (null != initForm.getIdConvocatoria()) {
			convocatorias.setIdConvocatoria(initForm.getIdConvocatoria());
			convocatorias = convocatoriasService.find(convocatorias);
			model.addAttribute("datosConv", convocatorias);
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);
		model.addAttribute("datosFaseCurso", puntuaciones);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		PuntuacionesController.logger.info("[GET - View] : faseCurso");
		return "faseCurso";
	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/faseBecas", method = RequestMethod.POST)
	public String mostrarfaseBecas(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		Convocatorias convocatorias = new Convocatorias();
		if (null != initForm.getIdConvocatoria()) {
			convocatorias.setIdConvocatoria(initForm.getIdConvocatoria());
			convocatorias = convocatoriasService.find(convocatorias);
			// String fechaResolucion =
			// UtilDate.convertirFechaEnString(convocatorias.getFechaResolucion());
			// convocatorias.setFechaResolucionStr(fechaResolucion);
			model.addAttribute("datosConv", convocatorias);
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);
		model.addAttribute("datosFaseCurso", puntuaciones);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		PuntuacionesController.logger.info("[GET - View] : faseBecas");
		return "faseBecas";
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterPuntuaciones
	 *            Puntuaciones Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Puntuaciones> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Puntuaciones> getAll(@ModelAttribute Puntuaciones filterPuntuaciones) {
		PuntuacionesController.logger.info("[GET - find_ALL] : Obtener Puntuaciones por filtro");
		return this.puntuacionesService.findAll(filterPuntuaciones, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param puntuaciones
	 *            Puntuaciones Bean que contiene la informacion a modificar.
	 * @return Puntuaciones Bean resultante de la modificacion.
	 */
	/*
	 * @RequestMapping(method = RequestMethod.PUT) public @ResponseBody
	 * Puntuaciones edit(@RequestBody Puntuaciones puntuaciones) { Puntuaciones
	 * puntuacionesAux = this.puntuacionesService.update(puntuaciones);
	 * PuntuacionesController.logger.
	 * info("[PUT] : Puntuaciones actualizado correctamente"); return
	 * puntuacionesAux; }
	 */

	/**
	 * Operacion CRUD Edit. Intercambio de becarios a suplentes. El suplente con
	 * la maxima puntuacion pasa a ser becario. Y el becario seleccionado pasa a
	 * ser suplente.
	 *
	 * @param Puntuaciones
	 *            Puntuaciones Bean que contiene la informacion a modificar.
	 * @return Puntuaciones Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/faseBecas/becarios/{idProcedimiento}/{idRow}", method = RequestMethod.POST)
	public @ResponseBody Puntuaciones intercambioBecariosSuplentes(
			@PathVariable("idProcedimiento") Integer idProcedimiento, @PathVariable("idRow") Integer idRow,
			@RequestBody Puntuaciones puntuaciones, @ModelAttribute(value = "usuario") Usuario usuario) {

		return puntuacionesService.intercambioBecariosSuplentes(idProcedimiento, idRow, puntuaciones, usuario);

	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param puntuaciones
	 *            Puntuaciones Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return Puntuaciones Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Puntuaciones add(@RequestBody Puntuaciones puntuaciones) {
		Puntuaciones puntuacionesAux = this.puntuacionesService.add(puntuaciones);
		PuntuacionesController.logger.info("[POST] : Puntuaciones insertado correctamente");
		return puntuacionesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idPuntuacion
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Puntuaciones Bean eliminado.
	 */
	@RequestMapping(value = "/{idPuntuacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Puntuaciones remove(@PathVariable Integer idPuntuacion) {
		Puntuaciones puntuaciones = new Puntuaciones();
		puntuaciones.setIdPuntuacion(idPuntuacion);
		this.puntuacionesService.remove(puntuaciones);
		PuntuacionesController.logger.info("[DELETE] : Puntuaciones borrado correctamente");
		return puntuaciones;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public ModelAndView mostrar(Model model, Puntuaciones puntuaciones,
			@ModelAttribute(value = "initForm") InitForm initForm) {
		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		return new ModelAndView("puntuacionExpediente");
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Puntuaciones> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "faseCurriculum/{idProcedimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Puntuaciones> filterFaseCurriculum(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idProcedimiento) {

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setIdProcedimiento(idProcedimiento);

		Expedientes expedientes = new Expedientes();
		expedientes.setProcedimientos(procedimientos);

		filterPuntuaciones.setExpedientes(expedientes);

		PuntuacionesController.logger.info("[POST - filter] : Obtener faseCurriculum");
		return this.puntuacionesService.filterFaseCurriculum(filterPuntuaciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Puntuaciones> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "faseConocimientos/{idProcedimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Puntuaciones> filterFaseConocimientos(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idProcedimiento) {

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setIdProcedimiento(idProcedimiento);

		Expedientes expedientes = new Expedientes();
		expedientes.setProcedimientos(procedimientos);

		filterPuntuaciones.setExpedientes(expedientes);

		PuntuacionesController.logger.info("[POST - filter] : Obtener faseConocimientos");
		return this.puntuacionesService.filterFaseConocimientos(filterPuntuaciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Puntuaciones> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "faseCurso/{idProcedimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Puntuaciones> filterFaseCurso(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idProcedimiento) {

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setIdProcedimiento(idProcedimiento);

		Expedientes expedientes = new Expedientes();
		expedientes.setProcedimientos(procedimientos);

		filterPuntuaciones.setExpedientes(expedientes);

		PuntuacionesController.logger.info("[POST - filter] : Obtener faseConocimientos");
		return this.puntuacionesService.filterFaseCurso(filterPuntuaciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Puntuaciones> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "faseBecas/becarios/{idProcedimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Puntuaciones> filterFaseBecasBecarios(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idProcedimiento) {

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setIdProcedimiento(idProcedimiento);

		Expedientes expedientes = new Expedientes();
		expedientes.setProcedimientos(procedimientos);

		filterPuntuaciones.setExpedientes(expedientes);

		PuntuacionesController.logger.info("[POST - filter] : Obtener faseBecas becarios");
		return this.puntuacionesService.filterFaseBecasBecarios(filterPuntuaciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Puntuaciones> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "faseBecas/suplentes/{idProcedimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Puntuaciones> filterFaseBecasSuplentes(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idProcedimiento) {

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setIdProcedimiento(idProcedimiento);

		Expedientes expedientes = new Expedientes();
		expedientes.setProcedimientos(procedimientos);

		filterPuntuaciones.setExpedientes(expedientes);

		PuntuacionesController.logger.info("[POST - filter] : Obtener faseBecas becarios");
		return this.puntuacionesService.filterFaseBecasSuplentes(filterPuntuaciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Puntuaciones> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Puntuaciones>> search(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody(param = "search") Puntuaciones searchPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PuntuacionesController.logger.info("[POST - search] : Buscar Puntuacioness");
		return this.puntuacionesService.search(filterPuntuaciones, searchPuntuaciones, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PuntuacionesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Puntuacioness");
		this.puntuacionesService.removeMultiple(filterPuntuaciones, jqGridRequestDto, false);
		PuntuacionesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/**
	 * Metodo que devuelve las puntuaciones actualizadas despues del calculo del
	 * pl-sql
	 * 
	 * @param idExpediente
	 * @return puntuaciones Puntuaciones
	 */
	@RequestMapping(value = "/refrescar/{idExpediente}", method = RequestMethod.GET)
	public @ResponseBody Puntuaciones refrescarPuntuaciones(@PathVariable Integer idExpediente) {
		Puntuaciones puntuaciones = new Puntuaciones();
		puntuaciones.setIdExpediente(idExpediente);
		try {
			puntuaciones = puntuacionesService.findAll(puntuaciones, null).get(0);
		} catch (Exception e) {
			PuntuacionesController.logger.info("[mostrar] : la puntuacion no existe");
		}
		return puntuaciones;
	}
	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Puntuaciones>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Puntuaciones>> jerarquia(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PuntuacionesController.logger.info("[POST - jerarquia] : Obtener Puntuacioness jerarquia");
		return this.puntuacionesService.jerarquia(filterPuntuaciones, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterPuntuaciones
	 *            Puntuaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Puntuaciones>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Puntuaciones>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Puntuaciones filterPuntuaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PuntuacionesController.logger.info("[POST - jerarquia] : Obtener Puntuacioness jerarquia - Hijos");
		return this.puntuacionesService.jerarquiaChildren(filterPuntuaciones, jqGridRequestDto);
	}

	/**
	 * Permite crear reportes xls o xlsx
	 * 
	 * @param filterDireccion
	 * @param jqGridRequestDto
	 * @param modelMap
	 * @param columns
	 * @param request
	 * @return
	 */
	@RequestMapping(value = { "{idFase}/{idProcedimiento}/xlsReport",
			"{idFase}/{idProcedimiento}/xlsxReport" }, method = RequestMethod.POST)
	protected ModelAndView getExcelPOI(@ModelAttribute Puntuaciones filterPuntuaciones,
			@PathVariable("idFase") Integer idFase, @PathVariable("idProcedimiento") Integer idProcedimiento,
			@ModelAttribute JQGridRequestDto jqGridRequestDto, ModelMap modelMap,
			@RequestParam(value = "columns", required = false) String columns, HttpServletRequest request) {

		Locale locale = LocaleContextHolder.getLocale();

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setIdProcedimiento(idProcedimiento);

		Expedientes expedientes = new Expedientes();
		expedientes.setProcedimientos(procedimientos);

		filterPuntuaciones.setExpedientes(expedientes);

		columns = "[['expedientes.folderNumber','" + appMessageSource.getMessage("excel.numExpediente", null, locale)
				+ "']" + ",['expedientes.datosTerceros.documento','"
				+ appMessageSource.getMessage("excel.dni", null, locale) + "']"
				+ ",['expedientes.datosTerceros.nombre','" + appMessageSource.getMessage("excel.nombre", null, locale)
				+ "']" + ",['expedientes.datosTerceros.apellido1','"
				+ appMessageSource.getMessage("excel.apellido1", null, locale) + "']"
				+ ",['expedientes.datosTerceros.apellido2','"
				+ appMessageSource.getMessage("excel.apellido2", null, locale) + "']";

		if (idFase == Constantes.ID_FASE1) {
			columns = columns + ",['requisitos','" + appMessageSource.getMessage("excel.cumpleReq", null, locale) + "']"
					+ ",['puntuacionTotCv','" + appMessageSource.getMessage("excel.pTotalCV", null, locale) + "']"
					+ "]";
		} else if (idFase == Constantes.ID_FASE2) {
			columns = columns + ",['puntuacionTotCv','" + appMessageSource.getMessage("excel.pTotalCV", null, locale)
					+ "']" + ",['notaConocimientos','"
					+ appMessageSource.getMessage("excel.notaConocimientos", null, locale) + "']"
					+ ",['puntuacionTotCon','" + appMessageSource.getMessage("excel.puntuacionTotCon", null, locale)
					+ "']" + "]";
		} else if (idFase == Constantes.ID_FASE3) {
			columns = columns + ",['puntuacionTotCv','" + appMessageSource.getMessage("excel.pTotalCV", null, locale)
					+ "']" + ",['notaConocimientos','"
					+ appMessageSource.getMessage("excel.notaConocimientos", null, locale) + "']" + ",['notaCurso','"
					+ appMessageSource.getMessage("excel.notaCurso", null, locale) + "']" + ",['puntuacionTotCon','"
					+ appMessageSource.getMessage("excel.puntuacionTotCon", null, locale) + "']" + "]";
		} else if (idFase == Constantes.ID_FASE4) {
			columns = columns + ",['expedientes.curriculum.ingles','"
					+ appMessageSource.getMessage("excel.in", null, locale) + "']"
					+ ",['expedientes.curriculum.frances','" + appMessageSource.getMessage("excel.fr", null, locale)
					+ "']" + ",['expedientes.curriculum.italiano','"
					+ appMessageSource.getMessage("excel.it", null, locale) + "']" + ",['puntuacionTotCon','"
					+ appMessageSource.getMessage("excel.puntuacionTotCon", null, locale) + "']" + ",['empresa','"
					+ appMessageSource.getMessage("excel.empresa", null, locale) + "']" + ",['dotacion','"
					+ appMessageSource.getMessage("excel.dotacion", null, locale) + "']" + "]";
		}

		// Acceso a BD para recuperar datos

		List<Puntuaciones> listPuntuacionesAll = new ArrayList<Puntuaciones>();

		// Nombre fichero
		if (idFase == Constantes.ID_FASE1) {
			listPuntuacionesAll = this.puntuacionesService.findAllLikeExportExcelCurr(filterPuntuaciones,
					jqGridRequestDto, null);

			modelMap.put("fileName", appMessageSource.getMessage("excel.faseCurriculum", null, locale));
		} else if (idFase == Constantes.ID_FASE2) {
			listPuntuacionesAll = this.puntuacionesService.findAllLikeExportExcelCono(filterPuntuaciones,
					jqGridRequestDto, null);
			modelMap.put("fileName", appMessageSource.getMessage("excel.faseConocimientos", null, locale));
		} else if (idFase == Constantes.ID_FASE3) {
			listPuntuacionesAll = this.puntuacionesService.findAllLikeExportExcelCurso(filterPuntuaciones,
					jqGridRequestDto, null);
			modelMap.put("fileName", appMessageSource.getMessage("excel.faseCurso", null, locale));
		} else if (idFase == Constantes.ID_FASE4) {
			listPuntuacionesAll = this.puntuacionesService.findAllLikeExportExcelBecarios(filterPuntuaciones,
					jqGridRequestDto, null);
			modelMap.put("fileName", appMessageSource.getMessage("excel.faseBecas", null, locale));
		}

		// Datos
		List<Object> reportData = new ArrayList<Object>();
		// Hoja 1
		ReportData<Puntuaciones> usuarioExcelDataAll = new ReportData<Puntuaciones>();
		// nombre hoja
		if (idFase == Constantes.ID_FASE1) {
			usuarioExcelDataAll.setSheetName(appMessageSource.getMessage("usuarioExcel.faseCurriculum", null, locale));
		} else if (idFase == Constantes.ID_FASE2) {
			usuarioExcelDataAll
					.setSheetName(appMessageSource.getMessage("usuarioExcel.faseConocimientos", null, locale));
		} else if (idFase == Constantes.ID_FASE3) {
			usuarioExcelDataAll.setSheetName(appMessageSource.getMessage("usuarioExcel.faseCurso", null, locale));
		} else if (idFase == Constantes.ID_FASE4) {
			usuarioExcelDataAll.setSheetName(appMessageSource.getMessage("usuarioExcel.faseBecas", null, locale));
		}

		// cabeceras hoja
		usuarioExcelDataAll.setHeaderNames(ReportData.parseColumns(columns));
		// datos hoja
		usuarioExcelDataAll.setModelData(listPuntuacionesAll);
		reportData.add(usuarioExcelDataAll);

		modelMap.put("reportData", reportData);

		// Generacion del XLS o XLSX
		if (request.getServletPath().indexOf("xlsReport") != -1) {
			return new ModelAndView("xlsReport", modelMap);
		} else {
			return new ModelAndView("xlsxReport", modelMap);
		}
	}

	/**
	 * Permite crear reportes xls o xlsx
	 * 
	 * @param filterDireccion
	 * @param jqGridRequestDto
	 * @param modelMap
	 * @param columns
	 * @param request
	 * @return
	 */
	@RequestMapping(value = { "/faseBecas/suplentes/{idProcedimiento}/xlsReport",
			"/faseBecas/suplentes/{idProcedimiento}/xlsxReport" }, method = RequestMethod.POST)
	protected ModelAndView getExcelSuplentes(@ModelAttribute Puntuaciones filterPuntuaciones,
			@PathVariable("idProcedimiento") Integer idProcedimiento, @ModelAttribute JQGridRequestDto jqGridRequestDto,
			ModelMap modelMap, @RequestParam(value = "columns", required = false) String columns,
			HttpServletRequest request) {

		Locale locale = LocaleContextHolder.getLocale();

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setIdProcedimiento(idProcedimiento);

		Expedientes expedientes = new Expedientes();
		expedientes.setProcedimientos(procedimientos);

		filterPuntuaciones.setExpedientes(expedientes);

		columns = "[['expedientes.folderNumber','" + appMessageSource.getMessage("excel.numExpediente", null, locale)
				+ "']" + ",['expedientes.datosTerceros.documento','"
				+ appMessageSource.getMessage("excel.dni", null, locale) + "']"
				+ ",['expedientes.datosTerceros.nombre','" + appMessageSource.getMessage("excel.nombre", null, locale)
				+ "']" + ",['expedientes.datosTerceros.apellido1','"
				+ appMessageSource.getMessage("excel.apellido1", null, locale) + "']"
				+ ",['expedientes.datosTerceros.apellido2','"
				+ appMessageSource.getMessage("excel.apellido2", null, locale) + "']"
				+ ",['expedientes.curriculum.ingles','" + appMessageSource.getMessage("excel.in", null, locale) + "']"
				+ ",['expedientes.curriculum.frances','" + appMessageSource.getMessage("excel.fr", null, locale) + "']"
				+ ",['expedientes.curriculum.italiano','" + appMessageSource.getMessage("excel.it", null, locale) + "']"
				+ ",['puntuacionTotCon','" + appMessageSource.getMessage("excel.puntuacionTotCon", null, locale) + "']"
				+ "]";

		// Acceso a BD para recuperar datos

		List<Puntuaciones> listPuntuacionesAll = this.puntuacionesService
				.findAllLikeExportExcelSuplentes(filterPuntuaciones, jqGridRequestDto, null);

		// Nombre fichero

		modelMap.put("fileName", appMessageSource.getMessage("excel.faseBecasSupl", null, locale));

		// Datos
		List<Object> reportData = new ArrayList<Object>();
		// Hoja 1
		ReportData<Puntuaciones> usuarioExcelDataAll = new ReportData<Puntuaciones>();
		// nombre hoja
		usuarioExcelDataAll.setSheetName(appMessageSource.getMessage("usuarioExcel.faseBecasSupl", null, locale));

		// cabeceras hoja
		usuarioExcelDataAll.setHeaderNames(ReportData.parseColumns(columns));
		// datos hoja
		usuarioExcelDataAll.setModelData(listPuntuacionesAll);
		reportData.add(usuarioExcelDataAll);

		modelMap.put("reportData", reportData);

		// Generacion del XLS o XLSX
		if (request.getServletPath().indexOf("xlsReport") != -1) {
			return new ModelAndView("xlsReport", modelMap);
		} else {
			return new ModelAndView("xlsxReport", modelMap);
		}
	}

}
