package com.ejie.ab60.control.BEC;

import com.ejie.ab60.control.estudioTecnico.MotivosDenegacionController;
import com.ejie.ab60.model.BEC.TiposCertificacion;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;
import com.ejie.ab60.service.BEC.TiposCertificacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * TiposCertificacionController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposcertificacion")

public class TiposCertificacionController {

	private static final Logger logger = LoggerFactory.getLogger(TiposCertificacionController.class);

	@Autowired
	private TiposCertificacionService tiposCertificacionService;

	/**
	 * Metodo que nos trae la lista para cargar el combo
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<TiposCertificacion> init(@PathVariable Integer idConvocatoria) {
		TiposCertificacionController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		TiposCertificacion tiposCertificacion = new TiposCertificacion();
		tiposCertificacion.setIdConvocatoria(idConvocatoria);
		return this.tiposCertificacionService.findCertificaciones(tiposCertificacion);

	}

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoCertificacion
	 *            Long
	 * @return TiposCertificacion Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idTipoCertificacion}", method = RequestMethod.GET)
	public @ResponseBody TiposCertificacion get(@PathVariable Long idTipoCertificacion) {
		TiposCertificacion tiposCertificacion = new TiposCertificacion();
		tiposCertificacion.setIdTipoCertificacion(idTipoCertificacion);
		tiposCertificacion = this.tiposCertificacionService.find(tiposCertificacion);
		TiposCertificacionController.logger.info("[GET - findBy_PK] : Obtener TiposCertificacion por PK");
		return tiposCertificacion;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposCertificacion
	 *            TiposCertificacion Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<TiposCertificacion> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposCertificacion> getAll(@ModelAttribute TiposCertificacion filterTiposCertificacion) {
		TiposCertificacionController.logger.info("[GET - find_ALL] : Obtener TiposCertificacion por filtro");
		return this.tiposCertificacionService.findAll(filterTiposCertificacion, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion Bean que contiene la informacion a
	 *            modificar.
	 * @return TiposCertificacion Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposCertificacion edit(@RequestBody TiposCertificacion tiposCertificacion) {
		TiposCertificacion tiposCertificacionAux = this.tiposCertificacionService.update(tiposCertificacion);
		TiposCertificacionController.logger.info("[PUT] : TiposCertificacion actualizado correctamente");
		return tiposCertificacionAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposCertificacion
	 *            TiposCertificacion Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return TiposCertificacion Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposCertificacion add(@RequestBody TiposCertificacion tiposCertificacion) {
		TiposCertificacion tiposCertificacionAux = this.tiposCertificacionService.add(tiposCertificacion);
		TiposCertificacionController.logger.info("[POST] : TiposCertificacion insertado correctamente");
		return tiposCertificacionAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoCertificacion
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposCertificacion Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoCertificacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposCertificacion remove(@PathVariable Long idTipoCertificacion) {
		TiposCertificacion tiposCertificacion = new TiposCertificacion();
		tiposCertificacion.setIdTipoCertificacion(idTipoCertificacion);
		this.tiposCertificacionService.remove(tiposCertificacion);
		TiposCertificacionController.logger.info("[DELETE] : TiposCertificacion borrado correctamente");
		return tiposCertificacion;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposCertificacionController.logger.info("[GET - View] : tiposcertificacion");
		return "tiposcertificacion";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposCertificacion
	 *            TiposCertificacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposCertificacion> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposCertificacion> filter(
			@RequestJsonBody(param = "filter") TiposCertificacion filterTiposCertificacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCertificacionController.logger.info("[POST - filter] : Obtener TiposCertificacions");
		return this.tiposCertificacionService.filter(filterTiposCertificacion, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposCertificacion
	 *            TiposCertificacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchTiposCertificacion
	 *            TiposCertificacion Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposCertificacion> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposCertificacion>> search(
			@RequestJsonBody(param = "filter") TiposCertificacion filterTiposCertificacion,
			@RequestJsonBody(param = "search") TiposCertificacion searchTiposCertificacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCertificacionController.logger.info("[POST - search] : Buscar TiposCertificacions");
		return this.tiposCertificacionService.search(filterTiposCertificacion, searchTiposCertificacion,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposCertificacion
	 *            TiposCertificacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TiposCertificacion filterTiposCertificacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCertificacionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposCertificacions");
		this.tiposCertificacionService.removeMultiple(filterTiposCertificacion, jqGridRequestDto, false);
		TiposCertificacionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposCertificacion
	 *            TiposCertificacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposCertificacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposCertificacion>> jerarquia(
			@RequestJsonBody(param = "filter") TiposCertificacion filterTiposCertificacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCertificacionController.logger.info("[POST - jerarquia] : Obtener TiposCertificacions jerarquia");
		return this.tiposCertificacionService.jerarquia(filterTiposCertificacion, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposCertificacion
	 *            TiposCertificacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposCertificacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposCertificacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposCertificacion filterTiposCertificacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCertificacionController.logger.info("[POST - jerarquia] : Obtener TiposCertificacions jerarquia - Hijos");
		return this.tiposCertificacionService.jerarquiaChildren(filterTiposCertificacion, jqGridRequestDto);
	}

}
