package com.ejie.ab60.control.CTP;

import com.ejie.ab60.service.CTP.AsociacionesSectorialesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.CTP.AsociacionesSectoriales;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;

/**
 * AsociacionesSectorialesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/asociacionessectoriales")

public class AsociacionesSectorialesController {

	private static final Logger logger = LoggerFactory.getLogger(AsociacionesSectorialesController.class);

	@Autowired
	private AsociacionesSectorialesService asociacionesSectorialesService;

	/**
	 * Metodo que nos trae la lista para cargar el combo de asociaciones
	 * sectoriales
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo", method = RequestMethod.GET)
	public @ResponseBody List<AsociacionesSectoriales> verValorCombo() {
		AsociacionesSectorialesController.logger
				.info("[GET - getValorCombo] : Obtener valores del combo de asociaciones sectoriales");
		return this.asociacionesSectorialesService.findAsociacionesSectoriales();

	}

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idAsociacion
	 *            Long
	 * @return AsociacionesSectoriales Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idAsociacion}", method = RequestMethod.GET)
	public @ResponseBody AsociacionesSectoriales get(@PathVariable Long idAsociacion) {
		AsociacionesSectoriales asociacionesSectoriales = new AsociacionesSectoriales();
		asociacionesSectoriales.setIdAsociacion(idAsociacion);
		asociacionesSectoriales = this.asociacionesSectorialesService.find(asociacionesSectoriales);
		AsociacionesSectorialesController.logger.info("[GET - findBy_PK] : Obtener AsociacionesSectoriales por PK");
		return asociacionesSectoriales;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<AsociacionesSectoriales> Lista de objetos correspondientes a
	 *         la busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<AsociacionesSectoriales> getAll(
			@ModelAttribute AsociacionesSectoriales filterAsociacionesSectoriales) {
		AsociacionesSectorialesController.logger.info("[GET - find_ALL] : Obtener AsociacionesSectoriales por filtro");
		return this.asociacionesSectorialesService.findAll(filterAsociacionesSectoriales, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene la informacion a
	 *            modificar.
	 * @return AsociacionesSectoriales Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody AsociacionesSectoriales edit(@RequestBody AsociacionesSectoriales asociacionesSectoriales) {
		AsociacionesSectoriales asociacionesSectorialesAux = this.asociacionesSectorialesService
				.update(asociacionesSectoriales);
		AsociacionesSectorialesController.logger.info("[PUT] : AsociacionesSectoriales actualizado correctamente");
		return asociacionesSectorialesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param asociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene la informacion con
	 *            la que se va a crear el nuevo registro.
	 * @return AsociacionesSectoriales Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody AsociacionesSectoriales add(@RequestBody AsociacionesSectoriales asociacionesSectoriales) {
		AsociacionesSectoriales asociacionesSectorialesAux = this.asociacionesSectorialesService
				.add(asociacionesSectoriales);
		AsociacionesSectorialesController.logger.info("[POST] : AsociacionesSectoriales insertado correctamente");
		return asociacionesSectorialesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAsociacion
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return AsociacionesSectoriales Bean eliminado.
	 */
	@RequestMapping(value = "/{idAsociacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody AsociacionesSectoriales remove(@PathVariable Long idAsociacion) {
		AsociacionesSectoriales asociacionesSectoriales = new AsociacionesSectoriales();
		asociacionesSectoriales.setIdAsociacion(idAsociacion);
		this.asociacionesSectorialesService.remove(asociacionesSectoriales);
		AsociacionesSectorialesController.logger.info("[DELETE] : AsociacionesSectoriales borrado correctamente");
		return asociacionesSectoriales;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AsociacionesSectorialesController.logger.info("[GET - View] : asociacionessectoriales");
		return "asociacionessectoriales";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<AsociacionesSectoriales> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<AsociacionesSectoriales> filter(
			@RequestJsonBody(param = "filter") AsociacionesSectoriales filterAsociacionesSectoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesSectorialesController.logger.info("[POST - filter] : Obtener AsociacionesSectorialess");
		return this.asociacionesSectorialesService.filter(filterAsociacionesSectoriales, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchAsociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<AsociacionesSectoriales> Dto que contiene el
	 *         resultado de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<AsociacionesSectoriales>> search(
			@RequestJsonBody(param = "filter") AsociacionesSectoriales filterAsociacionesSectoriales,
			@RequestJsonBody(param = "search") AsociacionesSectoriales searchAsociacionesSectoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesSectorialesController.logger.info("[POST - search] : Buscar AsociacionesSectorialess");
		return this.asociacionesSectorialesService.search(filterAsociacionesSectoriales, searchAsociacionesSectoriales,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") AsociacionesSectoriales filterAsociacionesSectoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesSectorialesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples AsociacionesSectorialess");
		this.asociacionesSectorialesService.removeMultiple(filterAsociacionesSectoriales, jqGridRequestDto, false);
		AsociacionesSectorialesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>> jerarquia(
			@RequestJsonBody(param = "filter") AsociacionesSectoriales filterAsociacionesSectoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesSectorialesController.logger
				.info("[POST - jerarquia] : Obtener AsociacionesSectorialess jerarquia");
		return this.asociacionesSectorialesService.jerarquia(filterAsociacionesSectoriales, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAsociacionesSectoriales
	 *            AsociacionesSectoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AsociacionesSectoriales>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") AsociacionesSectoriales filterAsociacionesSectoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesSectorialesController.logger
				.info("[POST - jerarquia] : Obtener AsociacionesSectorialess jerarquia - Hijos");
		return this.asociacionesSectorialesService.jerarquiaChildren(filterAsociacionesSectoriales, jqGridRequestDto);
	}

}
