package com.ejie.ab60.control.CTP;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.CTP.Proyectos;
import com.ejie.ab60.service.CTP.ProyectosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ProyectosController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/proyectos")

public class ProyectosController {

	private static final Logger logger = LoggerFactory.getLogger(ProyectosController.class);

	@Autowired
	private ProyectosService proyectosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idProyecto
	 *            String
	 * @return Proyectos Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idProyecto}", method = RequestMethod.GET)
	public @ResponseBody Proyectos get(@PathVariable String idProyecto) {
		Proyectos proyectos = new Proyectos();
		proyectos.setIdProyecto(idProyecto);
		proyectos = this.proyectosService.find(proyectos);
		ProyectosController.logger.info("[GET - findBy_PK] : Obtener Proyectos por PK");
		return proyectos;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterProyectos
	 *            Proyectos Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Proyectos> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Proyectos> getAll(@ModelAttribute Proyectos filterProyectos) {
		ProyectosController.logger.info("[GET - find_ALL] : Obtener Proyectos por filtro");
		return this.proyectosService.findAll(filterProyectos, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param proyectos
	 *            Proyectos Bean que contiene la informacion a modificar.
	 * @return Proyectos Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Proyectos edit(@RequestBody Proyectos proyectos) {
		Proyectos proyectosAux = this.proyectosService.update(proyectos);
		ProyectosController.logger.info("[PUT] : Proyectos actualizado correctamente");
		return proyectosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param proyectos
	 *            Proyectos Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Proyectos Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Proyectos add(@RequestBody Proyectos proyectos) {
		Proyectos proyectosAux = this.proyectosService.add(proyectos);
		ProyectosController.logger.info("[POST] : Proyectos insertado correctamente");
		return proyectosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idProyecto
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Proyectos Bean eliminado.
	 */
	@RequestMapping(value = "/{idProyecto}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Proyectos remove(@PathVariable String idProyecto) {
		Proyectos proyectos = new Proyectos();
		proyectos.setIdProyecto(idProyecto);
		this.proyectosService.remove(proyectos);
		ProyectosController.logger.info("[DELETE] : Proyectos borrado correctamente");
		return proyectos;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ProyectosController.logger.info("[GET - View] : proyectos");
		return "proyectos";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterProyectos
	 *            Proyectos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Proyectos> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Proyectos> filter(
			@RequestJsonBody(param = "filter") Proyectos filterProyectos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProyectosController.logger.info("[POST - filter] : Obtener Proyectoss");
		return this.proyectosService.filter(filterProyectos, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterProyectos
	 *            Proyectos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchProyectos
	 *            Proyectos Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Proyectos> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Proyectos>> search(
			@RequestJsonBody(param = "filter") Proyectos filterProyectos,
			@RequestJsonBody(param = "search") Proyectos searchProyectos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProyectosController.logger.info("[POST - search] : Buscar Proyectoss");
		return this.proyectosService.search(filterProyectos, searchProyectos, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterProyectos
	 *            Proyectos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Proyectos filterProyectos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProyectosController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Proyectoss");
		this.proyectosService.removeMultiple(filterProyectos, jqGridRequestDto, false);
		ProyectosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterProyectos
	 *            Proyectos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Proyectos>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Proyectos>> jerarquia(
			@RequestJsonBody(param = "filter") Proyectos filterProyectos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProyectosController.logger.info("[POST - jerarquia] : Obtener Proyectoss jerarquia");
		return this.proyectosService.jerarquia(filterProyectos, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterProyectos
	 *            Proyectos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Proyectos>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Proyectos>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Proyectos filterProyectos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProyectosController.logger.info("[POST - jerarquia] : Obtener Proyectoss jerarquia - Hijos");
		return this.proyectosService.jerarquiaChildren(filterProyectos, jqGridRequestDto);
	}

}
