package com.ejie.ab60.control.CTP;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.CTP.Solicitantes;
import com.ejie.ab60.service.CTP.SolicitantesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * SolicitantesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/solicitantes")

public class SolicitantesController {

	private static final Logger logger = LoggerFactory.getLogger(SolicitantesController.class);

	@Autowired
	private SolicitantesService solicitantesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idSolicitante
	 *            Long
	 * @return Solicitantes Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idSolicitante}", method = RequestMethod.GET)
	public @ResponseBody Solicitantes get(@PathVariable Long idSolicitante) {
		Solicitantes solicitantes = new Solicitantes();
		solicitantes.setIdSolicitante(idSolicitante);
		solicitantes = this.solicitantesService.find(solicitantes);
		SolicitantesController.logger.info("[GET - findBy_PK] : Obtener Solicitantes por PK");
		return solicitantes;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterSolicitantes
	 *            Solicitantes Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Solicitantes> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Solicitantes> getAll(@ModelAttribute Solicitantes filterSolicitantes) {
		SolicitantesController.logger.info("[GET - find_ALL] : Obtener Solicitantes por filtro");
		return this.solicitantesService.findAll(filterSolicitantes, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param solicitantes
	 *            Solicitantes Bean que contiene la informacion a modificar.
	 * @return Solicitantes Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Solicitantes edit(@RequestBody Solicitantes solicitantes) {
		Solicitantes solicitantesAux = this.solicitantesService.update(solicitantes);
		SolicitantesController.logger.info("[PUT] : Solicitantes actualizado correctamente");
		return solicitantesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param solicitantes
	 *            Solicitantes Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return Solicitantes Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Solicitantes add(@RequestBody Solicitantes solicitantes) {
		Solicitantes solicitantesAux = this.solicitantesService.add(solicitantes);
		SolicitantesController.logger.info("[POST] : Solicitantes insertado correctamente");
		return solicitantesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idSolicitante
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return Solicitantes Bean eliminado.
	 */
	@RequestMapping(value = "/{idSolicitante}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Solicitantes remove(@PathVariable Long idSolicitante) {
		Solicitantes solicitantes = new Solicitantes();
		solicitantes.setIdSolicitante(idSolicitante);
		this.solicitantesService.remove(solicitantes);
		SolicitantesController.logger.info("[DELETE] : Solicitantes borrado correctamente");
		return solicitantes;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		SolicitantesController.logger.info("[GET - View] : solicitantes");
		return "solicitantes";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterSolicitantes
	 *            Solicitantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Solicitantes> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Solicitantes> filter(
			@RequestJsonBody(param = "filter") Solicitantes filterSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SolicitantesController.logger.info("[POST - filter] : Obtener Solicitantess");
		return this.solicitantesService.filter(filterSolicitantes, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterSolicitantes
	 *            Solicitantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchSolicitantes
	 *            Solicitantes Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Solicitantes> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Solicitantes>> search(
			@RequestJsonBody(param = "filter") Solicitantes filterSolicitantes,
			@RequestJsonBody(param = "search") Solicitantes searchSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SolicitantesController.logger.info("[POST - search] : Buscar Solicitantess");
		return this.solicitantesService.search(filterSolicitantes, searchSolicitantes, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterSolicitantes
	 *            Solicitantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Solicitantes filterSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SolicitantesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Solicitantess");
		this.solicitantesService.removeMultiple(filterSolicitantes, jqGridRequestDto, false);
		SolicitantesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterSolicitantes
	 *            Solicitantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Solicitantes>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Solicitantes>> jerarquia(
			@RequestJsonBody(param = "filter") Solicitantes filterSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SolicitantesController.logger.info("[POST - jerarquia] : Obtener Solicitantess jerarquia");
		return this.solicitantesService.jerarquia(filterSolicitantes, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterSolicitantes
	 *            Solicitantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Solicitantes>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Solicitantes>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Solicitantes filterSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SolicitantesController.logger.info("[POST - jerarquia] : Obtener Solicitantess jerarquia - Hijos");
		return this.solicitantesService.jerarquiaChildren(filterSolicitantes, jqGridRequestDto);
	}

}
