package com.ejie.ab60.control.DEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DEC.ActAsociacion;
import com.ejie.ab60.service.DEC.ActAsociacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ActAsociacionController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/actasociacion")

public class ActAsociacionController {

	private static final Logger logger = LoggerFactory.getLogger(ActAsociacionController.class);

	@Autowired
	private ActAsociacionService actAsociacionService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idActAsociacion
	 *            Integer
	 * @return ActAsociacion Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idActAsociacion}", method = RequestMethod.GET)
	public @ResponseBody ActAsociacion get(@PathVariable Integer idActAsociacion) {
		ActAsociacion actAsociacion = new ActAsociacion();
		actAsociacion.setIdActAsociacion(idActAsociacion);
		actAsociacion = this.actAsociacionService.find(actAsociacion);
		ActAsociacionController.logger.info("[GET - findBy_PK] : Obtener ActAsociacion por PK");
		return actAsociacion;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterActAsociacion
	 *            ActAsociacion Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<ActAsociacion> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<ActAsociacion> getAll(@ModelAttribute ActAsociacion filterActAsociacion) {
		ActAsociacionController.logger.info("[GET - find_ALL] : Obtener ActAsociacion por filtro");
		return this.actAsociacionService.findAll(filterActAsociacion, null);
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ActAsociacionController.logger.info("[GET - View] : actasociacion");
		return "actasociacion";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterActAsociacion
	 *            ActAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<ActAsociacion> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<ActAsociacion> filter(
			@RequestJsonBody(param = "filter") ActAsociacion filterActAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ActAsociacionController.logger.info("[POST - filter] : Obtener ActAsociacions");
		return this.actAsociacionService.filter(filterActAsociacion, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterActAsociacion
	 *            ActAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchActAsociacion
	 *            ActAsociacion Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<ActAsociacion> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<ActAsociacion>> search(
			@RequestJsonBody(param = "filter") ActAsociacion filterActAsociacion,
			@RequestJsonBody(param = "search") ActAsociacion searchActAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ActAsociacionController.logger.info("[POST - search] : Buscar ActAsociacions");
		return this.actAsociacionService.search(filterActAsociacion, searchActAsociacion, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterActAsociacion
	 *            ActAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") ActAsociacion filterActAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ActAsociacionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples ActAsociacions");
		this.actAsociacionService.removeMultiple(filterActAsociacion, jqGridRequestDto, false);
		ActAsociacionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterActAsociacion
	 *            ActAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ActAsociacion>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ActAsociacion>> jerarquia(
			@RequestJsonBody(param = "filter") ActAsociacion filterActAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ActAsociacionController.logger.info("[POST - jerarquia] : Obtener ActAsociacions jerarquia");
		return this.actAsociacionService.jerarquia(filterActAsociacion, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterActAsociacion
	 *            ActAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ActAsociacion>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ActAsociacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") ActAsociacion filterActAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ActAsociacionController.logger.info("[POST - jerarquia] : Obtener ActAsociacions jerarquia - Hijos");
		return this.actAsociacionService.jerarquiaChildren(filterActAsociacion, jqGridRequestDto);
	}

}
