package com.ejie.ab60.control.DEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.model.DEC.ActAyuntamiento;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.DEC.ActAyuntamientoService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;

/**
 * ActAyuntamientoController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/actayuntamiento")

public class ActAyuntamientoController {

	private static final Logger logger = LoggerFactory.getLogger(ActAyuntamientoController.class);

	@Autowired
	private ActAyuntamientoService actAyuntamientoService;

	@Autowired
	private RelExpActSubService relExpActSubService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterActAyuntamiento
	 *            ActAyuntamiento Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<ActAyuntamiento> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<ActAyuntamiento> getAll(@ModelAttribute ActAyuntamiento filterActAyuntamiento) {
		ActAyuntamientoController.logger.info("[GET - find_ALL] : Obtener ActAyuntamiento por filtro");
		return this.actAyuntamientoService.findAll(filterActAyuntamiento, null);
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ActAyuntamientoController.logger.info("[GET - View] : actayuntamiento");
		return "actayuntamiento";
	}

	/**
	 * Metodo que saca la modal de conceptos relacionadas con Actu Sub
	 * 
	 * @param idCriterio,
	 * @param idExpediente
	 * @return String
	 */
	@RequestMapping(value = "/{idExpedientes}/{idCriterio}", method = RequestMethod.GET)
	public String cargarModal(@PathVariable("idExpedientes") Integer idExpedientes,
			@PathVariable("idCriterio") Integer idCriterio, Model model,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		ActAyuntamiento actAyuntamiento = new ActAyuntamiento();
		actAyuntamiento.setIdActAyuntamiento(idCriterio);
		ActAyuntamiento actAyuntamientoAux = this.actAyuntamientoService.findidRelacion(actAyuntamiento);
		Integer idRelacion = actAyuntamientoAux.getRelExpActSub().getIdRelExpActSub();
		RelExpActSub relExpActSub = this.relExpActSubService.findIdActSub(idRelacion);
		Integer idActSub = relExpActSub.getActSubvencionable().getIdActSub();
		RelExpActSub relExpActSubAux = relExpActSubService.findRelPorExpedientePorCriterio(idExpedientes, idActSub);

		model.addAttribute("criterio", idCriterio);
		model.addAttribute("expediente", idExpedientes);

		model.addAttribute("datosRelExpActSub", relExpActSubAux);
		return "ayuntamientos";

	}

	/**
	 * Operacion que me trae los totales de un expediente
	 * 
	 * 
	 * @param idExpedientes
	 * @return
	 */

	@RequestMapping(value = "/totales/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.GET)
	public @ResponseBody RelExpActSub totales(@PathVariable Integer idRelacion, @PathVariable Integer idExpediente,
			@PathVariable Integer idCriterio) {

		return this.relExpActSubService.findTotales(idRelacion);
	}

}
