package com.ejie.ab60.control.DEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DEC.AsociacionesComerciantes;
import com.ejie.ab60.service.DEC.AsociacionesComerciantesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AsociacionesComerciantesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/asociacionescomerciantes")

public class AsociacionesComerciantesController {

	private static final Logger logger = LoggerFactory.getLogger(AsociacionesComerciantesController.class);

	@Autowired
	private AsociacionesComerciantesService asociacionesComerciantesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idAsociacionComerciante
	 *            Integer
	 * @return AsociacionesComerciantes Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idAsociacionComerciante}", method = RequestMethod.GET)
	public @ResponseBody AsociacionesComerciantes get(@PathVariable Integer idAsociacionComerciante) {
		AsociacionesComerciantes asociacionesComerciantes = new AsociacionesComerciantes();
		asociacionesComerciantes.setIdAsociacionComerciante(idAsociacionComerciante);
		asociacionesComerciantes = this.asociacionesComerciantesService.find(asociacionesComerciantes);
		AsociacionesComerciantesController.logger.info("[GET - findBy_PK] : Obtener AsociacionesComerciantes por PK");
		return asociacionesComerciantes;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<AsociacionesComerciantes> Lista de objetos correspondientes
	 *         a la busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<AsociacionesComerciantes> getAll(
			@ModelAttribute AsociacionesComerciantes filterAsociacionesComerciantes) {
		AsociacionesComerciantesController.logger
				.info("[GET - find_ALL] : Obtener AsociacionesComerciantes por filtro");
		return this.asociacionesComerciantesService.findAll(filterAsociacionesComerciantes, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene la informacion a
	 *            modificar.
	 * @return AsociacionesComerciantes Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody AsociacionesComerciantes edit(@RequestBody AsociacionesComerciantes asociacionesComerciantes) {
		AsociacionesComerciantes asociacionesComerciantesAux = this.asociacionesComerciantesService
				.update(asociacionesComerciantes);
		AsociacionesComerciantesController.logger.info("[PUT] : AsociacionesComerciantes actualizado correctamente");
		return asociacionesComerciantesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param asociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene la informacion con
	 *            la que se va a crear el nuevo registro.
	 * @return AsociacionesComerciantes Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody AsociacionesComerciantes add(@RequestBody AsociacionesComerciantes asociacionesComerciantes) {
		AsociacionesComerciantes asociacionesComerciantesAux = this.asociacionesComerciantesService
				.add(asociacionesComerciantes);
		AsociacionesComerciantesController.logger.info("[POST] : AsociacionesComerciantes insertado correctamente");
		return asociacionesComerciantesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAsociacionComerciante
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return AsociacionesComerciantes Bean eliminado.
	 */
	@RequestMapping(value = "/{idAsociacionComerciante}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody AsociacionesComerciantes remove(@PathVariable Integer idAsociacionComerciante) {
		AsociacionesComerciantes asociacionesComerciantes = new AsociacionesComerciantes();
		asociacionesComerciantes.setIdAsociacionComerciante(idAsociacionComerciante);
		this.asociacionesComerciantesService.remove(asociacionesComerciantes);
		AsociacionesComerciantesController.logger.info("[DELETE] : AsociacionesComerciantes borrado correctamente");
		return asociacionesComerciantes;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AsociacionesComerciantesController.logger.info("[GET - View] : asociacionescomerciantes");
		return "asociacionescomerciantes";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<AsociacionesComerciantes> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<AsociacionesComerciantes> filter(
			@RequestJsonBody(param = "filter") AsociacionesComerciantes filterAsociacionesComerciantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesComerciantesController.logger.info("[POST - filter] : Obtener AsociacionesComerciantess");
		return this.asociacionesComerciantesService.filter(filterAsociacionesComerciantes, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchAsociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<AsociacionesComerciantes> Dto que contiene el
	 *         resultado de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<AsociacionesComerciantes>> search(
			@RequestJsonBody(param = "filter") AsociacionesComerciantes filterAsociacionesComerciantes,
			@RequestJsonBody(param = "search") AsociacionesComerciantes searchAsociacionesComerciantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesComerciantesController.logger.info("[POST - search] : Buscar AsociacionesComerciantess");
		return this.asociacionesComerciantesService.search(filterAsociacionesComerciantes,
				searchAsociacionesComerciantes, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") AsociacionesComerciantes filterAsociacionesComerciantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesComerciantesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples AsociacionesComerciantess");
		this.asociacionesComerciantesService.removeMultiple(filterAsociacionesComerciantes, jqGridRequestDto, false);
		AsociacionesComerciantesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>> jerarquia(
			@RequestJsonBody(param = "filter") AsociacionesComerciantes filterAsociacionesComerciantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesComerciantesController.logger
				.info("[POST - jerarquia] : Obtener AsociacionesComerciantess jerarquia");
		return this.asociacionesComerciantesService.jerarquia(filterAsociacionesComerciantes, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAsociacionesComerciantes
	 *            AsociacionesComerciantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AsociacionesComerciantes>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") AsociacionesComerciantes filterAsociacionesComerciantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociacionesComerciantesController.logger
				.info("[POST - jerarquia] : Obtener AsociacionesComerciantess jerarquia - Hijos");
		return this.asociacionesComerciantesService.jerarquiaChildren(filterAsociacionesComerciantes, jqGridRequestDto);
	}

}
