package com.ejie.ab60.control.DEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DEC.LimiteAsociaciones;
import com.ejie.ab60.service.DEC.LimiteAsociacionesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * LimiteAsociacionesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/limiteasociaciones")

public class LimiteAsociacionesController {

	private static final Logger logger = LoggerFactory.getLogger(LimiteAsociacionesController.class);

	@Autowired
	private LimiteAsociacionesService limiteAsociacionesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idMunicipioAso
	 *            Long
	 * @return LimiteAsociaciones Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idMunicipioAso}", method = RequestMethod.GET)
	public @ResponseBody LimiteAsociaciones get(@PathVariable Long idMunicipioAso) {
		LimiteAsociaciones limiteAsociaciones = new LimiteAsociaciones();
		limiteAsociaciones.setIdMunicipioAso(idMunicipioAso);
		limiteAsociaciones = this.limiteAsociacionesService.find(limiteAsociaciones);
		LimiteAsociacionesController.logger.info("[GET - findBy_PK] : Obtener LimiteAsociaciones por PK");
		return limiteAsociaciones;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<LimiteAsociaciones> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<LimiteAsociaciones> getAll(@ModelAttribute LimiteAsociaciones filterLimiteAsociaciones) {
		LimiteAsociacionesController.logger.info("[GET - find_ALL] : Obtener LimiteAsociaciones por filtro");
		return this.limiteAsociacionesService.findAll(filterLimiteAsociaciones, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param limiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene la informacion a
	 *            modificar.
	 * @return LimiteAsociaciones Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody LimiteAsociaciones edit(@RequestBody LimiteAsociaciones limiteAsociaciones) {
		LimiteAsociaciones limiteAsociacionesAux = this.limiteAsociacionesService.update(limiteAsociaciones);
		LimiteAsociacionesController.logger.info("[PUT] : LimiteAsociaciones actualizado correctamente");
		return limiteAsociacionesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param limiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return LimiteAsociaciones Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody LimiteAsociaciones add(@RequestBody LimiteAsociaciones limiteAsociaciones) {
		LimiteAsociaciones limiteAsociacionesAux = this.limiteAsociacionesService.add(limiteAsociaciones);
		LimiteAsociacionesController.logger.info("[POST] : LimiteAsociaciones insertado correctamente");
		return limiteAsociacionesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idMunicipioAso
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return LimiteAsociaciones Bean eliminado.
	 */
	@RequestMapping(value = "/{idMunicipioAso}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody LimiteAsociaciones remove(@PathVariable Long idMunicipioAso) {
		LimiteAsociaciones limiteAsociaciones = new LimiteAsociaciones();
		limiteAsociaciones.setIdMunicipioAso(idMunicipioAso);
		this.limiteAsociacionesService.remove(limiteAsociaciones);
		LimiteAsociacionesController.logger.info("[DELETE] : LimiteAsociaciones borrado correctamente");
		return limiteAsociaciones;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		LimiteAsociacionesController.logger.info("[GET - View] : limiteasociaciones");
		return "limiteasociaciones";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<LimiteAsociaciones> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<LimiteAsociaciones> filter(
			@RequestJsonBody(param = "filter") LimiteAsociaciones filterLimiteAsociaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAsociacionesController.logger.info("[POST - filter] : Obtener LimiteAsociacioness");
		return this.limiteAsociacionesService.filter(filterLimiteAsociaciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchLimiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<LimiteAsociaciones> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<LimiteAsociaciones>> search(
			@RequestJsonBody(param = "filter") LimiteAsociaciones filterLimiteAsociaciones,
			@RequestJsonBody(param = "search") LimiteAsociaciones searchLimiteAsociaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAsociacionesController.logger.info("[POST - search] : Buscar LimiteAsociacioness");
		return this.limiteAsociacionesService.search(filterLimiteAsociaciones, searchLimiteAsociaciones,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") LimiteAsociaciones filterLimiteAsociaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAsociacionesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples LimiteAsociacioness");
		this.limiteAsociacionesService.removeMultiple(filterLimiteAsociaciones, jqGridRequestDto, false);
		LimiteAsociacionesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<LimiteAsociaciones>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<LimiteAsociaciones>> jerarquia(
			@RequestJsonBody(param = "filter") LimiteAsociaciones filterLimiteAsociaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAsociacionesController.logger.info("[POST - jerarquia] : Obtener LimiteAsociacioness jerarquia");
		return this.limiteAsociacionesService.jerarquia(filterLimiteAsociaciones, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterLimiteAsociaciones
	 *            LimiteAsociaciones Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<LimiteAsociaciones>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<LimiteAsociaciones>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") LimiteAsociaciones filterLimiteAsociaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAsociacionesController.logger.info("[POST - jerarquia] : Obtener LimiteAsociacioness jerarquia - Hijos");
		return this.limiteAsociacionesService.jerarquiaChildren(filterLimiteAsociaciones, jqGridRequestDto);
	}

}
