package com.ejie.ab60.control.DEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DEC.LimiteAyuntamientos;
import com.ejie.ab60.service.DEC.LimiteAyuntamientosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * LimiteAyuntamientosController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/limiteayuntamientos")

public class LimiteAyuntamientosController {

	private static final Logger logger = LoggerFactory.getLogger(LimiteAyuntamientosController.class);

	@Autowired
	private LimiteAyuntamientosService limiteAyuntamientosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idMunicipioAyu
	 *            Long
	 * @return LimiteAyuntamientos Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idMunicipioAyu}", method = RequestMethod.GET)
	public @ResponseBody LimiteAyuntamientos get(@PathVariable Long idMunicipioAyu) {
		LimiteAyuntamientos limiteAyuntamientos = new LimiteAyuntamientos();
		limiteAyuntamientos.setIdMunicipioAyu(idMunicipioAyu);
		limiteAyuntamientos = this.limiteAyuntamientosService.find(limiteAyuntamientos);
		LimiteAyuntamientosController.logger.info("[GET - findBy_PK] : Obtener LimiteAyuntamientos por PK");
		return limiteAyuntamientos;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<LimiteAyuntamientos> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<LimiteAyuntamientos> getAll(
			@ModelAttribute LimiteAyuntamientos filterLimiteAyuntamientos) {
		LimiteAyuntamientosController.logger.info("[GET - find_ALL] : Obtener LimiteAyuntamientos por filtro");
		return this.limiteAyuntamientosService.findAll(filterLimiteAyuntamientos, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param limiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene la informacion a
	 *            modificar.
	 * @return LimiteAyuntamientos Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody LimiteAyuntamientos edit(@RequestBody LimiteAyuntamientos limiteAyuntamientos) {
		LimiteAyuntamientos limiteAyuntamientosAux = this.limiteAyuntamientosService.update(limiteAyuntamientos);
		LimiteAyuntamientosController.logger.info("[PUT] : LimiteAyuntamientos actualizado correctamente");
		return limiteAyuntamientosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param limiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return LimiteAyuntamientos Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody LimiteAyuntamientos add(@RequestBody LimiteAyuntamientos limiteAyuntamientos) {
		LimiteAyuntamientos limiteAyuntamientosAux = this.limiteAyuntamientosService.add(limiteAyuntamientos);
		LimiteAyuntamientosController.logger.info("[POST] : LimiteAyuntamientos insertado correctamente");
		return limiteAyuntamientosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idMunicipioAyu
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return LimiteAyuntamientos Bean eliminado.
	 */
	@RequestMapping(value = "/{idMunicipioAyu}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody LimiteAyuntamientos remove(@PathVariable Long idMunicipioAyu) {
		LimiteAyuntamientos limiteAyuntamientos = new LimiteAyuntamientos();
		limiteAyuntamientos.setIdMunicipioAyu(idMunicipioAyu);
		this.limiteAyuntamientosService.remove(limiteAyuntamientos);
		LimiteAyuntamientosController.logger.info("[DELETE] : LimiteAyuntamientos borrado correctamente");
		return limiteAyuntamientos;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		LimiteAyuntamientosController.logger.info("[GET - View] : limiteayuntamientos");
		return "limiteayuntamientos";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<LimiteAyuntamientos> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<LimiteAyuntamientos> filter(
			@RequestJsonBody(param = "filter") LimiteAyuntamientos filterLimiteAyuntamientos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAyuntamientosController.logger.info("[POST - filter] : Obtener LimiteAyuntamientoss");
		return this.limiteAyuntamientosService.filter(filterLimiteAyuntamientos, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchLimiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<LimiteAyuntamientos> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<LimiteAyuntamientos>> search(
			@RequestJsonBody(param = "filter") LimiteAyuntamientos filterLimiteAyuntamientos,
			@RequestJsonBody(param = "search") LimiteAyuntamientos searchLimiteAyuntamientos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAyuntamientosController.logger.info("[POST - search] : Buscar LimiteAyuntamientoss");
		return this.limiteAyuntamientosService.search(filterLimiteAyuntamientos, searchLimiteAyuntamientos,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") LimiteAyuntamientos filterLimiteAyuntamientos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAyuntamientosController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples LimiteAyuntamientoss");
		this.limiteAyuntamientosService.removeMultiple(filterLimiteAyuntamientos, jqGridRequestDto, false);
		LimiteAyuntamientosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<LimiteAyuntamientos>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<LimiteAyuntamientos>> jerarquia(
			@RequestJsonBody(param = "filter") LimiteAyuntamientos filterLimiteAyuntamientos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAyuntamientosController.logger.info("[POST - jerarquia] : Obtener LimiteAyuntamientoss jerarquia");
		return this.limiteAyuntamientosService.jerarquia(filterLimiteAyuntamientos, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterLimiteAyuntamientos
	 *            LimiteAyuntamientos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<LimiteAyuntamientos>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<LimiteAyuntamientos>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") LimiteAyuntamientos filterLimiteAyuntamientos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		LimiteAyuntamientosController.logger
				.info("[POST - jerarquia] : Obtener LimiteAyuntamientoss jerarquia - Hijos");
		return this.limiteAyuntamientosService.jerarquiaChildren(filterLimiteAyuntamientos, jqGridRequestDto);
	}

}
