package com.ejie.ab60.control.DEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DEC.RelMunAsoCom;
import com.ejie.ab60.service.DEC.RelMunAsoComService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelMunAsoComController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relmunasocom")

public class RelMunAsoComController {

	private static final Logger logger = LoggerFactory.getLogger(RelMunAsoComController.class);

	@Autowired
	private RelMunAsoComService relMunAsoComService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idMunicipioAsoCom
	 *            Integer
	 * @return RelMunAsoCom Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idMunicipioAsoCom}", method = RequestMethod.GET)
	public @ResponseBody RelMunAsoCom get(@PathVariable Integer idMunicipioAsoCom) {
		RelMunAsoCom relMunAsoCom = new RelMunAsoCom();
		relMunAsoCom.setIdMunicipioAsoCom(idMunicipioAsoCom);
		relMunAsoCom = this.relMunAsoComService.find(relMunAsoCom);
		RelMunAsoComController.logger.info("[GET - findBy_PK] : Obtener RelMunAsoCom por PK");
		return relMunAsoCom;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelMunAsoCom> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelMunAsoCom> getAll(@ModelAttribute RelMunAsoCom filterRelMunAsoCom) {
		RelMunAsoComController.logger.info("[GET - find_ALL] : Obtener RelMunAsoCom por filtro");
		return this.relMunAsoComService.findAll(filterRelMunAsoCom, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relMunAsoCom
	 *            RelMunAsoCom Bean que contiene la informacion a modificar.
	 * @return RelMunAsoCom Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelMunAsoCom edit(@RequestBody RelMunAsoCom relMunAsoCom) {
		RelMunAsoCom relMunAsoComAux = this.relMunAsoComService.update(relMunAsoCom);
		RelMunAsoComController.logger.info("[PUT] : RelMunAsoCom actualizado correctamente");
		return relMunAsoComAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relMunAsoCom
	 *            RelMunAsoCom Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelMunAsoCom Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelMunAsoCom add(@RequestBody RelMunAsoCom relMunAsoCom) {
		RelMunAsoCom relMunAsoComAux = this.relMunAsoComService.add(relMunAsoCom);
		RelMunAsoComController.logger.info("[POST] : RelMunAsoCom insertado correctamente");
		return relMunAsoComAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idMunicipioAsoCom
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelMunAsoCom Bean eliminado.
	 */
	@RequestMapping(value = "/{idMunicipioAsoCom}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelMunAsoCom remove(@PathVariable Integer idMunicipioAsoCom) {
		RelMunAsoCom relMunAsoCom = new RelMunAsoCom();
		relMunAsoCom.setIdMunicipioAsoCom(idMunicipioAsoCom);
		this.relMunAsoComService.remove(relMunAsoCom);
		RelMunAsoComController.logger.info("[DELETE] : RelMunAsoCom borrado correctamente");
		return relMunAsoCom;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelMunAsoComController.logger.info("[GET - View] : relmunasocom");
		return "relmunasocom";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelMunAsoCom> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelMunAsoCom> filter(
			@RequestJsonBody(param = "filter") RelMunAsoCom filterRelMunAsoCom,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelMunAsoComController.logger.info("[POST - filter] : Obtener RelMunAsoComs");
		return this.relMunAsoComService.filter(filterRelMunAsoCom, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelMunAsoCom
	 *            RelMunAsoCom Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelMunAsoCom> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelMunAsoCom>> search(
			@RequestJsonBody(param = "filter") RelMunAsoCom filterRelMunAsoCom,
			@RequestJsonBody(param = "search") RelMunAsoCom searchRelMunAsoCom,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelMunAsoComController.logger.info("[POST - search] : Buscar RelMunAsoComs");
		return this.relMunAsoComService.search(filterRelMunAsoCom, searchRelMunAsoCom, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelMunAsoCom filterRelMunAsoCom,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelMunAsoComController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelMunAsoComs");
		this.relMunAsoComService.removeMultiple(filterRelMunAsoCom, jqGridRequestDto, false);
		RelMunAsoComController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelMunAsoCom>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelMunAsoCom>> jerarquia(
			@RequestJsonBody(param = "filter") RelMunAsoCom filterRelMunAsoCom,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelMunAsoComController.logger.info("[POST - jerarquia] : Obtener RelMunAsoComs jerarquia");
		return this.relMunAsoComService.jerarquia(filterRelMunAsoCom, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelMunAsoCom
	 *            RelMunAsoCom Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelMunAsoCom>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelMunAsoCom>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelMunAsoCom filterRelMunAsoCom,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelMunAsoComController.logger.info("[POST - jerarquia] : Obtener RelMunAsoComs jerarquia - Hijos");
		return this.relMunAsoComService.jerarquiaChildren(filterRelMunAsoCom, jqGridRequestDto);
	}

}
