package com.ejie.ab60.control.DIV;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DIV.Acciones;
import com.ejie.ab60.service.DIV.AccionesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AccionesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/acciones")

public class AccionesController {

	private static final Logger logger = LoggerFactory.getLogger(AccionesController.class);

	@Autowired
	private AccionesService accionesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idAcciones
	 *            Integer
	 * @return Acciones Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idAcciones}", method = RequestMethod.GET)
	public @ResponseBody Acciones get(@PathVariable Integer idAcciones) {
		Acciones acciones = new Acciones();
		acciones.setIdAcciones(idAcciones);
		acciones = this.accionesService.find(acciones);
		AccionesController.logger.info("[GET - findBy_PK] : Obtener Acciones por PK");
		return acciones;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAcciones
	 *            Acciones Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Acciones> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Acciones> getAll(@ModelAttribute Acciones filterAcciones) {
		AccionesController.logger.info("[GET - find_ALL] : Obtener Acciones por filtro");
		return this.accionesService.findAll(filterAcciones, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param acciones
	 *            Acciones Bean que contiene la informacion a modificar.
	 * @return Acciones Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Acciones edit(@RequestBody Acciones acciones) {
		Acciones accionesAux = this.accionesService.update(acciones);
		AccionesController.logger.info("[PUT] : Acciones actualizado correctamente");
		return accionesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param acciones
	 *            Acciones Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Acciones Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Acciones add(@RequestBody Acciones acciones) {
		Acciones accionesAux = this.accionesService.add(acciones);
		AccionesController.logger.info("[POST] : Acciones insertado correctamente");
		return accionesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAcciones
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Acciones Bean eliminado.
	 */
	@RequestMapping(value = "/{idAcciones}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Acciones remove(@PathVariable Integer idAcciones) {
		Acciones acciones = new Acciones();
		acciones.setIdAcciones(idAcciones);
		this.accionesService.remove(acciones);
		AccionesController.logger.info("[DELETE] : Acciones borrado correctamente");
		return acciones;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AccionesController.logger.info("[GET - View] : acciones");
		return "acciones";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAcciones
	 *            Acciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Acciones> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Acciones> filter(@RequestJsonBody(param = "filter") Acciones filterAcciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AccionesController.logger.info("[POST - filter] : Obtener Accioness");
		return this.accionesService.filter(filterAcciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAcciones
	 *            Acciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAcciones
	 *            Acciones Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Acciones> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Acciones>> search(@RequestJsonBody(param = "filter") Acciones filterAcciones,
			@RequestJsonBody(param = "search") Acciones searchAcciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AccionesController.logger.info("[POST - search] : Buscar Accioness");
		return this.accionesService.search(filterAcciones, searchAcciones, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAcciones
	 *            Acciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Acciones filterAcciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AccionesController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Accioness");
		this.accionesService.removeMultiple(filterAcciones, jqGridRequestDto, false);
		AccionesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAcciones
	 *            Acciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Acciones>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Acciones>> jerarquia(
			@RequestJsonBody(param = "filter") Acciones filterAcciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AccionesController.logger.info("[POST - jerarquia] : Obtener Accioness jerarquia");
		return this.accionesService.jerarquia(filterAcciones, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAcciones
	 *            Acciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Acciones>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Acciones>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Acciones filterAcciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AccionesController.logger.info("[POST - jerarquia] : Obtener Accioness jerarquia - Hijos");
		return this.accionesService.jerarquiaChildren(filterAcciones, jqGridRequestDto);
	}

}
