package com.ejie.ab60.control.DIV;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DIV.EntidadesSolicitantes;
import com.ejie.ab60.service.DIV.EntidadesSolicitantesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * EntidadesSolicitantesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/entidadessolicitantes")

public class EntidadesSolicitantesController {

	private static final Logger logger = LoggerFactory.getLogger(EntidadesSolicitantesController.class);

	@Autowired
	private EntidadesSolicitantesService entidadesSolicitantesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idEntidadSolicitante
	 *            Integer
	 * @return EntidadesSolicitantes Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idEntidadSolicitante}", method = RequestMethod.GET)
	public @ResponseBody EntidadesSolicitantes get(@PathVariable Integer idEntidadSolicitante) {
		EntidadesSolicitantes entidadesSolicitantes = new EntidadesSolicitantes();
		entidadesSolicitantes.setIdEntidadSolicitante(idEntidadSolicitante);
		entidadesSolicitantes = this.entidadesSolicitantesService.find(entidadesSolicitantes);
		EntidadesSolicitantesController.logger.info("[GET - findBy_PK] : Obtener EntidadesSolicitantes por PK");
		return entidadesSolicitantes;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<EntidadesSolicitantes> Lista de objetos correspondientes a
	 *         la busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<EntidadesSolicitantes> getAll(
			@ModelAttribute EntidadesSolicitantes filterEntidadesSolicitantes) {
		EntidadesSolicitantesController.logger.info("[GET - find_ALL] : Obtener EntidadesSolicitantes por filtro");
		return this.entidadesSolicitantesService.findAll(filterEntidadesSolicitantes, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param entidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene la informacion a
	 *            modificar.
	 * @return EntidadesSolicitantes Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody EntidadesSolicitantes edit(@RequestBody EntidadesSolicitantes entidadesSolicitantes) {
		EntidadesSolicitantes entidadesSolicitantesAux = this.entidadesSolicitantesService
				.update(entidadesSolicitantes);
		EntidadesSolicitantesController.logger.info("[PUT] : EntidadesSolicitantes actualizado correctamente");
		return entidadesSolicitantesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param entidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return EntidadesSolicitantes Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody EntidadesSolicitantes add(@RequestBody EntidadesSolicitantes entidadesSolicitantes) {
		EntidadesSolicitantes entidadesSolicitantesAux = this.entidadesSolicitantesService.add(entidadesSolicitantes);
		EntidadesSolicitantesController.logger.info("[POST] : EntidadesSolicitantes insertado correctamente");
		return entidadesSolicitantesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idEntidadSolicitante
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return EntidadesSolicitantes Bean eliminado.
	 */
	@RequestMapping(value = "/{idEntidadSolicitante}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody EntidadesSolicitantes remove(@PathVariable Integer idEntidadSolicitante) {
		EntidadesSolicitantes entidadesSolicitantes = new EntidadesSolicitantes();
		entidadesSolicitantes.setIdEntidadSolicitante(idEntidadSolicitante);
		this.entidadesSolicitantesService.remove(entidadesSolicitantes);
		EntidadesSolicitantesController.logger.info("[DELETE] : EntidadesSolicitantes borrado correctamente");
		return entidadesSolicitantes;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		EntidadesSolicitantesController.logger.info("[GET - View] : entidadessolicitantes");
		return "entidadessolicitantes";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<EntidadesSolicitantes> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<EntidadesSolicitantes> filter(
			@RequestJsonBody(param = "filter") EntidadesSolicitantes filterEntidadesSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EntidadesSolicitantesController.logger.info("[POST - filter] : Obtener EntidadesSolicitantess");
		return this.entidadesSolicitantesService.filter(filterEntidadesSolicitantes, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchEntidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<EntidadesSolicitantes> Dto que contiene el resultado
	 *         de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<EntidadesSolicitantes>> search(
			@RequestJsonBody(param = "filter") EntidadesSolicitantes filterEntidadesSolicitantes,
			@RequestJsonBody(param = "search") EntidadesSolicitantes searchEntidadesSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EntidadesSolicitantesController.logger.info("[POST - search] : Buscar EntidadesSolicitantess");
		return this.entidadesSolicitantesService.search(filterEntidadesSolicitantes, searchEntidadesSolicitantes,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") EntidadesSolicitantes filterEntidadesSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EntidadesSolicitantesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples EntidadesSolicitantess");
		this.entidadesSolicitantesService.removeMultiple(filterEntidadesSolicitantes, jqGridRequestDto, false);
		EntidadesSolicitantesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<EntidadesSolicitantes>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<EntidadesSolicitantes>> jerarquia(
			@RequestJsonBody(param = "filter") EntidadesSolicitantes filterEntidadesSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EntidadesSolicitantesController.logger.info("[POST - jerarquia] : Obtener EntidadesSolicitantess jerarquia");
		return this.entidadesSolicitantesService.jerarquia(filterEntidadesSolicitantes, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterEntidadesSolicitantes
	 *            EntidadesSolicitantes Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<EntidadesSolicitantes>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<EntidadesSolicitantes>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") EntidadesSolicitantes filterEntidadesSolicitantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EntidadesSolicitantesController.logger
				.info("[POST - jerarquia] : Obtener EntidadesSolicitantess jerarquia - Hijos");
		return this.entidadesSolicitantesService.jerarquiaChildren(filterEntidadesSolicitantes, jqGridRequestDto);
	}

}
