package com.ejie.ab60.control.DIV;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DIV.RelExpEntSol;
import com.ejie.ab60.service.DIV.RelExpEntSolService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpEntSolController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relexpentsol")

public class RelExpEntSolController {

	private static final Logger logger = LoggerFactory.getLogger(RelExpEntSolController.class);

	@Autowired
	private RelExpEntSolService relExpEntSolService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelExpEntSol
	 *            Integer
	 * @return RelExpEntSol Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelExpEntSol}", method = RequestMethod.GET)
	public @ResponseBody RelExpEntSol get(@PathVariable Integer idRelExpEntSol) {
		RelExpEntSol relExpEntSol = new RelExpEntSol();
		relExpEntSol.setIdRelExpEntSol(idRelExpEntSol);
		relExpEntSol = this.relExpEntSolService.find(relExpEntSol);
		RelExpEntSolController.logger.info("[GET - findBy_PK] : Obtener RelExpEntSol por PK");
		return relExpEntSol;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelExpEntSol
	 *            RelExpEntSol Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelExpEntSol> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelExpEntSol> getAll(@ModelAttribute RelExpEntSol filterRelExpEntSol) {
		RelExpEntSolController.logger.info("[GET - find_ALL] : Obtener RelExpEntSol por filtro");
		return this.relExpEntSolService.findAll(filterRelExpEntSol, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpEntSol
	 *            RelExpEntSol Bean que contiene la informacion a modificar.
	 * @return RelExpEntSol Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelExpEntSol edit(@RequestBody RelExpEntSol relExpEntSol) {
		RelExpEntSol relExpEntSolAux = this.relExpEntSolService.update(relExpEntSol);
		RelExpEntSolController.logger.info("[PUT] : RelExpEntSol actualizado correctamente");
		return relExpEntSolAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relExpEntSol
	 *            RelExpEntSol Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelExpEntSol Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelExpEntSol add(@RequestBody RelExpEntSol relExpEntSol) {
		RelExpEntSol relExpEntSolAux = this.relExpEntSolService.add(relExpEntSol);
		RelExpEntSolController.logger.info("[POST] : RelExpEntSol insertado correctamente");
		return relExpEntSolAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelExpEntSol
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelExpEntSol Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelExpEntSol}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelExpEntSol remove(@PathVariable Integer idRelExpEntSol) {
		RelExpEntSol relExpEntSol = new RelExpEntSol();
		relExpEntSol.setIdRelExpEntSol(idRelExpEntSol);
		this.relExpEntSolService.remove(relExpEntSol);
		RelExpEntSolController.logger.info("[DELETE] : RelExpEntSol borrado correctamente");
		return relExpEntSol;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelExpEntSolController.logger.info("[GET - View] : relexpentsol");
		return "relexpentsol";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelExpEntSol
	 *            RelExpEntSol Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelExpEntSol> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpEntSol> filter(
			@RequestJsonBody(param = "filter") RelExpEntSol filterRelExpEntSol,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpEntSolController.logger.info("[POST - filter] : Obtener RelExpEntSols");
		return this.relExpEntSolService.filter(filterRelExpEntSol, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelExpEntSol
	 *            RelExpEntSol Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelExpEntSol
	 *            RelExpEntSol Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelExpEntSol> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelExpEntSol>> search(
			@RequestJsonBody(param = "filter") RelExpEntSol filterRelExpEntSol,
			@RequestJsonBody(param = "search") RelExpEntSol searchRelExpEntSol,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpEntSolController.logger.info("[POST - search] : Buscar RelExpEntSols");
		return this.relExpEntSolService.search(filterRelExpEntSol, searchRelExpEntSol, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelExpEntSol
	 *            RelExpEntSol Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelExpEntSol filterRelExpEntSol,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpEntSolController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelExpEntSols");
		this.relExpEntSolService.removeMultiple(filterRelExpEntSol, jqGridRequestDto, false);
		RelExpEntSolController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelExpEntSol
	 *            RelExpEntSol Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpEntSol>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpEntSol>> jerarquia(
			@RequestJsonBody(param = "filter") RelExpEntSol filterRelExpEntSol,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpEntSolController.logger.info("[POST - jerarquia] : Obtener RelExpEntSols jerarquia");
		return this.relExpEntSolService.jerarquia(filterRelExpEntSol, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelExpEntSol
	 *            RelExpEntSol Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpEntSol>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpEntSol>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelExpEntSol filterRelExpEntSol,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpEntSolController.logger.info("[POST - jerarquia] : Obtener RelExpEntSols jerarquia - Hijos");
		return this.relExpEntSolService.jerarquiaChildren(filterRelExpEntSol, jqGridRequestDto);
	}

}
