package com.ejie.ab60.control.DIV;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DIV.TiposActividad;
import com.ejie.ab60.service.DIV.TiposActividadService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposActividadController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposactividad")

public class TiposActividadController {

	private static final Logger logger = LoggerFactory.getLogger(TiposActividadController.class);

	@Autowired
	private TiposActividadService tiposActividadService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoActividad
	 *            Long
	 * @return TiposActividad Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoActividad}", method = RequestMethod.GET)
	public @ResponseBody TiposActividad get(@PathVariable Long idTipoActividad) {
		TiposActividad tiposActividad = new TiposActividad();
		tiposActividad.setIdTipoActividad(idTipoActividad);
		tiposActividad = this.tiposActividadService.find(tiposActividad);
		TiposActividadController.logger.info("[GET - findBy_PK] : Obtener TiposActividad por PK");
		return tiposActividad;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposActividad
	 *            TiposActividad Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<TiposActividad> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposActividad> getAll(@ModelAttribute TiposActividad filterTiposActividad) {
		TiposActividadController.logger.info("[GET - find_ALL] : Obtener TiposActividad por filtro");
		return this.tiposActividadService.findAll(filterTiposActividad, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposActividad
	 *            TiposActividad Bean que contiene la informacion a modificar.
	 * @return TiposActividad Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposActividad edit(@RequestBody TiposActividad tiposActividad) {
		TiposActividad tiposActividadAux = this.tiposActividadService.update(tiposActividad);
		TiposActividadController.logger.info("[PUT] : TiposActividad actualizado correctamente");
		return tiposActividadAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposActividad
	 *            TiposActividad Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return TiposActividad Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposActividad add(@RequestBody TiposActividad tiposActividad) {
		TiposActividad tiposActividadAux = this.tiposActividadService.add(tiposActividad);
		TiposActividadController.logger.info("[POST] : TiposActividad insertado correctamente");
		return tiposActividadAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoActividad
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposActividad Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoActividad}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposActividad remove(@PathVariable Long idTipoActividad) {
		TiposActividad tiposActividad = new TiposActividad();
		tiposActividad.setIdTipoActividad(idTipoActividad);
		this.tiposActividadService.remove(tiposActividad);
		TiposActividadController.logger.info("[DELETE] : TiposActividad borrado correctamente");
		return tiposActividad;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposActividadController.logger.info("[GET - View] : tiposactividad");
		return "tiposactividad";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposActividad
	 *            TiposActividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposActividad> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposActividad> filter(
			@RequestJsonBody(param = "filter") TiposActividad filterTiposActividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposActividadController.logger.info("[POST - filter] : Obtener TiposActividads");
		return this.tiposActividadService.filter(filterTiposActividad, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposActividad
	 *            TiposActividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchTiposActividad
	 *            TiposActividad Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposActividad> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposActividad>> search(
			@RequestJsonBody(param = "filter") TiposActividad filterTiposActividad,
			@RequestJsonBody(param = "search") TiposActividad searchTiposActividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposActividadController.logger.info("[POST - search] : Buscar TiposActividads");
		return this.tiposActividadService.search(filterTiposActividad, searchTiposActividad, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposActividad
	 *            TiposActividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TiposActividad filterTiposActividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposActividadController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposActividads");
		this.tiposActividadService.removeMultiple(filterTiposActividad, jqGridRequestDto, false);
		TiposActividadController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposActividad
	 *            TiposActividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposActividad>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposActividad>> jerarquia(
			@RequestJsonBody(param = "filter") TiposActividad filterTiposActividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposActividadController.logger.info("[POST - jerarquia] : Obtener TiposActividads jerarquia");
		return this.tiposActividadService.jerarquia(filterTiposActividad, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposActividad
	 *            TiposActividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposActividad>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposActividad>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposActividad filterTiposActividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposActividadController.logger.info("[POST - jerarquia] : Obtener TiposActividads jerarquia - Hijos");
		return this.tiposActividadService.jerarquiaChildren(filterTiposActividad, jqGridRequestDto);
	}

}
