package com.ejie.ab60.control.DIV;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.DIV.TiposAsociacion;
import com.ejie.ab60.service.DIV.TiposAsociacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposAsociacionController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposasociacion")

public class TiposAsociacionController {

	private static final Logger logger = LoggerFactory.getLogger(TiposAsociacionController.class);

	@Autowired
	private TiposAsociacionService tiposAsociacionService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoAsociacion
	 *            Long
	 * @return TiposAsociacion Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoAsociacion}", method = RequestMethod.GET)
	public @ResponseBody TiposAsociacion get(@PathVariable Long idTipoAsociacion) {
		TiposAsociacion tiposAsociacion = new TiposAsociacion();
		tiposAsociacion.setIdTipoAsociacion(idTipoAsociacion);
		tiposAsociacion = this.tiposAsociacionService.find(tiposAsociacion);
		TiposAsociacionController.logger.info("[GET - findBy_PK] : Obtener TiposAsociacion por PK");
		return tiposAsociacion;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposAsociacion
	 *            TiposAsociacion Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<TiposAsociacion> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposAsociacion> getAll(@ModelAttribute TiposAsociacion filterTiposAsociacion) {
		TiposAsociacionController.logger.info("[GET - find_ALL] : Obtener TiposAsociacion por filtro");
		return this.tiposAsociacionService.findAll(filterTiposAsociacion, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposAsociacion
	 *            TiposAsociacion Bean que contiene la informacion a modificar.
	 * @return TiposAsociacion Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposAsociacion edit(@RequestBody TiposAsociacion tiposAsociacion) {
		TiposAsociacion tiposAsociacionAux = this.tiposAsociacionService.update(tiposAsociacion);
		TiposAsociacionController.logger.info("[PUT] : TiposAsociacion actualizado correctamente");
		return tiposAsociacionAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposAsociacion
	 *            TiposAsociacion Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return TiposAsociacion Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposAsociacion add(@RequestBody TiposAsociacion tiposAsociacion) {
		TiposAsociacion tiposAsociacionAux = this.tiposAsociacionService.add(tiposAsociacion);
		TiposAsociacionController.logger.info("[POST] : TiposAsociacion insertado correctamente");
		return tiposAsociacionAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoAsociacion
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposAsociacion Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoAsociacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposAsociacion remove(@PathVariable Long idTipoAsociacion) {
		TiposAsociacion tiposAsociacion = new TiposAsociacion();
		tiposAsociacion.setIdTipoAsociacion(idTipoAsociacion);
		this.tiposAsociacionService.remove(tiposAsociacion);
		TiposAsociacionController.logger.info("[DELETE] : TiposAsociacion borrado correctamente");
		return tiposAsociacion;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposAsociacionController.logger.info("[GET - View] : tiposasociacion");
		return "tiposasociacion";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposAsociacion
	 *            TiposAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposAsociacion> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposAsociacion> filter(
			@RequestJsonBody(param = "filter") TiposAsociacion filterTiposAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAsociacionController.logger.info("[POST - filter] : Obtener TiposAsociacions");
		return this.tiposAsociacionService.filter(filterTiposAsociacion, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposAsociacion
	 *            TiposAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchTiposAsociacion
	 *            TiposAsociacion Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposAsociacion> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposAsociacion>> search(
			@RequestJsonBody(param = "filter") TiposAsociacion filterTiposAsociacion,
			@RequestJsonBody(param = "search") TiposAsociacion searchTiposAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAsociacionController.logger.info("[POST - search] : Buscar TiposAsociacions");
		return this.tiposAsociacionService.search(filterTiposAsociacion, searchTiposAsociacion, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposAsociacion
	 *            TiposAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TiposAsociacion filterTiposAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAsociacionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposAsociacions");
		this.tiposAsociacionService.removeMultiple(filterTiposAsociacion, jqGridRequestDto, false);
		TiposAsociacionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposAsociacion
	 *            TiposAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposAsociacion>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposAsociacion>> jerarquia(
			@RequestJsonBody(param = "filter") TiposAsociacion filterTiposAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAsociacionController.logger.info("[POST - jerarquia] : Obtener TiposAsociacions jerarquia");
		return this.tiposAsociacionService.jerarquia(filterTiposAsociacion, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposAsociacion
	 *            TiposAsociacion Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposAsociacion>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposAsociacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposAsociacion filterTiposAsociacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAsociacionController.logger.info("[POST - jerarquia] : Obtener TiposAsociacions jerarquia - Hijos");
		return this.tiposAsociacionService.jerarquiaChildren(filterTiposAsociacion, jqGridRequestDto);
	}

}
