package com.ejie.ab60.control.MEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.MEC.FacturasService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.util.UtilDate;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * FacturasController  
 * 
 *  
 */
@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/facturas")
public class FacturasController {

	private static final Logger logger = LoggerFactory.getLogger(FacturasController.class);

	@Autowired
	private RelExpActSubService relExpActSubService;
	@Autowired
	private FacturasService facturasService;
	@Autowired
	private ConvocatoriasService convocatoriasService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idFactura
	 *            Integer
	 * @return Facturas Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFactura}", method = RequestMethod.GET)
	public @ResponseBody Facturas get(@PathVariable Integer idFactura) {
		Facturas facturas = new Facturas();
		facturas.setIdFactura(idFactura);
		facturas = this.facturasService.find(facturas);
		FacturasController.logger.info("[GET - findBy_PK] : Obtener Facturas por PK");
		return facturas;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado, PARA LA FILA DE LA TABLA
	 * 
	 * @param idFactura
	 *            Integer
	 * @return Facturas Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}/{idFactura}", method = RequestMethod.GET)
	public @ResponseBody Facturas getEdit(@PathVariable("idRelacion") Integer idRelacion,
			@PathVariable("idFactura") Integer idFactura) {
		Facturas facturas = new Facturas();
		facturas.setIdFactura(idFactura);

		facturas = this.facturasService.find(facturas);

		String fechaFactura = UtilDate.convertirFechaEnString(facturas.getFechaFactura());
		String fechaPagado = UtilDate.convertirFechaEnString(facturas.getFechaPagado());

		facturas.setFechaFacturaStr(fechaFactura);
		facturas.setFechaPagadoStr(fechaPagado);
		FacturasController.logger.info("[GET - findBy_PK] : Obtener Facturas por PK");
		return facturas;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterFacturas
	 *            Facturas Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Facturas> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Facturas> getAll(@ModelAttribute Facturas filterFacturas) {
		FacturasController.logger.info("[GET - find_ALL] : Obtener Facturas por filtro");
		return this.facturasService.findAll(filterFacturas, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.PUT)
	public @ResponseBody Facturas edit(@PathVariable("idRelacion") Integer idRelacion,
			@PathVariable("idExpediente") Integer idExpediente, @PathVariable("idCriterio") Integer idCriterio,
			@RequestBody Facturas facturas, @ModelAttribute(value = "usuario") Usuario usuario) {
		FacturasController.logger.info("[GET - find_ALL] : Editamos Facturas por filtro");
		return this.facturasService.editFactura(idRelacion, idExpediente, idCriterio, facturas,
				Constantes.ORIGEN_DENEGACION_MINORACION_FACTURAS, usuario);

	}

	/**
	 * Metodo para modicar el importe de admitido, cuando le damos al boton de
	 * admitir todo
	 * 
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/tablaModificar/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.GET)
	public void editImporte(@PathVariable("idRelacion") Integer idRelacion, @PathVariable Integer idExpediente,
			@PathVariable Integer idCriterio, @ModelAttribute(value = "usuario") Usuario usuario) {
		facturasService.editImporte(idRelacion, idExpediente, idCriterio, usuario);

	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param facturas
	 *            Facturas Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Facturas Bean resultante del proceso de creacion.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.POST)
	public @ResponseBody Facturas add(@PathVariable Integer idRelacion, @PathVariable Integer idExpediente,
			@PathVariable Integer idCriterio, @RequestBody Facturas facturas,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return facturasService.add(idRelacion, idExpediente, idCriterio, facturas, usuario);
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado sw una fila de la tabla
	 *
	 * @param idFactura
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Facturas Bean eliminado.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}/{idFactura}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Facturas remove(@PathVariable Integer idFactura, @PathVariable Integer idRelacion,
			@PathVariable Integer idExpediente, @PathVariable Integer idCriterio,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return facturasService.removeFacturas(idFactura, idRelacion, idExpediente, idCriterio,
				Constantes.ORIGEN_DENEGACION_MINORACION_FACTURAS, usuario);

	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		FacturasController.logger.info("[GET - View] : facturas");
		return "facturas";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterFacturas
	 *            Facturas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Facturas> Dto que contiene el resultado del
	 *         filtrado realizado por el componente
	 */
	@RequestMapping(value = "/tabla/{idrelacion}/{idExpediente}/{idCriterio}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Facturas> filter(@RequestJsonBody(param = "filter") Facturas filterFacturas,
			@PathVariable Integer idrelacion, @PathVariable Integer idExpediente, @PathVariable Integer idCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idrelacion);
		relExpActSub.setIdExpediente(idExpediente);
		relExpActSub.setIdActSub(idCriterio);
		filterFacturas.setRelExpActSub(relExpActSub);

		// filterFacturas.set
		FacturasController.logger.info("[POST - filter] : Obtener Facturass con ides");

		return this.facturasService.filter(filterFacturas, jqGridRequestDto, false);
	}

	/**
	 * Metodo que saca la modal de facturas relacionadas con Actu Sub
	 * 
	 * @param idCriterio
	 * @param idExpediente
	 * @return String
	 */
	@RequestMapping(value = "/{idExpedientes}/{idCriterio}/{expedienteValidado}", method = RequestMethod.GET)
	public String cargarModal(@PathVariable("idExpedientes") Integer idExpedientes,
			@PathVariable("expedienteValidado") Integer expedienteValidado,
			@PathVariable("idCriterio") Integer idCriterio, Model model) {
		return this.facturasService.cargarModal(idExpedientes, expedienteValidado, idCriterio, model);

	}

	/**
	 * Operacion que me trae los totales de las facturas de una acion
	 * cubvencionable
	 * 
	 * 
	 * @param idRelacion
	 *            Integer
	 * @param idExpediente
	 *            Integer
	 * @param idCriterio,
	 *            Integer
	 * @return RelExpActSub
	 */

	@RequestMapping(value = "/totales/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.GET)
	public @ResponseBody RelExpActSub totales(@PathVariable Integer idRelacion, @PathVariable Integer idExpediente,
			@PathVariable Integer idCriterio) {

		RelExpActSub relExpActSubId = new RelExpActSub();
		FacturasController.logger.info("[POST - filter] : Obtener RelacionSubvencionable con ides");
		if (0 == idRelacion) {
			relExpActSubId = relExpActSubService.findUltimoId(idExpediente, idCriterio);
			idRelacion = relExpActSubId.getIdRelExpActSub();
			RelExpActSub ultimaRelacionExistente = relExpActSubService.findLastId(idExpediente, idCriterio);
			if (!ultimaRelacionExistente.getIdRelExpActSub().equals(idRelacion)) {
				idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
			}
		}

		return this.relExpActSubService.findTotales(idRelacion);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterFacturas
	 *            Facturas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchFacturas
	 *            Facturas Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Facturas> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Facturas>> search(@RequestJsonBody(param = "filter") Facturas filterFacturas,
			@RequestJsonBody(param = "search") Facturas searchFacturas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FacturasController.logger.info("[POST - search] : Buscar Facturass");
		return this.facturasService.search(filterFacturas, searchFacturas, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterFacturas
	 *            Facturas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Facturas filterFacturas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FacturasController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Facturass");
		this.facturasService.removeMultiple(filterFacturas, jqGridRequestDto, false);
		FacturasController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterFacturas
	 *            Facturas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Facturas>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Facturas>> jerarquia(
			@RequestJsonBody(param = "filter") Facturas filterFacturas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FacturasController.logger.info("[POST - jerarquia] : Obtener Facturass jerarquia");
		return this.facturasService.jerarquia(filterFacturas, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterFacturas
	 *            Facturas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Facturas>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Facturas>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Facturas filterFacturas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		FacturasController.logger.info("[POST - jerarquia] : Obtener Facturass jerarquia - Hijos");
		return this.facturasService.jerarquiaChildren(filterFacturas, jqGridRequestDto);
	}

	/**
	 * FILTER PARA MODAL DESDE MARCAR COMO INSPECCIONABLE ACCESIBLE DESDE
	 * ESTUDIO TECNICO O JUSTIFICACION PARA ENVIO DE DATOS A AB79 A PARTIR DE
	 * WEBSERVICE
	 */

	@RequestMapping(value = "/marcarInspeccionable/{idExpediente}/{idConvocatoria}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Facturas> filter(@RequestJsonBody(param = "filter") Facturas filterFacturas,
			@PathVariable Integer idExpediente, @PathVariable Integer idConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		// filterFacturas.set
		FacturasController.logger.info("[POST - filter] : Obtener Facturass con ides");

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdExpediente(idExpediente);
		filterFacturas.setRelExpActSub(relExpActSub);

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);
		convocatoria = convocatoriasService.find(convocatoria);

		switch (convocatoria.getIdTipoAyuda()) {
		case Constantes.TIPO_AYUDA_EMCO:
			return this.facturasService.filterMarcarInspeccionableEMCO(filterFacturas, jqGridRequestDto, false);
		default:
			return this.facturasService.filterMarcarInspeccionable(filterFacturas, jqGridRequestDto, false);
		}

	}

	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}/{idFactura}", method = RequestMethod.GET)
	public @ResponseBody Facturas getEdit(@PathVariable("idFactura") Integer idFactura) {
		Facturas factura = new Facturas();
		factura.setIdFactura(idFactura);

		factura = this.facturasService.find(factura);

		FacturasController.logger.info("[GET - findBy_PK] : Obtener Facturas por PK");
		return factura;
	}

	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Facturas> filterEMCO(
			@RequestJsonBody(param = "filter") Facturas filterConceptos, @PathVariable Integer idRelacion,
			@PathVariable Integer idExpediente, @PathVariable Integer idActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idRelacion);
		filterConceptos.setRelExpActSub(relExpActSub);

		// filterFacturas.set
		FacturasController.logger.info("[POST - filter] : Obtener Conceptos con ides");
		return this.facturasService.filterEMCO(filterConceptos, jqGridRequestDto, false);
	}

	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubHijo}", method = RequestMethod.PUT)
	public @ResponseBody Facturas edit(@PathVariable("idRelacion") Integer idRelacion,
			@PathVariable("idActSubHijo") Integer idActSubHijo, @PathVariable("idExpediente") Integer idExpediente,
			@PathVariable("idActSub") Integer idActSub, @RequestBody Facturas factura,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		Integer idActSubPadre = this.relExpActSubService.findRelExpActSubEmprePadreEMCO(idActSubHijo);

		factura = this.facturasService.editFacturaEMCO(idRelacion, idExpediente, idActSub, factura,
				Constantes.ORIGEN_DENEGACION_MINORACION_FACTURAS, usuario, idActSubPadre, idActSubHijo);

		return factura;
	}

	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubHijo}", method = RequestMethod.POST)
	public @ResponseBody Facturas add(@RequestBody Facturas factura, @PathVariable Integer idRelacion,
			@PathVariable Integer idExpediente, @PathVariable Integer idActSub, @PathVariable Integer idActSubHijo,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		Integer idActSubPadre = this.relExpActSubService.findRelExpActSubEmprePadreEMCO(idActSubHijo);

		factura = this.facturasService.addFacturaEMCO(idRelacion, factura, usuario, idExpediente, idActSub,
				idActSubPadre, idActSubHijo);

		return factura;
	}

	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubHijo}/{idFactura}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Facturas removeEMCO(@PathVariable Integer idRelacion, @PathVariable Integer idExpediente,
			@PathVariable Integer idActSub, @PathVariable Integer idActSubHijo, @PathVariable Integer idFactura,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		Integer idActSubPadre = this.relExpActSubService.findRelExpActSubEmprePadreEMCO(idActSubHijo);

		return facturasService.removeFacturasEMCO(idRelacion, idFactura, usuario, idExpediente, idActSub, idActSubHijo,
				idActSubPadre);
	}

	@RequestMapping(value = "/tablaModificar/{idRelacion}/{idExpediente}", method = RequestMethod.GET)
	public void editImporte(@PathVariable("idRelacion") Integer idRelacion, @PathVariable Integer idExpediente,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		facturasService.editImporteEMCO(idRelacion, idExpediente, usuario);
	}
}
