package com.ejie.ab60.control.MEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.MEC.Iae;
import com.ejie.ab60.service.MEC.IaeService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * IaeController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/iae")

public class IaeController {

	private static final Logger logger = LoggerFactory.getLogger(IaeController.class);

	@Autowired
	private IaeService iaeService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idIae
	 *            String
	 * @return Iae Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idIae}", method = RequestMethod.GET)
	public @ResponseBody Iae get(@PathVariable String idIae) {
		Iae iae = new Iae();
		iae.setIdIae(idIae);
		iae = this.iaeService.find(iae);
		IaeController.logger.info("[GET - findBy_PK] : Obtener Iae por PK");
		return iae;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterIae
	 *            Iae Objeto que contiene los parametros de filtrado utilizados
	 *            en la busqueda.
	 * @return List<Iae> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Iae> getAll(@ModelAttribute Iae filterIae) {
		IaeController.logger.info("[GET - find_ALL] : Obtener Iae por filtro");
		return this.iaeService.findAll(filterIae, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param iae
	 *            Iae Bean que contiene la informacion a modificar.
	 * @return Iae Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Iae edit(@RequestBody Iae iae) {
		Iae iaeAux = this.iaeService.update(iae);
		IaeController.logger.info("[PUT] : Iae actualizado correctamente");
		return iaeAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param iae
	 *            Iae Bean que contiene la informacion con la que se va a crear
	 *            el nuevo registro.
	 * @return Iae Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Iae add(@RequestBody Iae iae) {
		Iae iaeAux = this.iaeService.add(iae);
		IaeController.logger.info("[POST] : Iae insertado correctamente");
		return iaeAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idIae
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Iae Bean eliminado.
	 */
	@RequestMapping(value = "/{idIae}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Iae remove(@PathVariable String idIae) {
		Iae iae = new Iae();
		iae.setIdIae(idIae);
		this.iaeService.remove(iae);
		IaeController.logger.info("[DELETE] : Iae borrado correctamente");
		return iae;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		IaeController.logger.info("[GET - View] : iae");
		return "iae";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterIae
	 *            Iae Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Iae> Dto que contiene el resultado del filtrado
	 *         realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Iae> filter(@RequestJsonBody(param = "filter") Iae filterIae,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		IaeController.logger.info("[POST - filter] : Obtener Iaes");
		return this.iaeService.filter(filterIae, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterIae
	 *            Iae Bean que contiene los parametros de filtrado a emplear.
	 * @param searchIae
	 *            Iae Bean que contiene los parametros de busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Iae> Dto que contiene el resultado de la busqueda
	 *         realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Iae>> search(@RequestJsonBody(param = "filter") Iae filterIae,
			@RequestJsonBody(param = "search") Iae searchIae, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		IaeController.logger.info("[POST - search] : Buscar Iaes");
		return this.iaeService.search(filterIae, searchIae, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterIae
	 *            Iae Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Iae filterIae,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		IaeController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Iaes");
		this.iaeService.removeMultiple(filterIae, jqGridRequestDto, false);
		IaeController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterIae
	 *            Iae Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Iae>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Iae>> jerarquia(
			@RequestJsonBody(param = "filter") Iae filterIae, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		IaeController.logger.info("[POST - jerarquia] : Obtener Iaes jerarquia");
		return this.iaeService.jerarquia(filterIae, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterIae
	 *            Iae Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Iae>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Iae>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Iae filterIae, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		IaeController.logger.info("[POST - jerarquia] : Obtener Iaes jerarquia - Hijos");
		return this.iaeService.jerarquiaChildren(filterIae, jqGridRequestDto);
	}

}
