package com.ejie.ab60.control.MEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.model.MEC.Participantes;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.MEC.ParticipantesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ParticipantesController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/participantes")

public class ParticipantesController {

	private static final Logger logger = LoggerFactory.getLogger(ParticipantesController.class);

	@Autowired
	private ParticipantesService participantesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterParticipantes
	 *            Participantes Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Participantes> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Participantes> getAll(@ModelAttribute Participantes filterParticipantes) {
		ParticipantesController.logger.info("[GET - find_ALL] : Obtener Participantes por filtro");
		return this.participantesService.findAll(filterParticipantes, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param participantes
	 *            Participantes Bean que contiene la informacion a modificar.
	 * @return Participantes Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Participantes edit(@RequestBody Participantes participantes,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		Participantes participantesAux = null;
		if (null != participantes.getIdParticipante()) {
			participantes.setUsuarioUltmodificacion(usuario.getNombreUsuario());
			participantesAux = this.participantesService.update(participantes);
		} else {
			participantes.setUsuarioRegistro(usuario.getNombreUsuario());
			participantesAux = this.participantesService.add(participantes);
		}

		ParticipantesController.logger.info("[PUT] : Participantes actualizado correctamente");
		return participantesAux;
	}

	/**
	 * Operacion CRUD Read. Seleccionar el registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idParticipantes
	 *            Integer Identificador del objeto que se desea ver.
	 * @return Participantes .
	 */
	@RequestMapping(value = "cargarParticipante/{idParticipante}", method = RequestMethod.GET)
	public @ResponseBody Participantes getbyIdParticipante(@PathVariable Integer idParticipante) {

		Participantes participantes = this.participantesService.findParticipante(idParticipante);
		ParticipantesController.logger.info("[FIND] : Participantes localizado correctamente con id:" + idParticipante);
		return participantes;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param participantes
	 *            Participantes Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return Participantes Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Participantes add(@RequestBody Participantes participantes) {
		Participantes participantesAux = this.participantesService.add(participantes);
		ParticipantesController.logger.info("[POST] : Participantes insertado correctamente");
		return participantesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idParticipante
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Participantes Bean eliminado.
	 */
	@RequestMapping(value = "/{idParticipante}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Participantes remove(@PathVariable Integer idParticipante) {
		Participantes participantes = new Participantes();
		participantes.setIdParticipante(idParticipante);
		this.participantesService.remove(participantes);
		ParticipantesController.logger.info("[DELETE] : Participantes borrado correctamente");
		return participantes;
	}

	@RequestMapping(value = "removeParticipante/{idParticipante}", method = RequestMethod.PUT)
	public @ResponseBody Participantes removeParticipante(@PathVariable Integer idParticipante) {
		Participantes participantes = new Participantes();
		participantes.setIdParticipante(idParticipante);
		this.participantesService.remove(participantes);
		ParticipantesController.logger.info("[FIND] : Participante eliminado correctamente");
		return participantes;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ParticipantesController.logger.info("[GET - View] : participantes");
		return "participantes";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterParticipantes
	 *            Participantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Participantes> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Participantes> filter(
			@RequestJsonBody(param = "filter") Participantes filterParticipantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParticipantesController.logger.info("[POST - filter] : Obtener Participantess");
		return this.participantesService.filter(filterParticipantes, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterParticipantes
	 *            Participantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchParticipantes
	 *            Participantes Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Participantes> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Participantes>> search(
			@RequestJsonBody(param = "filter") Participantes filterParticipantes,
			@RequestJsonBody(param = "search") Participantes searchParticipantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParticipantesController.logger.info("[POST - search] : Buscar Participantess");
		return this.participantesService.search(filterParticipantes, searchParticipantes, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterParticipantes
	 *            Participantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") Participantes filterParticipantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParticipantesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Participantess");
		this.participantesService.removeMultiple(filterParticipantes, jqGridRequestDto, false);
		ParticipantesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterParticipantes
	 *            Participantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Participantes>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Participantes>> jerarquia(
			@RequestJsonBody(param = "filter") Participantes filterParticipantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParticipantesController.logger.info("[POST - jerarquia] : Obtener Participantess jerarquia");
		return this.participantesService.jerarquia(filterParticipantes, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterParticipantes
	 *            Participantes Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Participantes>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Participantes>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Participantes filterParticipantes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParticipantesController.logger.info("[POST - jerarquia] : Obtener Participantess jerarquia - Hijos");
		return this.participantesService.jerarquiaChildren(filterParticipantes, jqGridRequestDto);
	}

}
