package com.ejie.ab60.control.MEC;

import com.ejie.ab60.model.MEC.RelFacMotDen;

import com.ejie.ab60.service.MEC.RelFacMotDenService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * RelFacMotDenController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relfacmotden")

public class RelFacMotDenController {

	private static final Logger logger = LoggerFactory.getLogger(RelFacMotDenController.class);

	@Autowired
	private RelFacMotDenService relFacMotDenService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelFacMotDen
	 *            Integer
	 * @return RelFacMotDen Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFactura}", method = RequestMethod.GET)
	public @ResponseBody List<RelFacMotDen> get(@PathVariable Integer idFactura) {

		List<RelFacMotDen> relAFacMotDenList = this.relFacMotDenService.findIdsFacturaMotivosDenegaciones(idFactura);
		RelFacMotDenController.logger.info("[GET - findBy_PK] : Obtener RelFacMotDen por PK");
		return relAFacMotDenList;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelFacMotDen
	 *            RelFacMotDen Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelFacMotDen> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelFacMotDen> getAll(@ModelAttribute RelFacMotDen filterRelFacMotDen) {
		RelFacMotDenController.logger.info("[GET - find_ALL] : Obtener RelFacMotDen por filtro");
		return this.relFacMotDenService.findAll(filterRelFacMotDen, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relFacMotDen
	 *            RelFacMotDen Bean que contiene la informacion a modificar.
	 * @return RelFacMotDen Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelFacMotDen edit(@RequestBody RelFacMotDen relFacMotDen) {
		RelFacMotDen relFacMotDenAux = this.relFacMotDenService.update(relFacMotDen);
		RelFacMotDenController.logger.info("[PUT] : RelFacMotDen actualizado correctamente");
		return relFacMotDenAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relFacMotDen
	 *            RelFacMotDen Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelFacMotDen Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelFacMotDen add(@RequestBody RelFacMotDen relFacMotDen) {
		RelFacMotDen relFacMotDenAux = this.relFacMotDenService.add(relFacMotDen);
		RelFacMotDenController.logger.info("[POST] : RelFacMotDen insertado correctamente");
		return relFacMotDenAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelFacMotDen
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelFacMotDen Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelFacMotDen}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelFacMotDen remove(@PathVariable Integer idRelFacMotDen) {
		RelFacMotDen relFacMotDen = new RelFacMotDen();
		relFacMotDen.setIdRelFacMotDen(idRelFacMotDen);
		this.relFacMotDenService.remove(relFacMotDen);
		RelFacMotDenController.logger.info("[DELETE] : RelFacMotDen borrado correctamente");
		return relFacMotDen;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelFacMotDenController.logger.info("[GET - View] : relfacmotden");
		return "relfacmotden";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelFacMotDen
	 *            RelFacMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelFacMotDen> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelFacMotDen> filter(
			@RequestJsonBody(param = "filter") RelFacMotDen filterRelFacMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotDenController.logger.info("[POST - filter] : Obtener RelFacMotDens");
		return this.relFacMotDenService.filter(filterRelFacMotDen, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelFacMotDen
	 *            RelFacMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelFacMotDen
	 *            RelFacMotDen Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelFacMotDen> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelFacMotDen>> search(
			@RequestJsonBody(param = "filter") RelFacMotDen filterRelFacMotDen,
			@RequestJsonBody(param = "search") RelFacMotDen searchRelFacMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotDenController.logger.info("[POST - search] : Buscar RelFacMotDens");
		return this.relFacMotDenService.search(filterRelFacMotDen, searchRelFacMotDen, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelFacMotDen
	 *            RelFacMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelFacMotDen filterRelFacMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotDenController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelFacMotDens");
		this.relFacMotDenService.removeMultiple(filterRelFacMotDen, jqGridRequestDto, false);
		RelFacMotDenController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelFacMotDen
	 *            RelFacMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelFacMotDen>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelFacMotDen>> jerarquia(
			@RequestJsonBody(param = "filter") RelFacMotDen filterRelFacMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotDenController.logger.info("[POST - jerarquia] : Obtener RelFacMotDens jerarquia");
		return this.relFacMotDenService.jerarquia(filterRelFacMotDen, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelFacMotDen
	 *            RelFacMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelFacMotDen>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelFacMotDen>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelFacMotDen filterRelFacMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotDenController.logger.info("[POST - jerarquia] : Obtener RelFacMotDens jerarquia - Hijos");
		return this.relFacMotDenService.jerarquiaChildren(filterRelFacMotDen, jqGridRequestDto);
	}

}
