package com.ejie.ab60.control.MEC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.MEC.RelFacMotMin;
import com.ejie.ab60.service.MEC.RelFacMotMinService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelFacMotMinController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relfacmotmin")

public class RelFacMotMinController {

	private static final Logger logger = LoggerFactory.getLogger(RelFacMotMinController.class);

	@Autowired
	private RelFacMotMinService relFacMotMinService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelFacMotMin
	 *            Integer
	 * @return RelFacMotMin Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFactura}/{tipoInspeccion}", method = RequestMethod.GET)
	public @ResponseBody List<RelFacMotMin> get(@PathVariable Integer idFactura, @PathVariable Integer tipoInspeccion) {

		Integer origenMotivosMinoracion = 0;

		if (tipoInspeccion == Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO) {
			origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_FACTURAS;
		} else if (tipoInspeccion == Constantes.TIPO_INSPECCION_JUSTIFICACION) {
			origenMotivosMinoracion = Constantes.ORIGEN_JUSTIFICACION_FACTURAS;
		}

		List<RelFacMotMin> relFacMotMinList = this.relFacMotMinService.findIdsFacturaMotivosMinoraciones(idFactura,
				origenMotivosMinoracion);
		RelFacMotMinController.logger.info("[GET - findBy_PK] : Obtener RelFacMotMin por PK");
		return relFacMotMinList;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelFacMotMin
	 *            RelFacMotMin Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelFacMotMin> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelFacMotMin> getAll(@ModelAttribute RelFacMotMin filterRelFacMotMin) {
		RelFacMotMinController.logger.info("[GET - find_ALL] : Obtener RelFacMotMin por filtro");
		return this.relFacMotMinService.findAll(filterRelFacMotMin, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relFacMotMin
	 *            RelFacMotMin Bean que contiene la informacion a modificar.
	 * @return RelFacMotMin Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelFacMotMin edit(@RequestBody RelFacMotMin relFacMotMin) {
		RelFacMotMin relFacMotMinAux = this.relFacMotMinService.update(relFacMotMin);
		RelFacMotMinController.logger.info("[PUT] : RelFacMotMin actualizado correctamente");
		return relFacMotMinAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relFacMotMin
	 *            RelFacMotMin Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelFacMotMin Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelFacMotMin add(@RequestBody RelFacMotMin relFacMotMin) {
		RelFacMotMin relFacMotMinAux = this.relFacMotMinService.add(relFacMotMin);
		RelFacMotMinController.logger.info("[POST] : RelFacMotMin insertado correctamente");
		return relFacMotMinAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelFacMotMin
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelFacMotMin Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelFacMotMin}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelFacMotMin remove(@PathVariable Integer idRelFacMotMin) {
		RelFacMotMin relFacMotMin = new RelFacMotMin();
		relFacMotMin.setIdRelFacMotMin(idRelFacMotMin);
		this.relFacMotMinService.remove(relFacMotMin);
		RelFacMotMinController.logger.info("[DELETE] : RelFacMotMin borrado correctamente");
		return relFacMotMin;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelFacMotMinController.logger.info("[GET - View] : relfacmotmin");
		return "relfacmotmin";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelFacMotMin
	 *            RelFacMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelFacMotMin> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelFacMotMin> filter(
			@RequestJsonBody(param = "filter") RelFacMotMin filterRelFacMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotMinController.logger.info("[POST - filter] : Obtener RelFacMotMins");
		return this.relFacMotMinService.filter(filterRelFacMotMin, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelFacMotMin
	 *            RelFacMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelFacMotMin
	 *            RelFacMotMin Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelFacMotMin> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelFacMotMin>> search(
			@RequestJsonBody(param = "filter") RelFacMotMin filterRelFacMotMin,
			@RequestJsonBody(param = "search") RelFacMotMin searchRelFacMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotMinController.logger.info("[POST - search] : Buscar RelFacMotMins");
		return this.relFacMotMinService.search(filterRelFacMotMin, searchRelFacMotMin, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelFacMotMin
	 *            RelFacMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelFacMotMin filterRelFacMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotMinController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelFacMotMins");
		this.relFacMotMinService.removeMultiple(filterRelFacMotMin, jqGridRequestDto, false);
		RelFacMotMinController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelFacMotMin
	 *            RelFacMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelFacMotMin>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelFacMotMin>> jerarquia(
			@RequestJsonBody(param = "filter") RelFacMotMin filterRelFacMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotMinController.logger.info("[POST - jerarquia] : Obtener RelFacMotMins jerarquia");
		return this.relFacMotMinService.jerarquia(filterRelFacMotMin, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelFacMotMin
	 *            RelFacMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelFacMotMin>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelFacMotMin>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelFacMotMin filterRelFacMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacMotMinController.logger.info("[POST - jerarquia] : Obtener RelFacMotMins jerarquia - Hijos");
		return this.relFacMotMinService.jerarquiaChildren(filterRelFacMotMin, jqGridRequestDto);
	}

}
