package com.ejie.ab60.control.OTC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.OTC.OficinasTecnicas;
import com.ejie.ab60.service.OTC.OficinasTecnicasService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * OficinasTecnicasController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/oficinastecnicas")

public class OficinasTecnicasController {

	private static final Logger logger = LoggerFactory.getLogger(OficinasTecnicasController.class);

	@Autowired
	private OficinasTecnicasService oficinasTecnicasService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idOficinaTecnica
	 *            Integer
	 * @return OficinasTecnicas Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idOficinaTecnica}", method = RequestMethod.GET)
	public @ResponseBody OficinasTecnicas get(@PathVariable Integer idOficinaTecnica) {
		OficinasTecnicas oficinasTecnicas = new OficinasTecnicas();
		oficinasTecnicas.setIdOficinaTecnica(idOficinaTecnica);
		oficinasTecnicas = this.oficinasTecnicasService.find(oficinasTecnicas);
		OficinasTecnicasController.logger.info("[GET - findBy_PK] : Obtener OficinasTecnicas por PK");
		return oficinasTecnicas;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<OficinasTecnicas> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<OficinasTecnicas> getAll(@ModelAttribute OficinasTecnicas filterOficinasTecnicas) {
		OficinasTecnicasController.logger.info("[GET - find_ALL] : Obtener OficinasTecnicas por filtro");
		return this.oficinasTecnicasService.findAll(filterOficinasTecnicas, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param oficinasTecnicas
	 *            OficinasTecnicas Bean que contiene la informacion a modificar.
	 * @return OficinasTecnicas Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody OficinasTecnicas edit(@RequestBody OficinasTecnicas oficinasTecnicas) {
		OficinasTecnicas oficinasTecnicasAux = this.oficinasTecnicasService.update(oficinasTecnicas);
		OficinasTecnicasController.logger.info("[PUT] : OficinasTecnicas actualizado correctamente");
		return oficinasTecnicasAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param oficinasTecnicas
	 *            OficinasTecnicas Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return OficinasTecnicas Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody OficinasTecnicas add(@RequestBody OficinasTecnicas oficinasTecnicas) {
		OficinasTecnicas oficinasTecnicasAux = this.oficinasTecnicasService.add(oficinasTecnicas);
		OficinasTecnicasController.logger.info("[POST] : OficinasTecnicas insertado correctamente");
		return oficinasTecnicasAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idOficinaTecnica
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return OficinasTecnicas Bean eliminado.
	 */
	@RequestMapping(value = "/{idOficinaTecnica}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody OficinasTecnicas remove(@PathVariable Integer idOficinaTecnica) {
		OficinasTecnicas oficinasTecnicas = new OficinasTecnicas();
		oficinasTecnicas.setIdOficinaTecnica(idOficinaTecnica);
		this.oficinasTecnicasService.remove(oficinasTecnicas);
		OficinasTecnicasController.logger.info("[DELETE] : OficinasTecnicas borrado correctamente");
		return oficinasTecnicas;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		OficinasTecnicasController.logger.info("[GET - View] : oficinastecnicas");
		return "oficinastecnicas";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<OficinasTecnicas> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<OficinasTecnicas> filter(
			@RequestJsonBody(param = "filter") OficinasTecnicas filterOficinasTecnicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OficinasTecnicasController.logger.info("[POST - filter] : Obtener OficinasTecnicass");
		return this.oficinasTecnicasService.filter(filterOficinasTecnicas, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchOficinasTecnicas
	 *            OficinasTecnicas Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<OficinasTecnicas> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<OficinasTecnicas>> search(
			@RequestJsonBody(param = "filter") OficinasTecnicas filterOficinasTecnicas,
			@RequestJsonBody(param = "search") OficinasTecnicas searchOficinasTecnicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OficinasTecnicasController.logger.info("[POST - search] : Buscar OficinasTecnicass");
		return this.oficinasTecnicasService.search(filterOficinasTecnicas, searchOficinasTecnicas, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") OficinasTecnicas filterOficinasTecnicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OficinasTecnicasController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples OficinasTecnicass");
		this.oficinasTecnicasService.removeMultiple(filterOficinasTecnicas, jqGridRequestDto, false);
		OficinasTecnicasController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<OficinasTecnicas>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OficinasTecnicas>> jerarquia(
			@RequestJsonBody(param = "filter") OficinasTecnicas filterOficinasTecnicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OficinasTecnicasController.logger.info("[POST - jerarquia] : Obtener OficinasTecnicass jerarquia");
		return this.oficinasTecnicasService.jerarquia(filterOficinasTecnicas, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterOficinasTecnicas
	 *            OficinasTecnicas Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<OficinasTecnicas>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OficinasTecnicas>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") OficinasTecnicas filterOficinasTecnicas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OficinasTecnicasController.logger.info("[POST - jerarquia] : Obtener OficinasTecnicass jerarquia - Hijos");
		return this.oficinasTecnicasService.jerarquiaChildren(filterOficinasTecnicas, jqGridRequestDto);
	}

}
