package com.ejie.ab60.control.OTC;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.OTC.Zonas;
import com.ejie.ab60.service.OTC.ZonasService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ZonasController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/zonas")

public class ZonasController {

	private static final Logger logger = LoggerFactory.getLogger(ZonasController.class);

	@Autowired
	private ZonasService zonasService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idZona
	 *            Long
	 * @return Zonas Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idZona}", method = RequestMethod.GET)
	public @ResponseBody Zonas get(@PathVariable Long idZona) {
		Zonas zonas = new Zonas();
		zonas.setIdZona(idZona);
		zonas = this.zonasService.find(zonas);
		ZonasController.logger.info("[GET - findBy_PK] : Obtener Zonas por PK");
		return zonas;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterZonas
	 *            Zonas Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Zonas> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Zonas> getAll(@ModelAttribute Zonas filterZonas) {
		ZonasController.logger.info("[GET - find_ALL] : Obtener Zonas por filtro");
		return this.zonasService.findAll(filterZonas, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param zonas
	 *            Zonas Bean que contiene la informacion a modificar.
	 * @return Zonas Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Zonas edit(@RequestBody Zonas zonas) {
		Zonas zonasAux = this.zonasService.update(zonas);
		ZonasController.logger.info("[PUT] : Zonas actualizado correctamente");
		return zonasAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param zonas
	 *            Zonas Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Zonas Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Zonas add(@RequestBody Zonas zonas) {
		Zonas zonasAux = this.zonasService.add(zonas);
		ZonasController.logger.info("[POST] : Zonas insertado correctamente");
		return zonasAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idZona
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return Zonas Bean eliminado.
	 */
	@RequestMapping(value = "/{idZona}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Zonas remove(@PathVariable Long idZona) {
		Zonas zonas = new Zonas();
		zonas.setIdZona(idZona);
		this.zonasService.remove(zonas);
		ZonasController.logger.info("[DELETE] : Zonas borrado correctamente");
		return zonas;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ZonasController.logger.info("[GET - View] : zonas");
		return "zonas";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterZonas
	 *            Zonas Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Zonas> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Zonas> filter(@RequestJsonBody(param = "filter") Zonas filterZonas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ZonasController.logger.info("[POST - filter] : Obtener Zonass");
		return this.zonasService.filter(filterZonas, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterZonas
	 *            Zonas Bean que contiene los parametros de filtrado a emplear.
	 * @param searchZonas
	 *            Zonas Bean que contiene los parametros de busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Zonas> Dto que contiene el resultado de la busqueda
	 *         realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Zonas>> search(@RequestJsonBody(param = "filter") Zonas filterZonas,
			@RequestJsonBody(param = "search") Zonas searchZonas, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ZonasController.logger.info("[POST - search] : Buscar Zonass");
		return this.zonasService.search(filterZonas, searchZonas, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterZonas
	 *            Zonas Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Zonas filterZonas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ZonasController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Zonass");
		this.zonasService.removeMultiple(filterZonas, jqGridRequestDto, false);
		ZonasController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterZonas
	 *            Zonas Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Zonas>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Zonas>> jerarquia(
			@RequestJsonBody(param = "filter") Zonas filterZonas, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ZonasController.logger.info("[POST - jerarquia] : Obtener Zonass jerarquia");
		return this.zonasService.jerarquia(filterZonas, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterZonas
	 *            Zonas Bean que contiene los parametros de filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Zonas>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Zonas>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Zonas filterZonas, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ZonasController.logger.info("[POST - jerarquia] : Obtener Zonass jerarquia - Hijos");
		return this.zonasService.jerarquiaChildren(filterZonas, jqGridRequestDto);
	}

}
