package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.AmbitosTerritoriales;
import com.ejie.ab60.service.PTT.AmbitosTerritorialesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * AmbitosTerritorialesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/ambitosterritoriales")

public class AmbitosTerritorialesController {

	private static final Logger logger = LoggerFactory.getLogger(AmbitosTerritorialesController.class);

	@Autowired
	private AmbitosTerritorialesService ambitosTerritorialesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idAmbitoTerritorial
	 *            Long
	 * @return AmbitosTerritoriales Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idAmbitoTerritorial}", method = RequestMethod.GET)
	public @ResponseBody AmbitosTerritoriales get(@PathVariable Long idAmbitoTerritorial) {
		AmbitosTerritoriales ambitosTerritoriales = new AmbitosTerritoriales();
		ambitosTerritoriales.setIdAmbitoTerritorial(idAmbitoTerritorial);
		ambitosTerritoriales = this.ambitosTerritorialesService.find(ambitosTerritoriales);
		AmbitosTerritorialesController.logger.info("[GET - findBy_PK] : Obtener AmbitosTerritoriales por PK");
		return ambitosTerritoriales;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<AmbitosTerritoriales> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<AmbitosTerritoriales> getAll(
			@ModelAttribute AmbitosTerritoriales filterAmbitosTerritoriales) {
		AmbitosTerritorialesController.logger.info("[GET - find_ALL] : Obtener AmbitosTerritoriales por filtro");
		return this.ambitosTerritorialesService.findAll(filterAmbitosTerritoriales, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param ambitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene la informacion a
	 *            modificar.
	 * @return AmbitosTerritoriales Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody AmbitosTerritoriales edit(@RequestBody AmbitosTerritoriales ambitosTerritoriales) {
		AmbitosTerritoriales ambitosTerritorialesAux = this.ambitosTerritorialesService.update(ambitosTerritoriales);
		AmbitosTerritorialesController.logger.info("[PUT] : AmbitosTerritoriales actualizado correctamente");
		return ambitosTerritorialesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param ambitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return AmbitosTerritoriales Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody AmbitosTerritoriales add(@RequestBody AmbitosTerritoriales ambitosTerritoriales) {
		AmbitosTerritoriales ambitosTerritorialesAux = this.ambitosTerritorialesService.add(ambitosTerritoriales);
		AmbitosTerritorialesController.logger.info("[POST] : AmbitosTerritoriales insertado correctamente");
		return ambitosTerritorialesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAmbitoTerritorial
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return AmbitosTerritoriales Bean eliminado.
	 */
	@RequestMapping(value = "/{idAmbitoTerritorial}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody AmbitosTerritoriales remove(@PathVariable Long idAmbitoTerritorial) {
		AmbitosTerritoriales ambitosTerritoriales = new AmbitosTerritoriales();
		ambitosTerritoriales.setIdAmbitoTerritorial(idAmbitoTerritorial);
		this.ambitosTerritorialesService.remove(ambitosTerritoriales);
		AmbitosTerritorialesController.logger.info("[DELETE] : AmbitosTerritoriales borrado correctamente");
		return ambitosTerritoriales;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AmbitosTerritorialesController.logger.info("[GET - View] : ambitosterritoriales");
		return "ambitosterritoriales";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<AmbitosTerritoriales> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<AmbitosTerritoriales> filter(
			@RequestJsonBody(param = "filter") AmbitosTerritoriales filterAmbitosTerritoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AmbitosTerritorialesController.logger.info("[POST - filter] : Obtener AmbitosTerritorialess");
		return this.ambitosTerritorialesService.filter(filterAmbitosTerritoriales, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchAmbitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<AmbitosTerritoriales> Dto que contiene el resultado
	 *         de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<AmbitosTerritoriales>> search(
			@RequestJsonBody(param = "filter") AmbitosTerritoriales filterAmbitosTerritoriales,
			@RequestJsonBody(param = "search") AmbitosTerritoriales searchAmbitosTerritoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AmbitosTerritorialesController.logger.info("[POST - search] : Buscar AmbitosTerritorialess");
		return this.ambitosTerritorialesService.search(filterAmbitosTerritoriales, searchAmbitosTerritoriales,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") AmbitosTerritoriales filterAmbitosTerritoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AmbitosTerritorialesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples AmbitosTerritorialess");
		this.ambitosTerritorialesService.removeMultiple(filterAmbitosTerritoriales, jqGridRequestDto, false);
		AmbitosTerritorialesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<AmbitosTerritoriales>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AmbitosTerritoriales>> jerarquia(
			@RequestJsonBody(param = "filter") AmbitosTerritoriales filterAmbitosTerritoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AmbitosTerritorialesController.logger.info("[POST - jerarquia] : Obtener AmbitosTerritorialess jerarquia");
		return this.ambitosTerritorialesService.jerarquia(filterAmbitosTerritoriales, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAmbitosTerritoriales
	 *            AmbitosTerritoriales Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<AmbitosTerritoriales>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AmbitosTerritoriales>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") AmbitosTerritoriales filterAmbitosTerritoriales,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AmbitosTerritorialesController.logger
				.info("[POST - jerarquia] : Obtener AmbitosTerritorialess jerarquia - Hijos");
		return this.ambitosTerritorialesService.jerarquiaChildren(filterAmbitosTerritoriales, jqGridRequestDto);
	}

}
