package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.Competitividad;
import com.ejie.ab60.service.PTT.CompetitividadService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * CompetitividadController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/competitividad")

public class CompetitividadController {

	private static final Logger logger = LoggerFactory.getLogger(CompetitividadController.class);

	@Autowired
	private CompetitividadService competitividadService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idConpetitividad
	 *            Integer
	 * @return Competitividad Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idConpetitividad}", method = RequestMethod.GET)
	public @ResponseBody Competitividad get(@PathVariable Integer idConpetitividad) {
		Competitividad competitividad = new Competitividad();
		competitividad.setIdCompetitividad(idConpetitividad);
		competitividad = this.competitividadService.find(competitividad);
		CompetitividadController.logger.info("[GET - findBy_PK] : Obtener Competitividad por PK");
		return competitividad;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterCompetitividad
	 *            Competitividad Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Competitividad> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Competitividad> getAll(@ModelAttribute Competitividad filterCompetitividad) {
		CompetitividadController.logger.info("[GET - find_ALL] : Obtener Competitividad por filtro");
		return this.competitividadService.findAll(filterCompetitividad, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param competitividad
	 *            Competitividad Bean que contiene la informacion a modificar.
	 * @return Competitividad Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Competitividad edit(@RequestBody Competitividad competitividad) {
		Competitividad competitividadAux = this.competitividadService.update(competitividad);
		CompetitividadController.logger.info("[PUT] : Competitividad actualizado correctamente");
		return competitividadAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param competitividad
	 *            Competitividad Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return Competitividad Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Competitividad add(@RequestBody Competitividad competitividad) {
		Competitividad competitividadAux = this.competitividadService.add(competitividad);
		CompetitividadController.logger.info("[POST] : Competitividad insertado correctamente");
		return competitividadAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idConpetitividad
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Competitividad Bean eliminado.
	 */
	@RequestMapping(value = "/{idConpetitividad}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Competitividad remove(@PathVariable Integer idConpetitividad) {
		Competitividad competitividad = new Competitividad();
		competitividad.setIdCompetitividad(idConpetitividad);
		this.competitividadService.remove(competitividad);
		CompetitividadController.logger.info("[DELETE] : Competitividad borrado correctamente");
		return competitividad;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		CompetitividadController.logger.info("[GET - View] : competitividad");
		return "competitividad";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterCompetitividad
	 *            Competitividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Competitividad> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Competitividad> filter(
			@RequestJsonBody(param = "filter") Competitividad filterCompetitividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CompetitividadController.logger.info("[POST - filter] : Obtener Competitividads");
		return this.competitividadService.filter(filterCompetitividad, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterCompetitividad
	 *            Competitividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchCompetitividad
	 *            Competitividad Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Competitividad> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Competitividad>> search(
			@RequestJsonBody(param = "filter") Competitividad filterCompetitividad,
			@RequestJsonBody(param = "search") Competitividad searchCompetitividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CompetitividadController.logger.info("[POST - search] : Buscar Competitividads");
		return this.competitividadService.search(filterCompetitividad, searchCompetitividad, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterCompetitividad
	 *            Competitividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") Competitividad filterCompetitividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CompetitividadController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Competitividads");
		this.competitividadService.removeMultiple(filterCompetitividad, jqGridRequestDto, false);
		CompetitividadController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterCompetitividad
	 *            Competitividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Competitividad>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Competitividad>> jerarquia(
			@RequestJsonBody(param = "filter") Competitividad filterCompetitividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CompetitividadController.logger.info("[POST - jerarquia] : Obtener Competitividads jerarquia");
		return this.competitividadService.jerarquia(filterCompetitividad, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterCompetitividad
	 *            Competitividad Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Competitividad>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Competitividad>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Competitividad filterCompetitividad,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CompetitividadController.logger.info("[POST - jerarquia] : Obtener Competitividads jerarquia - Hijos");
		return this.competitividadService.jerarquiaChildren(filterCompetitividad, jqGridRequestDto);
	}

}
