package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.model.PTT.ContratacionesPersonal;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.service.PTT.ContratacionesPersonalService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.estudioTecnico.EstudioTecnicoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ContratacionesPersonalController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/contratacionespersonal")

public class ContratacionesPersonalController {

	private static final Logger logger = LoggerFactory.getLogger(ContratacionesPersonalController.class);

	@Autowired
	private ContratacionesPersonalService contratacionesPersonalService;

	@Autowired
	private RelExpActSubService relEXpActSubService;

	@Autowired
	private EstudioTecnicoService estudioTecnicoService;
	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idContratacionPersonal
	 *            Integer
	 * @return ContratacionesPersonal Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idContratacionPersonal}", method = RequestMethod.GET)
	public @ResponseBody ContratacionesPersonal get(@PathVariable Integer idContratacionPersonal) {
		ContratacionesPersonal contratacionesPersonal = new ContratacionesPersonal();
		contratacionesPersonal.setIdContratacionPersonal(idContratacionPersonal);
		contratacionesPersonal = this.contratacionesPersonalService.find(contratacionesPersonal);
		ContratacionesPersonalController.logger.info("[GET - findBy_PK] : Obtener ContratacionesPersonal por PK");
		return contratacionesPersonal;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idContratacionPersonal
	 *            Integer
	 * @return ContratacionesPersonal Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}/{idContratacionPersonal}", method = RequestMethod.GET)
	public @ResponseBody ContratacionesPersonal getEdit(@PathVariable Integer idContratacionPersonal) {
		ContratacionesPersonal contratacionesPersonal = new ContratacionesPersonal();
		contratacionesPersonal.setIdContratacionPersonal(idContratacionPersonal);

		contratacionesPersonal = this.contratacionesPersonalService.find(contratacionesPersonal);

		ContratacionesPersonalController.logger.info("[GET - findBy_PK] : Obtener ContratacionesPersonal por PK");
		return contratacionesPersonal;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<ContratacionesPersonal> Lista de objetos correspondientes a
	 *         la busqueda realizada.
	 */
	// @RequestMapping(method = RequestMethod.GET)
	// public @ResponseBody List<ContratacionesPersonal> getAll(
	// @ModelAttribute ContratacionesPersonal filterContratacionesPersonal) {
	// ContratacionesPersonalController.logger.info("[GET - find_ALL] : Obtener
	// ContratacionesPersonal por filtro");
	// return
	// this.contratacionesPersonalService.findAll(filterContratacionesPersonal,
	// null);
	// }

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene la informacion a
	 *            modificar.
	 * @return ContratacionesPersonal Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody ContratacionesPersonal edit(@RequestBody ContratacionesPersonal contratacionesPersonal) {
		ContratacionesPersonal contratacionesPersonalAux = this.contratacionesPersonalService
				.update(contratacionesPersonal);
		ContratacionesPersonalController.logger.info("[PUT] : ContratacionesPersonal actualizado correctamente");
		return contratacionesPersonalAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param contratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return ContratacionesPersonal Bean resultante del proceso de creacion.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.POST)
	public @ResponseBody ContratacionesPersonal add(@RequestBody ContratacionesPersonal contratacionesPersonal) {
		ContratacionesPersonal contratacionesPersonalAux = this.contratacionesPersonalService
				.add(contratacionesPersonal);
		ContratacionesPersonalController.logger.info("[POST] : ContratacionesPersonal insertado correctamente");
		return contratacionesPersonalAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idContratacionPersonal
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return ContratacionesPersonal Bean eliminado.
	 */
	@RequestMapping(value = "/{idContratacionPersonal}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody ContratacionesPersonal remove(@PathVariable Integer idContratacionPersonal) {
		ContratacionesPersonal contratacionesPersonal = new ContratacionesPersonal();
		contratacionesPersonal.setIdContratacionPersonal(idContratacionPersonal);
		this.contratacionesPersonalService.remove(contratacionesPersonal);
		ContratacionesPersonalController.logger.info("[DELETE] : ContratacionesPersonal borrado correctamente");
		return contratacionesPersonal;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ContratacionesPersonalController.logger.info("[GET - View] : contratacionespersonal");
		return "contratacionesPersonal";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<ContratacionesPersonal> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<ContratacionesPersonal> filter(
			@RequestJsonBody(param = "filter") ContratacionesPersonal filterContratacionesPersonal,
			@PathVariable Integer idrelacion, @PathVariable Integer idExpediente, @PathVariable Integer idCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idrelacion);
		filterContratacionesPersonal.setRelExpActSub(relExpActSub);
		filterContratacionesPersonal.setIdExpediente(idExpediente);
		filterContratacionesPersonal.setIdActSub(idCriterio);
		ContratacionesPersonalController.logger.info("[POST - filter] : Obtener Facturass con ides");
		return this.contratacionesPersonalService.filter(filterContratacionesPersonal, jqGridRequestDto, false);
	}

	/**
	 * Metodo que saca la modal de facturas relacionadas con Actu Sub
	 * 
	 * @param idCriterio,
	 * @param idExpediente
	 * @return String
	 */
	// @RequestMapping(value = "", method = RequestMethod.GET)
	// public String cargarModal(@PathVariable("idExpedientes") Integer
	// idExpedientes,
	// @PathVariable("idCriterio") Integer idCriterio, Model model) {
	//
	// RelExpActSub relExpActSub =
	// relEXpActSubService.findRelPorExpedientePorCriterio(idExpedientes,
	// idCriterio);
	// model.addAttribute("criterio", idCriterio);
	// model.addAttribute("expediente", idExpedientes);
	// if (null == relExpActSub) {
	// relExpActSub = new RelExpActSub();
	// relExpActSub.setIdRelExpActSub(0);
	// relExpActSub.setIdActSub(idCriterio);
	// }
	// model.addAttribute("datosRelExpActSub", relExpActSub);
	// return "contratacionesPersonal";
	//
	// }

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchContratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<ContratacionesPersonal> Dto que contiene el resultado
	 *         de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<ContratacionesPersonal>> search(
			@RequestJsonBody(param = "filter") ContratacionesPersonal filterContratacionesPersonal,
			@RequestJsonBody(param = "search") ContratacionesPersonal searchContratacionesPersonal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ContratacionesPersonalController.logger.info("[POST - search] : Buscar ContratacionesPersonals");
		return this.contratacionesPersonalService.search(filterContratacionesPersonal, searchContratacionesPersonal,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") ContratacionesPersonal filterContratacionesPersonal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ContratacionesPersonalController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples ContratacionesPersonals");
		this.contratacionesPersonalService.removeMultiple(filterContratacionesPersonal, jqGridRequestDto, false);
		ContratacionesPersonalController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>> jerarquia(
			@RequestJsonBody(param = "filter") ContratacionesPersonal filterContratacionesPersonal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ContratacionesPersonalController.logger.info("[POST - jerarquia] : Obtener ContratacionesPersonals jerarquia");
		return this.contratacionesPersonalService.jerarquia(filterContratacionesPersonal, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterContratacionesPersonal
	 *            ContratacionesPersonal Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ContratacionesPersonal>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") ContratacionesPersonal filterContratacionesPersonal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ContratacionesPersonalController.logger
				.info("[POST - jerarquia] : Obtener ContratacionesPersonals jerarquia - Hijos");
		return this.contratacionesPersonalService.jerarquiaChildren(filterContratacionesPersonal, jqGridRequestDto);
	}

}
