package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.GastosTuristicos;
import com.ejie.ab60.service.PTT.GastosTuristicosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * GastosTuristicosController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/gastosturisticos")

public class GastosTuristicosController {

	private static final Logger logger = LoggerFactory.getLogger(GastosTuristicosController.class);

	@Autowired
	private GastosTuristicosService gastosTuristicosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idGastosTuristicos
	 *            Integer
	 * @return GastosTuristicos Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idGastosTuristicos}", method = RequestMethod.GET)
	public @ResponseBody GastosTuristicos get(@PathVariable Integer idGastosTuristicos) {
		GastosTuristicos gastosTuristicos = new GastosTuristicos();
		gastosTuristicos.setIdGastosTuristicos(idGastosTuristicos);
		gastosTuristicos = this.gastosTuristicosService.find(gastosTuristicos);
		GastosTuristicosController.logger.info("[GET - findBy_PK] : Obtener GastosTuristicos por PK");
		return gastosTuristicos;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterGastosTuristicos
	 *            GastosTuristicos Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<GastosTuristicos> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<GastosTuristicos> getAll(@ModelAttribute GastosTuristicos filterGastosTuristicos) {
		GastosTuristicosController.logger.info("[GET - find_ALL] : Obtener GastosTuristicos por filtro");
		return this.gastosTuristicosService.findAll(filterGastosTuristicos, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param gastosTuristicos
	 *            GastosTuristicos Bean que contiene la informacion a modificar.
	 * @return GastosTuristicos Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody GastosTuristicos edit(@RequestBody GastosTuristicos gastosTuristicos) {
		GastosTuristicos gastosTuristicosAux = this.gastosTuristicosService.update(gastosTuristicos);
		GastosTuristicosController.logger.info("[PUT] : GastosTuristicos actualizado correctamente");
		return gastosTuristicosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param gastosTuristicos
	 *            GastosTuristicos Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return GastosTuristicos Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody GastosTuristicos add(@RequestBody GastosTuristicos gastosTuristicos) {
		GastosTuristicos gastosTuristicosAux = this.gastosTuristicosService.add(gastosTuristicos);
		GastosTuristicosController.logger.info("[POST] : GastosTuristicos insertado correctamente");
		return gastosTuristicosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idGastosTuristicos
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return GastosTuristicos Bean eliminado.
	 */
	@RequestMapping(value = "/{idGastosTuristicos}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody GastosTuristicos remove(@PathVariable Integer idGastosTuristicos) {
		GastosTuristicos gastosTuristicos = new GastosTuristicos();
		gastosTuristicos.setIdGastosTuristicos(idGastosTuristicos);
		this.gastosTuristicosService.remove(gastosTuristicos);
		GastosTuristicosController.logger.info("[DELETE] : GastosTuristicos borrado correctamente");
		return gastosTuristicos;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		GastosTuristicosController.logger.info("[GET - View] : gastosturisticos");
		return "gastosturisticos";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterGastosTuristicos
	 *            GastosTuristicos Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<GastosTuristicos> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<GastosTuristicos> filter(
			@RequestJsonBody(param = "filter") GastosTuristicos filterGastosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		GastosTuristicosController.logger.info("[POST - filter] : Obtener GastosTuristicoss");
		return this.gastosTuristicosService.filter(filterGastosTuristicos, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterGastosTuristicos
	 *            GastosTuristicos Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchGastosTuristicos
	 *            GastosTuristicos Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<GastosTuristicos> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<GastosTuristicos>> search(
			@RequestJsonBody(param = "filter") GastosTuristicos filterGastosTuristicos,
			@RequestJsonBody(param = "search") GastosTuristicos searchGastosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		GastosTuristicosController.logger.info("[POST - search] : Buscar GastosTuristicoss");
		return this.gastosTuristicosService.search(filterGastosTuristicos, searchGastosTuristicos, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterGastosTuristicos
	 *            GastosTuristicos Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") GastosTuristicos filterGastosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		GastosTuristicosController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples GastosTuristicoss");
		this.gastosTuristicosService.removeMultiple(filterGastosTuristicos, jqGridRequestDto, false);
		GastosTuristicosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterGastosTuristicos
	 *            GastosTuristicos Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<GastosTuristicos>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<GastosTuristicos>> jerarquia(
			@RequestJsonBody(param = "filter") GastosTuristicos filterGastosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		GastosTuristicosController.logger.info("[POST - jerarquia] : Obtener GastosTuristicoss jerarquia");
		return this.gastosTuristicosService.jerarquia(filterGastosTuristicos, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterGastosTuristicos
	 *            GastosTuristicos Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<GastosTuristicos>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<GastosTuristicos>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") GastosTuristicos filterGastosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		GastosTuristicosController.logger.info("[POST - jerarquia] : Obtener GastosTuristicoss jerarquia - Hijos");
		return this.gastosTuristicosService.jerarquiaChildren(filterGastosTuristicos, jqGridRequestDto);
	}

}
