package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.ModalidadesContrato;
import com.ejie.ab60.service.PTT.ModalidadesContratoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ModalidadesContratoController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/modalidadescontrato")

public class ModalidadesContratoController {

	private static final Logger logger = LoggerFactory.getLogger(ModalidadesContratoController.class);

	@Autowired
	private ModalidadesContratoService modalidadesContratoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Metodo que nos trae la lista para cargar el combo
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo", method = RequestMethod.GET)
	public @ResponseBody List<ModalidadesContrato> init() {
		ModalidadesContratoController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.modalidadesContratoService.findModalidadesContrato();

	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idModalidadContrato
	 *            Long
	 * @return ModalidadesContrato Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idModalidadContrato}", method = RequestMethod.GET)
	public @ResponseBody ModalidadesContrato get(@PathVariable Long idModalidadContrato) {
		ModalidadesContrato modalidadesContrato = new ModalidadesContrato();
		modalidadesContrato.setIdModalidadContrato(idModalidadContrato);
		modalidadesContrato = this.modalidadesContratoService.find(modalidadesContrato);
		ModalidadesContratoController.logger.info("[GET - findBy_PK] : Obtener ModalidadesContrato por PK");
		return modalidadesContrato;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<ModalidadesContrato> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<ModalidadesContrato> getAll(
			@ModelAttribute ModalidadesContrato filterModalidadesContrato) {
		ModalidadesContratoController.logger.info("[GET - find_ALL] : Obtener ModalidadesContrato por filtro");
		return this.modalidadesContratoService.findAll(filterModalidadesContrato, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato Bean que contiene la informacion a
	 *            modificar.
	 * @return ModalidadesContrato Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody ModalidadesContrato edit(@RequestBody ModalidadesContrato modalidadesContrato) {
		ModalidadesContrato modalidadesContratoAux = this.modalidadesContratoService.update(modalidadesContrato);
		ModalidadesContratoController.logger.info("[PUT] : ModalidadesContrato actualizado correctamente");
		return modalidadesContratoAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param modalidadesContrato
	 *            ModalidadesContrato Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return ModalidadesContrato Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody ModalidadesContrato add(@RequestBody ModalidadesContrato modalidadesContrato) {
		ModalidadesContrato modalidadesContratoAux = this.modalidadesContratoService.add(modalidadesContrato);
		ModalidadesContratoController.logger.info("[POST] : ModalidadesContrato insertado correctamente");
		return modalidadesContratoAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idModalidadContrato
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return ModalidadesContrato Bean eliminado.
	 */
	@RequestMapping(value = "/{idModalidadContrato}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody ModalidadesContrato remove(@PathVariable Long idModalidadContrato) {
		ModalidadesContrato modalidadesContrato = new ModalidadesContrato();
		modalidadesContrato.setIdModalidadContrato(idModalidadContrato);
		this.modalidadesContratoService.remove(modalidadesContrato);
		ModalidadesContratoController.logger.info("[DELETE] : ModalidadesContrato borrado correctamente");
		return modalidadesContrato;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ModalidadesContratoController.logger.info("[GET - View] : modalidadescontrato");
		return "modalidadescontrato";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<ModalidadesContrato> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<ModalidadesContrato> filter(
			@RequestJsonBody(param = "filter") ModalidadesContrato filterModalidadesContrato,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadesContratoController.logger.info("[POST - filter] : Obtener ModalidadesContratos");
		return this.modalidadesContratoService.filter(filterModalidadesContrato, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchModalidadesContrato
	 *            ModalidadesContrato Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<ModalidadesContrato> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<ModalidadesContrato>> search(
			@RequestJsonBody(param = "filter") ModalidadesContrato filterModalidadesContrato,
			@RequestJsonBody(param = "search") ModalidadesContrato searchModalidadesContrato,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadesContratoController.logger.info("[POST - search] : Buscar ModalidadesContratos");
		return this.modalidadesContratoService.search(filterModalidadesContrato, searchModalidadesContrato,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") ModalidadesContrato filterModalidadesContrato,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadesContratoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples ModalidadesContratos");
		this.modalidadesContratoService.removeMultiple(filterModalidadesContrato, jqGridRequestDto, false);
		ModalidadesContratoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ModalidadesContrato>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ModalidadesContrato>> jerarquia(
			@RequestJsonBody(param = "filter") ModalidadesContrato filterModalidadesContrato,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadesContratoController.logger.info("[POST - jerarquia] : Obtener ModalidadesContratos jerarquia");
		return this.modalidadesContratoService.jerarquia(filterModalidadesContrato, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterModalidadesContrato
	 *            ModalidadesContrato Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ModalidadesContrato>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ModalidadesContrato>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") ModalidadesContrato filterModalidadesContrato,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadesContratoController.logger
				.info("[POST - jerarquia] : Obtener ModalidadesContratos jerarquia - Hijos");
		return this.modalidadesContratoService.jerarquiaChildren(filterModalidadesContrato, jqGridRequestDto);
	}

}
