package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.PersonasContratadas;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.service.PTT.PersonasContratadasService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PersonasContratadasController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/personascontratadas")

public class PersonasContratadasController {

	private static final Logger logger = LoggerFactory.getLogger(PersonasContratadasController.class);

	@Autowired
	private PersonasContratadasService personasContratadasService;

	@Autowired
	private RelExpActSubService relEXpActSubService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idPersonaContratada
	 *            Integer
	 * @return PersonasContratadas Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idPersonaContratada}", method = RequestMethod.GET)
	public @ResponseBody PersonasContratadas get(@PathVariable Integer idPersonaContratada) {
		PersonasContratadas personasContratadas = new PersonasContratadas();
		personasContratadas.setIdPersonaContratada(idPersonaContratada);
		personasContratadas = this.personasContratadasService.find(personasContratadas);
		PersonasContratadasController.logger.info("[GET - findBy_PK] : Obtener PersonasContratadas por PK");
		return personasContratadas;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterPersonasContratadas
	 *            PersonasContratadas Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<PersonasContratadas> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	// @RequestMapping(method = RequestMethod.GET)
	// public @ResponseBody List<PersonasContratadas> getAll(
	// @ModelAttribute PersonasContratadas filterPersonasContratadas) {
	// PersonasContratadasController.logger.info("[GET - find_ALL] : Obtener
	// PersonasContratadas por filtro");
	// return this.personasContratadasService.findAll(filterPersonasContratadas,
	// null);
	// }

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas Bean que contiene la informacion a
	 *            modificar.
	 * @return PersonasContratadas Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.PUT)
	public @ResponseBody PersonasContratadas edit(@RequestBody PersonasContratadas personasContratadas) {
		PersonasContratadas personasContratadasAux = this.personasContratadasService.update(personasContratadas);
		PersonasContratadasController.logger.info("[PUT] : PersonasContratadas actualizado correctamente");
		return personasContratadasAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param personasContratadas
	 *            PersonasContratadas Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return PersonasContratadas Bean resultante del proceso de creacion.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idCriterio}", method = RequestMethod.POST)
	public @ResponseBody PersonasContratadas add(@RequestBody PersonasContratadas personasContratadas) {
		PersonasContratadas personasContratadasAux = this.personasContratadasService.add(personasContratadas);
		PersonasContratadasController.logger.info("[POST] : PersonasContratadas insertado correctamente");
		return personasContratadasAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idPersonaContratada
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return PersonasContratadas Bean eliminado.
	 */
	@RequestMapping(value = "/{idPersonaContratada}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody PersonasContratadas remove(@PathVariable Integer idPersonaContratada) {
		PersonasContratadas personasContratadas = new PersonasContratadas();
		personasContratadas.setIdPersonaContratada(idPersonaContratada);
		this.personasContratadasService.remove(personasContratadas);
		PersonasContratadasController.logger.info("[DELETE] : PersonasContratadas borrado correctamente");
		return personasContratadas;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		PersonasContratadasController.logger.info("[GET - View] : personascontratadas");
		return "personascontratadas";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPersonasContratadas
	 *            PersonasContratadas Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<PersonasContratadas> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<PersonasContratadas> filter(
			@RequestJsonBody(param = "filter") PersonasContratadas filterPersonasContratadas,
			@PathVariable Integer idrelacion, @PathVariable Integer idExpediente, @PathVariable Integer idCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idrelacion);
		filterPersonasContratadas.setRelExpActSub(relExpActSub);
		filterPersonasContratadas.setIdExpediente(idExpediente);
		filterPersonasContratadas.setIdActSub(idCriterio);
		PersonasContratadasController.logger.info("[POST - filter] : Obtener PersonasContratadass");
		return this.personasContratadasService.filter(filterPersonasContratadas, jqGridRequestDto, false);
	}

	/**
	 * Metodo que saca la modal de conceptos relacionadas con Actu Sub
	 * 
	 * @param idCriterio,
	 * @param idExpediente
	 * @return String
	 */
	// @RequestMapping(value = "", method = RequestMethod.GET)
	// public String cargarModal(@PathVariable("idExpedientes") Integer
	// idExpedientes,
	// @PathVariable("idCriterio") Integer idCriterio, Model model) {
	// RelExpActSub relExpActSub = new RelExpActSub();
	// relExpActSub =
	// relEXpActSubService.findRelPorExpedientePorCriterio(idExpedientes,
	// idCriterio);
	//
	// model.addAttribute("criterio", idCriterio);
	// model.addAttribute("expediente", idExpedientes);
	// if (null == relExpActSub) {
	// relExpActSub = new RelExpActSub();
	// relExpActSub.setIdRelExpActSub(0);
	// relExpActSub.setIdActSub(idCriterio);
	// }
	// model.addAttribute("datosRelExpActSub", relExpActSub);
	// return "personasContratadas";
	//
	// }

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterPersonasContratadas
	 *            PersonasContratadas Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchPersonasContratadas
	 *            PersonasContratadas Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<PersonasContratadas> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<PersonasContratadas>> search(
			@RequestJsonBody(param = "filter") PersonasContratadas filterPersonasContratadas,
			@RequestJsonBody(param = "search") PersonasContratadas searchPersonasContratadas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PersonasContratadasController.logger.info("[POST - search] : Buscar PersonasContratadass");
		return this.personasContratadasService.search(filterPersonasContratadas, searchPersonasContratadas,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterPersonasContratadas
	 *            PersonasContratadas Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") PersonasContratadas filterPersonasContratadas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PersonasContratadasController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples PersonasContratadass");
		this.personasContratadasService.removeMultiple(filterPersonasContratadas, jqGridRequestDto, false);
		PersonasContratadasController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterPersonasContratadas
	 *            PersonasContratadas Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PersonasContratadas>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PersonasContratadas>> jerarquia(
			@RequestJsonBody(param = "filter") PersonasContratadas filterPersonasContratadas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PersonasContratadasController.logger.info("[POST - jerarquia] : Obtener PersonasContratadass jerarquia");
		return this.personasContratadasService.jerarquia(filterPersonasContratadas, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterPersonasContratadas
	 *            PersonasContratadas Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PersonasContratadas>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PersonasContratadas>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") PersonasContratadas filterPersonasContratadas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PersonasContratadasController.logger
				.info("[POST - jerarquia] : Obtener PersonasContratadass jerarquia - Hijos");
		return this.personasContratadasService.jerarquiaChildren(filterPersonasContratadas, jqGridRequestDto);
	}

}
