package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.PertenenciasRedes;
import com.ejie.ab60.service.PTT.PertenenciasRedesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PertenenciasRedesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/pertenenciasredes")

public class PertenenciasRedesController {

	private static final Logger logger = LoggerFactory.getLogger(PertenenciasRedesController.class);

	@Autowired
	private PertenenciasRedesService pertenenciasRedesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idPertenenciaRedes
	 *            Integer
	 * @return PertenenciasRedes Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idPertenenciaRedes}", method = RequestMethod.GET)
	public @ResponseBody PertenenciasRedes get(@PathVariable Integer idPertenenciaRedes) {
		PertenenciasRedes pertenenciasRedes = new PertenenciasRedes();
		pertenenciasRedes.setIdPertenenciaRedes(idPertenenciaRedes);
		pertenenciasRedes = this.pertenenciasRedesService.find(pertenenciasRedes);
		PertenenciasRedesController.logger.info("[GET - findBy_PK] : Obtener PertenenciasRedes por PK");
		return pertenenciasRedes;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<PertenenciasRedes> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<PertenenciasRedes> getAll(@ModelAttribute PertenenciasRedes filterPertenenciasRedes) {
		PertenenciasRedesController.logger.info("[GET - find_ALL] : Obtener PertenenciasRedes por filtro");
		return this.pertenenciasRedesService.findAll(filterPertenenciasRedes, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param pertenenciasRedes
	 *            PertenenciasRedes Bean que contiene la informacion a
	 *            modificar.
	 * @return PertenenciasRedes Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody PertenenciasRedes edit(@RequestBody PertenenciasRedes pertenenciasRedes) {
		PertenenciasRedes pertenenciasRedesAux = this.pertenenciasRedesService.update(pertenenciasRedes);
		PertenenciasRedesController.logger.info("[PUT] : PertenenciasRedes actualizado correctamente");
		return pertenenciasRedesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param pertenenciasRedes
	 *            PertenenciasRedes Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return PertenenciasRedes Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody PertenenciasRedes add(@RequestBody PertenenciasRedes pertenenciasRedes) {
		PertenenciasRedes pertenenciasRedesAux = this.pertenenciasRedesService.add(pertenenciasRedes);
		PertenenciasRedesController.logger.info("[POST] : PertenenciasRedes insertado correctamente");
		return pertenenciasRedesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idPertenenciaRedes
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return PertenenciasRedes Bean eliminado.
	 */
	@RequestMapping(value = "/{idPertenenciaRedes}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody PertenenciasRedes remove(@PathVariable Integer idPertenenciaRedes) {
		PertenenciasRedes pertenenciasRedes = new PertenenciasRedes();
		pertenenciasRedes.setIdPertenenciaRedes(idPertenenciaRedes);
		this.pertenenciasRedesService.remove(pertenenciasRedes);
		PertenenciasRedesController.logger.info("[DELETE] : PertenenciasRedes borrado correctamente");
		return pertenenciasRedes;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		PertenenciasRedesController.logger.info("[GET - View] : pertenenciasredes");
		return "pertenenciasredes";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<PertenenciasRedes> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<PertenenciasRedes> filter(
			@RequestJsonBody(param = "filter") PertenenciasRedes filterPertenenciasRedes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PertenenciasRedesController.logger.info("[POST - filter] : Obtener PertenenciasRedess");
		return this.pertenenciasRedesService.filter(filterPertenenciasRedes, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchPertenenciasRedes
	 *            PertenenciasRedes Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<PertenenciasRedes> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<PertenenciasRedes>> search(
			@RequestJsonBody(param = "filter") PertenenciasRedes filterPertenenciasRedes,
			@RequestJsonBody(param = "search") PertenenciasRedes searchPertenenciasRedes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PertenenciasRedesController.logger.info("[POST - search] : Buscar PertenenciasRedess");
		return this.pertenenciasRedesService.search(filterPertenenciasRedes, searchPertenenciasRedes, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") PertenenciasRedes filterPertenenciasRedes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PertenenciasRedesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples PertenenciasRedess");
		this.pertenenciasRedesService.removeMultiple(filterPertenenciasRedes, jqGridRequestDto, false);
		PertenenciasRedesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PertenenciasRedes>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PertenenciasRedes>> jerarquia(
			@RequestJsonBody(param = "filter") PertenenciasRedes filterPertenenciasRedes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PertenenciasRedesController.logger.info("[POST - jerarquia] : Obtener PertenenciasRedess jerarquia");
		return this.pertenenciasRedesService.jerarquia(filterPertenenciasRedes, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterPertenenciasRedes
	 *            PertenenciasRedes Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PertenenciasRedes>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PertenenciasRedes>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") PertenenciasRedes filterPertenenciasRedes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PertenenciasRedesController.logger.info("[POST - jerarquia] : Obtener PertenenciasRedess jerarquia - Hijos");
		return this.pertenenciasRedesService.jerarquiaChildren(filterPertenenciasRedes, jqGridRequestDto);
	}

}
