package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.ProductosTuristicos;
import com.ejie.ab60.service.PTT.ProductosTuristicosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ProductosTuristicosController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/productosturisticos")

public class ProductosTuristicosController {

	private static final Logger logger = LoggerFactory.getLogger(ProductosTuristicosController.class);

	@Autowired
	private ProductosTuristicosService productosTuristicosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Metodo que nos trae la lista para cargar el combo de productos turisticos
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<ProductosTuristicos> init(@PathVariable int idConvocatoria) {
		ProductosTuristicosController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		ProductosTuristicos productosTuristicos = new ProductosTuristicos();
		productosTuristicos.setIdConvocatoria(idConvocatoria);
		return this.productosTuristicosService.findProductosTuristicos(productosTuristicos);

	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idProductoTuristico
	 *            Long
	 * @return ProductosTuristicos Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idProductoTuristico}", method = RequestMethod.GET)
	public @ResponseBody ProductosTuristicos get(@PathVariable Long idProductoTuristico) {
		ProductosTuristicos productosTuristicos = new ProductosTuristicos();
		productosTuristicos.setIdProductoTuristico(idProductoTuristico);
		productosTuristicos = this.productosTuristicosService.find(productosTuristicos);
		ProductosTuristicosController.logger.info("[GET - findBy_PK] : Obtener ProductosTuristicos por PK");
		return productosTuristicos;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<ProductosTuristicos> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<ProductosTuristicos> getAll(
			@ModelAttribute ProductosTuristicos filterProductosTuristicos) {
		ProductosTuristicosController.logger.info("[GET - find_ALL] : Obtener ProductosTuristicos por filtro");
		return this.productosTuristicosService.findAll(filterProductosTuristicos, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param productosTuristicos
	 *            ProductosTuristicos Bean que contiene la informacion a
	 *            modificar.
	 * @return ProductosTuristicos Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody ProductosTuristicos edit(@RequestBody ProductosTuristicos productosTuristicos) {
		ProductosTuristicos productosTuristicosAux = this.productosTuristicosService.update(productosTuristicos);
		ProductosTuristicosController.logger.info("[PUT] : ProductosTuristicos actualizado correctamente");
		return productosTuristicosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param productosTuristicos
	 *            ProductosTuristicos Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return ProductosTuristicos Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody ProductosTuristicos add(@RequestBody ProductosTuristicos productosTuristicos) {
		ProductosTuristicos productosTuristicosAux = this.productosTuristicosService.add(productosTuristicos);
		ProductosTuristicosController.logger.info("[POST] : ProductosTuristicos insertado correctamente");
		return productosTuristicosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idProductoTuristico
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return ProductosTuristicos Bean eliminado.
	 */
	@RequestMapping(value = "/{idProductoTuristico}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody ProductosTuristicos remove(@PathVariable Long idProductoTuristico) {
		ProductosTuristicos productosTuristicos = new ProductosTuristicos();
		productosTuristicos.setIdProductoTuristico(idProductoTuristico);
		this.productosTuristicosService.remove(productosTuristicos);
		ProductosTuristicosController.logger.info("[DELETE] : ProductosTuristicos borrado correctamente");
		return productosTuristicos;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ProductosTuristicosController.logger.info("[GET - View] : productosturisticos");
		return "productosturisticos";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<ProductosTuristicos> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<ProductosTuristicos> filter(
			@RequestJsonBody(param = "filter") ProductosTuristicos filterProductosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProductosTuristicosController.logger.info("[POST - filter] : Obtener ProductosTuristicoss");
		return this.productosTuristicosService.filter(filterProductosTuristicos, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchProductosTuristicos
	 *            ProductosTuristicos Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<ProductosTuristicos> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<ProductosTuristicos>> search(
			@RequestJsonBody(param = "filter") ProductosTuristicos filterProductosTuristicos,
			@RequestJsonBody(param = "search") ProductosTuristicos searchProductosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProductosTuristicosController.logger.info("[POST - search] : Buscar ProductosTuristicoss");
		return this.productosTuristicosService.search(filterProductosTuristicos, searchProductosTuristicos,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") ProductosTuristicos filterProductosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProductosTuristicosController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples ProductosTuristicoss");
		this.productosTuristicosService.removeMultiple(filterProductosTuristicos, jqGridRequestDto, false);
		ProductosTuristicosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ProductosTuristicos>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ProductosTuristicos>> jerarquia(
			@RequestJsonBody(param = "filter") ProductosTuristicos filterProductosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProductosTuristicosController.logger.info("[POST - jerarquia] : Obtener ProductosTuristicoss jerarquia");
		return this.productosTuristicosService.jerarquia(filterProductosTuristicos, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterProductosTuristicos
	 *            ProductosTuristicos Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ProductosTuristicos>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ProductosTuristicos>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") ProductosTuristicos filterProductosTuristicos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ProductosTuristicosController.logger
				.info("[POST - jerarquia] : Obtener ProductosTuristicoss jerarquia - Hijos");
		return this.productosTuristicosService.jerarquiaChildren(filterProductosTuristicos, jqGridRequestDto);
	}

}
