package com.ejie.ab60.control.PTT;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.PTT.RelExpAmbTer;
import com.ejie.ab60.service.PTT.RelExpAmbTerService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpAmbTerController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relexpambter")

public class RelExpAmbTerController {

	private static final Logger logger = LoggerFactory.getLogger(RelExpAmbTerController.class);

	@Autowired
	private RelExpAmbTerService relExpAmbTerService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelExpAmbTer
	 *            Integer
	 * @return RelExpAmbTer Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelExpAmbTer}", method = RequestMethod.GET)
	public @ResponseBody RelExpAmbTer get(@PathVariable Integer idRelExpAmbTer) {
		RelExpAmbTer relExpAmbTer = new RelExpAmbTer();
		relExpAmbTer.setIdRelExpAmbTer(idRelExpAmbTer);
		relExpAmbTer = this.relExpAmbTerService.find(relExpAmbTer);
		RelExpAmbTerController.logger.info("[GET - findBy_PK] : Obtener RelExpAmbTer por PK");
		return relExpAmbTer;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelExpAmbTer> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelExpAmbTer> getAll(@ModelAttribute RelExpAmbTer filterRelExpAmbTer) {
		RelExpAmbTerController.logger.info("[GET - find_ALL] : Obtener RelExpAmbTer por filtro");
		return this.relExpAmbTerService.findAll(filterRelExpAmbTer, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpAmbTer
	 *            RelExpAmbTer Bean que contiene la informacion a modificar.
	 * @return RelExpAmbTer Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelExpAmbTer edit(@RequestBody RelExpAmbTer relExpAmbTer) {
		RelExpAmbTer relExpAmbTerAux = this.relExpAmbTerService.update(relExpAmbTer);
		RelExpAmbTerController.logger.info("[PUT] : RelExpAmbTer actualizado correctamente");
		return relExpAmbTerAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relExpAmbTer
	 *            RelExpAmbTer Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelExpAmbTer Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelExpAmbTer add(@RequestBody RelExpAmbTer relExpAmbTer) {
		RelExpAmbTer relExpAmbTerAux = this.relExpAmbTerService.add(relExpAmbTer);
		RelExpAmbTerController.logger.info("[POST] : RelExpAmbTer insertado correctamente");
		return relExpAmbTerAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelExpAmbTer
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelExpAmbTer Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelExpAmbTer}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelExpAmbTer remove(@PathVariable Integer idRelExpAmbTer) {
		RelExpAmbTer relExpAmbTer = new RelExpAmbTer();
		relExpAmbTer.setIdRelExpAmbTer(idRelExpAmbTer);
		this.relExpAmbTerService.remove(relExpAmbTer);
		RelExpAmbTerController.logger.info("[DELETE] : RelExpAmbTer borrado correctamente");
		return relExpAmbTer;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelExpAmbTerController.logger.info("[GET - View] : relexpambter");
		return "relexpambter";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelExpAmbTer> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpAmbTer> filter(
			@RequestJsonBody(param = "filter") RelExpAmbTer filterRelExpAmbTer,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpAmbTerController.logger.info("[POST - filter] : Obtener RelExpAmbTers");
		return this.relExpAmbTerService.filter(filterRelExpAmbTer, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelExpAmbTer
	 *            RelExpAmbTer Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelExpAmbTer> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelExpAmbTer>> search(
			@RequestJsonBody(param = "filter") RelExpAmbTer filterRelExpAmbTer,
			@RequestJsonBody(param = "search") RelExpAmbTer searchRelExpAmbTer,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpAmbTerController.logger.info("[POST - search] : Buscar RelExpAmbTers");
		return this.relExpAmbTerService.search(filterRelExpAmbTer, searchRelExpAmbTer, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelExpAmbTer filterRelExpAmbTer,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpAmbTerController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelExpAmbTers");
		this.relExpAmbTerService.removeMultiple(filterRelExpAmbTer, jqGridRequestDto, false);
		RelExpAmbTerController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpAmbTer>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpAmbTer>> jerarquia(
			@RequestJsonBody(param = "filter") RelExpAmbTer filterRelExpAmbTer,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpAmbTerController.logger.info("[POST - jerarquia] : Obtener RelExpAmbTers jerarquia");
		return this.relExpAmbTerService.jerarquia(filterRelExpAmbTer, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelExpAmbTer
	 *            RelExpAmbTer Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpAmbTer>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpAmbTer>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelExpAmbTer filterRelExpAmbTer,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpAmbTerController.logger.info("[POST - jerarquia] : Obtener RelExpAmbTers jerarquia - Hijos");
		return this.relExpAmbTerService.jerarquiaChildren(filterRelExpAmbTer, jqGridRequestDto);
	}

}
