package com.ejie.ab60.control.actuacionesSubvencionables;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotDen;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubMotDenService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * RelActSubMotDenController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relactsubmotden")

public class RelActSubMotDenController {

	private static final Logger logger = LoggerFactory.getLogger(RelActSubMotDenController.class);

	@Autowired
	private RelActSubMotDenService relActSubMotDenService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelActSubMotDen
	 *            Integer
	 * @return RelActSubMotDen Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelActSub}", method = RequestMethod.GET)
	public @ResponseBody List<RelActSubMotDen> get(@PathVariable Integer idRelActSub) {

		List<RelActSubMotDen> relActSubMotDenList = this.relActSubMotDenService.findIdsMotivosDenegaciones(idRelActSub);
		RelActSubMotDenController.logger.info("[GET - findBy_PK] : Obtener RelActSubMotDen por PK");
		return relActSubMotDenList;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelActSubMotDen> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelActSubMotDen> getAll(@ModelAttribute RelActSubMotDen filterRelActSubMotDen) {
		RelActSubMotDenController.logger.info("[GET - find_ALL] : Obtener RelActSubMotDen por filtro");
		return this.relActSubMotDenService.findAll(filterRelActSubMotDen, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relActSubMotDen
	 *            RelActSubMotDen Bean que contiene la informacion a modificar.
	 * @return RelActSubMotDen Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelActSubMotDen edit(@RequestBody RelActSubMotDen relActSubMotDen) {
		RelActSubMotDen relActSubMotDenAux = this.relActSubMotDenService.update(relActSubMotDen);
		RelActSubMotDenController.logger.info("[PUT] : RelActSubMotDen actualizado correctamente");
		return relActSubMotDenAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relActSubMotDen
	 *            RelActSubMotDen Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return RelActSubMotDen Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelActSubMotDen add(@RequestBody RelActSubMotDen relActSubMotDen) {
		RelActSubMotDen relActSubMotDenAux = this.relActSubMotDenService.add(relActSubMotDen);
		RelActSubMotDenController.logger.info("[POST] : RelActSubMotDen insertado correctamente");
		return relActSubMotDenAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelActSubMotDen
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelActSubMotDen Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelActSubMotDen}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelActSubMotDen remove(@PathVariable Integer idRelActSubMotDen) {
		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
		relActSubMotDen.setIdRelActSubMotDen(idRelActSubMotDen);
		this.relActSubMotDenService.remove(relActSubMotDen, Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE);
		RelActSubMotDenController.logger.info("[DELETE] : RelActSubMotDen borrado correctamente");
		return relActSubMotDen;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelActSubMotDenController.logger.info("[GET - View] : relactsubmotden");
		return "relactsubmotden";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelActSubMotDen> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelActSubMotDen> filter(
			@RequestJsonBody(param = "filter") RelActSubMotDen filterRelActSubMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotDenController.logger.info("[POST - filter] : Obtener RelActSubMotDens");
		return this.relActSubMotDenService.filter(filterRelActSubMotDen, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelActSubMotDen
	 *            RelActSubMotDen Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelActSubMotDen> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelActSubMotDen>> search(
			@RequestJsonBody(param = "filter") RelActSubMotDen filterRelActSubMotDen,
			@RequestJsonBody(param = "search") RelActSubMotDen searchRelActSubMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotDenController.logger.info("[POST - search] : Buscar RelActSubMotDens");
		return this.relActSubMotDenService.search(filterRelActSubMotDen, searchRelActSubMotDen, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") RelActSubMotDen filterRelActSubMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotDenController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelActSubMotDens");
		this.relActSubMotDenService.removeMultiple(filterRelActSubMotDen, jqGridRequestDto, false);
		RelActSubMotDenController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelActSubMotDen>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelActSubMotDen>> jerarquia(
			@RequestJsonBody(param = "filter") RelActSubMotDen filterRelActSubMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotDenController.logger.info("[POST - jerarquia] : Obtener RelActSubMotDens jerarquia");
		return this.relActSubMotDenService.jerarquia(filterRelActSubMotDen, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelActSubMotDen
	 *            RelActSubMotDen Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelActSubMotDen>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelActSubMotDen>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelActSubMotDen filterRelActSubMotDen,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotDenController.logger.info("[POST - jerarquia] : Obtener RelActSubMotDens jerarquia - Hijos");
		return this.relActSubMotDenService.jerarquiaChildren(filterRelActSubMotDen, jqGridRequestDto);
	}

}
