package com.ejie.ab60.control.actuacionesSubvencionables;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotMin;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubMotMinService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * RelActSubMotMinController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relactsubmotmin")

public class RelActSubMotMinController {

	private static final Logger logger = LoggerFactory.getLogger(RelActSubMotMinController.class);

	@Autowired
	private RelActSubMotMinService relActSubMotMinService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelActSubMotDen
	 *            Integer
	 * @return RelActSubMotDen Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelActSub}", method = RequestMethod.GET)
	public @ResponseBody List<RelActSubMotMin> get(@PathVariable Integer idRelActSub) {

		Integer origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_ACT_SUBV;

		List<RelActSubMotMin> relActSubMotMinList = this.relActSubMotMinService.findIdsMotivosMinoraciones(idRelActSub,
				origenMotivosMinoracion);
		RelActSubMotMinController.logger.info("[GET - findBy_PK] : Obtener RelActSubMotMin por PK");
		return relActSubMotMinList;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelActSubMotMin> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelActSubMotMin> getAll(@ModelAttribute RelActSubMotMin filterRelActSubMotMin) {
		RelActSubMotMinController.logger.info("[GET - find_ALL] : Obtener RelActSubMotMin por filtro");
		return this.relActSubMotMinService.findAll(filterRelActSubMotMin, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relActSubMotMin
	 *            RelActSubMotMin Bean que contiene la informacion a modificar.
	 * @return RelActSubMotMin Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelActSubMotMin edit(@RequestBody RelActSubMotMin relActSubMotMin) {
		RelActSubMotMin relActSubMotMinAux = this.relActSubMotMinService.update(relActSubMotMin);
		RelActSubMotMinController.logger.info("[PUT] : RelActSubMotMin actualizado correctamente");
		return relActSubMotMinAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relActSubMotMin
	 *            RelActSubMotMin Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return RelActSubMotMin Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelActSubMotMin add(@RequestBody RelActSubMotMin relActSubMotMin) {
		RelActSubMotMin relActSubMotMinAux = this.relActSubMotMinService.add(relActSubMotMin);
		RelActSubMotMinController.logger.info("[POST] : RelActSubMotMin insertado correctamente");
		return relActSubMotMinAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelActSubMotMin
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelActSubMotMin Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelActSubMotMin}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelActSubMotMin remove(@PathVariable Integer idRelActSubMotMin) {
		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		relActSubMotMin.setIdRelActSubMotMin(idRelActSubMotMin);
		this.relActSubMotMinService.remove(relActSubMotMin, Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE);
		RelActSubMotMinController.logger.info("[DELETE] : RelActSubMotMin borrado correctamente");
		return relActSubMotMin;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelActSubMotMinController.logger.info("[GET - View] : relactsubmotmin");
		return "relactsubmotmin";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelActSubMotMin> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelActSubMotMin> filter(
			@RequestJsonBody(param = "filter") RelActSubMotMin filterRelActSubMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotMinController.logger.info("[POST - filter] : Obtener RelActSubMotMins");
		return this.relActSubMotMinService.filter(filterRelActSubMotMin, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelActSubMotMin
	 *            RelActSubMotMin Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelActSubMotMin> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelActSubMotMin>> search(
			@RequestJsonBody(param = "filter") RelActSubMotMin filterRelActSubMotMin,
			@RequestJsonBody(param = "search") RelActSubMotMin searchRelActSubMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotMinController.logger.info("[POST - search] : Buscar RelActSubMotMins");
		return this.relActSubMotMinService.search(filterRelActSubMotMin, searchRelActSubMotMin, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") RelActSubMotMin filterRelActSubMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotMinController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelActSubMotMins");
		this.relActSubMotMinService.removeMultiple(filterRelActSubMotMin, jqGridRequestDto, false);
		RelActSubMotMinController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelActSubMotMin>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelActSubMotMin>> jerarquia(
			@RequestJsonBody(param = "filter") RelActSubMotMin filterRelActSubMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotMinController.logger.info("[POST - jerarquia] : Obtener RelActSubMotMins jerarquia");
		return this.relActSubMotMinService.jerarquia(filterRelActSubMotMin, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelActSubMotMin
	 *            RelActSubMotMin Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelActSubMotMin>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelActSubMotMin>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelActSubMotMin filterRelActSubMotMin,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubMotMinController.logger.info("[POST - jerarquia] : Obtener RelActSubMotMins jerarquia - Hijos");
		return this.relActSubMotMinService.jerarquiaChildren(filterRelActSubMotMin, jqGridRequestDto);
	}

}
