package com.ejie.ab60.control.actuacionesSubvencionables;

import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubSubact;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubSubactService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * RelActSubSubactController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relactsubsubact")

public class RelActSubSubactController {

	private static final Logger logger = LoggerFactory.getLogger(RelActSubSubactController.class);

	@Autowired
	private RelActSubSubactService relActSubSubactService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelActSubSubact
	 *            Integer
	 * @return RelActSubSubact Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelActSubSubact}", method = RequestMethod.GET)
	public @ResponseBody RelActSubSubact get(@PathVariable Integer idRelActSubSubact) {
		RelActSubSubact relActSubSubact = new RelActSubSubact();
		relActSubSubact.setIdRelActSubSubact(idRelActSubSubact);
		relActSubSubact = this.relActSubSubactService.find(relActSubSubact);
		RelActSubSubactController.logger.info("[GET - findBy_PK] : Obtener RelActSubSubact por PK");
		return relActSubSubact;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelActSubSubact
	 *            RelActSubSubact Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelActSubSubact> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelActSubSubact> getAll(@ModelAttribute RelActSubSubact filterRelActSubSubact) {
		RelActSubSubactController.logger.info("[GET - find_ALL] : Obtener RelActSubSubact por filtro");
		return this.relActSubSubactService.findAll(filterRelActSubSubact, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relActSubSubact
	 *            RelActSubSubact Bean que contiene la informacion a modificar.
	 * @return RelActSubSubact Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelActSubSubact edit(@RequestBody RelActSubSubact relActSubSubact) {
		RelActSubSubact relActSubSubactAux = this.relActSubSubactService.update(relActSubSubact);
		RelActSubSubactController.logger.info("[PUT] : RelActSubSubact actualizado correctamente");
		return relActSubSubactAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relActSubSubact
	 *            RelActSubSubact Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return RelActSubSubact Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelActSubSubact add(@RequestBody RelActSubSubact relActSubSubact) {
		RelActSubSubact relActSubSubactAux = this.relActSubSubactService.add(relActSubSubact);
		RelActSubSubactController.logger.info("[POST] : RelActSubSubact insertado correctamente");
		return relActSubSubactAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelActSubSubact
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelActSubSubact Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelActSubSubact}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelActSubSubact remove(@PathVariable Integer idRelActSubSubact) {
		RelActSubSubact relActSubSubact = new RelActSubSubact();
		relActSubSubact.setIdRelActSubSubact(idRelActSubSubact);
		this.relActSubSubactService.remove(relActSubSubact);
		RelActSubSubactController.logger.info("[DELETE] : RelActSubSubact borrado correctamente");
		return relActSubSubact;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelActSubSubactController.logger.info("[GET - View] : relactsubsubact");
		return "relactsubsubact";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelActSubSubact
	 *            RelActSubSubact Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelActSubSubact> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelActSubSubact> filter(
			@RequestJsonBody(param = "filter") RelActSubSubact filterRelActSubSubact,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubSubactController.logger.info("[POST - filter] : Obtener RelActSubSubacts");
		return this.relActSubSubactService.filter(filterRelActSubSubact, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelActSubSubact
	 *            RelActSubSubact Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelActSubSubact
	 *            RelActSubSubact Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelActSubSubact> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelActSubSubact>> search(
			@RequestJsonBody(param = "filter") RelActSubSubact filterRelActSubSubact,
			@RequestJsonBody(param = "search") RelActSubSubact searchRelActSubSubact,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubSubactController.logger.info("[POST - search] : Buscar RelActSubSubacts");
		return this.relActSubSubactService.search(filterRelActSubSubact, searchRelActSubSubact, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelActSubSubact
	 *            RelActSubSubact Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") RelActSubSubact filterRelActSubSubact,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubSubactController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelActSubSubacts");
		this.relActSubSubactService.removeMultiple(filterRelActSubSubact, jqGridRequestDto, false);
		RelActSubSubactController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelActSubSubact
	 *            RelActSubSubact Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelActSubSubact>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelActSubSubact>> jerarquia(
			@RequestJsonBody(param = "filter") RelActSubSubact filterRelActSubSubact,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubSubactController.logger.info("[POST - jerarquia] : Obtener RelActSubSubacts jerarquia");
		return this.relActSubSubactService.jerarquia(filterRelActSubSubact, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelActSubSubact
	 *            RelActSubSubact Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelActSubSubact>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelActSubSubact>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelActSubSubact filterRelActSubSubact,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelActSubSubactController.logger.info("[POST - jerarquia] : Obtener RelActSubSubacts jerarquia - Hijos");
		return this.relActSubSubactService.jerarquiaChildren(filterRelActSubSubact, jqGridRequestDto);
	}

}
