package com.ejie.ab60.control.actuacionesSubvencionables;

import java.math.BigDecimal;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.PTT.ContratacionesPersonal;
import com.ejie.ab60.model.PTT.GastosTuristicos;
import com.ejie.ab60.model.PTT.PersonasContratadas;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.PTT.GastosTuristicosService;
import com.ejie.ab60.service.PTT.PersonasContratadasService;
import com.ejie.ab60.service.actuacionesSubvencionables.ActSubvencionableService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpActSubController  
 * 
 *  
 */
@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/relexpactsub")
public class RelExpActSubController {

	private static final Logger logger = LoggerFactory.getLogger(RelExpActSubController.class);

	@Autowired
	private RelExpActSubService relExpActSubService;

	@Autowired
	private ConvocatoriasService convocatoriasService;

	@Autowired
	private GastosTuristicosService gastosTuristicosService;

	@Autowired
	private PersonasContratadasService personasContratadasService;

	@Autowired
	private ActSubvencionableService actSubvencionableService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelExpActSub
	 *            Integer
	 * @return RelExpActSub Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelExpActSub}", method = RequestMethod.GET)
	public @ResponseBody RelExpActSub get(@PathVariable Integer idRelExpActSub) {
		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idRelExpActSub);
		relExpActSub = this.relExpActSubService.find(relExpActSub);
		RelExpActSubController.logger.info("[GET - findBy_PK] : Obtener RelExpActSub por PK");
		return relExpActSub;
	}

	/**
	 * Metod para hacer un update de estudio tecnico
	 * 
	 * @param tercero
	 * @return EstudioTecnico Bean resultante del proceso de creacion
	 */
	@RequestMapping(value = "/save/{idExpediente}/{idConvocatoria}", method = RequestMethod.POST)
	public @ResponseBody() RelExpActSub saveDatos(@PathVariable Integer idExpediente,
			@PathVariable Integer idConvocatoria, @RequestBody() RelExpActSub relExpActSub,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return relExpActSubService.saveDatos(idExpediente, idConvocatoria, relExpActSub,
				Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE, usuario);

	}

	/**
	 * Metod para hacer un update de estudio tecnico
	 * 
	 * @param tercero
	 * @return EstudioTecnico Bean resultante del proceso de creacion
	 */
	@RequestMapping(value = "/saveJustificacion/{idExpediente}/{idConvocatoria}", method = RequestMethod.POST)
	public @ResponseBody() RelExpActSub saveDatosJustificacion(@PathVariable Integer idExpediente,
			@PathVariable Integer idConvocatoria, @RequestBody() RelExpActSub relExpActSub,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return relExpActSubService.saveDatosJustificacion(idExpediente, idConvocatoria, relExpActSub,
				Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE_JUS, usuario);

	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelExpActSub> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelExpActSub> getAll(@ModelAttribute RelExpActSub filterRelExpActSub) {
		RelExpActSubController.logger.info("[GET - find_ALL] : Obtener RelExpActSub por filtro");
		return this.relExpActSubService.findAll(filterRelExpActSub, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpActSub
	 *            RelExpActSub Bean que contiene la informacion a modificar.
	 * @return RelExpActSub Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelExpActSub edit(@RequestBody RelExpActSub relExpActSub) {

		RelExpActSub relExpActSubAux = this.relExpActSubService.update(relExpActSub);
		RelExpActSubController.logger.info("[PUT] : RelExpActSub actualizado correctamente");
		return relExpActSubAux;
	}

	@RequestMapping(value = "/{idExpediente}", method = RequestMethod.PUT)
	public @ResponseBody List<RelExpActSub> editOTC(@RequestBody RelExpActSub relExpActSub,
			@PathVariable Integer idExpediente, @ModelAttribute(value = "usuario") Usuario usuario) {

		BigDecimal importeAdmitido = null;

		if (relExpActSub.getImporteJusAdmitidoStr() != null) {
			relExpActSub.setImporteJusAdmitidoStr(relExpActSub.getImporteJusAdmitidoStrInline().replace(".", ""));
			importeAdmitido = new BigDecimal(relExpActSub.getImporteJusAdmitidoStrInline().replace(",", "."));
		}

		relExpActSub.setImporteJustAdmitido(importeAdmitido);

		relExpActSub = this.relExpActSubService.modificaJustOTC(relExpActSub, idExpediente, usuario);

		return null;
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpActSub
	 *            RelExpActSub Bean que contiene la informacion a modificar.
	 * @return RelExpActSub Bean resultante de la modificacion.
	 * @throws Exception
	 */
	@RequestMapping(value = "/{idConvocatoria}/{idExpediente}", method = RequestMethod.PUT)
	public @ResponseBody RelExpActSub edit(@RequestBody RelExpActSub relExpActSub, @PathVariable Integer idConvocatoria,
			@PathVariable Integer idExpediente, @ModelAttribute(value = "usuario") Usuario usuario) throws Exception {

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);
		convocatoria = convocatoriasService.find(convocatoria);
		switch (convocatoria.getIdTipoAyuda()) {
		case Constantes.TIPO_AYUDA_DEC:

			List<RelExpActSub> exento = this.relExpActSubService.findExentoPorExpediente(idExpediente);

			if (exento.size() == 0) {
				relExpActSub.setExento(0);
			} else {
				relExpActSub.setExento(exento.get(0).getExento());
			}

			relExpActSub = this.relExpActSubService.modificaDEC(relExpActSub, idConvocatoria, idExpediente,
					Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE, usuario);

			break;

		case Constantes.TIPO_AYUDA_EMCO:
			relExpActSub = this.relExpActSubService.modificaEMCO(relExpActSub, idConvocatoria, idExpediente,
					Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE, usuario);
			break;

		case Constantes.TIPO_AYUDA_PTT:

			relExpActSub = relExpActSubService.modificaPTT(relExpActSub, idExpediente, idConvocatoria,
					Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE, usuario);

			break;

		case Constantes.TIPO_AYUDA_OTC:
			// metodo para tratar los importes admitidos del inline
			String importeAdmitidoSinFormato = eliminarFormatoImporteAdmitido(relExpActSub);
			relExpActSub.setImporteAdmitido(new BigDecimal(importeAdmitidoSinFormato));
			relExpActSub = this.relExpActSubService.modificaOTC(relExpActSub, idExpediente, idConvocatoria, usuario);
			break;

		case Constantes.TIPO_AYUDA_OMIC:
			String importeAdmitidoSinFormatoOMIC = eliminarFormatoImporteAdmitido(relExpActSub);
			relExpActSub.setImporteAdmitido(new BigDecimal(importeAdmitidoSinFormatoOMIC));
			relExpActSub = this.relExpActSubService.modificaOMIC(relExpActSub, idExpediente, usuario);

		default:
			break;
		}
		RelExpActSubController.logger.info("[PUT] : RelExpActSub actualizado correctamente");
		return relExpActSub;
	}

	private String eliminarFormatoImporteAdmitido(RelExpActSub relExpActSub) {
		String importeAdmitido = relExpActSub.getImporteAdmitidoStrInline();
		if (-1 != importeAdmitido.indexOf(",")) {
			importeAdmitido = importeAdmitido.replaceAll("\\.", "");
			importeAdmitido = importeAdmitido.replaceAll(",", "\\.");
		}

		return importeAdmitido;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relExpActSub
	 *            RelExpActSub Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelExpActSub Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelExpActSub add(@RequestBody RelExpActSub relExpActSub) {
		RelExpActSub relExpActSubAux = this.relExpActSubService.add(relExpActSub);
		RelExpActSubController.logger.info("[POST] : RelExpActSub insertado correctamente");
		return relExpActSubAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param actSubvencionable
	 *            ActSubvencionable Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return ActSubvencionable Bean resultante del proceso de creacion.
	 * @throws Exception
	 */
	@RequestMapping(value = "/{idConvocatoria}/{idExpediente}", method = RequestMethod.POST)
	public @ResponseBody RelExpActSub add(@RequestBody RelExpActSub relExpActSub, @PathVariable Integer idConvocatoria,
			@PathVariable Integer idExpediente, @ModelAttribute(value = "usuario") Usuario usuario) throws Exception {

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);

		convocatoria = convocatoriasService.find(convocatoria);

		switch (convocatoria.getIdTipoAyuda()) {
		case Constantes.TIPO_AYUDA_DEC:

			relExpActSub = this.relExpActSubService.anyadeDEC(relExpActSub, idExpediente, idConvocatoria, usuario);

			break;
		case Constantes.TIPO_AYUDA_EMCO:

			relExpActSub = this.relExpActSubService.anyadeEMCO(relExpActSub, idExpediente, idConvocatoria, usuario);

			break;
		case Constantes.TIPO_AYUDA_PTT:

			relExpActSub = relExpActSubService.anyadePTT(relExpActSub, usuario, idExpediente, idConvocatoria,
					Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE);

			break;
		default:
			break;
		}

		return relExpActSub;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 *
	 * @param idRelExpActSub
	 *            Integer
	 * @return RelExpActSub Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idConvocatoria}/{idExpediente}/{idClavePrimaria}", method = RequestMethod.GET)
	public @ResponseBody RelExpActSub getData(@PathVariable Integer idConvocatoria, @PathVariable Integer idExpediente,
			@PathVariable Integer idClavePrimaria, @ModelAttribute(value = "usuario") Usuario usuario) {

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);

		convocatoria = convocatoriasService.find(convocatoria);

		RelExpActSub relExpActSub = new RelExpActSub();

		switch (convocatoria.getIdTipoAyuda()) {
		case Constantes.TIPO_AYUDA_DEC:

			relExpActSub = this.relExpActSubService.buscaDEC(relExpActSub, idExpediente, idConvocatoria,
					idClavePrimaria, usuario);

			break;
		case Constantes.TIPO_AYUDA_PTT:
			relExpActSub = this.relExpActSubService.findDetallePTT(idExpediente, idConvocatoria, idClavePrimaria);

			Integer idAgrupacionActSub = actSubvencionableService
					.obtenerIdentificadorAgrupacion(relExpActSub.getActSubvencionable().getIdActSub());

			if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Programa_Calidad_Destinos
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Programa_TIC
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Programa_Ecoetiquetas_Europea
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Programa_Compromiso_Accesibilidad
					|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Programa_Compromiso_Codigo_Etico) {
				PersonasContratadas personasContratadas = personasContratadasService
						.findPersonasContratadasPorRelExpActSub(idClavePrimaria).get(0);

				ContratacionesPersonal contratacionesPersonal = new ContratacionesPersonal();
				contratacionesPersonal
						.setIdModalidadContrato(personasContratadas.getModalidadesContrato().getIdModalidadContrato());
				contratacionesPersonal.setIdSexo(personasContratadas.getSexo().getIdSexo());
				contratacionesPersonal.setNombre(personasContratadas.getNombrePC());
				contratacionesPersonal.setApellido1(personasContratadas.getApellido1PC());
				contratacionesPersonal.setApellido2(personasContratadas.getApellido2PC());
				contratacionesPersonal.setEmpresaContratada(personasContratadas.getEmpresaContratada());
				relExpActSub.setContratacionesPersonal(contratacionesPersonal);

				relExpActSub.setIdActSub(relExpActSub.getActSubvencionable().getIdActSub());
				relExpActSub.setPersonasContratadas(personasContratadas);

			} else if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion) {
				GastosTuristicos gastosTuristicos = gastosTuristicosService
						.findGastosTuristicosPorRelExpActSub(idClavePrimaria);
				relExpActSub.setGastosTuristicos(gastosTuristicos);
				relExpActSub.setProductosTuristicos(gastosTuristicos.getProductosTuristicos());
			}

			break;
		case Constantes.TIPO_AYUDA_EMCO:

			relExpActSub = this.relExpActSubService.buscaEMCO(relExpActSub, idExpediente, idConvocatoria,
					idClavePrimaria, usuario);

			break;
		default:
			break;
		}

		return relExpActSub;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 *
	 * @param idRelExpActSub
	 *            Integer
	 * @return RelExpActSub Objeto correspondiente al identificador indicado.
	 * @throws Exception
	 */
	@RequestMapping(value = "/{idConvocatoria}/{idExpediente}/{idClavePrimaria}", method = RequestMethod.DELETE)
	public @ResponseBody RelExpActSub delete(@PathVariable Integer idConvocatoria, @PathVariable Integer idExpediente,
			@PathVariable Integer idClavePrimaria, @ModelAttribute(value = "usuario") Usuario usuario)
			throws Exception {

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);

		convocatoria = convocatoriasService.find(convocatoria);

		RelExpActSub relExpActSub = new RelExpActSub();

		switch (convocatoria.getIdTipoAyuda()) {
		case Constantes.TIPO_AYUDA_DEC:
			relExpActSub = this.relExpActSubService.borraDEC(relExpActSub, idConvocatoria, idExpediente,
					idClavePrimaria, Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE, usuario);

			break;
		case Constantes.TIPO_AYUDA_EMCO:
			relExpActSub = this.relExpActSubService.borraEMCO(relExpActSub, idConvocatoria, idExpediente,
					idClavePrimaria, Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE, usuario);

			break;
		case Constantes.TIPO_AYUDA_PTT:

			relExpActSub = relExpActSubService.borraPTT(relExpActSub, idClavePrimaria, idExpediente, idConvocatoria,
					Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE, usuario);

			break;
		default:
			break;
		}

		return relExpActSub;
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelExpActSub
	 *            RelExpActSub Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelExpActSub> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/{idConvocatoria}/{idExpedientes}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpActSub> filter(@PathVariable Integer idExpedientes,
			@PathVariable Integer idConvocatoria, @RequestJsonBody(param = "filter") RelExpActSub filterRelExpActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		Integer idExpediente = idExpedientes;
		filterRelExpActSub.setIdconvocatoria(idConvocatoria);
		filterRelExpActSub.setIdExpediente(idExpediente);

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);

		convocatoria = convocatoriasService.find(convocatoria);

		JQGridResponseDto<RelExpActSub> tablaResultado = null;

		switch (convocatoria.getIdTipoAyuda()) {
		case Constantes.TIPO_AYUDA_MEC:
			tablaResultado = relExpActSubService.filter(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_EMET:
			tablaResultado = relExpActSubService.filterEMET(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_PTT:
			tablaResultado = relExpActSubService.filterPTT(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_CTP:
			tablaResultado = relExpActSubService.filterCTP(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_DEC:
			tablaResultado = relExpActSubService.filterDEC(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_OTC:
			tablaResultado = relExpActSubService.filterOTC(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_OMIC:
			tablaResultado = relExpActSubService.filterOMIC(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_EMCO:
			tablaResultado = relExpActSubService.filterEMCO(filterRelExpActSub, jqGridRequestDto, false);
			break;
		case Constantes.TIPO_AYUDA_COVIDT:
		case Constantes.TIPO_AYUDA_COVIDM:
			tablaResultado = relExpActSubService.filterCOVIDT(filterRelExpActSub, jqGridRequestDto, false);
			break;
		default:
			break;
		}

		return tablaResultado;
	}

	@RequestMapping(value = "/{idExpediente}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpActSub> filter(
			@RequestJsonBody(param = "filter") RelExpActSub filterRelFacActSubvencionables,
			@PathVariable Integer idExpediente, @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpActSubController.logger.info("[POST - filter] : Obtener RelFacActSubvencionabless");

		filterRelFacActSubvencionables.setIdExpediente(idExpediente);
		return this.relExpActSubService.filterJustificacion(filterRelFacActSubvencionables, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelExpActSub
	 *            RelExpActSub Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelExpActSub
	 *            RelExpActSub Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelExpActSub> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelExpActSub>> search(
			@RequestJsonBody(param = "filter") RelExpActSub filterRelExpActSub,
			@RequestJsonBody(param = "search") RelExpActSub searchRelExpActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpActSubController.logger.info("[POST - search] : Buscar RelExpActSubs");
		return this.relExpActSubService.search(filterRelExpActSub, searchRelExpActSub, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelExpActSub
	 *            RelExpActSub Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelExpActSub filterRelExpActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpActSubController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelExpActSubs");
		this.relExpActSubService.removeMultiple(filterRelExpActSub, jqGridRequestDto, false);
		RelExpActSubController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelExpActSub
	 *            RelExpActSub Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpActSub>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpActSub>> jerarquia(
			@RequestJsonBody(param = "filter") RelExpActSub filterRelExpActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpActSubController.logger.info("[POST - jerarquia] : Obtener RelExpActSubs jerarquia");
		return this.relExpActSubService.jerarquia(filterRelExpActSub, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelExpActSub
	 *            RelExpActSub Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpActSub>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpActSub>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelExpActSub filterRelExpActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpActSubController.logger.info("[POST - jerarquia] : Obtener RelExpActSubs jerarquia - Hijos");
		return this.relExpActSubService.jerarquiaChildren(filterRelExpActSub, jqGridRequestDto);
	}

	@RequestMapping(value = "/recalcularImportePresentado/{idExpediente}/{exento}", method = RequestMethod.GET)
	public @ResponseBody String recalcularImportePresentado(@PathVariable Integer idExpediente,
			@PathVariable Integer exento) {
		RelExpActSubController.logger.info("[GET] : Recalcular importe presentado en base a exento");
		this.relExpActSubService.recalcularImportePresentado(idExpediente, exento);
		return "OK";
	}

}
