package com.ejie.ab60.control.convocatorias;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.control.justificacion.RelFacActSubvencionablesController;
import com.ejie.ab60.model.Idiomas;
import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.convocatorias.AplicacionesPresupuestarias;
import com.ejie.ab60.model.convocatorias.ReferenciasIntervencion;
import com.ejie.ab60.model.justificacion.RelFacActSubvencionables;
import com.ejie.ab60.model.nora.T17Provincia;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.convocatorias.AplicacionesPresupuestariasService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.convocatorias.ReferenciasIntervencionService;
import com.ejie.ab60.util.UtilDate;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.TableRowDto;

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/aplicacionespresupuestarias")
public class AplicacionesPresupuestariasController {

	private static final Logger logger = LoggerFactory.getLogger(AplicacionesPresupuestariasController.class);

	@Autowired
	private ConvocatoriasService convocatoriasService;

	@Autowired
	private AplicacionesPresupuestariasService aplicacionesPresupuestariasService;

	@Autowired
	private ReferenciasIntervencionService referenciaIntervencionService;

	@RequestMapping(value = "/{idConvocatoria}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<AplicacionesPresupuestarias> filter(
			@RequestJsonBody(param = "filter") AplicacionesPresupuestarias aplPresupuestaria,
			@PathVariable Integer idConvocatoria, @RequestJsonBody JQGridRequestDto jqGridRequestDto) throws Exception {

		aplPresupuestaria.setIdConvocatoria(idConvocatoria);

		return this.aplicacionesPresupuestariasService.filter(aplPresupuestaria, jqGridRequestDto, false);

	}

	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<AplicacionesPresupuestarias> filterInicial(
			@RequestJsonBody(param = "filter") AplicacionesPresupuestarias aplPresupuestaria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) throws Exception {

		return this.aplicacionesPresupuestariasService.filter(aplPresupuestaria, jqGridRequestDto, false);

	}

	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<AplicacionesPresupuestarias>> search(
			@RequestJsonBody(param = "filter") AplicacionesPresupuestarias filterAplicacionesPresupuestarias,
			@RequestJsonBody(param = "search") AplicacionesPresupuestarias searchAplicacionesPresupuestarias,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AplicacionesPresupuestariasController.logger.info("[POST - search] : Buscar AplicacionesPresupuestarias");
		return this.aplicacionesPresupuestariasService.search(filterAplicacionesPresupuestarias,
				searchAplicacionesPresupuestarias, jqGridRequestDto, false);
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAplicacionPresupuestaria
	 *            Integer
	 * @return AplicacionesPresupuestarias Bean eliminado.
	 */
	@RequestMapping(value = "/{idAplicacionPresupuestaria}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody AplicacionesPresupuestarias remove(@PathVariable Integer idAplicacionPresupuestaria) {

		AplicacionesPresupuestariasController.logger.info("[DELETE] : BORRAR AplicacionesPresupuestarias");

		AplicacionesPresupuestarias aplPresu = new AplicacionesPresupuestarias();
		aplPresu.setIdAplicacionPresupuestaria(idAplicacionPresupuestaria);

		ReferenciasIntervencion ref = new ReferenciasIntervencion();
		ref.setIdAplicacionPresupuestaria(idAplicacionPresupuestaria);
		referenciaIntervencionService.removeByAplicacionPresu(ref);

		return aplicacionesPresupuestariasService.remove(aplPresu);

	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param aplicacionesPresupuestarias
	 *            AplicacionesPresupuestarias Bean que contiene la informacion
	 *            con la que se va a crear el nuevo registro.
	 * @return AplicacionesPresupuestarias Bean resultante del proceso de
	 *         creacion.
	 */
	@RequestMapping(value = "/{idConvocatoria}", method = RequestMethod.POST)
	public @ResponseBody AplicacionesPresupuestarias add(@PathVariable Integer idConvocatoria,
			@RequestBody AplicacionesPresupuestarias aplicacionesPresupuestarias) {

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);

		if (aplicacionesPresupuestarias.getProvincia() == null)
			aplicacionesPresupuestarias.setProvincia(new T17Provincia());
		aplicacionesPresupuestarias.setIdConvocatoria(idConvocatoria);
		aplicacionesPresupuestarias.setUsuarioRegistro(usuario.getNombreUsuario());
		aplicacionesPresupuestarias.setFechaRegistro(new Date());

		this.aplicacionesPresupuestariasService.add(aplicacionesPresupuestarias);

		return aplicacionesPresupuestarias;
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param aplicacionesPresupuestarias
	 *            AplicacionesPresupuestarias Bean que contiene la informacion a
	 *            modificar.
	 * @return AplicacionesPresupuestarias Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/{idConvocatoria}", method = RequestMethod.PUT)
	public @ResponseBody AplicacionesPresupuestarias edit(
			@RequestBody AplicacionesPresupuestarias aplicacionesPresupuestarias,
			@PathVariable Integer idConvocatoria) {

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);

		if (aplicacionesPresupuestarias.getProvincia() == null)
			aplicacionesPresupuestarias.setProvincia(new T17Provincia());
		aplicacionesPresupuestarias.setIdConvocatoria(idConvocatoria);
		aplicacionesPresupuestarias.setUsuarioUltmodificacion(usuario.getNombreUsuario());
		aplicacionesPresupuestarias.setFechaUltmodificacion(new Date());

		try {
			this.aplicacionesPresupuestariasService.update(aplicacionesPresupuestarias);
		} catch (Exception e) {
			AplicacionesPresupuestariasController.logger
					.info("[ERROR] : Valores diferentes entre importe e importe disponible");
		}

		return aplicacionesPresupuestarias;
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param aplicacionesPresupuestarias
	 *            AplicacionesPresupuestarias Bean que contiene la informacion a
	 *            modificar.
	 * @return AplicacionesPresupuestarias Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/editar/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody AplicacionesPresupuestarias editConValidacion(
			@RequestParam(value = "idAplicacionPresupuestaria", required = true) Integer idAplicacionPresupuestaria,
			@RequestParam(value = "ejercicioAplicPresu", required = true) String ejercicioAplicPresu,
			@RequestParam(value = "agrupacionAplicPresu", required = true) String agrupacionAplicPresu,
			@RequestParam(value = "gastoIngresoAplicPresu", required = true) String gastoIngresoAplicPresu,
			@RequestParam(value = "seccionAplicPresu", required = true) String seccionAplicPresu,
			@RequestParam(value = "servicioAplicPresu", required = true) String servicioAplicPresu,
			@RequestParam(value = "centroAplicPresu", required = true) String centroAplicPresu,
			@RequestParam(value = "cacAplicPresu", required = true) String cacAplicPresu,
			@RequestParam(value = "scAplicPresu", required = true) String scAplicPresu,
			@RequestParam(value = "programaAplicPresu", required = true) String programaAplicPresu,
			@RequestParam(value = "partidaAplicPresu", required = true) String partidaAplicPresu,
			@RequestParam(value = "letraControlAplicPresu", required = true) String letraControlAplicPresu,
			@RequestParam(value = "idImporte", required = true) BigDecimal importe,
			@RequestParam(value = "idImporteDisponible", required = true) BigDecimal importeDisponible,
			@RequestParam(value = "provincia", required = true) String idProvincia,
			@RequestParam(value = "idRefIntervencion", required = true) Integer idRefIntervencion,
			@RequestParam(value = "ejercicioRefInter", required = true) String ejercicioRefInter,
			@RequestParam(value = "anyoRefInter", required = true) String anyoRefInter,
			@RequestParam(value = "numeroRefInter", required = true) String numeroRefInter,
			@RequestParam(value = "disponibleRefInter", required = true) String disponibleRefInter,
			@RequestParam(value = "obligacionRefInter", required = true) String obligacionRefInter,
			@PathVariable Integer idConvocatoria) {

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);

		AplicacionesPresupuestarias aplicacionesPresupuestarias = new AplicacionesPresupuestarias();
		aplicacionesPresupuestarias.setIdAplicacionPresupuestaria(idAplicacionPresupuestaria);
		aplicacionesPresupuestarias.setEjercicio(ejercicioAplicPresu);
		aplicacionesPresupuestarias.setAgrupacion(agrupacionAplicPresu);
		aplicacionesPresupuestarias.setGastoIngreso(gastoIngresoAplicPresu);
		aplicacionesPresupuestarias.setSeccion(seccionAplicPresu);
		aplicacionesPresupuestarias.setServicio(servicioAplicPresu);
		aplicacionesPresupuestarias.setCentro(centroAplicPresu);
		aplicacionesPresupuestarias.setCac(cacAplicPresu);
		aplicacionesPresupuestarias.setSc(scAplicPresu);
		aplicacionesPresupuestarias.setPrograma(programaAplicPresu);
		aplicacionesPresupuestarias.setPartida(partidaAplicPresu);
		aplicacionesPresupuestarias.setLetraControl(letraControlAplicPresu);
		aplicacionesPresupuestarias.setImporte(importe);
		aplicacionesPresupuestarias.setImporteDisponible(importeDisponible);

		if (idProvincia == null)
			aplicacionesPresupuestarias.setProvincia(new T17Provincia());
		else {
			aplicacionesPresupuestarias.setProvincia(new T17Provincia());
			aplicacionesPresupuestarias.getProvincia().setId(idProvincia);
		}

		aplicacionesPresupuestarias.setIdConvocatoria(idConvocatoria);

		ReferenciasIntervencion refIntervencion = new ReferenciasIntervencion();
		refIntervencion.setIdReferenciaIntervencion(idRefIntervencion);
		refIntervencion.setEjercicio(ejercicioRefInter);
		refIntervencion.setAnyoOrigen(anyoRefInter);
		refIntervencion.setNumero(numeroRefInter);
		refIntervencion.setDisponible(disponibleRefInter);
		refIntervencion.setObligacion(obligacionRefInter);

		try {
			if (idAplicacionPresupuestaria != null) {
				aplicacionesPresupuestarias.setUsuarioUltmodificacion(usuario.getNombreUsuario());
				aplicacionesPresupuestarias.setFechaUltmodificacion(new Date());
				refIntervencion.setIdAplicacionPresupuestaria(idAplicacionPresupuestaria);

				this.aplicacionesPresupuestariasService.update(aplicacionesPresupuestarias);

				if (idRefIntervencion != null) {
					refIntervencion.setUsuarioUltmodificacion(usuario.getNombreUsuario());
					refIntervencion.setFechaUltmodificacion(new Date());

					this.referenciaIntervencionService.update(refIntervencion);
				} else {
					refIntervencion.setUsuarioRegistro(usuario.getNombreUsuario());
					refIntervencion.setFechaRegistro(new Date());

					this.referenciaIntervencionService.add(refIntervencion);
				}

			} else {
				aplicacionesPresupuestarias.setUsuarioRegistro(usuario.getNombreUsuario());
				aplicacionesPresupuestarias.setFechaRegistro(new Date());

				aplicacionesPresupuestarias = this.aplicacionesPresupuestariasService.add(aplicacionesPresupuestarias);
				refIntervencion
						.setIdAplicacionPresupuestaria(aplicacionesPresupuestarias.getIdAplicacionPresupuestaria());
				refIntervencion.setUsuarioRegistro(usuario.getNombreUsuario());
				refIntervencion.setFechaRegistro(new Date());

				this.referenciaIntervencionService.add(refIntervencion);
			}
			aplicacionesPresupuestarias.setControlError(false);

		} catch (Exception e) {
			AplicacionesPresupuestariasController.logger
					.info("[ERROR] : Valores diferentes entre importe e importe disponible");
			aplicacionesPresupuestarias.setControlError(true);
		}

		return aplicacionesPresupuestarias;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 *
	 * @param idAplicacionPresupuestaria
	 *            Integer
	 * @return AplicacionesPresupuestarias Objeto correspondiente al
	 *         identificador indicado.
	 */
	@RequestMapping(value = "/{idAplicacionPresupuestaria}", method = RequestMethod.GET)
	public @ResponseBody AplicacionesPresupuestarias getData(@PathVariable Integer idAplicacionPresupuestaria) {
		AplicacionesPresupuestariasController.logger
				.info("[GET - findBy_PK] : Obtener AplicacionesPresupuestarias por PK");

		AplicacionesPresupuestarias aplPresu = new AplicacionesPresupuestarias();
		aplPresu.setIdAplicacionPresupuestaria(idAplicacionPresupuestaria);

		aplPresu = aplicacionesPresupuestariasService.find(aplPresu);

		ReferenciasIntervencion refIntervencion = new ReferenciasIntervencion();
		refIntervencion.setIdAplicacionPresupuestaria(aplPresu.getIdAplicacionPresupuestaria());

		aplPresu.setRefIntervencion(referenciaIntervencionService.findByAplicPresu(refIntervencion));

		if (aplPresu.getRefIntervencion() == null) {
			aplPresu.setRefIntervencion(new ReferenciasIntervencion());
		}

		return aplPresu;
	}

}
