package com.ejie.ab60.control.convocatorias;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.convocatorias.TiposConvocatoria;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.util.PermisosXLNETS;
import com.ejie.ab60.util.UtilDate;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ConvocatoriasController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/convocatorias")

public class ConvocatoriasController {

	private static final Logger logger = LoggerFactory.getLogger(ConvocatoriasController.class);

	@Autowired
	private ConvocatoriasService convocatoriasService;

	/**
	 * @param model
	 *            Model
	 * @param initForm
	 *            InitForm
	 * 
	 * @return ModelAndView
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public ModelAndView mostrar(Model model, Convocatorias convocatorias, Procedimientos procedimientos,
			@ModelAttribute(value = "initForm") InitForm initForm) {
		if (null != initForm.getIdConvocatoria()) {
			convocatorias.setIdConvocatoria(initForm.getIdConvocatoria());
			convocatorias = convocatoriasService.find(convocatorias);
			String fechaResolucion = UtilDate.convertirFechaEnString(convocatorias.getFechaResolucion());
			String fechaOrden = UtilDate.convertirFechaEnString(convocatorias.getFechaOrdenDia());
			convocatorias.setFechaResolucionStr(fechaResolucion);
			convocatorias.setFechaOrdenDiaStr(fechaOrden);
			model.addAttribute("datosConv", convocatorias);
			String idioma = LocaleContextHolder.getLocale().getLanguage();
			model.addAttribute("lenguaje", idioma);
			if (null != convocatorias.getActSubvencionables() && !convocatorias.getActSubvencionables().isEmpty()) {
				// el tipo importe determina si el importe que se muestra en
				// pantalla es el importe de la convocatoria o el de las
				// acciones subvencionables
				model.addAttribute("tipoImporte", 1);
			} else {
				model.addAttribute("tipoImporte", 0);
			}
			return new ModelAndView("convocatorias");
		} else {
			return new ModelAndView("folderError");
		}
	}

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idConvocatoria
	 *            Integer
	 * @return Convocatorias Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "idConvocatoria/{idConvocatoria}", method = RequestMethod.POST)
	public @ResponseBody String get(@PathVariable Integer idConvocatoria, Model model) {
		Convocatorias convocatorias = new Convocatorias();
		convocatorias.setIdConvocatoria(idConvocatoria);
		convocatorias = this.convocatoriasService.find(convocatorias);
		model.addAttribute("datosConv", convocatorias);
		ConvocatoriasController.logger.info("[GET - findBy_PK] : Obtener Convocatorias por PK");
		return "convocatorias";
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idConvocatoria
	 *            Integer
	 * @return Convocatorias Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "obtenerFaseActiva/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody Convocatorias getFaseActiva(@PathVariable Integer idConvocatoria) {
		Convocatorias convocatorias = new Convocatorias();
		convocatorias.setIdConvocatoria(idConvocatoria);
		convocatorias = this.convocatoriasService.findFaseActiva(convocatorias);
		ConvocatoriasController.logger.info("[GET - findBy_PK] : Obtener Fase Activa por IdProcedimiento");
		return convocatorias;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterConvocatorias
	 *            Convocatorias Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Convocatorias> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Convocatorias> getAll(@ModelAttribute Convocatorias filterConvocatorias) {
		ConvocatoriasController.logger.info("[GET - find_ALL] : Obtener Convocatorias por filtro");
		return this.convocatoriasService.findAll(filterConvocatorias, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param convocatorias
	 *            Convocatorias Bean que contiene la informacion a modificar.
	 * @return Convocatorias Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Convocatorias edit(@RequestBody Convocatorias convocatorias) {
		Convocatorias convocatoriasAux = this.convocatoriasService.update(convocatorias);
		ConvocatoriasController.logger.info("[PUT] : Convocatorias actualizado correctamente");
		return convocatoriasAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param convocatorias
	 *            Convocatorias Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return Convocatorias Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Convocatorias add(HttpServletRequest httpRequest, @RequestBody Convocatorias convocatorias,
			Procedimientos procedimientos, TiposConvocatoria tiposConvocatoria,
			@ModelAttribute(value = "initForm") InitForm initForm, HttpServletRequest request) {
		// variable con idAcSub#importe|idAcSub#importe...
		String importesActSubActualizar = convocatorias.getImportesActSubActualizar();
		List<ActSubvencionable> listaActSubvencionables = new ArrayList<ActSubvencionable>();
		if (null != importesActSubActualizar && !"".equalsIgnoreCase(importesActSubActualizar)) {
			String[] listaAccionesSubencionablesConSuImporte = importesActSubActualizar.split("%");
			for (String accionesSubencionablesConSuImporte : listaAccionesSubencionablesConSuImporte) {
				String[] idAccionImporte = accionesSubencionablesConSuImporte.split("#");
				ActSubvencionable actSubvencionable = new ActSubvencionable();
				actSubvencionable.setIdActSub(Integer.parseInt(idAccionImporte[0]));
				actSubvencionable.setImporte(new BigDecimal(idAccionImporte[1]));
				listaActSubvencionables.add(actSubvencionable);
			}
			convocatorias.setActSubvencionables(listaActSubvencionables);
		}

		convocatorias.setFechaUltmodificacion(new Date());
		convocatorias.setUsuarioUltmodificacion(PermisosXLNETS.fncLogin(httpRequest));

		convocatorias.setIdConvocatoria(initForm.getIdConvocatoria());
		convocatorias.setIdTipoAyuda(initForm.getTipoAyuda());
		convocatorias.setFechaResolucionStr(
				UtilDate.convertirStringEnStringFormateado(convocatorias.getFechaResolucionStr()));

		convocatorias
				.setFechaOrdenDiaStr(UtilDate.convertirStringEnStringFormateado(convocatorias.getFechaOrdenDiaStr()));

		Convocatorias convocatoriasAux = this.convocatoriasService.update(convocatorias);

		ConvocatoriasController.logger.info("[POST] : Convocatorias modificado correctamente");
		return convocatoriasAux;

	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idConvocatoria
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Convocatorias Bean eliminado.
	 */
	@RequestMapping(value = "/{idConvocatoria}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Convocatorias remove(@PathVariable Integer idConvocatoria) {
		Convocatorias convocatorias = new Convocatorias();
		convocatorias.setIdConvocatoria(idConvocatoria);
		this.convocatoriasService.remove(convocatorias);
		ConvocatoriasController.logger.info("[DELETE] : Convocatorias borrado correctamente");
		return convocatorias;
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param faseActiva
	 *            Integer
	 * @param idProcedimiento
	 *            Integer
	 * @param usuario
	 *            Usuario
	 * @return Convocatorias Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/aplicarCorte/{idConvocatoria}/{faseActiva}/{idProcedimiento}", method = RequestMethod.GET)
	public @ResponseBody Convocatorias aplicarCorte(@PathVariable Integer idConvocatoria,
			@PathVariable Integer faseActiva, @PathVariable Integer idProcedimiento) {

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);

		return convocatoriasService.aplicarCorte(idConvocatoria, faseActiva, idProcedimiento, usuario);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param idConvocatoria
	 *            Integer
	 * @param faseActiva
	 *            Integer
	 * @param idProcedimiento
	 *            Integer
	 * @param usuario
	 *            Usuario
	 * @return Convocatorias Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/deshacerCorte/{idConvocatoria}/{faseActiva}/{idProcedimiento}", method = RequestMethod.GET)
	public @ResponseBody Convocatorias deshacerCorte(@PathVariable Integer idConvocatoria,
			@PathVariable Integer faseActiva, @PathVariable Integer idProcedimiento) {

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);

		return convocatoriasService.deshacerCorte(idConvocatoria, faseActiva, idProcedimiento, usuario);
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterConvocatorias
	 *            Convocatorias Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Convocatorias> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Convocatorias> filter(
			@RequestJsonBody(param = "filter") Convocatorias filterConvocatorias,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConvocatoriasController.logger.info("[POST - filter] : Obtener Convocatoriass");
		return this.convocatoriasService.filter(filterConvocatorias, jqGridRequestDto, false);
	}

	/**
	 * 
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterConvocatorias
	 *            Convocatorias Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchConvocatorias
	 *            Convocatorias Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Convocatorias> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Convocatorias>> search(
			@RequestJsonBody(param = "filter") Convocatorias filterConvocatorias,
			@RequestJsonBody(param = "search") Convocatorias searchConvocatorias,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConvocatoriasController.logger.info("[POST - search] : Buscar Convocatoriass");
		return this.convocatoriasService.search(filterConvocatorias, searchConvocatorias, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterConvocatorias
	 *            Convocatorias Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") Convocatorias filterConvocatorias,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConvocatoriasController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Convocatoriass");
		this.convocatoriasService.removeMultiple(filterConvocatorias, jqGridRequestDto, false);
		ConvocatoriasController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterConvocatorias
	 *            Convocatorias Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Convocatorias>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Convocatorias>> jerarquia(
			@RequestJsonBody(param = "filter") Convocatorias filterConvocatorias,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConvocatoriasController.logger.info("[POST - jerarquia] : Obtener Convocatoriass jerarquia");
		return this.convocatoriasService.jerarquia(filterConvocatorias, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterConvocatorias
	 *            Convocatorias Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Convocatorias>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Convocatorias>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Convocatorias filterConvocatorias,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConvocatoriasController.logger.info("[POST - jerarquia] : Obtener Convocatoriass jerarquia - Hijos");
		return this.convocatoriasService.jerarquiaChildren(filterConvocatorias, jqGridRequestDto);
	}

	@RequestMapping(value = "/updateFecha/{dia}/{mes}/{anyo}", method = RequestMethod.POST)
	public @ResponseBody Convocatorias updateFecha(@PathVariable String dia, @PathVariable String mes,
			@PathVariable String anyo, @ModelAttribute(value = "initForm") InitForm initForm) {
		ConvocatoriasController.logger.info("[POST - jerarquia] : Update fechas");
		Convocatorias convocatoria = new Convocatorias();
		String fecha = dia + "/" + mes + "/" + anyo;

		SimpleDateFormat formato = new SimpleDateFormat("dd/MM/yyyy");
		Date fechaDate = null;

		try {
			fechaDate = formato.parse(fecha);
		} catch (ParseException ex) {
			System.out.println(ex);
		}

		convocatoria.setFechaResolucion(fechaDate);
		convocatoria.setIdConvocatoria(initForm.getIdConvocatoria());
		this.convocatoriasService.updateFechas(convocatoria);
		return convocatoria;
	}

}
