package com.ejie.ab60.control.convocatorias;

import java.util.HashMap;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.convocatorias.DatosContables;
import com.ejie.ab60.model.convocatorias.InfDatosIkus;
import com.ejie.ab60.model.convocatorias.ReferenciasIntervencion;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.convocatorias.DatosContablesService;
import com.ejie.ab60.service.convocatorias.ReferenciasIntervencionService;

/**
 * DatosContablesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/datoscontables")

public class DatosContablesController {

	private static final Logger logger = LoggerFactory.getLogger(DatosContablesController.class);

	@Autowired
	private DatosContablesService datosContablesService;

	@Autowired
	private ReferenciasIntervencionService referenciasIntervencionService;

	@Autowired
	private ConvocatoriasService convocatoriasService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idDatoContable
	 *            String
	 * @return DatosContables Objeto correspondiente al identificador indicado.
	 */
	/*
	 * @RequestMapping(value = "/{idDatoContable}", method = RequestMethod.GET)
	 * public @ResponseBody DatosContables get(@PathVariable Integer
	 * idDatoContable) { DatosContables datosContables = new DatosContables();
	 * datosContables.setIdDatoContable(idDatoContable); datosContables =
	 * this.datosContablesService.find(datosContables);
	 * DatosContablesController.logger.
	 * info("[GET - findBy_PK] : Obtener DatosContables por PK"); return
	 * datosContables; }
	 */
	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterDatosContables
	 *            DatosContables Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<DatosContables> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	/*
	 * @RequestMapping(method = RequestMethod.GET) public @ResponseBody
	 * List<DatosContables> getAll(@ModelAttribute DatosContables
	 * filterDatosContables) { DatosContablesController.logger.
	 * info("[GET - find_ALL] : Obtener DatosContables por filtro"); return
	 * this.datosContablesService.findAll(filterDatosContables, null); }
	 */

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param datosContables
	 *            DatosContables Bean que contiene la informacion a modificar.
	 * @return DatosContables Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody DatosContables edit(@RequestBody DatosContables datosContables) {
		DatosContables datosContablesAux = this.datosContablesService.update(datosContables);
		DatosContablesController.logger.info("[PUT] : DatosContables actualizado correctamente");
		return datosContablesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param datosContables
	 *            DatosContables Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return DatosContables Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody DatosContables add(@RequestBody DatosContables datosContables) {
		DatosContables datosContablesAux = this.datosContablesService.add(datosContables);
		DatosContablesController.logger.info("[POST] : DatosContables insertado correctamente");
		return datosContablesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idDatoContable
	 *            String Identificador del objeto que se desea eliminar.
	 * @return DatosContables Bean eliminado.
	 */
	/*
	 * @RequestMapping(value = "/{idDatoContable}", method =
	 * RequestMethod.DELETE)
	 * 
	 * @ResponseStatus(value = HttpStatus.OK) public @ResponseBody
	 * DatosContables remove(@PathVariable Integer idDatoContable) {
	 * DatosContables datosContables = new DatosContables();
	 * datosContables.setIdDatoContable(idDatoContable);
	 * this.datosContablesService.remove(datosContables);
	 * DatosContablesController.logger.
	 * info("[DELETE] : DatosContables borrado correctamente"); return
	 * datosContables; }
	 */

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model, Convocatorias convocatorias,
			@ModelAttribute(value = "initForm") InitForm initForm) {
		DatosContablesController.logger.info("[GET - View] : datoscontables");

		Integer idConvocatoria = initForm.getIdConvocatoria();

		convocatorias.setIdConvocatoria(idConvocatoria);
		convocatorias = convocatoriasService.find(convocatorias);
		model.addAttribute("datosConv", convocatorias);

		InfDatosIkus datosIkus = new InfDatosIkus();

		datosIkus.setDatosContables(new DatosContables());
		datosIkus.getDatosContables().setIdConvocatoria(idConvocatoria);
		datosIkus.setDatosContables(datosContablesService.findbyConvocatoria(datosIkus.getDatosContables()));

		if (datosIkus.getDatosContables() == null)
			datosIkus.setDatosContables(new DatosContables());

		model.addAttribute("infDatosIkus", datosIkus);

		return "datoscontables";
	}

	@RequestMapping(value = "/obtenerDatoContable/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody() HashMap<String, String> getDatosContables(
			@PathVariable("idConvocatoria") Integer idConvocatoria) {
		DatosContablesController.logger.info("[GET - View] : datoscontables");

		InfDatosIkus datosIkus = new InfDatosIkus();

		datosIkus.setDatosContables(new DatosContables());
		datosIkus.getDatosContables().setIdConvocatoria(idConvocatoria);
		datosIkus.setDatosContables(datosContablesService.findbyConvocatoria(datosIkus.getDatosContables()));

		HashMap<String, String> retorno = new HashMap<String, String>();

		if (datosIkus.getDatosContables() == null) {
			datosIkus.setDatosContables(new DatosContables());

			return new HashMap<String, String>();
		} else {
			if (datosIkus.getDatosContables().getIdDatoContable() == null) {
				retorno.put("idDatoContable", "");
			} else {
				retorno.put("idDatoContable", datosIkus.getDatosContables().getIdDatoContable().toString());
			}

			if (datosIkus.getDatosContables().getInstitucion() == null) {
				retorno.put("institucion", "");
			} else {
				retorno.put("institucion", datosIkus.getDatosContables().getInstitucion());
			}

			if (datosIkus.getDatosContables().getEjercicio() == null) {
				retorno.put("ejercicio", "");
			} else {
				retorno.put("ejercicio", datosIkus.getDatosContables().getEjercicio());
			}

			if (datosIkus.getDatosContables().getSeccion() == null) {
				retorno.put("seccion", "");
			} else {
				retorno.put("seccion", datosIkus.getDatosContables().getSeccion());
			}

			if (datosIkus.getDatosContables().getUsuarioIkus() == null) {
				retorno.put("usuarioIKUS", "");
			} else {
				retorno.put("usuarioIKUS", datosIkus.getDatosContables().getUsuarioIkus());
			}

			if (datosIkus.getDatosContables().getIdIdioma() == null) {
				retorno.put("idioma", "");
			} else {
				retorno.put("idioma", datosIkus.getDatosContables().getIdIdioma().toString());
			}

			if (datosIkus.getDatosContables().getConceptoResumido() == null) {
				retorno.put("concepto", "");
			} else {
				retorno.put("concepto", datosIkus.getDatosContables().getConceptoResumido());
			}

			if (datosIkus.getDatosContables().getImporte() == null) {
				retorno.put("importe", "");
			} else {
				retorno.put("importe", datosIkus.getDatosContables().getImporte().toString());
			}

			if (datosIkus.getDatosContables().getImporteDisponible() == null) {
				retorno.put("importeDisponible", "");
			} else {
				retorno.put("importeDisponible", datosIkus.getDatosContables().getImporteDisponible().toString());
			}

			return retorno;
		}

	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterDatosContables
	 *            DatosContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<DatosContables> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	/*
	 * @RequestMapping(value = "/filter", method = RequestMethod.POST)
	 * public @ResponseBody JQGridResponseDto<DatosContables> filter(
	 * 
	 * @RequestJsonBody(param = "filter") DatosContables filterDatosContables,
	 * 
	 * @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
	 * DatosContablesController.logger.
	 * info("[POST - filter] : Obtener DatosContabless"); return
	 * this.datosContablesService.filter(filterDatosContables, jqGridRequestDto,
	 * false); }
	 */

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterDatosContables
	 *            DatosContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchDatosContables
	 *            DatosContables Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<DatosContables> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	/*
	 * @RequestMapping(value = "/search", method = RequestMethod.POST)
	 * public @ResponseBody List<TableRowDto<DatosContables>> search(
	 * 
	 * @RequestJsonBody(param = "filter") DatosContables filterDatosContables,
	 * 
	 * @RequestJsonBody(param = "search") DatosContables searchDatosContables,
	 * 
	 * @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
	 * DatosContablesController.logger.
	 * info("[POST - search] : Buscar DatosContabless"); return
	 * this.datosContablesService.search(filterDatosContables,
	 * searchDatosContables, jqGridRequestDto, false); }
	 */

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterDatosContables
	 *            DatosContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	/*
	 * @RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	 * 
	 * @ResponseStatus(value = HttpStatus.OK) public @ResponseBody List<String>
	 * removeMultiple(
	 * 
	 * @RequestJsonBody(param = "filter") DatosContables filterDatosContables,
	 * 
	 * @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
	 * DatosContablesController.logger
	 * .info("[POST - search] : [POST - removeMultiple] : Eliminar multiples DatosContabless"
	 * ); this.datosContablesService.removeMultiple(filterDatosContables,
	 * jqGridRequestDto, false);
	 * DatosContablesController.logger.info("All entities correctly deleted!");
	 * 
	 * return jqGridRequestDto.getMultiselection().getSelectedIds(); }
	 */

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterDatosContables
	 *            DatosContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<DatosContables>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	/*
	 * @RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	 * public @ResponseBody JQGridResponseDto<JerarquiaDto<DatosContables>>
	 * jerarquia(
	 * 
	 * @RequestJsonBody(param = "filter") DatosContables filterDatosContables,
	 * 
	 * @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
	 * DatosContablesController.logger.
	 * info("[POST - jerarquia] : Obtener DatosContabless jerarquia"); return
	 * this.datosContablesService.jerarquia(filterDatosContables,
	 * jqGridRequestDto, false); }
	 */

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterDatosContables
	 *            DatosContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<DatosContables>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	/*
	 * @RequestMapping(value = "/jerarquiaChildren", method =
	 * RequestMethod.POST) public @ResponseBody
	 * JQGridResponseDto<JerarquiaDto<DatosContables>> jerarquiaChildren(
	 * 
	 * @RequestJsonBody(param = "filter") DatosContables filterDatosContables,
	 * 
	 * @RequestJsonBody JQGridRequestDto jqGridRequestDto) {
	 * DatosContablesController.logger.
	 * info("[POST - jerarquia] : Obtener DatosContabless jerarquia - Hijos");
	 * return this.datosContablesService.jerarquiaChildren(filterDatosContables,
	 * jqGridRequestDto); }
	 */

	@RequestMapping(value = "/{idAplicPresu}", method = RequestMethod.POST)
	public @ResponseBody ReferenciasIntervencion get(@PathVariable Integer idAplicPresu) {
		ReferenciasIntervencion referenciaInter = new ReferenciasIntervencion();
		referenciaInter.setIdAplicacionPresupuestaria(idAplicPresu);

		referenciaInter = this.referenciasIntervencionService.findByAplicPresu(referenciaInter);
		DatosContablesController.logger.info("[GET - findBy_PK] : Obtener Aplicaciones Presupuestarias por PK");
		return referenciaInter;
	}

}