package com.ejie.ab60.control.convocatorias;

import com.ejie.ab60.service.convocatorias.TiposAyudaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.ejie.ab60.model.convocatorias.TiposAyuda;

/**
 * TiposAyudaController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposayuda")

public class TiposAyudaController {

	private static final Logger logger = LoggerFactory.getLogger(TiposAyudaController.class);

	@Autowired
	private TiposAyudaService tiposAyudaService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoAyuda
	 *            Long
	 * @return TiposAyuda Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoAyuda}", method = RequestMethod.GET)
	public @ResponseBody TiposAyuda get(@PathVariable Long idTipoAyuda) {
		TiposAyuda tiposAyuda = new TiposAyuda();
		tiposAyuda.setIdTipoAyuda(idTipoAyuda);
		tiposAyuda = this.tiposAyudaService.find(tiposAyuda);
		TiposAyudaController.logger.info("[GET - findBy_PK] : Obtener TiposAyuda por PK");
		return tiposAyuda;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposAyuda
	 *            TiposAyuda Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<TiposAyuda> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposAyuda> getAll(@ModelAttribute TiposAyuda filterTiposAyuda) {
		TiposAyudaController.logger.info("[GET - find_ALL] : Obtener TiposAyuda por filtro");
		return this.tiposAyudaService.findAll(filterTiposAyuda, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda Bean que contiene la informacion a modificar.
	 * @return TiposAyuda Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposAyuda edit(@RequestBody TiposAyuda tiposAyuda) {
		TiposAyuda tiposAyudaAux = this.tiposAyudaService.update(tiposAyuda);
		TiposAyudaController.logger.info("[PUT] : TiposAyuda actualizado correctamente");
		return tiposAyudaAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposAyuda
	 *            TiposAyuda Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return TiposAyuda Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposAyuda add(@RequestBody TiposAyuda tiposAyuda) {
		TiposAyuda tiposAyudaAux = this.tiposAyudaService.add(tiposAyuda);
		TiposAyudaController.logger.info("[POST] : TiposAyuda insertado correctamente");
		return tiposAyudaAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoAyuda
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposAyuda Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoAyuda}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposAyuda remove(@PathVariable Long idTipoAyuda) {
		TiposAyuda tiposAyuda = new TiposAyuda();
		tiposAyuda.setIdTipoAyuda(idTipoAyuda);
		this.tiposAyudaService.remove(tiposAyuda);
		TiposAyudaController.logger.info("[DELETE] : TiposAyuda borrado correctamente");
		return tiposAyuda;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposAyudaController.logger.info("[GET - View] : tiposayuda");
		return "tiposayuda";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposAyuda
	 *            TiposAyuda Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposAyuda> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposAyuda> filter(
			@RequestJsonBody(param = "filter") TiposAyuda filterTiposAyuda,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAyudaController.logger.info("[POST - filter] : Obtener TiposAyudas");
		return this.tiposAyudaService.filter(filterTiposAyuda, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposAyuda
	 *            TiposAyuda Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchTiposAyuda
	 *            TiposAyuda Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposAyuda> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposAyuda>> search(
			@RequestJsonBody(param = "filter") TiposAyuda filterTiposAyuda,
			@RequestJsonBody(param = "search") TiposAyuda searchTiposAyuda,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAyudaController.logger.info("[POST - search] : Buscar TiposAyudas");
		return this.tiposAyudaService.search(filterTiposAyuda, searchTiposAyuda, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposAyuda
	 *            TiposAyuda Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") TiposAyuda filterTiposAyuda,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAyudaController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposAyudas");
		this.tiposAyudaService.removeMultiple(filterTiposAyuda, jqGridRequestDto, false);
		TiposAyudaController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposAyuda
	 *            TiposAyuda Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposAyuda>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposAyuda>> jerarquia(
			@RequestJsonBody(param = "filter") TiposAyuda filterTiposAyuda,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAyudaController.logger.info("[POST - jerarquia] : Obtener TiposAyudas jerarquia");
		return this.tiposAyudaService.jerarquia(filterTiposAyuda, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposAyuda
	 *            TiposAyuda Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposAyuda>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposAyuda>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposAyuda filterTiposAyuda,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposAyudaController.logger.info("[POST - jerarquia] : Obtener TiposAyudas jerarquia - Hijos");
		return this.tiposAyudaService.jerarquiaChildren(filterTiposAyuda, jqGridRequestDto);
	}

}
