package com.ejie.ab60.control.convocatorias;

import com.ejie.ab60.service.convocatorias.TiposConvocatoriaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.ejie.ab60.model.convocatorias.TiposConvocatoria;

/**
 * TiposConvocatoriaController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposconvocatoria")

public class TiposConvocatoriaController {

	private static final Logger logger = LoggerFactory.getLogger(TiposConvocatoriaController.class);

	@Autowired
	private TiposConvocatoriaService tiposConvocatoriaService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoConvocatoria
	 *            Long
	 * @return TiposConvocatoria Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idTipoConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody TiposConvocatoria get(@PathVariable Long idTipoConvocatoria) {
		TiposConvocatoria tiposConvocatoria = new TiposConvocatoria();
		tiposConvocatoria.setIdTipoConvocatoria(idTipoConvocatoria);
		tiposConvocatoria = this.tiposConvocatoriaService.find(tiposConvocatoria);
		TiposConvocatoriaController.logger.info("[GET - findBy_PK] : Obtener TiposConvocatoria por PK");
		return tiposConvocatoria;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<TiposConvocatoria> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposConvocatoria> getAll(@ModelAttribute TiposConvocatoria filterTiposConvocatoria) {
		TiposConvocatoriaController.logger.info("[GET - find_ALL] : Obtener TiposConvocatoria por filtro");
		return this.tiposConvocatoriaService.findAll(filterTiposConvocatoria, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria Bean que contiene la informacion a
	 *            modificar.
	 * @return TiposConvocatoria Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposConvocatoria edit(@RequestBody TiposConvocatoria tiposConvocatoria) {
		TiposConvocatoria tiposConvocatoriaAux = this.tiposConvocatoriaService.update(tiposConvocatoria);
		TiposConvocatoriaController.logger.info("[PUT] : TiposConvocatoria actualizado correctamente");
		return tiposConvocatoriaAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposConvocatoria
	 *            TiposConvocatoria Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return TiposConvocatoria Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposConvocatoria add(@RequestBody TiposConvocatoria tiposConvocatoria) {
		TiposConvocatoria tiposConvocatoriaAux = this.tiposConvocatoriaService.add(tiposConvocatoria);
		TiposConvocatoriaController.logger.info("[POST] : TiposConvocatoria insertado correctamente");
		return tiposConvocatoriaAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoConvocatoria
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposConvocatoria Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoConvocatoria}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposConvocatoria remove(@PathVariable Long idTipoConvocatoria) {
		TiposConvocatoria tiposConvocatoria = new TiposConvocatoria();
		tiposConvocatoria.setIdTipoConvocatoria(idTipoConvocatoria);
		this.tiposConvocatoriaService.remove(tiposConvocatoria);
		TiposConvocatoriaController.logger.info("[DELETE] : TiposConvocatoria borrado correctamente");
		return tiposConvocatoria;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposConvocatoriaController.logger.info("[GET - View] : tiposconvocatoria");
		return "tiposconvocatoria";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposConvocatoria> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposConvocatoria> filter(
			@RequestJsonBody(param = "filter") TiposConvocatoria filterTiposConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposConvocatoriaController.logger.info("[POST - filter] : Obtener TiposConvocatorias");
		return this.tiposConvocatoriaService.filter(filterTiposConvocatoria, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchTiposConvocatoria
	 *            TiposConvocatoria Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposConvocatoria> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposConvocatoria>> search(
			@RequestJsonBody(param = "filter") TiposConvocatoria filterTiposConvocatoria,
			@RequestJsonBody(param = "search") TiposConvocatoria searchTiposConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposConvocatoriaController.logger.info("[POST - search] : Buscar TiposConvocatorias");
		return this.tiposConvocatoriaService.search(filterTiposConvocatoria, searchTiposConvocatoria, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TiposConvocatoria filterTiposConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposConvocatoriaController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposConvocatorias");
		this.tiposConvocatoriaService.removeMultiple(filterTiposConvocatoria, jqGridRequestDto, false);
		TiposConvocatoriaController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposConvocatoria>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposConvocatoria>> jerarquia(
			@RequestJsonBody(param = "filter") TiposConvocatoria filterTiposConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposConvocatoriaController.logger.info("[POST - jerarquia] : Obtener TiposConvocatorias jerarquia");
		return this.tiposConvocatoriaService.jerarquia(filterTiposConvocatoria, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposConvocatoria
	 *            TiposConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposConvocatoria>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposConvocatoria>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposConvocatoria filterTiposConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposConvocatoriaController.logger.info("[POST - jerarquia] : Obtener TiposConvocatorias jerarquia - Hijos");
		return this.tiposConvocatoriaService.jerarquiaChildren(filterTiposConvocatoria, jqGridRequestDto);
	}

}
