package com.ejie.ab60.control.criteriosPuntuacion;

import com.ejie.ab60.service.criteriosPuntuacion.CriteriosPuntuacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;

/**
 * CriteriosPuntuacionController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/criteriospuntuacion")

public class CriteriosPuntuacionController {

	private static final Logger logger = LoggerFactory.getLogger(CriteriosPuntuacionController.class);

	@Autowired
	private CriteriosPuntuacionService criteriosPuntuacionService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idCriterio
	 *            Integer
	 * @return CriteriosPuntuacion Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idCriterio}", method = RequestMethod.GET)
	public @ResponseBody CriteriosPuntuacion get(@PathVariable Integer idCriterio) {
		CriteriosPuntuacion criteriosPuntuacion = new CriteriosPuntuacion();
		criteriosPuntuacion.setIdCriterio(idCriterio);
		criteriosPuntuacion = this.criteriosPuntuacionService.find(criteriosPuntuacion);
		CriteriosPuntuacionController.logger.info("[GET - findBy_PK] : Obtener CriteriosPuntuacion por PK");
		return criteriosPuntuacion;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<CriteriosPuntuacion> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<CriteriosPuntuacion> getAll(
			@ModelAttribute CriteriosPuntuacion filterCriteriosPuntuacion) {
		CriteriosPuntuacionController.logger.info("[GET - find_ALL] : Obtener CriteriosPuntuacion por filtro");
		return this.criteriosPuntuacionService.findAll(filterCriteriosPuntuacion, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene la informacion a
	 *            modificar.
	 * @return CriteriosPuntuacion Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody CriteriosPuntuacion edit(@RequestBody CriteriosPuntuacion criteriosPuntuacion) {
		CriteriosPuntuacion criteriosPuntuacionAux = this.criteriosPuntuacionService.update(criteriosPuntuacion);
		CriteriosPuntuacionController.logger.info("[PUT] : CriteriosPuntuacion actualizado correctamente");
		return criteriosPuntuacionAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param criteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return CriteriosPuntuacion Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody CriteriosPuntuacion add(@RequestBody CriteriosPuntuacion criteriosPuntuacion) {
		CriteriosPuntuacion criteriosPuntuacionAux = this.criteriosPuntuacionService.add(criteriosPuntuacion);
		CriteriosPuntuacionController.logger.info("[POST] : CriteriosPuntuacion insertado correctamente");
		return criteriosPuntuacionAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idCriterio
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return CriteriosPuntuacion Bean eliminado.
	 */
	@RequestMapping(value = "/{idCriterio}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody CriteriosPuntuacion remove(@PathVariable Integer idCriterio) {
		CriteriosPuntuacion criteriosPuntuacion = new CriteriosPuntuacion();
		criteriosPuntuacion.setIdCriterio(idCriterio);
		this.criteriosPuntuacionService.remove(criteriosPuntuacion);
		CriteriosPuntuacionController.logger.info("[DELETE] : CriteriosPuntuacion borrado correctamente");
		return criteriosPuntuacion;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		CriteriosPuntuacionController.logger.info("[GET - View] : criteriospuntuacion");
		return "criteriospuntuacion";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<CriteriosPuntuacion> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<CriteriosPuntuacion> filter(
			@RequestJsonBody(param = "filter") CriteriosPuntuacion filterCriteriosPuntuacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CriteriosPuntuacionController.logger.info("[POST - filter] : Obtener CriteriosPuntuacions");
		return this.criteriosPuntuacionService.filter(filterCriteriosPuntuacion, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchCriteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<CriteriosPuntuacion> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<CriteriosPuntuacion>> search(
			@RequestJsonBody(param = "filter") CriteriosPuntuacion filterCriteriosPuntuacion,
			@RequestJsonBody(param = "search") CriteriosPuntuacion searchCriteriosPuntuacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CriteriosPuntuacionController.logger.info("[POST - search] : Buscar CriteriosPuntuacions");
		return this.criteriosPuntuacionService.search(filterCriteriosPuntuacion, searchCriteriosPuntuacion,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") CriteriosPuntuacion filterCriteriosPuntuacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CriteriosPuntuacionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples CriteriosPuntuacions");
		this.criteriosPuntuacionService.removeMultiple(filterCriteriosPuntuacion, jqGridRequestDto, false);
		CriteriosPuntuacionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>> jerarquia(
			@RequestJsonBody(param = "filter") CriteriosPuntuacion filterCriteriosPuntuacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CriteriosPuntuacionController.logger.info("[POST - jerarquia] : Obtener CriteriosPuntuacions jerarquia");
		return this.criteriosPuntuacionService.jerarquia(filterCriteriosPuntuacion, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterCriteriosPuntuacion
	 *            CriteriosPuntuacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<CriteriosPuntuacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") CriteriosPuntuacion filterCriteriosPuntuacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CriteriosPuntuacionController.logger
				.info("[POST - jerarquia] : Obtener CriteriosPuntuacions jerarquia - Hijos");
		return this.criteriosPuntuacionService.jerarquiaChildren(filterCriteriosPuntuacion, jqGridRequestDto);
	}

}
