package com.ejie.ab60.control.criteriosPuntuacion;

import com.ejie.ab60.service.criteriosPuntuacion.RelExpCriPunService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

import java.math.BigDecimal;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.criteriosPuntuacion.CriteriosPuntuacion;
import com.ejie.ab60.model.criteriosPuntuacion.RelExpCriPun;
import com.ejie.ab60.model.usuario.Usuario;

/**
 * RelExpCriPunController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/relexpcripun")

public class RelExpCriPunController {

	private static final Logger logger = LoggerFactory.getLogger(RelExpCriPunController.class);

	@Autowired
	private RelExpCriPunService relExpCriPunService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelExpCriPun
	 *            Integer
	 * @return RelExpCriPun Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelExpCriPun}", method = RequestMethod.GET)
	public @ResponseBody RelExpCriPun get(@PathVariable Integer idRelExpCriPun) {
		RelExpCriPun relExpCriPun = new RelExpCriPun();
		relExpCriPun.setIdRelExpCriPun(idRelExpCriPun);
		relExpCriPun = this.relExpCriPunService.find(relExpCriPun);
		RelExpCriPunController.logger.info("[GET - findBy_PK] : Obtener RelExpCriPun por PK");
		return relExpCriPun;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelExpCriPun
	 *            RelExpCriPun Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelExpCriPun> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelExpCriPun> getAll(@ModelAttribute RelExpCriPun filterRelExpCriPun) {
		RelExpCriPunController.logger.info("[GET - find_ALL] : Obtener RelExpCriPun por filtro");
		return this.relExpCriPunService.findAll(filterRelExpCriPun, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun Bean que contiene la informacion a modificar.
	 * @param usuario
	 *            Usuario Usuario de sesi�n
	 * @return RelExpCriPun Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "tabla/{idExpediente}/{idConvocatoria}", method = RequestMethod.PUT)
	public @ResponseBody RelExpCriPun edit(@RequestBody RelExpCriPun relExpCriPun,
			@ModelAttribute(value = "usuario") Usuario usuario) throws Exception {

		// Busco la Puntuacion Teorica porque al editar la Puntuacion Admitida
		// no devuelve la Teorica
		RelExpCriPun puntTeorica = this.relExpCriPunService.findPuntTeorica(relExpCriPun);
		RelExpCriPunController.logger.info("[PUT] : Obtengo la puntuacion teorica");
		relExpCriPun.setPuntuacionTeorica(puntTeorica.getPuntuacionTeorica());

		// Método para tratar la puntuación admitida del inline
		String puntuacionAdmitidaSinFormato = eliminarFormatoPuntuacionAdmitida(relExpCriPun);
		relExpCriPun.setPuntuacionAdmitida(new BigDecimal(puntuacionAdmitidaSinFormato));

		RelExpCriPun relExpCriPunAux = this.relExpCriPunService.update(relExpCriPun, usuario);
		RelExpCriPunController.logger.info("[PUT] : RelExpCriPun actualizado correctamente");
		return relExpCriPunAux;
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param RelExpCriPun
	 *            RelExpCriPun Bean que contiene la informacion a modificar.
	 * @param idExpediente
	 *            Integer
	 * @param usuario
	 *            Usuario Usuario de sesi�n
	 * @return RelExpCriPun Bean resultante de la modificacion.
	 * @throws Exception
	 */
	@RequestMapping(value = "/updatePuntuacionAdmitida/{idExpediente}", method = RequestMethod.POST)
	public @ResponseBody RelExpCriPun editPuntuacionAdmitida(@PathVariable Integer idExpediente,
			@RequestBody RelExpCriPun relExpCriPun, @ModelAttribute(value = "usuario") Usuario usuario)
			throws Exception {

		if (!"".equals(relExpCriPun.getPuntuacionTeoricaStrInline())) {
			// Método para tratar la puntuación teórica del inline
			String puntuacionTeoricaSinFormato = eliminarFormatoPuntuacionTeorica(relExpCriPun);
			relExpCriPun.setPuntuacionTeorica(new BigDecimal(puntuacionTeoricaSinFormato));
		}

		RelExpCriPun relExpCriPunAux = this.relExpCriPunService.updatePuntuacionAdmitida(relExpCriPun, idExpediente,
				usuario);
		RelExpCriPunController.logger.info("[POST] : Puntuacion admitida actualizada correctamente");

		return relExpCriPunAux;

	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relExpCriPun
	 *            RelExpCriPun Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelExpCriPun Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelExpCriPun add(@RequestBody RelExpCriPun relExpCriPun) {
		RelExpCriPun relExpCriPunAux = this.relExpCriPunService.add(relExpCriPun);
		RelExpCriPunController.logger.info("[POST] : RelExpCriPun insertado correctamente");
		return relExpCriPunAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelExpCriPun
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelExpCriPun Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelExpCriPun}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelExpCriPun remove(@PathVariable Integer idRelExpCriPun) {
		RelExpCriPun relExpCriPun = new RelExpCriPun();
		relExpCriPun.setIdRelExpCriPun(idRelExpCriPun);
		this.relExpCriPunService.remove(relExpCriPun);
		RelExpCriPunController.logger.info("[DELETE] : RelExpCriPun borrado correctamente");
		return relExpCriPun;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelExpCriPunController.logger.info("[GET - View] : relexpcripun");
		return "relexpcripun";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelExpCriPun
	 *            RelExpCriPun Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelExpCriPun> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpCriPun> filter(
			@RequestJsonBody(param = "filter") RelExpCriPun filterRelExpCriPun,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpCriPunController.logger.info("[POST - filter] : Obtener RelExpCriPuns");
		return this.relExpCriPunService.filter(filterRelExpCriPun, jqGridRequestDto, false);
	}

	/**
	 * Devuelve los criterios de puntuacion a un determinado expediente.
	 *
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param idExpediente
	 *            Integer
	 * @return JQGridResponseDto
	 * 
	 */
	@RequestMapping(value = "tabla/{idExpediente}/{idConvocatoria}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpCriPun> findCriteriosPorExpediente(
			@RequestJsonBody() JQGridRequestDto jqGridRequestDto, @PathVariable Integer idExpediente,
			@PathVariable Integer idConvocatoria) {
		RelExpCriPun relExpCriPun = new RelExpCriPun();
		CriteriosPuntuacion criPun = new CriteriosPuntuacion();
		Convocatorias convocatorias = new Convocatorias();
		relExpCriPun.setIdExpediente(idExpediente);
		convocatorias.setIdConvocatoria(idConvocatoria);
		criPun.setConvocatorias(convocatorias);
		relExpCriPun.setCriteriosPuntuacion(criPun);

		RelExpCriPunController.logger.info("[POST - findBy_PK] : Obtener CriteriosPuntuacion por Expediente");

		return this.relExpCriPunService.filter(relExpCriPun, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelExpCriPun
	 *            RelExpCriPun Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelExpCriPun
	 *            RelExpCriPun Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelExpCriPun> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelExpCriPun>> search(
			@RequestJsonBody(param = "filter") RelExpCriPun filterRelExpCriPun,
			@RequestJsonBody(param = "search") RelExpCriPun searchRelExpCriPun,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpCriPunController.logger.info("[POST - search] : Buscar RelExpCriPuns");
		return this.relExpCriPunService.search(filterRelExpCriPun, searchRelExpCriPun, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelExpCriPun
	 *            RelExpCriPun Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelExpCriPun filterRelExpCriPun,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpCriPunController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelExpCriPuns");
		this.relExpCriPunService.removeMultiple(filterRelExpCriPun, jqGridRequestDto, false);
		RelExpCriPunController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelExpCriPun
	 *            RelExpCriPun Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpCriPun>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpCriPun>> jerarquia(
			@RequestJsonBody(param = "filter") RelExpCriPun filterRelExpCriPun,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpCriPunController.logger.info("[POST - jerarquia] : Obtener RelExpCriPuns jerarquia");
		return this.relExpCriPunService.jerarquia(filterRelExpCriPun, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelExpCriPun
	 *            RelExpCriPun Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpCriPun>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpCriPun>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelExpCriPun filterRelExpCriPun,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpCriPunController.logger.info("[POST - jerarquia] : Obtener RelExpCriPuns jerarquia - Hijos");
		return this.relExpCriPunService.jerarquiaChildren(filterRelExpCriPun, jqGridRequestDto);
	}

	private String eliminarFormatoPuntuacionAdmitida(RelExpCriPun relExpCriPun) {
		String puntuacionAdmitida = relExpCriPun.getPuntuacionAdmitidaStrInline();
		if (-1 != puntuacionAdmitida.indexOf(",")) {
			puntuacionAdmitida = puntuacionAdmitida.replaceAll("\\.", "");
			puntuacionAdmitida = puntuacionAdmitida.replaceAll(",", "\\.");
		}

		return puntuacionAdmitida;
	}

	private String eliminarFormatoPuntuacionTeorica(RelExpCriPun relExpCriPun) {
		String puntuacionTeorica = relExpCriPun.getPuntuacionTeoricaStrInline();
		if (-1 != puntuacionTeorica.indexOf(",")) {
			puntuacionTeorica = puntuacionTeorica.replaceAll("\\.", "");
			puntuacionTeorica = puntuacionTeorica.replaceAll(",", "\\.");
		}

		return puntuacionTeorica;
	}

}
