package com.ejie.ab60.control.criteriosPuntuacion;

import com.ejie.ab60.service.criteriosPuntuacion.TiposCriterioService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.ejie.ab60.model.criteriosPuntuacion.TiposCriterio;

/**
 * TiposCriterioController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposcriterio")

public class TiposCriterioController {

	private static final Logger logger = LoggerFactory.getLogger(TiposCriterioController.class);

	@Autowired
	private TiposCriterioService tiposCriterioService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoCriterio
	 *            Long
	 * @return TiposCriterio Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoCriterio}", method = RequestMethod.GET)
	public @ResponseBody TiposCriterio get(@PathVariable Long idTipoCriterio) {
		TiposCriterio tiposCriterio = new TiposCriterio();
		tiposCriterio.setIdTipoCriterio(idTipoCriterio);
		tiposCriterio = this.tiposCriterioService.find(tiposCriterio);
		TiposCriterioController.logger.info("[GET - findBy_PK] : Obtener TiposCriterio por PK");
		return tiposCriterio;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposCriterio
	 *            TiposCriterio Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<TiposCriterio> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposCriterio> getAll(@ModelAttribute TiposCriterio filterTiposCriterio) {
		TiposCriterioController.logger.info("[GET - find_ALL] : Obtener TiposCriterio por filtro");
		return this.tiposCriterioService.findAll(filterTiposCriterio, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio Bean que contiene la informacion a modificar.
	 * @return TiposCriterio Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposCriterio edit(@RequestBody TiposCriterio tiposCriterio) {
		TiposCriterio tiposCriterioAux = this.tiposCriterioService.update(tiposCriterio);
		TiposCriterioController.logger.info("[PUT] : TiposCriterio actualizado correctamente");
		return tiposCriterioAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposCriterio
	 *            TiposCriterio Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return TiposCriterio Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposCriterio add(@RequestBody TiposCriterio tiposCriterio) {
		TiposCriterio tiposCriterioAux = this.tiposCriterioService.add(tiposCriterio);
		TiposCriterioController.logger.info("[POST] : TiposCriterio insertado correctamente");
		return tiposCriterioAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoCriterio
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposCriterio Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoCriterio}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposCriterio remove(@PathVariable Long idTipoCriterio) {
		TiposCriterio tiposCriterio = new TiposCriterio();
		tiposCriterio.setIdTipoCriterio(idTipoCriterio);
		this.tiposCriterioService.remove(tiposCriterio);
		TiposCriterioController.logger.info("[DELETE] : TiposCriterio borrado correctamente");
		return tiposCriterio;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposCriterioController.logger.info("[GET - View] : tiposcriterio");
		return "tiposcriterio";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposCriterio
	 *            TiposCriterio Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposCriterio> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposCriterio> filter(
			@RequestJsonBody(param = "filter") TiposCriterio filterTiposCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCriterioController.logger.info("[POST - filter] : Obtener TiposCriterios");
		return this.tiposCriterioService.filter(filterTiposCriterio, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposCriterio
	 *            TiposCriterio Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchTiposCriterio
	 *            TiposCriterio Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposCriterio> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposCriterio>> search(
			@RequestJsonBody(param = "filter") TiposCriterio filterTiposCriterio,
			@RequestJsonBody(param = "search") TiposCriterio searchTiposCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCriterioController.logger.info("[POST - search] : Buscar TiposCriterios");
		return this.tiposCriterioService.search(filterTiposCriterio, searchTiposCriterio, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposCriterio
	 *            TiposCriterio Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TiposCriterio filterTiposCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCriterioController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposCriterios");
		this.tiposCriterioService.removeMultiple(filterTiposCriterio, jqGridRequestDto, false);
		TiposCriterioController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposCriterio
	 *            TiposCriterio Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposCriterio>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposCriterio>> jerarquia(
			@RequestJsonBody(param = "filter") TiposCriterio filterTiposCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCriterioController.logger.info("[POST - jerarquia] : Obtener TiposCriterios jerarquia");
		return this.tiposCriterioService.jerarquia(filterTiposCriterio, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposCriterio
	 *            TiposCriterio Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposCriterio>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposCriterio>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposCriterio filterTiposCriterio,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposCriterioController.logger.info("[POST - jerarquia] : Obtener TiposCriterios jerarquia - Hijos");
		return this.tiposCriterioService.jerarquiaChildren(filterTiposCriterio, jqGridRequestDto);
	}

}
