package com.ejie.ab60.control.estudioTecnico;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.OtrosIngresos;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotDen;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotMin;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubSubact;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.OtrosIngresosService;
import com.ejie.ab60.service.actuacionesSubvencionables.ActSubvencionableService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubMotDenService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubMotMinService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubSubactService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.estudioTecnico.ConceptosService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * ConceptosController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/conceptos")

public class ConceptosController {

	private static final Logger logger = LoggerFactory.getLogger(ConceptosController.class);

	@Autowired
	private ConceptosService conceptosService;

	@Autowired
	private RelExpActSubService relEXpActSubService;

	@Autowired
	private ActSubvencionableService actSubvencionableService;

	@Autowired
	private RelActSubSubactService relActSubSubactService;

	@Autowired
	private RelActSubMotMinService relActSubMotMinService;

	@Autowired
	private RelActSubMotDenService relActSubMotDenService;

	@Autowired
	private OtrosIngresosService otrosIngresosService;

	@Autowired
	private ExpedientesService expedientesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idConcepto
	 *            Integer
	 * @return Conceptos Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idConcepto}", method = RequestMethod.GET)
	public @ResponseBody Conceptos get(@PathVariable Integer idConcepto) {
		Conceptos conceptos = new Conceptos();
		conceptos.setIdConcepto(idConcepto);
		conceptos = this.conceptosService.find(conceptos);
		ConceptosController.logger.info("[GET - findBy_PK] : Obtener Conceptos por PK");
		return conceptos;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado, PARA LA FILA DE LA TABLA
	 * 
	 * @param idFactura
	 *            Integer
	 * @return Facturas Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}/{idConcepto}", method = RequestMethod.GET)
	public @ResponseBody Conceptos getEdit(@PathVariable("idConcepto") Integer idConcepto) {
		Conceptos conceptos = new Conceptos();
		conceptos.setIdConcepto(idConcepto);

		conceptos = this.conceptosService.find(conceptos);

		ConceptosController.logger.info("[GET - findBy_PK] : Obtener Facturas por PK");
		return conceptos;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idExpediente
	 *            Integer
	 * @param idRelacion
	 *            Integer
	 * @return Conceptos Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/sumatorio/{idExpediente}/{idRelacion}/{idActSub}", method = RequestMethod.GET)
	public @ResponseBody Conceptos getSumatorioConceptos(@PathVariable Integer idExpediente,
			@PathVariable Integer idRelacion, @PathVariable Integer idActSub,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return conceptosService.getSumatorioConceptos(idExpediente, idRelacion, idActSub, usuario);

	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelacion
	 *            Integer
	 * @return Conceptos Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/sumatorio/{idRelacion}/{idExpediente}", method = RequestMethod.GET)
	public @ResponseBody Conceptos getSumatorioConceptos(@PathVariable Integer idRelacion,
			@PathVariable Integer idExpediente, @ModelAttribute(value = "usuario") Usuario usuario) {

		return conceptosService.getSumatorioConceptos(idExpediente, idRelacion, usuario);

	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterConceptos
	 *            Conceptos Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Conceptos> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Conceptos> getAll(@ModelAttribute Conceptos filterConceptos) {
		ConceptosController.logger.info("[GET - find_ALL] : Obtener Conceptos por filtro");
		return this.conceptosService.findAll(filterConceptos, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param Conceptos
	 *            Conceptos Bean que contiene la informacion a modificar.
	 * @return Conceptos Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}", method = RequestMethod.PUT)
	public @ResponseBody Conceptos edit(@PathVariable("idRelacion") Integer idRelacion,
			@PathVariable("idActSubPadre") Integer idActSubPadre, @PathVariable("idExpediente") Integer idExpediente,
			@PathVariable("idActSub") Integer idActSub, @RequestBody Conceptos conceptos,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return conceptosService.edit(idRelacion, idActSubPadre, idExpediente, idActSub, conceptos, usuario);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param facturas
	 *            Conceptos Bean que contiene la informacion a modificar.
	 * @return Conceptos Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/tablaModificar/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}", method = RequestMethod.GET)
	public void editImporte(@PathVariable("idRelacion") Integer idRelacion,
			@PathVariable("idExpediente") Integer idExpediente, @PathVariable("idActSub") Integer idActSub,
			@PathVariable("idActSubPadre") Integer idActSubPadre, @ModelAttribute(value = "usuario") Usuario usuario) {
		conceptosService.editImporte(idRelacion, idExpediente, idActSub, idActSubPadre, usuario);
	}

	/**
	 * Operacion que me trae los totales de un expediente
	 * 
	 * 
	 * @param idExpedientes
	 * @return
	 */

	@RequestMapping(value = "/totales/{idRelacion}/{idExpediente}/{idActSub}", method = RequestMethod.GET)
	public @ResponseBody RelExpActSub totales(@PathVariable Integer idRelacion, @PathVariable Integer idExpediente,
			@PathVariable Integer idActSub) {
		ConceptosController.logger.info("[GET - filter] : Obtener RelExpActSubs");
		if (0 == idRelacion) {
			RelExpActSub relExpActSubId = relEXpActSubService.findUltimoId(idExpediente, idActSub);
			idRelacion = relExpActSubId.getIdRelExpActSub();
			RelExpActSub ultimaRelacionExistente = relEXpActSubService.findLastId(idExpediente, idActSub);
			if (!ultimaRelacionExistente.getIdRelExpActSub().equals(idRelacion)) {
				idRelacion = ultimaRelacionExistente.getIdRelExpActSub();
			}
		}

		return this.relEXpActSubService.findTotales(idRelacion);
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param conceptos
	 *            Conceptos Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Conceptos Bean resultante del proceso de creacion.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}", method = RequestMethod.POST)
	public @ResponseBody Conceptos add(@PathVariable Integer idRelacion, @PathVariable Integer idExpediente,
			@PathVariable Integer idActSubPadre, @PathVariable Integer idActSub, @RequestBody Conceptos conceptos,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return conceptosService.add(idRelacion, idExpediente, idActSubPadre, idActSub, conceptos, usuario);
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idConcepto
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Conceptos Bean eliminado.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}/{idConcepto}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Conceptos remove(@PathVariable("idRelacion") Integer idRelacion,
			@PathVariable("idExpediente") Integer idExpediente, @PathVariable("idConcepto") Integer idConcepto,
			@PathVariable("idActSub") Integer idActSub, @PathVariable("idActSubPadre") Integer idActSubPadre,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		Expedientes expediente = new Expedientes();
		expediente.setIdExpediente(idExpediente);
		Expedientes expedienteAux = this.expedientesService.find(expediente);

		if (expedienteAux.getProcedimientos().getCodProcedureId().equals(Constantes.COD_PROCEDURE_COVIDT)
				|| expedienteAux.getProcedimientos().getCodProcedureId().equals(Constantes.COD_PROCEDURE_COVIDM)) {
			return conceptosService.removeCovidT(idRelacion, idExpediente, idConcepto, idActSub, idActSubPadre,
					usuario);
		} else {
			return conceptosService.remove(idRelacion, idExpediente, idConcepto, idActSub, idActSubPadre, usuario);
		}

	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ConceptosController.logger.info("[GET - View] : conceptos");
		return "conceptos";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterConceptos
	 *            Conceptos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Conceptos> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/tabla/{idRelacion}/{idExpediente}/{idActSub}/{idActSubPadre}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Conceptos> filter(
			@RequestJsonBody(param = "filter") Conceptos filterConceptos, @PathVariable Integer idRelacion,
			@PathVariable Integer idExpediente, @PathVariable Integer idActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub.setIdRelExpActSub(idRelacion);
		filterConceptos.setRelExpActSub(relExpActSub);
		filterConceptos.setIdExpediente(idExpediente);
		filterConceptos.setIdActSub(idActSub);

		// filterConceptos.setIdRelExpActSub(idrelacion);
		ConceptosController.logger.info("[POST - filter] : Obtener Conceptos con ides");
		return this.conceptosService.filter(filterConceptos, jqGridRequestDto, false);
	}

	/**
	 * Metodo que saca la modal de conceptos relacionadas con Actu Sub
	 * 
	 * @param idActSub,
	 * @param idExpediente
	 * @return String
	 */
	@RequestMapping(value = "/{idExpedientes}/{idActSub}/{expedienteValidado}/{idActSubPadre}", method = RequestMethod.GET)
	public String cargarModal(@PathVariable("idExpedientes") Integer idExpedientes,
			@PathVariable("expedienteValidado") Integer expedienteValidado, @PathVariable("idActSub") Integer idActSub,
			@PathVariable("idActSubPadre") Integer idActSubPadre, Model model) {
		String idsMotivosMinoracionSeleccionados = "";
		String idsMotivosDenegacionselecionados = "";
		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
		Integer origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_ACT_SUBV;

		Integer idAgrupacionActSub = actSubvencionableService.obtenerIdentificadorAgrupacion(idActSub);

		String idioma = LocaleContextHolder.getLocale().getLanguage();
		RelExpActSub relExpActSub = new RelExpActSub();
		if (idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Pertenencia_Redes
				|| idAgrupacionActSub == Constantes.ID_AGRUPACION_PTT_Gastos_Creacion) {
			relExpActSub = relEXpActSubService.findRelPorExpedientePorCriterioPTT(idExpedientes, idActSub);
		} else if (idAgrupacionActSub == Constantes.ID_AGRUPACION_CTP_Apoyo_Creacion
				|| idAgrupacionActSub == Constantes.ID_AGRUPACION_CTP_Actuaciones_Destinadas
				|| idAgrupacionActSub == Constantes.ID_AGRUPACION_CTP_Apoyo_Eventos) {
			List<ActSubvencionable> listaActSub = actSubvencionableService
					.findActSubporConvocatoriaPorActSubPadre(idActSub, idExpedientes);
			model.addAttribute("listaActSub", listaActSub);
			relExpActSub = relEXpActSubService.findRelPorExpedientePorCriterio(idExpedientes, idActSub);
		} else {
			relExpActSub = relEXpActSubService.findRelPorExpedientePorCriterio(idExpedientes, idActSub);
		}
		model.addAttribute("lenguaje", idioma);
		model.addAttribute("idActSub", idActSub);
		model.addAttribute("idAgrupacionActSub", idAgrupacionActSub);
		model.addAttribute("expedienteValidado", expedienteValidado);
		model.addAttribute("expediente", idExpedientes);
		if (null == relExpActSub) {
			relExpActSub = new RelExpActSub();
			relExpActSub.setIdRelExpActSub(0);
			relExpActSub.setIdActSub(idActSub);
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSubPadre(idActSubPadre);
			relExpActSub.setActSubvencionable(actSubvencionable);

		}
		relActSubMotMin.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		relActSubMotDen.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		List<RelActSubMotMin> relActSubMotMinList = relActSubMotMinService
				.findIdsMotivosMinoraciones(relExpActSub.getIdRelExpActSub(), origenMotivosMinoracion);
		List<RelActSubMotDen> relActSubMotDenList = relActSubMotDenService
				.findIdsMotivosDenegaciones(relExpActSub.getIdRelExpActSub());

		if (relActSubMotMinList.size() > 0) {
			for (int indice = 0; indice < relActSubMotMinList.size(); indice++) {
				idsMotivosMinoracionSeleccionados += Long
						.toString(relActSubMotMinList.get(indice).getIdMotivoMinoracion());
				if ((indice + 1) != relActSubMotMinList.size()) {
					idsMotivosMinoracionSeleccionados += ",";
				}
			}
			model.addAttribute("idsMotivosMinoracionSeleccionados", idsMotivosMinoracionSeleccionados);
			model.addAttribute("relActSubMotMinLis", relActSubMotMinList);
		}
		if (relActSubMotDenList.size() > 0) {
			for (int i = 0; i < relActSubMotDenList.size(); i++) {
				idsMotivosDenegacionselecionados += Long.toString(relActSubMotDenList.get(i).getIdMotivoDenegacion());
				if ((i + 1) != relActSubMotDenList.size()) {
					idsMotivosDenegacionselecionados += ",";
				}
			}
			model.addAttribute("idsMotivosDenegacionselecionados", idsMotivosDenegacionselecionados);
			model.addAttribute("relActSubMotDenList", relActSubMotDenList);
		}

		OtrosIngresos otrosIngresos = new OtrosIngresos();
		otrosIngresos.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		otrosIngresos.setFase(Constantes.FASE_SOLICITUD);
		otrosIngresos = this.otrosIngresosService.findByIdRelExpActSub(otrosIngresos);
		if (otrosIngresos != null) {
			model.addAttribute("otrosIngresos", otrosIngresos.getImporte());
		}

		model.addAttribute("datosRelExpActSub", relExpActSub);
		return "conceptos";

	}

	/**
	 * Metodo que saca la modal de conceptos relacionadas con Actu Sub
	 * 
	 * @param idActSub,
	 * @param idExpediente
	 * @return String
	 */
	@RequestMapping(value = "/{idExpedientes}/{idActSub}/{expedienteValidado}/{idActSubPadre}/{entidadBancaria}", method = RequestMethod.GET)
	public String cargarModalEntidadBancaria(@PathVariable("idExpedientes") Integer idExpedientes,
			@PathVariable("expedienteValidado") Integer expedienteValidado, @PathVariable("idActSub") Integer idActSub,
			@PathVariable("idActSubPadre") Integer idActSubPadre,
			@PathVariable("entidadBancaria") String entidadBancaria, Model model) {
		String idsMotivosMinoracionSeleccionados = "";
		String idsMotivosDenegacionselecionados = "";
		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
		Integer origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_ACT_SUBV;

		Integer idAgrupacionActSub = actSubvencionableService.obtenerIdentificadorAgrupacion(idActSub);

		String idioma = LocaleContextHolder.getLocale().getLanguage();
		RelExpActSub relExpActSub = new RelExpActSub();

		if ("0".equals(entidadBancaria)) {
			relExpActSub = relEXpActSubService.findRelPorExpedientePorCriterio(idExpedientes, idActSub);
		} else {
			relExpActSub = relEXpActSubService.findRelPorExpedientePorCriterioEntidadBancaria(idExpedientes, idActSub,
					entidadBancaria);
		}

		model.addAttribute("lenguaje", idioma);
		model.addAttribute("idActSub", idActSub);
		model.addAttribute("idAgrupacionActSub", idAgrupacionActSub);
		model.addAttribute("expedienteValidado", expedienteValidado);
		model.addAttribute("expediente", idExpedientes);
		if (null == relExpActSub) {
			relExpActSub = new RelExpActSub();
			relExpActSub.setIdRelExpActSub(0);
			relExpActSub.setIdActSub(idActSub);
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSubPadre(idActSubPadre);
			relExpActSub.setActSubvencionable(actSubvencionable);

		}
		model.addAttribute("entidadBancaria", relExpActSub.getActSubvencionable().getEntidadBancaria());
		relActSubMotMin.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		relActSubMotDen.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		List<RelActSubMotMin> relActSubMotMinList = relActSubMotMinService
				.findIdsMotivosMinoraciones(relExpActSub.getIdRelExpActSub(), origenMotivosMinoracion);
		List<RelActSubMotDen> relActSubMotDenList = relActSubMotDenService
				.findIdsMotivosDenegaciones(relExpActSub.getIdRelExpActSub());

		if (relActSubMotMinList.size() > 0) {
			for (int indice = 0; indice < relActSubMotMinList.size(); indice++) {
				idsMotivosMinoracionSeleccionados += Long
						.toString(relActSubMotMinList.get(indice).getIdMotivoMinoracion());
				if ((indice + 1) != relActSubMotMinList.size()) {
					idsMotivosMinoracionSeleccionados += ",";
				}
			}
			model.addAttribute("idsMotivosMinoracionSeleccionados", idsMotivosMinoracionSeleccionados);
			model.addAttribute("relActSubMotMinLis", relActSubMotMinList);
		}
		if (relActSubMotDenList.size() > 0) {
			for (int i = 0; i < relActSubMotDenList.size(); i++) {
				idsMotivosDenegacionselecionados += Long.toString(relActSubMotDenList.get(i).getIdMotivoDenegacion());
				if ((i + 1) != relActSubMotDenList.size()) {
					idsMotivosDenegacionselecionados += ",";
				}
			}
			model.addAttribute("idsMotivosDenegacionselecionados", idsMotivosDenegacionselecionados);
			model.addAttribute("relActSubMotDenList", relActSubMotDenList);
		}

		OtrosIngresos otrosIngresos = new OtrosIngresos();
		otrosIngresos.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		otrosIngresos.setFase(Constantes.FASE_SOLICITUD);
		otrosIngresos = this.otrosIngresosService.findByIdRelExpActSub(otrosIngresos);
		if (otrosIngresos != null) {
			model.addAttribute("otrosIngresos", otrosIngresos.getImporte());
		}

		model.addAttribute("datosRelExpActSub", relExpActSub);
		return "conceptos";

	}

	/**
	 * Metodo que saca la modal de conceptos relacionadas con Actu Sub de CTP
	 * 
	 * @param idConvocatoria
	 *            Integer
	 * @param idActSub
	 *            Integer
	 * @param idExpediente
	 *            Integer
	 * @return String
	 */
	@RequestMapping(value = "/modalCTP/{idExpedientes}/{idConvocatoria}/{idActSub}/{expedienteValidado}", method = RequestMethod.GET)
	public String cargarModalCPT(@PathVariable("idExpedientes") Integer idExpedientes,
			@PathVariable("expedienteValidado") Integer expedienteValidado, @PathVariable("idActSub") Integer idActSub,
			@PathVariable("idConvocatoria") Integer idConvocatoria, Model model) {
		String idsMotivosMinoracionSeleccionados = "";
		String idsMotivosDenegacionselecionados = "";
		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
		Integer origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_ACT_SUBV;

		Integer idAgrupacionActSub = actSubvencionableService.obtenerIdentificadorAgrupacion(idActSub);

		String idioma = LocaleContextHolder.getLocale().getLanguage();
		RelExpActSub relExpActSub = new RelExpActSub();
		relExpActSub = relEXpActSubService.findRelPorExpedientePorCriterio(idExpedientes, idActSub);
		List<ActSubvencionable> listaActSub = actSubvencionableService
				.findActSubporConvocatoriaPorActSubPadre(idConvocatoria, idActSub);

		List<RelActSubSubact> relActSubSbactList = relActSubSubactService
				.findIdActSubSubact(relExpActSub.getIdRelExpActSub());
		if (null != relActSubSbactList) {
			model.addAttribute("listaIdsActSub", relActSubSbactList);
		}
		model.addAttribute("lenguaje", idioma);
		model.addAttribute("expedienteValidado", expedienteValidado);
		model.addAttribute("listaActSub", listaActSub);

		model.addAttribute("idActSub", idActSub);
		model.addAttribute("idAgrupacionActSub", idAgrupacionActSub);
		model.addAttribute("expediente", idExpedientes);

		relActSubMotMin.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		relActSubMotDen.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		List<RelActSubMotMin> relActSubMotMinList = relActSubMotMinService
				.findIdsMotivosMinoraciones(relExpActSub.getIdRelExpActSub(), origenMotivosMinoracion);
		List<RelActSubMotDen> relActSubMotDenList = relActSubMotDenService
				.findIdsMotivosDenegaciones(relExpActSub.getIdRelExpActSub());

		if (relActSubMotMinList.size() > 0) {
			for (int indice = 0; indice < relActSubMotMinList.size(); indice++) {
				idsMotivosMinoracionSeleccionados += Long
						.toString(relActSubMotMinList.get(indice).getIdMotivoMinoracion());
				if ((indice + 1) != relActSubMotMinList.size()) {
					idsMotivosMinoracionSeleccionados += ",";
				}
			}
			model.addAttribute("idsMotivosMinoracionSeleccionados", idsMotivosMinoracionSeleccionados);
			model.addAttribute("relActSubMotMinLis", relActSubMotMinList);
		}
		if (relActSubMotDenList.size() > 0) {
			for (int i = 0; i < relActSubMotDenList.size(); i++) {
				idsMotivosDenegacionselecionados += Long.toString(relActSubMotDenList.get(i).getIdMotivoDenegacion());
				if ((i + 1) != relActSubMotDenList.size()) {
					idsMotivosDenegacionselecionados += ",";
				}
			}
			model.addAttribute("idsMotivosDenegacionselecionados", idsMotivosDenegacionselecionados);
			model.addAttribute("relActSubMotDenList", relActSubMotDenList);
		}

		OtrosIngresos otrosIngresos = new OtrosIngresos();
		otrosIngresos.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		otrosIngresos.setFase(Constantes.FASE_SOLICITUD);
		otrosIngresos = this.otrosIngresosService.findByIdRelExpActSub(otrosIngresos);
		if (otrosIngresos != null) {
			model.addAttribute("otrosIngresos", otrosIngresos.getImporte());
		}

		model.addAttribute("datosRelExpActSub", relExpActSub);
		return "conceptos";

	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterConceptos
	 *            Conceptos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchConceptos
	 *            Conceptos Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Conceptos> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Conceptos>> search(
			@RequestJsonBody(param = "filter") Conceptos filterConceptos,
			@RequestJsonBody(param = "search") Conceptos searchConceptos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConceptosController.logger.info("[POST - search] : Buscar Conceptoss");
		return this.conceptosService.search(filterConceptos, searchConceptos, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterConceptos
	 *            Conceptos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Conceptos filterConceptos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConceptosController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Conceptoss");
		this.conceptosService.removeMultiple(filterConceptos, jqGridRequestDto, false);
		ConceptosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterConceptos
	 *            Conceptos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Conceptos>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Conceptos>> jerarquia(
			@RequestJsonBody(param = "filter") Conceptos filterConceptos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConceptosController.logger.info("[POST - jerarquia] : Obtener Conceptoss jerarquia");
		return this.conceptosService.jerarquia(filterConceptos, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterConceptos
	 *            Conceptos Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Conceptos>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Conceptos>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Conceptos filterConceptos,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ConceptosController.logger.info("[POST - jerarquia] : Obtener Conceptoss jerarquia - Hijos");
		return this.conceptosService.jerarquiaChildren(filterConceptos, jqGridRequestDto);
	}

}
