package com.ejie.ab60.control.estudioTecnico;

import com.ejie.ab60.model.estudioTecnico.ErroresCalculo;
import com.ejie.ab60.service.estudioTecnico.ErroresCalculoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * ErroresCalculoController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/errorescalculo")

public class ErroresCalculoController {

	private static final Logger logger = LoggerFactory.getLogger(ErroresCalculoController.class);

	@Autowired
	private ErroresCalculoService erroresCalculoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idCodigoerror
	 *            Integer
	 * @return ErroresCalculo Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idCodigoerror}", method = RequestMethod.GET)
	public @ResponseBody ErroresCalculo get(@PathVariable Integer idCodigoerror) {
		ErroresCalculo erroresCalculo = new ErroresCalculo();
		erroresCalculo.setIdCodigoerror(idCodigoerror);

		erroresCalculo = this.erroresCalculoService.find(erroresCalculo);
		ErroresCalculoController.logger.info("[GET - findBy_PK] : Obtener ErroresCalculo por PK");
		return erroresCalculo;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterErroresCalculo
	 *            ErroresCalculo Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<ErroresCalculo> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<ErroresCalculo> getAll(@ModelAttribute ErroresCalculo filterErroresCalculo) {
		ErroresCalculoController.logger.info("[GET - find_ALL] : Obtener ErroresCalculo por filtro");
		return this.erroresCalculoService.findAll(filterErroresCalculo, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo Bean que contiene la informacion a modificar.
	 * @return ErroresCalculo Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody ErroresCalculo edit(@RequestBody ErroresCalculo erroresCalculo) {
		ErroresCalculo erroresCalculoAux = this.erroresCalculoService.update(erroresCalculo);
		ErroresCalculoController.logger.info("[PUT] : ErroresCalculo actualizado correctamente");
		return erroresCalculoAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param erroresCalculo
	 *            ErroresCalculo Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return ErroresCalculo Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody ErroresCalculo add(@RequestBody ErroresCalculo erroresCalculo) {
		ErroresCalculo erroresCalculoAux = this.erroresCalculoService.add(erroresCalculo);
		ErroresCalculoController.logger.info("[POST] : ErroresCalculo insertado correctamente");
		return erroresCalculoAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idCodigoerror
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return ErroresCalculo Bean eliminado.
	 */
	@RequestMapping(value = "/{idCodigoerror}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody ErroresCalculo remove(@PathVariable Integer idCodigoerror) {
		ErroresCalculo erroresCalculo = new ErroresCalculo();
		erroresCalculo.setIdCodigoerror(idCodigoerror);
		this.erroresCalculoService.remove(erroresCalculo);
		ErroresCalculoController.logger.info("[DELETE] : ErroresCalculo borrado correctamente");
		return erroresCalculo;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ErroresCalculoController.logger.info("[GET - View] : errorescalculo");
		return "errorescalculo";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterErroresCalculo
	 *            ErroresCalculo Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<ErroresCalculo> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<ErroresCalculo> filter(
			@RequestJsonBody(param = "filter") ErroresCalculo filterErroresCalculo,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ErroresCalculoController.logger.info("[POST - filter] : Obtener ErroresCalculos");
		return this.erroresCalculoService.filter(filterErroresCalculo, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterErroresCalculo
	 *            ErroresCalculo Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchErroresCalculo
	 *            ErroresCalculo Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<ErroresCalculo> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<ErroresCalculo>> search(
			@RequestJsonBody(param = "filter") ErroresCalculo filterErroresCalculo,
			@RequestJsonBody(param = "search") ErroresCalculo searchErroresCalculo,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ErroresCalculoController.logger.info("[POST - search] : Buscar ErroresCalculos");
		return this.erroresCalculoService.search(filterErroresCalculo, searchErroresCalculo, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterErroresCalculo
	 *            ErroresCalculo Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") ErroresCalculo filterErroresCalculo,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ErroresCalculoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples ErroresCalculos");
		this.erroresCalculoService.removeMultiple(filterErroresCalculo, jqGridRequestDto, false);
		ErroresCalculoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterErroresCalculo
	 *            ErroresCalculo Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ErroresCalculo>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ErroresCalculo>> jerarquia(
			@RequestJsonBody(param = "filter") ErroresCalculo filterErroresCalculo,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ErroresCalculoController.logger.info("[POST - jerarquia] : Obtener ErroresCalculos jerarquia");
		return this.erroresCalculoService.jerarquia(filterErroresCalculo, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterErroresCalculo
	 *            ErroresCalculo Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<ErroresCalculo>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<ErroresCalculo>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") ErroresCalculo filterErroresCalculo,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ErroresCalculoController.logger.info("[POST - jerarquia] : Obtener ErroresCalculos jerarquia - Hijos");
		return this.erroresCalculoService.jerarquiaChildren(filterErroresCalculo, jqGridRequestDto);
	}

}
