package com.ejie.ab60.control.estudioTecnico;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.estudioTecnico.Horarios;
import com.ejie.ab60.service.estudioTecnico.HorariosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * HorariosController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/horarios")

public class HorariosController {

	private static final Logger logger = LoggerFactory.getLogger(HorariosController.class);

	@Autowired
	private HorariosService horariosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idHorario
	 *            Long
	 * @return Horarios Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idHorario}", method = RequestMethod.GET)
	public @ResponseBody Horarios get(@PathVariable Long idHorario) {
		Horarios horarios = new Horarios();
		horarios.setIdHorario(idHorario);
		horarios = this.horariosService.find(horarios);
		HorariosController.logger.info("[GET - findBy_PK] : Obtener Horarios por PK");
		return horarios;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterHorarios
	 *            Horarios Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Horarios> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Horarios> getAll(@ModelAttribute Horarios filterHorarios) {
		HorariosController.logger.info("[GET - find_ALL] : Obtener Horarios por filtro");
		return this.horariosService.findAll(filterHorarios, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param horarios
	 *            Horarios Bean que contiene la informacion a modificar.
	 * @return Horarios Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Horarios edit(@RequestBody Horarios horarios) {
		Horarios horariosAux = this.horariosService.update(horarios);
		HorariosController.logger.info("[PUT] : Horarios actualizado correctamente");
		return horariosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param horarios
	 *            Horarios Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Horarios Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Horarios add(@RequestBody Horarios horarios) {
		Horarios horariosAux = this.horariosService.add(horarios);
		HorariosController.logger.info("[POST] : Horarios insertado correctamente");
		return horariosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idHorario
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return Horarios Bean eliminado.
	 */
	@RequestMapping(value = "/{idHorario}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Horarios remove(@PathVariable Long idHorario) {
		Horarios horarios = new Horarios();
		horarios.setIdHorario(idHorario);
		this.horariosService.remove(horarios);
		HorariosController.logger.info("[DELETE] : Horarios borrado correctamente");
		return horarios;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		HorariosController.logger.info("[GET - View] : horarios");
		return "horarios";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterHorarios
	 *            Horarios Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Horarios> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Horarios> filter(@RequestJsonBody(param = "filter") Horarios filterHorarios,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HorariosController.logger.info("[POST - filter] : Obtener Horarioss");
		return this.horariosService.filter(filterHorarios, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterHorarios
	 *            Horarios Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchHorarios
	 *            Horarios Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Horarios> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Horarios>> search(@RequestJsonBody(param = "filter") Horarios filterHorarios,
			@RequestJsonBody(param = "search") Horarios searchHorarios,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HorariosController.logger.info("[POST - search] : Buscar Horarioss");
		return this.horariosService.search(filterHorarios, searchHorarios, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterHorarios
	 *            Horarios Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Horarios filterHorarios,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HorariosController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Horarioss");
		this.horariosService.removeMultiple(filterHorarios, jqGridRequestDto, false);
		HorariosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterHorarios
	 *            Horarios Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Horarios>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Horarios>> jerarquia(
			@RequestJsonBody(param = "filter") Horarios filterHorarios,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HorariosController.logger.info("[POST - jerarquia] : Obtener Horarioss jerarquia");
		return this.horariosService.jerarquia(filterHorarios, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterHorarios
	 *            Horarios Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Horarios>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Horarios>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Horarios filterHorarios,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HorariosController.logger.info("[POST - jerarquia] : Obtener Horarioss jerarquia - Hijos");
		return this.horariosService.jerarquiaChildren(filterHorarios, jqGridRequestDto);
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de horarios
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idPoblacion}/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<Horarios> init(@PathVariable("idPoblacion") Integer idPoblacion,
			@PathVariable("idConvocatoria") Integer idConvocatoria) {
		HorariosController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.horariosService.findByPoblacion(idPoblacion, idConvocatoria);

	}

}
