package com.ejie.ab60.control.estudioTecnico;

import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.estudioTecnico.MotivosDenegacion;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.estudioTecnico.MotivosDenegacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * MotivosDenegacionController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/motivosdenegacion")

public class MotivosDenegacionController {

	private static final Logger logger = LoggerFactory.getLogger(MotivosDenegacionController.class);

	@Autowired
	private MotivosDenegacionService motivosDenegacionService;

	/**
	 * Metodo que nos trae la lista para cargar el combo de motivos de
	 * denegación para actuaciones subvencionables
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorComboActSubvencionable/{idConvocatoria}/{origen}/{idRelExpActSub}", method = RequestMethod.GET)
	public @ResponseBody List<MotivosDenegacion> verValorComboActSubvencionable(@PathVariable Integer idConvocatoria,
			@PathVariable Integer origen, @PathVariable Integer idRelExpActSub) {
		MotivosDenegacionController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");

		return this.motivosDenegacionService.findDenegacionActSubvencionable(idConvocatoria, origen, idRelExpActSub);

	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de motivos de
	 * denegación para facturas
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorComboFacturas/{idConvocatoria}/{origen}/{idFactura}", method = RequestMethod.GET)
	public @ResponseBody List<MotivosDenegacion> verValorComboFacturas(@PathVariable Integer idConvocatoria,
			@PathVariable Integer origen, @PathVariable Integer idFactura) {
		MotivosDenegacionController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");

		return this.motivosDenegacionService.findDenegacionFacturas(idConvocatoria, origen, idFactura);

	}

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idMotivoDenegacion
	 *            Long
	 * @return MotivosDenegacion Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idMotivoDenegacion}", method = RequestMethod.GET)
	public @ResponseBody MotivosDenegacion get(@PathVariable Long idMotivoDenegacion) {
		MotivosDenegacion motivosDenegacion = new MotivosDenegacion();
		motivosDenegacion.setIdMotivoDenegacion(idMotivoDenegacion);
		motivosDenegacion = this.motivosDenegacionService.find(motivosDenegacion);
		MotivosDenegacionController.logger.info("[GET - findBy_PK] : Obtener MotivosDenegacion por PK");
		return motivosDenegacion;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<MotivosDenegacion> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<MotivosDenegacion> getAll(@ModelAttribute MotivosDenegacion filterMotivosDenegacion) {
		MotivosDenegacionController.logger.info("[GET - find_ALL] : Obtener MotivosDenegacion por filtro");
		return this.motivosDenegacionService.findAll(filterMotivosDenegacion, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion Bean que contiene la informacion a
	 *            modificar.
	 * @return MotivosDenegacion Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody MotivosDenegacion edit(@RequestBody MotivosDenegacion motivosDenegacion) {

		MotivosDenegacion motivosDenegacionAux = motivosDenegacion;
		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		motivosDenegacionAux.setUsuarioUltModificacion(usuario.getNombreUsuario());
		motivosDenegacionAux.setFechaUltModificacion(fecha);

		motivosDenegacionAux = this.motivosDenegacionService.update(motivosDenegacionAux);
		MotivosDenegacionController.logger.info("[PUT] : MotivosDenegacion actualizado correctamente");

		return motivosDenegacionAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param motivosDenegacion
	 *            MotivosDenegacion Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return MotivosDenegacion Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody MotivosDenegacion add(@RequestBody MotivosDenegacion motivosDenegacion) {
		MotivosDenegacion motivosDenegacionAux = motivosDenegacion;

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		motivosDenegacionAux.setUsuarioRegistro(usuario.getNombreUsuario());
		motivosDenegacionAux.setFechaRegistro(fecha);

		motivosDenegacionAux = this.motivosDenegacionService.add(motivosDenegacionAux);
		MotivosDenegacionController.logger.info("[POST] : MotivosMinoracion insertado correctamente");
		return motivosDenegacionAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idMotivoDenegacion
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return MotivosDenegacion Bean eliminado.
	 */
	@RequestMapping(value = "/{idMotivoDenegacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody MotivosDenegacion remove(@PathVariable Long idMotivoDenegacion) {
		MotivosDenegacion motivosDenegacion = new MotivosDenegacion();

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		motivosDenegacion.setUsuarioUltModificacion(usuario.getNombreUsuario());
		motivosDenegacion.setFechaUltModificacion(fecha);

		motivosDenegacion.setIdMotivoDenegacion(idMotivoDenegacion);
		motivosDenegacion.setBaja(Constantes.BAJA);

		this.motivosDenegacionService.remove(motivosDenegacion);
		MotivosDenegacionController.logger.info("[DELETE] : MotivosDenegacion borrado correctamente");
		return motivosDenegacion;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {
		MotivosDenegacionController.logger.info("[GET - View] : motivosdenegacion");
		model.addAttribute("motivosDenegacion", new MotivosDenegacion());

		return "motivosdenegacion";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<MotivosDenegacion> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<MotivosDenegacion> filter(
			@RequestJsonBody(param = "filter") MotivosDenegacion filterMotivosDenegacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		MotivosDenegacionController.logger.info("[POST - filter] : Obtener MotivosDenegacions");
		filterMotivosDenegacion.setBaja(Constantes.NO_BAJA);
		return this.motivosDenegacionService.filter(filterMotivosDenegacion, jqGridRequestDto);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchMotivosDenegacion
	 *            MotivosDenegacion Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<MotivosDenegacion> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<MotivosDenegacion>> search(
			@RequestJsonBody(param = "filter") MotivosDenegacion filterMotivosDenegacion,
			@RequestJsonBody(param = "search") MotivosDenegacion searchMotivosDenegacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDenegacionController.logger.info("[POST - search] : Buscar MotivosDenegacions");
		return this.motivosDenegacionService.search(filterMotivosDenegacion, searchMotivosDenegacion, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") MotivosDenegacion filterMotivosDenegacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDenegacionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples MotivosDenegacions");
		this.motivosDenegacionService.removeMultiple(filterMotivosDenegacion, jqGridRequestDto, false);
		MotivosDenegacionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosDenegacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosDenegacion>> jerarquia(
			@RequestJsonBody(param = "filter") MotivosDenegacion filterMotivosDenegacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDenegacionController.logger.info("[POST - jerarquia] : Obtener MotivosDenegacions jerarquia");
		return this.motivosDenegacionService.jerarquia(filterMotivosDenegacion, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterMotivosDenegacion
	 *            MotivosDenegacion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosDenegacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosDenegacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") MotivosDenegacion filterMotivosDenegacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDenegacionController.logger.info("[POST - jerarquia] : Obtener MotivosDenegacions jerarquia - Hijos");
		return this.motivosDenegacionService.jerarquiaChildren(filterMotivosDenegacion, jqGridRequestDto);
	}

}
