package com.ejie.ab60.control.estudioTecnico;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.estudioTecnico.MotivosDesestimacion;
import com.ejie.ab60.service.estudioTecnico.MotivosDesestimacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * MotivosDesestimacionController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/motivosdesestimacion")

public class MotivosDesestimacionController {

	private static final Logger logger = LoggerFactory.getLogger(MotivosDesestimacionController.class);

	@Autowired
	private MotivosDesestimacionService motivosDesestimacionService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idMotivoDesestimacion
	 *            Long
	 * @return MotivosDesestimacion Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idMotivoDesestimacion}", method = RequestMethod.GET)
	public @ResponseBody MotivosDesestimacion get(@PathVariable Long idMotivoDesestimacion) {
		MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
		motivosDesestimacion.setIdMotivoDesestimacion(idMotivoDesestimacion);
		motivosDesestimacion = this.motivosDesestimacionService.find(motivosDesestimacion);
		MotivosDesestimacionController.logger.info("[GET - findBy_PK] : Obtener MotivosDesestimacion por PK");
		return motivosDesestimacion;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<MotivosDesestimacion> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<MotivosDesestimacion> getAll(
			@ModelAttribute MotivosDesestimacion filterMotivosDesestimacion) {
		MotivosDesestimacionController.logger.info("[GET - find_ALL] : Obtener MotivosDesestimacion por filtro");
		return this.motivosDesestimacionService.findAll(filterMotivosDesestimacion, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param motivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene la informacion a
	 *            modificar.
	 * @return MotivosDesestimacion Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody MotivosDesestimacion edit(@RequestBody MotivosDesestimacion motivosDesestimacion) {
		MotivosDesestimacion motivosDesestimacionAux = this.motivosDesestimacionService.update(motivosDesestimacion);
		MotivosDesestimacionController.logger.info("[PUT] : MotivosDesestimacion actualizado correctamente");
		return motivosDesestimacionAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param motivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return MotivosDesestimacion Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody MotivosDesestimacion add(@RequestBody MotivosDesestimacion motivosDesestimacion) {
		MotivosDesestimacion motivosDesestimacionAux = this.motivosDesestimacionService.add(motivosDesestimacion);
		MotivosDesestimacionController.logger.info("[POST] : MotivosDesestimacion insertado correctamente");
		return motivosDesestimacionAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idMotivoDesestimacion
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return MotivosDesestimacion Bean eliminado.
	 */
	@RequestMapping(value = "/{idMotivoDesestimacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody MotivosDesestimacion remove(@PathVariable Long idMotivoDesestimacion) {
		MotivosDesestimacion motivosDesestimacion = new MotivosDesestimacion();
		motivosDesestimacion.setIdMotivoDesestimacion(idMotivoDesestimacion);
		this.motivosDesestimacionService.remove(motivosDesestimacion);
		MotivosDesestimacionController.logger.info("[DELETE] : MotivosDesestimacion borrado correctamente");
		return motivosDesestimacion;
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de motivos
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo", method = RequestMethod.GET)
	public @ResponseBody List<MotivosDesestimacion> init() {
		MotivosDesestimacionController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.motivosDesestimacionService.findMotivo();

	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		MotivosDesestimacionController.logger.info("[GET - View] : motivosdesestimacion");
		return "motivosdesestimacion";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<MotivosDesestimacion> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<MotivosDesestimacion> filter(
			@RequestJsonBody(param = "filter") MotivosDesestimacion filterMotivosDesestimacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDesestimacionController.logger.info("[POST - filter] : Obtener MotivosDesestimacions");
		return this.motivosDesestimacionService.filter(filterMotivosDesestimacion, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchMotivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<MotivosDesestimacion> Dto que contiene el resultado
	 *         de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<MotivosDesestimacion>> search(
			@RequestJsonBody(param = "filter") MotivosDesestimacion filterMotivosDesestimacion,
			@RequestJsonBody(param = "search") MotivosDesestimacion searchMotivosDesestimacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDesestimacionController.logger.info("[POST - search] : Buscar MotivosDesestimacions");
		return this.motivosDesestimacionService.search(filterMotivosDesestimacion, searchMotivosDesestimacion,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") MotivosDesestimacion filterMotivosDesestimacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDesestimacionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples MotivosDesestimacions");
		this.motivosDesestimacionService.removeMultiple(filterMotivosDesestimacion, jqGridRequestDto, false);
		MotivosDesestimacionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosDesestimacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosDesestimacion>> jerarquia(
			@RequestJsonBody(param = "filter") MotivosDesestimacion filterMotivosDesestimacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDesestimacionController.logger.info("[POST - jerarquia] : Obtener MotivosDesestimacions jerarquia");
		return this.motivosDesestimacionService.jerarquia(filterMotivosDesestimacion, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterMotivosDesestimacion
	 *            MotivosDesestimacion Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosDesestimacion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosDesestimacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") MotivosDesestimacion filterMotivosDesestimacion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosDesestimacionController.logger
				.info("[POST - jerarquia] : Obtener MotivosDesestimacions jerarquia - Hijos");
		return this.motivosDesestimacionService.jerarquiaChildren(filterMotivosDesestimacion, jqGridRequestDto);
	}

}
