package com.ejie.ab60.control.estudioTecnico;

import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.estudioTecnico.MotivosMinoracion;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.estudioTecnico.MotivosMinoracionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * MotivosMinoracionController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/motivosminoracion")

public class MotivosMinoracionController {

	private static final Logger logger = LoggerFactory.getLogger(MotivosMinoracionController.class);

	@Autowired
	private MotivosMinoracionService motivosMinoracionService;

	/**
	 * Metodo que nos trae la lista para cargar el combo de minoracion
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorComboActSubvencionable/{idConvocatoria}/{origen}/{idRelExpActSub}", method = RequestMethod.GET)
	public @ResponseBody List<MotivosMinoracion> verValorComboActSubvencionable(@PathVariable Integer idConvocatoria,
			@PathVariable Integer origen, @PathVariable Integer idRelExpActSub) {
		MotivosMinoracionController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.motivosMinoracionService.findMinoracionActSubvencionable(idConvocatoria, origen, idRelExpActSub);

	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de minoracion
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorComboFacturas/{idConvocatoria}/{origen}/{idFactura}", method = RequestMethod.GET)
	public @ResponseBody List<MotivosMinoracion> verValorComboFacturas(@PathVariable Integer idConvocatoria,
			@PathVariable Integer origen, @PathVariable Integer idFactura) {
		MotivosMinoracionController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.motivosMinoracionService.findMinoracionFacturas(idConvocatoria, origen, idFactura);

	}

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idMotivoMinoracion
	 *            Long
	 * @return MotivosMinoracion Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idMotivoMinoracion}", method = RequestMethod.GET)
	public @ResponseBody MotivosMinoracion get(@PathVariable Long idMotivoMinoracion, Model model) {
		MotivosMinoracion motivosMinoracion = new MotivosMinoracion();
		motivosMinoracion.setIdMotivoMinoracion(idMotivoMinoracion);
		motivosMinoracion = this.motivosMinoracionService.find(motivosMinoracion);
		MotivosMinoracionController.logger.info("[GET - findBy_PK] : Obtener MotivosMinoracion por PK");
		return motivosMinoracion;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<MotivosMinoracion> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<MotivosMinoracion> getAll(@ModelAttribute MotivosMinoracion filterMotivosMinoracion) {
		MotivosMinoracionController.logger.info("[GET - find_ALL] : Obtener MotivosMinoracion por filtro");
		return this.motivosMinoracionService.findAll(filterMotivosMinoracion, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param motivosMinoracion
	 *            MotivosMinoracion Bean que contiene la informacion a
	 *            modificar.
	 * @return MotivosMinoracion Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody MotivosMinoracion edit(@RequestBody MotivosMinoracion motivosMinoracion) {

		MotivosMinoracion motivosMinoracionAux = motivosMinoracion;

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		motivosMinoracionAux.setUsuarioUltModificacion(usuario.getNombreUsuario());
		motivosMinoracionAux.setFechaUltModificacion(fecha);

		motivosMinoracionAux = this.motivosMinoracionService.update(motivosMinoracionAux);

		MotivosMinoracionController.logger.info("[PUT] : MotivosMinoracion actualizado correctamente");
		return motivosMinoracionAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param motivosMinoracion
	 *            MotivosMinoracion Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return MotivosMinoracion Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody MotivosMinoracion add(@RequestBody MotivosMinoracion motivosMinoracion) {

		MotivosMinoracion motivosMinoracionAux = motivosMinoracion;

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		motivosMinoracionAux.setUsuarioRegistro(usuario.getNombreUsuario());
		motivosMinoracionAux.setFechaRegistro(fecha);

		motivosMinoracionAux.setBaja(Constantes.NO_BAJA);

		motivosMinoracionAux = this.motivosMinoracionService.add(motivosMinoracionAux);
		MotivosMinoracionController.logger.info("[POST] : MotivosMinoracion insertado correctamente");
		return motivosMinoracionAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idMotivoMinoracion
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return MotivosMinoracion Bean eliminado.
	 */
	@RequestMapping(value = "/{idMotivoMinoracion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody MotivosMinoracion remove(@PathVariable Long idMotivoMinoracion) {
		MotivosMinoracion motivosMinoracion = new MotivosMinoracion();

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		motivosMinoracion.setUsuarioUltModificacion(usuario.getNombreUsuario());
		motivosMinoracion.setFechaUltModificacion(fecha);

		motivosMinoracion.setIdMotivoMinoracion(idMotivoMinoracion);
		motivosMinoracion.setBaja(Constantes.BAJA);

		this.motivosMinoracionService.remove(motivosMinoracion);
		MotivosMinoracionController.logger.info("[DELETE] : MotivosMinoracion borrado correctamente");
		return motivosMinoracion;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {
		MotivosMinoracionController.logger.info("[GET - View] : motivosminoracion");
		model.addAttribute("motivosMinoracion", new MotivosMinoracion());
		return "motivosminoracion";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<MotivosMinoracion> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */

	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<MotivosMinoracion> filter(
			@RequestJsonBody(param = "filter") MotivosMinoracion filterMotivosMinoracion, Integer idConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		System.out.print(filterMotivosMinoracion.getConvocatoria().getIdConvocatoria());
		MotivosMinoracionController.logger.info("[POST - jqGrid] : Obtener Usuarios");
		filterMotivosMinoracion.setBusqConvocatoria(filterMotivosMinoracion.getConvocatoria().getIdConvocatoria());
		return this.motivosMinoracionService.filter(filterMotivosMinoracion, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchMotivosMinoracion
	 *            MotivosMinoracion Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<MotivosMinoracion> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<MotivosMinoracion>> search(
			@RequestJsonBody(param = "filter") MotivosMinoracion filterMotivosMinoracion,
			@RequestJsonBody(param = "search") MotivosMinoracion searchMotivosMinoracion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosMinoracionController.logger.info("[POST - search] : Buscar MotivosMinoracions");
		return this.motivosMinoracionService.search(filterMotivosMinoracion, searchMotivosMinoracion, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") MotivosMinoracion filterMotivosMinoracion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosMinoracionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples MotivosMinoracions");
		this.motivosMinoracionService.removeMultiple(filterMotivosMinoracion, jqGridRequestDto, false);
		MotivosMinoracionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosMinoracion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosMinoracion>> jerarquia(
			@RequestJsonBody(param = "filter") MotivosMinoracion filterMotivosMinoracion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosMinoracionController.logger.info("[POST - jerarquia] : Obtener MotivosMinoracions jerarquia");
		return this.motivosMinoracionService.jerarquia(filterMotivosMinoracion, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterMotivosMinoracion
	 *            MotivosMinoracion Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosMinoracion>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosMinoracion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") MotivosMinoracion filterMotivosMinoracion,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosMinoracionController.logger.info("[POST - jerarquia] : Obtener MotivosMinoracions jerarquia - Hijos");
		return this.motivosMinoracionService.jerarquiaChildren(filterMotivosMinoracion, jqGridRequestDto);
	}

}
