package com.ejie.ab60.control.estudioTecnico;

import java.util.List;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.model.estudioTecnico.OtrasAyudas;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.estudioTecnico.OtrasAyudasService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * OtrasAyudasController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/otrasayudas")

public class OtrasAyudasController {

	private static final Logger logger = LoggerFactory.getLogger(OtrasAyudasController.class);

	@Autowired
	private OtrasAyudasService otrasAyudasService;

	@Autowired
	private ProcedimientosService procedimientosService;

	/**
	 * @param model
	 *            Model
	 * @param usuario
	 *            Usuario
	 * 
	 * @return ModelAndView
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public ModelAndView mostrar(Model model, OtrasAyudas otrasAyudas,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		return new ModelAndView("ayuda");

	}

	/**
	 * @param model
	 *            Model
	 * @param usuario
	 *            Usuario
	 * 
	 * @return ModelAndView
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public ModelAndView mostrarGet(Model model, OtrasAyudas otrasAyudas,
			@ModelAttribute(value = "initForm") InitForm initForm) {

		return new ModelAndView("ayuda");

	}
	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idOtraAyuda
	 *            Integer
	 * @return OtrasAyudas Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idOtraAyuda}", method = RequestMethod.GET)
	public @ResponseBody OtrasAyudas get(@PathVariable Integer idOtraAyuda) {
		OtrasAyudas otrasAyudas = new OtrasAyudas();
		otrasAyudas.setIdOtraAyuda(idOtraAyuda);
		otrasAyudas = this.otrasAyudasService.find(otrasAyudas);
		OtrasAyudasController.logger.info("[GET - findBy_PK] : Obtener OtrasAyudas por PK");
		return otrasAyudas;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idExpediente
	 *            Integer
	 * @param tipoOtraAyuda
	 *            Integer
	 * @param idOtraAyuda
	 *            Integer
	 * @return OtrasAyudas Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idExpediente}/{tipoOtraAyuda}/{idOtraAyuda}", method = RequestMethod.GET)
	public @ResponseBody OtrasAyudas getEdit(@PathVariable Integer idExpediente, @PathVariable Integer tipoOtraAyuda,
			@PathVariable Integer idOtraAyuda) {
		OtrasAyudas otrasAyudas = new OtrasAyudas();
		otrasAyudas.setIdOtraAyuda(idOtraAyuda);
		otrasAyudas = this.otrasAyudasService.find(otrasAyudas);
		OtrasAyudasController.logger.info("[GET - findBy_PK] : Obtener OtrasAyudas por PK");
		return otrasAyudas;
	}

	/**
	 * Devuelve las ayudas asociadas a un determinado expediente.
	 *
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param idExpediente
	 *            Integer
	 * @return JQGridResponseDto
	 * 
	 */
	@RequestMapping(value = "/{idExpediente}/{tipoOtraAyuda}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<OtrasAyudas> findAyudasPorExpediente(
			@RequestJsonBody() JQGridRequestDto jqGridRequestDto, @PathVariable Integer idExpediente,
			@PathVariable Integer tipoOtraAyuda) {
		OtrasAyudas otrasAyudas = new OtrasAyudas();
		otrasAyudas.setIdExpediente(idExpediente);
		otrasAyudas.setIdTipoOtraAyuda(tipoOtraAyuda);
		OtrasAyudasController.logger.info("[GET - findBy_PK] : Obtener OtrasAyudas por Expediente");

		return this.otrasAyudasService.filter(otrasAyudas, jqGridRequestDto, false);
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterOtrasAyudas
	 *            OtrasAyudas Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<OtrasAyudas> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<OtrasAyudas> getAll(@ModelAttribute OtrasAyudas filterOtrasAyudas) {
		OtrasAyudasController.logger.info("[GET - find_ALL] : Obtener OtrasAyudas por filtro");
		return this.otrasAyudasService.findAll(filterOtrasAyudas, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas Bean que contiene la informacion a modificar.
	 * @return OtrasAyudas Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody OtrasAyudas edit(@RequestBody OtrasAyudas otrasAyudas) {
		OtrasAyudas otrasAyudasAux = this.otrasAyudasService.update(otrasAyudas);
		OtrasAyudasController.logger.info("[PUT] : OtrasAyudas actualizado correctamente");
		return otrasAyudasAux;
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param httpRequest
	 *            HttpServletRequest
	 * @param idExpediente
	 *            Integer
	 * @param tipoOtraAyuda
	 *            Integer
	 * @param otrasAyudas
	 *            OtrasAyudas Bean que contiene la informacion a modificar.
	 * @return OtrasAyudas Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/{idExpediente}/{tipoOtraAyuda}", method = RequestMethod.PUT)
	public @ResponseBody OtrasAyudas editConFiltro(HttpServletRequest httpRequest, @PathVariable Integer idExpediente,
			@PathVariable Integer tipoOtraAyuda, @RequestBody OtrasAyudas otrasAyudas,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return otrasAyudasService.editConFiltro(httpRequest, idExpediente, tipoOtraAyuda, otrasAyudas, usuario);

	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param otrasAyudas
	 *            OtrasAyudas Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return OtrasAyudas Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody OtrasAyudas add(@RequestBody OtrasAyudas otrasAyudas) {
		OtrasAyudas otrasAyudasAux = this.otrasAyudasService.add(otrasAyudas);
		OtrasAyudasController.logger.info("[POST] : OtrasAyudas insertado correctamente");
		return otrasAyudasAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param httpRequest
	 *            HttpServletRequest
	 * @param idExpediente
	 *            Integer
	 * @param tipoOtraAyuda
	 *            Integer
	 * @param otrasAyudas
	 *            OtrasAyudas Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return OtrasAyudas Bean resultante del proceso de creacion.
	 */
	@RequestMapping(value = "/{idExpediente}/{tipoOtraAyuda}", method = RequestMethod.POST)
	public @ResponseBody OtrasAyudas addConFiltro(HttpServletRequest httpRequest, @PathVariable Integer idExpediente,
			@PathVariable Integer tipoOtraAyuda, @RequestBody OtrasAyudas otrasAyudas,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		return otrasAyudasService.addConFiltro(httpRequest, idExpediente, tipoOtraAyuda, otrasAyudas, usuario);

	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idOtraAyuda
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return OtrasAyudas Bean eliminado.
	 */
	@RequestMapping(value = "/{idOtraAyuda}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody OtrasAyudas remove(@PathVariable Integer idOtraAyuda) {
		OtrasAyudas otrasAyudas = new OtrasAyudas();
		otrasAyudas.setIdOtraAyuda(idOtraAyuda);
		this.otrasAyudasService.remove(otrasAyudas);
		OtrasAyudasController.logger.info("[DELETE] : OtrasAyudas borrado correctamente");
		return otrasAyudas;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idExpediente
	 *            Integer
	 * @param tipoOtraAyuda
	 *            Integer
	 * @param idOtraAyuda
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return OtrasAyudas Bean eliminado.
	 */
	@RequestMapping(value = "/{idExpediente}/{tipoOtraAyuda}/{idOtraAyuda}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody OtrasAyudas remove(@PathVariable Integer idExpediente, @PathVariable Integer tipoOtraAyuda,
			@PathVariable Integer idOtraAyuda) {

		return otrasAyudasService.remove(idExpediente, tipoOtraAyuda, idOtraAyuda);

	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */

	@RequestMapping(value = "/ayudas", method = RequestMethod.GET)
	public String getFormEdit(Model model, OtrasAyudas otrasAyudas,
			@ModelAttribute(value = "initForm") InitForm initForm) {
		model.addAttribute("ayuda", otrasAyudas);
		OtrasAyudasController.logger.info("[GET - View] : pagosexpediente");
		return "otrasayudas";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterOtrasAyudas
	 *            OtrasAyudas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<OtrasAyudas> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<OtrasAyudas> filter(
			@RequestJsonBody(param = "filter") OtrasAyudas filterOtrasAyudas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasAyudasController.logger.info("[POST - filter] : Obtener OtrasAyudass");
		return this.otrasAyudasService.filter(filterOtrasAyudas, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterOtrasAyudas
	 *            OtrasAyudas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchOtrasAyudas
	 *            OtrasAyudas Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<OtrasAyudas> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<OtrasAyudas>> search(
			@RequestJsonBody(param = "filter") OtrasAyudas filterOtrasAyudas,
			@RequestJsonBody(param = "search") OtrasAyudas searchOtrasAyudas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasAyudasController.logger.info("[POST - search] : Buscar OtrasAyudass");
		return this.otrasAyudasService.search(filterOtrasAyudas, searchOtrasAyudas, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterOtrasAyudas
	 *            OtrasAyudas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") OtrasAyudas filterOtrasAyudas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasAyudasController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples OtrasAyudass");
		this.otrasAyudasService.removeMultiple(filterOtrasAyudas, jqGridRequestDto, false);
		OtrasAyudasController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterOtrasAyudas
	 *            OtrasAyudas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<OtrasAyudas>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OtrasAyudas>> jerarquia(
			@RequestJsonBody(param = "filter") OtrasAyudas filterOtrasAyudas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasAyudasController.logger.info("[POST - jerarquia] : Obtener OtrasAyudass jerarquia");
		return this.otrasAyudasService.jerarquia(filterOtrasAyudas, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterOtrasAyudas
	 *            OtrasAyudas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<OtrasAyudas>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OtrasAyudas>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") OtrasAyudas filterOtrasAyudas,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasAyudasController.logger.info("[POST - jerarquia] : Obtener OtrasAyudass jerarquia - Hijos");
		return this.otrasAyudasService.jerarquiaChildren(filterOtrasAyudas, jqGridRequestDto);
	}

}
