package com.ejie.ab60.control.estudioTecnico;

import com.ejie.ab60.service.estudioTecnico.PoblacionesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.ejie.ab60.model.estudioTecnico.Poblaciones;

/**
 * PoblacionesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/poblaciones")

public class PoblacionesController {

	private static final Logger logger = LoggerFactory.getLogger(PoblacionesController.class);

	@Autowired
	private PoblacionesService poblacionesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idPoblacion
	 *            Integer
	 * @return Poblaciones Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idPoblacion}", method = RequestMethod.GET)
	public @ResponseBody Poblaciones get(@PathVariable Integer idPoblacion) {
		Poblaciones poblaciones = new Poblaciones();
		poblaciones.setIdPoblacion(idPoblacion);
		poblaciones = this.poblacionesService.find(poblaciones);
		PoblacionesController.logger.info("[GET - findBy_PK] : Obtener Poblaciones por PK");
		return poblaciones;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterPoblaciones
	 *            Poblaciones Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Poblaciones> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Poblaciones> getAll(@ModelAttribute Poblaciones filterPoblaciones) {
		PoblacionesController.logger.info("[GET - find_ALL] : Obtener Poblaciones por filtro");
		return this.poblacionesService.findAll(filterPoblaciones, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param poblaciones
	 *            Poblaciones Bean que contiene la informacion a modificar.
	 * @return Poblaciones Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Poblaciones edit(@RequestBody Poblaciones poblaciones) {
		Poblaciones poblacionesAux = this.poblacionesService.update(poblaciones);
		PoblacionesController.logger.info("[PUT] : Poblaciones actualizado correctamente");
		return poblacionesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param poblaciones
	 *            Poblaciones Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return Poblaciones Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Poblaciones add(@RequestBody Poblaciones poblaciones) {
		Poblaciones poblacionesAux = this.poblacionesService.add(poblaciones);
		PoblacionesController.logger.info("[POST] : Poblaciones insertado correctamente");
		return poblacionesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idPoblacion
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Poblaciones Bean eliminado.
	 */
	@RequestMapping(value = "/{idPoblacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Poblaciones remove(@PathVariable Integer idPoblacion) {
		Poblaciones poblaciones = new Poblaciones();
		poblaciones.setIdPoblacion(idPoblacion);
		this.poblacionesService.remove(poblaciones);
		PoblacionesController.logger.info("[DELETE] : Poblaciones borrado correctamente");
		return poblaciones;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		PoblacionesController.logger.info("[GET - View] : poblaciones");
		return "poblaciones";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPoblaciones
	 *            Poblaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Poblaciones> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Poblaciones> filter(
			@RequestJsonBody(param = "filter") Poblaciones filterPoblaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PoblacionesController.logger.info("[POST - filter] : Obtener Poblacioness");
		return this.poblacionesService.filter(filterPoblaciones, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterPoblaciones
	 *            Poblaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchPoblaciones
	 *            Poblaciones Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Poblaciones> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Poblaciones>> search(
			@RequestJsonBody(param = "filter") Poblaciones filterPoblaciones,
			@RequestJsonBody(param = "search") Poblaciones searchPoblaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PoblacionesController.logger.info("[POST - search] : Buscar Poblacioness");
		return this.poblacionesService.search(filterPoblaciones, searchPoblaciones, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterPoblaciones
	 *            Poblaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Poblaciones filterPoblaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PoblacionesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Poblacioness");
		this.poblacionesService.removeMultiple(filterPoblaciones, jqGridRequestDto, false);
		PoblacionesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterPoblaciones
	 *            Poblaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Poblaciones>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Poblaciones>> jerarquia(
			@RequestJsonBody(param = "filter") Poblaciones filterPoblaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PoblacionesController.logger.info("[POST - jerarquia] : Obtener Poblacioness jerarquia");
		return this.poblacionesService.jerarquia(filterPoblaciones, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterPoblaciones
	 *            Poblaciones Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Poblaciones>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Poblaciones>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Poblaciones filterPoblaciones,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PoblacionesController.logger.info("[POST - jerarquia] : Obtener Poblacioness jerarquia - Hijos");
		return this.poblacionesService.jerarquiaChildren(filterPoblaciones, jqGridRequestDto);
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de poblaciones
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<Poblaciones> init(@PathVariable Integer idConvocatoria) {
		PoblacionesController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.poblacionesService.findByConvocatoria(idConvocatoria);

	}

}
