package com.ejie.ab60.control.estudioTecnico;

import com.ejie.ab60.model.estudioTecnico.RelExpErrCal;
import com.ejie.ab60.service.actuacionesSubvencionables.ActSubvencionableService;
import com.ejie.ab60.service.estudioTecnico.RelExpErrCalService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * RelExpErrCalController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relexperrcal")

public class RelExpErrCalController {

	private static final Logger logger = LoggerFactory.getLogger(RelExpErrCalController.class);

	@Autowired
	private RelExpErrCalService relExpErrCalService;

	@Autowired
	private ActSubvencionableService actSubvencionableService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelExpErrCal
	 *            Integer
	 * @return RelExpErrCal Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelExpErrCal}", method = RequestMethod.GET)
	public @ResponseBody RelExpErrCal get(@PathVariable Integer idRelExpErrCal) {
		RelExpErrCal relExpErrCal = new RelExpErrCal();
		relExpErrCal.setIdRelExpErrCal(idRelExpErrCal);
		relExpErrCal = this.relExpErrCalService.find(relExpErrCal);
		RelExpErrCalController.logger.info("[GET - findBy_PK] : Obtener RelExpErrCal por PK");
		return relExpErrCal;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelExpErrCal
	 *            Integer
	 * @return RelExpErrCal Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "verLimites/{idExpediente}/{fase}", method = RequestMethod.GET)
	public @ResponseBody List<RelExpErrCal> getLimites(@PathVariable Integer idExpediente, @PathVariable Integer fase) {

		RelExpErrCal relexperrcal = new RelExpErrCal();
		relexperrcal.setIdExpediente(idExpediente);
		relexperrcal.setFase(fase);

		List<RelExpErrCal> relExpErrCalList = this.relExpErrCalService.findLimites(relexperrcal);
		List<RelExpErrCal> relExpErrCalLista = new ArrayList<RelExpErrCal>();

		for (RelExpErrCal relExpErrCal : relExpErrCalList) {
			if (relExpErrCal.getErroresCalculo().getActSubvencionable().getIdActSub() != 0) {
				relExpErrCalLista.add(this.actSubvencionableService.obtenerDescripcionActSub(relExpErrCal));
			} else {
				relExpErrCalLista.add(relExpErrCal);
			}
		}

		RelExpErrCalController.logger.info("[GET - findBy_PK] : Obtener Limites por Expediente");
		return relExpErrCalLista;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelExpErrCal
	 *            RelExpErrCal Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelExpErrCal> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelExpErrCal> getAll(@ModelAttribute RelExpErrCal filterRelExpErrCal) {
		RelExpErrCalController.logger.info("[GET - find_ALL] : Obtener RelExpErrCal por filtro");
		return this.relExpErrCalService.findAll(filterRelExpErrCal, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpErrCal
	 *            RelExpErrCal Bean que contiene la informacion a modificar.
	 * @return RelExpErrCal Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelExpErrCal edit(@RequestBody RelExpErrCal relExpErrCal) {
		RelExpErrCal relExpErrCalAux = this.relExpErrCalService.update(relExpErrCal);
		RelExpErrCalController.logger.info("[PUT] : RelExpErrCal actualizado correctamente");
		return relExpErrCalAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relExpErrCal
	 *            RelExpErrCal Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelExpErrCal Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelExpErrCal add(@RequestBody RelExpErrCal relExpErrCal) {
		RelExpErrCal relExpErrCalAux = this.relExpErrCalService.add(relExpErrCal);
		RelExpErrCalController.logger.info("[POST] : RelExpErrCal insertado correctamente");
		return relExpErrCalAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelExpErrCal
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelExpErrCal Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelExpErrCal}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelExpErrCal remove(@PathVariable Integer idRelExpErrCal) {
		RelExpErrCal relExpErrCal = new RelExpErrCal();
		relExpErrCal.setIdRelExpErrCal(idRelExpErrCal);
		this.relExpErrCalService.remove(relExpErrCal);
		RelExpErrCalController.logger.info("[DELETE] : RelExpErrCal borrado correctamente");
		return relExpErrCal;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelExpErrCalController.logger.info("[GET - View] : relexperrcal");
		return "relexperrcal";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelExpErrCal
	 *            RelExpErrCal Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelExpErrCal> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpErrCal> filter(
			@RequestJsonBody(param = "filter") RelExpErrCal filterRelExpErrCal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpErrCalController.logger.info("[POST - filter] : Obtener RelExpErrCals");
		return this.relExpErrCalService.filter(filterRelExpErrCal, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelExpErrCal
	 *            RelExpErrCal Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelExpErrCal
	 *            RelExpErrCal Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelExpErrCal> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelExpErrCal>> search(
			@RequestJsonBody(param = "filter") RelExpErrCal filterRelExpErrCal,
			@RequestJsonBody(param = "search") RelExpErrCal searchRelExpErrCal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpErrCalController.logger.info("[POST - search] : Buscar RelExpErrCals");
		return this.relExpErrCalService.search(filterRelExpErrCal, searchRelExpErrCal, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelExpErrCal
	 *            RelExpErrCal Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelExpErrCal filterRelExpErrCal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpErrCalController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelExpErrCals");
		this.relExpErrCalService.removeMultiple(filterRelExpErrCal, jqGridRequestDto, false);
		RelExpErrCalController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelExpErrCal
	 *            RelExpErrCal Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpErrCal>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpErrCal>> jerarquia(
			@RequestJsonBody(param = "filter") RelExpErrCal filterRelExpErrCal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpErrCalController.logger.info("[POST - jerarquia] : Obtener RelExpErrCals jerarquia");
		return this.relExpErrCalService.jerarquia(filterRelExpErrCal, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelExpErrCal
	 *            RelExpErrCal Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpErrCal>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpErrCal>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelExpErrCal filterRelExpErrCal,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpErrCalController.logger.info("[POST - jerarquia] : Obtener RelExpErrCals jerarquia - Hijos");
		return this.relExpErrCalService.jerarquiaChildren(filterRelExpErrCal, jqGridRequestDto);
	}

}
