package com.ejie.ab60.control.estudioTecnico;

import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.estudioTecnico.TecnicosResponsables;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.estudioTecnico.TecnicosResponsablesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

/**
 * TecnicosResponsablesController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tecnicosresponsables")

public class TecnicosResponsablesController {

	private static final Logger logger = LoggerFactory.getLogger(TecnicosResponsablesController.class);

	@Autowired
	private TecnicosResponsablesService tecnicosResponsablesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTecnicoResponsable
	 *            Integer
	 * @return TecnicosResponsables Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idTecnicoResponsable}", method = RequestMethod.GET)
	public @ResponseBody TecnicosResponsables get(@PathVariable Integer idTecnicoResponsable, Model model) {
		TecnicosResponsables tecnicosResponsables = new TecnicosResponsables();
		tecnicosResponsables.setIdTecnicoResponsable(idTecnicoResponsable);
		tecnicosResponsables = this.tecnicosResponsablesService.find(tecnicosResponsables);
		TecnicosResponsablesController.logger.info("[GET - findBy_PK] : Obtener TecnicosResponsables por PK");

		return tecnicosResponsables;
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de tecnicos
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idConvocatoria}/{idExpediente}/{justificacion}", method = RequestMethod.GET)
	public @ResponseBody List<TecnicosResponsables> init(@PathVariable Integer idConvocatoria,
			@PathVariable Integer idExpediente, @PathVariable boolean justificacion) {
		TecnicosResponsablesController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.tecnicosResponsablesService.findTecnico(idConvocatoria, idExpediente, justificacion);

	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTecnicosResponsables
	 *            TecnicosResponsables Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<TecnicosResponsables> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TecnicosResponsables> getAll(
			@ModelAttribute TecnicosResponsables filterTecnicosResponsables) {
		TecnicosResponsablesController.logger.info("[GET - find_ALL] : Obtener TecnicosResponsables por filtro");
		return this.tecnicosResponsablesService.findAll(filterTecnicosResponsables, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tecnicosResponsables
	 *            TecnicosResponsables Bean que contiene la informacion a
	 *            modificar.
	 * @return TecnicosResponsables Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TecnicosResponsables edit(@RequestBody TecnicosResponsables tecnicosResponsables) {
		TecnicosResponsables tecnicosResponsablesAux = tecnicosResponsables;
		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		tecnicosResponsablesAux.setUsuarioUltModificacion(usuario.getNombreUsuario());
		tecnicosResponsablesAux.setFechaUltModificacion(fecha);

		tecnicosResponsablesAux = this.tecnicosResponsablesService.update(tecnicosResponsablesAux);
		TecnicosResponsablesController.logger.info("[PUT] : TecnicosResponsables actualizado correctamente");

		return tecnicosResponsablesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tecnicosResponsables
	 *            TecnicosResponsables Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return TecnicosResponsables Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TecnicosResponsables add(@RequestBody TecnicosResponsables tecnicosResponsables) {

		TecnicosResponsables tecnicosResponsablesAux = tecnicosResponsables;
		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		tecnicosResponsablesAux.setUsuarioRegistro(usuario.getNombreUsuario());
		tecnicosResponsablesAux.setFechaRegistro(fecha);

		tecnicosResponsablesAux.setBaja(Constantes.NO_BAJA);

		tecnicosResponsablesAux = this.tecnicosResponsablesService.add(tecnicosResponsablesAux);
		TecnicosResponsablesController.logger.info("[POST] : TecnicosResponsables insertado correctamente");
		return tecnicosResponsablesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTecnicoResponsable
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return TecnicosResponsables Bean eliminado.
	 */
	@RequestMapping(value = "/{idTecnicoResponsable}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TecnicosResponsables remove(@PathVariable Integer idTecnicoResponsable) {
		TecnicosResponsables tecnicosResponsablesAux = new TecnicosResponsables();
		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		Usuario usuario = new Usuario();
		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}
		usuario.setNombreUsuario(username);
		Date fecha = new Date();

		tecnicosResponsablesAux.setUsuarioUltModificacion(usuario.getNombreUsuario());
		tecnicosResponsablesAux.setFechaUltModificacion(fecha);

		tecnicosResponsablesAux.setIdTecnicoResponsable(idTecnicoResponsable);
		tecnicosResponsablesAux.setBaja(Constantes.BAJA);

		this.tecnicosResponsablesService.remove(tecnicosResponsablesAux);
		TecnicosResponsablesController.logger.info("[DELETE] : TecnicosResponsables borrado correctamente");
		return tecnicosResponsablesAux;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @param initForm
	 *            InitForm
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {
		TecnicosResponsablesController.logger.info("[GET - View] : tecnicosresponsables");

		model.addAttribute("tecnicosResponsable", new TecnicosResponsables());

		return "tecnicosresponsable";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTecnicosResponsables
	 *            TecnicosResponsables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TecnicosResponsables> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TecnicosResponsables> filter(
			@RequestJsonBody(param = "filter") TecnicosResponsables filterTecnicosResponsables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TecnicosResponsablesController.logger.info("[POST - filter] : Obtener TecnicosResponsabless");
		filterTecnicosResponsables.setBaja(Constantes.NO_BAJA);
		return this.tecnicosResponsablesService.filter(filterTecnicosResponsables, jqGridRequestDto);
	}

}
