package com.ejie.ab60.control.estudioTecnico;

import com.ejie.ab60.service.estudioTecnico.TiposGastoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.estudioTecnico.TiposGasto;

/**
 * TiposGastoController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposgasto")

public class TiposGastoController {

	private static final Logger logger = LoggerFactory.getLogger(TiposGastoController.class);

	@Autowired
	private TiposGastoService tiposGastoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Metodo que nos trae la lista para cargar el combo de tipos gasto
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idCriterio}/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<TiposGasto> init(@PathVariable Integer idCriterio, @PathVariable Integer idConvocatoria) {
		TiposGastoController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.tiposGastoService.findTiposGasto(idCriterio, idConvocatoria);

	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoGasto
	 *            Long
	 * @return TiposGasto Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoGasto}", method = RequestMethod.GET)
	public @ResponseBody TiposGasto get(@PathVariable Long idTipoGasto) {
		TiposGasto tiposGasto = new TiposGasto();
		tiposGasto.setIdTipoGasto(idTipoGasto);
		tiposGasto = this.tiposGastoService.find(tiposGasto);
		TiposGastoController.logger.info("[GET - findBy_PK] : Obtener TiposGasto por PK");
		return tiposGasto;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposGasto
	 *            TiposGasto Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<TiposGasto> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposGasto> getAll(@ModelAttribute TiposGasto filterTiposGasto) {
		TiposGastoController.logger.info("[GET - find_ALL] : Obtener TiposGasto por filtro");
		return this.tiposGastoService.findAll(filterTiposGasto, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposGasto
	 *            TiposGasto Bean que contiene la informacion a modificar.
	 * @return TiposGasto Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposGasto edit(@RequestBody TiposGasto tiposGasto) {
		TiposGasto tiposGastoAux = this.tiposGastoService.update(tiposGasto);
		TiposGastoController.logger.info("[PUT] : TiposGasto actualizado correctamente");
		return tiposGastoAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposGasto
	 *            TiposGasto Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return TiposGasto Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposGasto add(@RequestBody TiposGasto tiposGasto) {
		TiposGasto tiposGastoAux = this.tiposGastoService.add(tiposGasto);
		TiposGastoController.logger.info("[POST] : TiposGasto insertado correctamente");
		return tiposGastoAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoGasto
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposGasto Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoGasto}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposGasto remove(@PathVariable Long idTipoGasto) {
		TiposGasto tiposGasto = new TiposGasto();
		tiposGasto.setIdTipoGasto(idTipoGasto);
		this.tiposGastoService.remove(tiposGasto);
		TiposGastoController.logger.info("[DELETE] : TiposGasto borrado correctamente");
		return tiposGasto;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposGastoController.logger.info("[GET - View] : tiposgasto");
		return "tiposgasto";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposGasto
	 *            TiposGasto Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposGasto> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposGasto> filter(
			@RequestJsonBody(param = "filter") TiposGasto filterTiposGasto,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposGastoController.logger.info("[POST - filter] : Obtener TiposGastos");
		return this.tiposGastoService.filter(filterTiposGasto, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposGasto
	 *            TiposGasto Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchTiposGasto
	 *            TiposGasto Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposGasto> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposGasto>> search(
			@RequestJsonBody(param = "filter") TiposGasto filterTiposGasto,
			@RequestJsonBody(param = "search") TiposGasto searchTiposGasto,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposGastoController.logger.info("[POST - search] : Buscar TiposGastos");
		return this.tiposGastoService.search(filterTiposGasto, searchTiposGasto, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposGasto
	 *            TiposGasto Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") TiposGasto filterTiposGasto,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposGastoController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposGastos");
		this.tiposGastoService.removeMultiple(filterTiposGasto, jqGridRequestDto, false);
		TiposGastoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposGasto
	 *            TiposGasto Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposGasto>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposGasto>> jerarquia(
			@RequestJsonBody(param = "filter") TiposGasto filterTiposGasto,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposGastoController.logger.info("[POST - jerarquia] : Obtener TiposGastos jerarquia");
		return this.tiposGastoService.jerarquia(filterTiposGasto, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposGasto
	 *            TiposGasto Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposGasto>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposGasto>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposGasto filterTiposGasto,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposGastoController.logger.info("[POST - jerarquia] : Obtener TiposGastos jerarquia - Hijos");
		return this.tiposGastoService.jerarquiaChildren(filterTiposGasto, jqGridRequestDto);
	}

}
