package com.ejie.ab60.control.estudioTecnico;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.estudioTecnico.TiposResultado;
import com.ejie.ab60.service.estudioTecnico.TiposResultadoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposResultadoController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposresultado")

public class TiposResultadoController {

	private static final Logger logger = LoggerFactory.getLogger(TiposResultadoController.class);

	@Autowired
	private TiposResultadoService tiposResultadoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idResultado
	 *            Long
	 * @return TiposResultado Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idResultado}", method = RequestMethod.GET)
	public @ResponseBody TiposResultado get(@PathVariable Long idResultado) {
		TiposResultado tiposResultado = new TiposResultado();
		tiposResultado.setIdResultado(idResultado);
		tiposResultado = this.tiposResultadoService.find(tiposResultado);
		TiposResultadoController.logger.info("[GET - findBy_PK] : Obtener TiposResultado por PK");
		return tiposResultado;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposResultado
	 *            TiposResultado Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<TiposResultado> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposResultado> getAll(@ModelAttribute TiposResultado filterTiposResultado) {
		TiposResultadoController.logger.info("[GET - find_ALL] : Obtener TiposResultado por filtro");
		return this.tiposResultadoService.findAll(filterTiposResultado, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposResultado
	 *            TiposResultado Bean que contiene la informacion a modificar.
	 * @return TiposResultado Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposResultado edit(@RequestBody TiposResultado tiposResultado) {
		TiposResultado tiposResultadoAux = this.tiposResultadoService.update(tiposResultado);
		TiposResultadoController.logger.info("[PUT] : TiposResultado actualizado correctamente");
		return tiposResultadoAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposResultado
	 *            TiposResultado Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return TiposResultado Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposResultado add(@RequestBody TiposResultado tiposResultado) {
		TiposResultado tiposResultadoAux = this.tiposResultadoService.add(tiposResultado);
		TiposResultadoController.logger.info("[POST] : TiposResultado insertado correctamente");
		return tiposResultadoAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idResultado
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposResultado Bean eliminado.
	 */
	@RequestMapping(value = "/{idResultado}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposResultado remove(@PathVariable Long idResultado) {
		TiposResultado tiposResultado = new TiposResultado();
		tiposResultado.setIdResultado(idResultado);
		this.tiposResultadoService.remove(tiposResultado);
		TiposResultadoController.logger.info("[DELETE] : TiposResultado borrado correctamente");
		return tiposResultado;
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de resultados
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo", method = RequestMethod.GET)
	public @ResponseBody List<TiposResultado> init() {
		TiposResultadoController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.tiposResultadoService.findResultado();

	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposResultadoController.logger.info("[GET - View] : tiposresultado");
		return "tiposresultado";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposResultado
	 *            TiposResultado Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposResultado> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposResultado> filter(
			@RequestJsonBody(param = "filter") TiposResultado filterTiposResultado,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResultadoController.logger.info("[POST - filter] : Obtener TiposResultados");
		return this.tiposResultadoService.filter(filterTiposResultado, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposResultado
	 *            TiposResultado Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchTiposResultado
	 *            TiposResultado Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposResultado> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposResultado>> search(
			@RequestJsonBody(param = "filter") TiposResultado filterTiposResultado,
			@RequestJsonBody(param = "search") TiposResultado searchTiposResultado,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResultadoController.logger.info("[POST - search] : Buscar TiposResultados");
		return this.tiposResultadoService.search(filterTiposResultado, searchTiposResultado, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposResultado
	 *            TiposResultado Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TiposResultado filterTiposResultado,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResultadoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposResultados");
		this.tiposResultadoService.removeMultiple(filterTiposResultado, jqGridRequestDto, false);
		TiposResultadoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposResultado
	 *            TiposResultado Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposResultado>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposResultado>> jerarquia(
			@RequestJsonBody(param = "filter") TiposResultado filterTiposResultado,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResultadoController.logger.info("[POST - jerarquia] : Obtener TiposResultados jerarquia");
		return this.tiposResultadoService.jerarquia(filterTiposResultado, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposResultado
	 *            TiposResultado Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposResultado>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposResultado>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposResultado filterTiposResultado,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResultadoController.logger.info("[POST - jerarquia] : Obtener TiposResultados jerarquia - Hijos");
		return this.tiposResultadoService.jerarquiaChildren(filterTiposResultado, jqGridRequestDto);
	}

}
