package com.ejie.ab60.control.expedientes;

import java.util.List;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.model.VTInsSinExpediente;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.expedientes.RelExpInsSinExp;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.terceros.DatosTerceros;
import com.ejie.ab60.service.VTInsSinExpedienteService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.ab60.service.expedientes.RelExpInsSinExpService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.ab60.service.terceros.DatosTercerosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/expedientesRelacionados")

public class ExpedientesRelacionadosController {

	private static final Logger logger = LoggerFactory.getLogger(ExpedientesRelacionadosController.class);

	@Autowired
	private ExpedientesService expedientesService;

	@Autowired
	private DatosTercerosService datosTercerosService;

	@Autowired
	private VTInsSinExpedienteService vTInsSinExpedienteService;

	@Autowired
	private RelExpInsSinExpService relExpInsSinExpService;

	@Autowired
	private ProcedimientosService procedimientosService;

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {

		String expediente = initForm.getFolderNumber();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();
		Expedientes expedienteAux = new Expedientes();
		expedienteAux.setIdExpediente(initForm.getIdExpediente());
		expedienteAux = this.expedientesService.find(expedienteAux);

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		model.addAttribute("relacionExpediente", expedienteAux.getRelacionExpediente());
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);
		model.addAttribute("expediente", expediente);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		ExpedientesRelacionadosController.logger.info("[POST - View] : expedientesRelacionados");
		return "expedientesRelacionados";
	}

	@RequestMapping(value = "/titular/{idExpediente}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Expedientes> filterTitular(
			@RequestJsonBody(param = "filter") Expedientes filterExpedientes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idExpediente) {
		ExpedientesRelacionadosController.logger.info("[POST - filter] : Obtener expedientes relacionados por titular");

		List<DatosTerceros> listaTitulares = this.datosTercerosService.findTitularExpediente(idExpediente);

		if (!listaTitulares.isEmpty()) {

			String documentosTitular = "";

			for (DatosTerceros titular : listaTitulares) {
				if (titular.getDocumento() != null) {
					documentosTitular += "\'" + titular.getDocumento() + "\', ";
				}
			}

			if (documentosTitular.length() > 0) {
				documentosTitular = documentosTitular.substring(0, documentosTitular.length() - 2);
			}

			return this.expedientesService.filterExpedientesRelacionadosTitular(documentosTitular, idExpediente,
					jqGridRequestDto);
		} else {
			return new JQGridResponseDto<Expedientes>();
		}

	}

	@RequestMapping(value = "/ubicacionEstablecimiento/{identificadorEstablecimiento}/{idExpediente}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Expedientes> filterUbicacion(
			@RequestJsonBody(param = "filter") Expedientes filterExpedientes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable String identificadorEstablecimiento,
			@PathVariable Integer idExpediente) {
		ExpedientesRelacionadosController.logger.info(
				"[POST - filter] : Obtener expedientes relacionados por ubicación (Identificador Establecimiento)");

		return this.expedientesService.filterExpedientesRelacionadosUbicacion(identificadorEstablecimiento,
				idExpediente, jqGridRequestDto);
	}

	@RequestMapping(value = "/ubicacionRelacionExpediente/{relacionExpediente}/{idExpediente}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Expedientes> filterUbicacionRelacionExpediente(
			@RequestJsonBody(param = "filter") Expedientes filterExpedientes,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer relacionExpediente,
			@PathVariable Integer idExpediente) {
		ExpedientesRelacionadosController.logger
				.info("[POST - filter] : Obtener expedientes relacionados por ubicación (Relación Expediente)");

		return this.expedientesService.filterExpedientesRelacionadosUbicacionRelacionExpediente(relacionExpediente,
				idExpediente, jqGridRequestDto);
	}

	@RequestMapping(value = "/inspeccionesTitular/{idExpediente}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<VTInsSinExpediente> filterInspeccionesTitular(
			@RequestJsonBody(param = "filter") VTInsSinExpediente filterVTInsSinExpediente,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idExpediente) {
		ExpedientesRelacionadosController.logger
				.info("[POST - filter] : Obtener inspecciones relacionadas por titular");

		List<DatosTerceros> listaTitulares = this.datosTercerosService.findTitularExpediente(idExpediente);

		if (!listaTitulares.isEmpty()) {
			String documentosTitular = "";

			for (DatosTerceros titular : listaTitulares) {
				if (titular.getDocumento() != null) {
					documentosTitular += "\'" + titular.getDocumento() + "\', ";
				}
			}

			if (documentosTitular.length() > 0) {
				documentosTitular = documentosTitular.substring(0, documentosTitular.length() - 2);
			}

			return this.vTInsSinExpedienteService.filterInspeccionesRelacionadasTitular(documentosTitular,
					jqGridRequestDto);

		} else {
			return new JQGridResponseDto<VTInsSinExpediente>();
		}
	}

	@RequestMapping(value = "/inspeccionesUbicacion/{idExpediente}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpInsSinExp> filterInspeccionesUbicacion(
			@RequestJsonBody(param = "filter") RelExpInsSinExp filterRelExpInsSinExp,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @PathVariable Integer idExpediente) {
		ExpedientesRelacionadosController.logger
				.info("[POST - filter] : Obtener inspecciones relacionadas por ubicación");

		return this.relExpInsSinExpService.filterInspeccionesRelacionadasUbicacion(idExpediente, jqGridRequestDto);
	}

}
