package com.ejie.ab60.control.expedientes;

import java.util.ArrayList;
import java.util.GregorianCalendar;
import java.util.List;
import java.util.Locale;

import javax.annotation.Resource;
import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.adaptadores.ab79WebServiceAdaptadorService;
import com.ejie.ab60.clientesWS.ab79WebService.Ab79Exception;
import com.ejie.ab60.clientesWS.ab79WebService.DatosInspeccionWS;
import com.ejie.ab60.clientesWS.ab79WebService.InspeccionWS;
import com.ejie.ab60.clientesWS.ab79WebService.PreguntasExpedienteWS;
import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.RelExpIns;
import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.MEC.RelFacMotMin;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotMin;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.estudioTecnico.MotivosMinoracion;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.expedientes.MarcarInspeccionable;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;
import com.ejie.ab60.model.preguntasExpediente.PreguntasExpediente;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.RelExpInsService;
import com.ejie.ab60.service.MEC.FacturasService;
import com.ejie.ab60.service.MEC.RelFacMotMinService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubMotMinService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.estudioTecnico.MotivosMinoracionService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.ab60.service.expedientes.MarcarInspeccionableService;
import com.ejie.ab60.service.preguntasExpediente.PreguntasExpedienteService;
import com.ejie.ab60.util.UtilDate;

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/marcarinspeccionable")

public class MarcarInspeccionableController {

	@Autowired
	private ExpedientesService expedienteService;

	@Autowired
	private MarcarInspeccionableService marcarInspeccionableService;

	@Autowired
	private RelExpInsService relExpInsService;

	@Autowired
	private RelExpActSubService relExpActSubService;

	@Autowired
	private ab79WebServiceAdaptadorService ab79WebServiceAdaptadorService;

	@Autowired
	private PreguntasExpedienteService preguntasExpedienteService;

	@Autowired
	private RelActSubMotMinService relActSubMotMinService;

	@Autowired
	private RelFacMotMinService relFacMotMinService;

	@Autowired
	private FacturasService facturasService;

	@Autowired
	private MotivosMinoracionService motivosMinoracionService;

	@Resource
	private ReloadableResourceBundleMessageSource appMessageSource;

	private static final Logger logger = LoggerFactory.getLogger(MarcarInspeccionableController.class);

	@RequestMapping(value = "/datosInspeccionable/{idExpediente}/{tipoInspeccion}/{idConvocatoria}", method = RequestMethod.GET)
	public String datosInspeccionable(@PathVariable Integer idExpediente, @PathVariable Integer tipoInspeccion,
			@PathVariable Integer idConvocatoria, Model model) {

		Locale locale = LocaleContextHolder.getLocale();

		Expedientes expediente = new Expedientes();
		expediente.setIdExpediente(idExpediente);
		expediente = this.expedienteService.find(expediente);

		MarcarInspeccionable marcarInspeccionable = new MarcarInspeccionable();
		marcarInspeccionable.setExpediente(expediente);
		marcarInspeccionable = this.marcarInspeccionableService.findInspeccionable(marcarInspeccionable);
		marcarInspeccionable.setExpediente(expediente);
		marcarInspeccionable.setFolderYTitulo(expediente.getFolderNumber() + " - " + expediente.getTitulo());

		if (tipoInspeccion == Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO) {
			String fecha = UtilDate.convertirFechaEnString(marcarInspeccionable.getFechaLimInspeccion());
			marcarInspeccionable.setFechaLimInspeccionStr(fecha);
			marcarInspeccionable.setObservacionInspeccion(marcarInspeccionable.getObservacionInspeccion());
		} else if (tipoInspeccion == Constantes.TIPO_INSPECCION_JUSTIFICACION) {
			String fecha = UtilDate.convertirFechaEnString(marcarInspeccionable.getFechaLimInspeccionJus());
			marcarInspeccionable.setFechaLimInspeccionStr(fecha);
			marcarInspeccionable.setObservacionInspeccion(marcarInspeccionable.getObservacionInspeccionJus());
		}

		List<RelExpActSub> relExpActSubLista = new ArrayList<RelExpActSub>();
		relExpActSubLista = this.relExpActSubService.findRelEXpActSubPorExpedienteMET(idExpediente, idConvocatoria);

		String observaciones = "";

		RelExpIns relExpIns = new RelExpIns();
		relExpIns.setIdExpediente(idExpediente);
		relExpIns.setTipoInspeccion(tipoInspeccion);

		relExpIns = this.relExpInsService.findByIdExpediente(relExpIns);

		if (relExpIns != null) {
			observaciones = marcarInspeccionableService.findDatosProyectoPorId(idExpediente, tipoInspeccion);
		} else {
			if (relExpActSubLista != null) {

				observaciones = appMessageSource.getMessage("fexpediente.motivosMinoracion", null, locale) + "\n";
				List<RelActSubMotMin> relActSubMotMinList = new ArrayList<RelActSubMotMin>();
				List<RelFacMotMin> relFacMotMinList = new ArrayList<RelFacMotMin>();
				List<Facturas> facturasList = new ArrayList<Facturas>();
				List<RelActSubMotMin> relActSubMotMinListAux = new ArrayList<RelActSubMotMin>();
				List<RelFacMotMin> relFacMotMinListAux = new ArrayList<RelFacMotMin>();
				Integer origenMotivosMinoracion = 0;

				for (RelExpActSub relExpActSub : relExpActSubLista) {
					if (relExpActSub.getIdRelExpActSub() != 0 || relExpActSub.getIdRelExpActSub() != null) {

						if (tipoInspeccion == Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO) {
							origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_ACT_SUBV;
						} else if (tipoInspeccion == Constantes.TIPO_INSPECCION_JUSTIFICACION) {
							origenMotivosMinoracion = Constantes.ORIGEN_JUSTIFICACION_ACT_SUBV;
						}

						Integer idRelActSub = relExpActSub.getIdRelExpActSub();
						relActSubMotMinList = this.relActSubMotMinService.findIdsMotivosMinoraciones(idRelActSub,
								origenMotivosMinoracion);

						facturasList = this.facturasService.findFacturasPorRelExpActSub(idRelActSub);

						if (!facturasList.isEmpty()) {

							if (tipoInspeccion == Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO) {
								origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_FACTURAS;
							} else if (tipoInspeccion == Constantes.TIPO_INSPECCION_JUSTIFICACION) {
								origenMotivosMinoracion = Constantes.ORIGEN_JUSTIFICACION_FACTURAS;
							}

							for (Facturas factura : facturasList) {
								relFacMotMinList = this.relFacMotMinService.findIdsFacturaMotivosMinoraciones(
										factura.getIdFactura(), origenMotivosMinoracion);

								if (!relFacMotMinList.isEmpty()) {
									for (RelFacMotMin relFacMotMin : relFacMotMinList) {
										relFacMotMinListAux.add(relFacMotMin);
									}
								}

							}
						}

						if (relActSubMotMinList.size() != 0) {
							for (RelActSubMotMin relActSubMotMin : relActSubMotMinList) {
								relActSubMotMinListAux.add(relActSubMotMin);
							}
						}
					}
				}

				if (relActSubMotMinListAux.size() != 0) {
					for (RelActSubMotMin relActSubMotMin : relActSubMotMinListAux) {

						MotivosMinoracion motivosMinoracion = new MotivosMinoracion();
						List<MotivosMinoracion> listaMotivosMinoracion = new ArrayList<MotivosMinoracion>();

						if (relActSubMotMin != null && relActSubMotMin.getIdMotivoMinoracion() != null) {
							motivosMinoracion.setIdMotivoMinoracion(relActSubMotMin.getIdMotivoMinoracion());
							listaMotivosMinoracion = this.motivosMinoracionService.findAll(motivosMinoracion, null);
						}

						for (MotivosMinoracion motivosMinoracionAux : listaMotivosMinoracion) {
							if (locale.getLanguage() == "es") {
								observaciones += motivosMinoracionAux.getDescripcionCastellano() + "\n";
							} else {
								observaciones += motivosMinoracionAux.getDescripcionEuskera() + "\n";
							}
						}
					}
				}

				if (!relFacMotMinListAux.isEmpty()) {
					for (RelFacMotMin relFacMotMin : relFacMotMinListAux) {

						MotivosMinoracion motivoMinoracionFacturas = new MotivosMinoracion();
						List<MotivosMinoracion> listaMotivosMinoracionFacturas = new ArrayList<MotivosMinoracion>();

						if (relFacMotMin != null && relFacMotMin.getIdMotivoMinoracion() != null) {
							motivoMinoracionFacturas.setIdMotivoMinoracion(relFacMotMin.getIdMotivoMinoracion());
							listaMotivosMinoracionFacturas = this.motivosMinoracionService
									.findAll(motivoMinoracionFacturas, null);
						}

						for (MotivosMinoracion motivoMinoracionFacturasAux : listaMotivosMinoracionFacturas) {
							if (locale.getLanguage() == "es") {
								observaciones += motivoMinoracionFacturasAux.getDescripcionCastellano() + "\n";
							} else {
								observaciones += motivoMinoracionFacturasAux.getDescripcionEuskera() + "\n";
							}
						}

					}
				}

			}
		}

		if ((appMessageSource.getMessage("fexpediente.motivosMinoracion", null, locale) + "\n").equals(observaciones)) {
			observaciones = "";
		}

		marcarInspeccionable.setObservacionInspeccion(observaciones);

		model.addAttribute("inspeccionable", marcarInspeccionable);

		return "marcarInspeccionable";
	}

	@RequestMapping(value = "/enviarWS/{tipoInspeccion}", method = RequestMethod.POST)
	public @ResponseBody String enviarWS(@RequestBody MarcarInspeccionable marcarInspeccionable,
			@PathVariable Integer tipoInspeccion, @ModelAttribute(value = "usuario") Usuario usuario) {

		Usuario usuarioAux = new Usuario();
		usuarioAux.setNombreUsuario(usuario.getNombreUsuario());

		marcarInspeccionable.setUsuario(usuarioAux);

		marcarInspeccionable.setOrigenInspeccion(Constantes.ORIGEN_INSPECCION_AYUDAS);

		InspeccionWS objetoEnviarWebService = new InspeccionWS();
		List<DatosInspeccionWS> listaFacturas = new ArrayList<DatosInspeccionWS>();

		GregorianCalendar conversor = new GregorianCalendar();

		for (int i = 0; i < marcarInspeccionable.getFacturas().size(); i++) {

			marcarInspeccionable.getFacturas().get(i).setUsuarioUltmodificacion(usuarioAux.getNombreUsuario());

			DatosInspeccionWS facturas = new DatosInspeccionWS();

			if (marcarInspeccionable.getFacturas().get(i).getFechaFactura() != null) {
				conversor.setTime(marcarInspeccionable.getFacturas().get(i).getFechaFactura());

				try {
					XMLGregorianCalendar FechaXMLGregorian = DatatypeFactory.newInstance()
							.newXMLGregorianCalendar(conversor);

					facturas.setFechaFactura(FechaXMLGregorian);

				} catch (DatatypeConfigurationException e) {
					e.printStackTrace();
				}
			}

			facturas.setImporte(marcarInspeccionable.getFacturas().get(i).getImporte());
			facturas.setImporteAdmitido(marcarInspeccionable.getFacturas().get(i).getImporteAdmitido());
			facturas.setNumeroFactura(marcarInspeccionable.getFacturas().get(i).getNumeroFactura());
			facturas.setObservacionesCastellano(marcarInspeccionable.getFacturas().get(i).getObservacionesCastellano());
			facturas.setObservacionesEuskera(marcarInspeccionable.getFacturas().get(i).getObservacionesEuskera());
			facturas.setProveedor(marcarInspeccionable.getFacturas().get(i).getProveedor());
			facturas.setDescripcionCastellano(marcarInspeccionable.getFacturas().get(i).getDescripcionCastellano());
			facturas.setDescripcionEuskera(marcarInspeccionable.getFacturas().get(i).getDescripcionEuskera());

			listaFacturas.add(facturas);
		}

		for (int x = 0; x < listaFacturas.size(); x++) {
			objetoEnviarWebService.getDatosInspeccionWS().add(listaFacturas.get(x));
		}

		if (marcarInspeccionable != null && marcarInspeccionable.getFechaLimInspeccion() != null) {
			conversor.setTime(marcarInspeccionable.getFechaLimInspeccion());
			try {
				XMLGregorianCalendar FechaXMLGregorian = DatatypeFactory.newInstance()
						.newXMLGregorianCalendar(conversor);
				objetoEnviarWebService.setFechaLimiteInspeccion(FechaXMLGregorian);
			} catch (DatatypeConfigurationException e) {
				e.printStackTrace();
			}
		}

		objetoEnviarWebService.setObservacionesActuacionInspeccion(marcarInspeccionable.getObservacionInspeccion());
		objetoEnviarWebService.setTipoInspeccion(tipoInspeccion);

		PreguntasExpediente filterPreguntasExpediente = new PreguntasExpediente();
		filterPreguntasExpediente.setIdExpediente(marcarInspeccionable.getExpediente().getIdExpediente());
		filterPreguntasExpediente.setTipoInspeccion(tipoInspeccion);
		List<PreguntasExpediente> listaPreguntasExpediente = this.preguntasExpedienteService
				.findAll(filterPreguntasExpediente, null);

		List<PreguntasExpedienteWS> listaPreguntasExpedienteWS = new ArrayList<PreguntasExpedienteWS>();

		for (PreguntasExpediente preguntaExpediente : listaPreguntasExpediente) {
			PreguntasExpedienteWS preguntaExpedienteWS = new PreguntasExpedienteWS();

			preguntaExpedienteWS.setDescripcionCastellano(preguntaExpediente.getDescripcionCastellano());
			preguntaExpedienteWS.setDescripcionEuskera(preguntaExpediente.getDescripcionEuskera());
			preguntaExpedienteWS.setIdTipoPregunta(preguntaExpediente.getTipoPregunta());
			preguntaExpedienteWS.setOpcionesCastellano(preguntaExpediente.getOpcionesCastellano());
			preguntaExpedienteWS.setOpcionesEuskera(preguntaExpediente.getOpcionesEuskera());

			listaPreguntasExpedienteWS.add(preguntaExpedienteWS);
		}

		try {
			String respuesta = ab79WebServiceAdaptadorService.crearInspeccion(
					marcarInspeccionable.getExpediente().getFolderId(), objetoEnviarWebService,
					listaPreguntasExpedienteWS, usuarioAux, marcarInspeccionable.getOrigenInspeccion(), null, null,
					null, null, null);

			if (respuesta != null) {
				// Si va bien, guardar los datos en AB60
				respuesta = this.marcarInspeccionableService.guardarMarcarInspeccionable(marcarInspeccionable,
						tipoInspeccion, respuesta);
			}

			return respuesta;
		} catch (Ab79Exception e) {
			e.printStackTrace();
			MarcarInspeccionableController.logger.error("[enviarWS] - " + e.getMessage());
			return "error";
		}

	}

	@RequestMapping(value = "/tieneInspeccion/{idExpediente}/{tipoInspeccion}", method = RequestMethod.POST)
	public @ResponseBody RelExpIns tieneInspeccion(@PathVariable Integer idExpediente,
			@PathVariable Integer tipoInspeccion) {

		RelExpIns relExpIns = new RelExpIns();
		relExpIns.setIdExpediente(idExpediente);
		relExpIns.setTipoInspeccion(tipoInspeccion);

		relExpIns = this.relExpInsService.findByIdExpediente(relExpIns);

		return relExpIns;
	}

	@RequestMapping(value = "/actInspeccionable/{idExpediente}/{idConvocatoria}", method = RequestMethod.GET)
	public String actInspeccionable(@PathVariable Integer idExpediente, @PathVariable Integer idConvocatoria,
			Model model) {

		Locale locale = LocaleContextHolder.getLocale();

		Expedientes expediente = new Expedientes();
		expediente.setIdExpediente(idExpediente);
		expediente = this.expedienteService.find(expediente);

		MarcarInspeccionableAct marcarInspeccionableAct = new MarcarInspeccionableAct();
		marcarInspeccionableAct.setExpediente(expediente);
		marcarInspeccionableAct = this.marcarInspeccionableService.findInspeccionableAct(marcarInspeccionableAct);
		marcarInspeccionableAct.setExpediente(expediente);
		marcarInspeccionableAct.setFolderYTitulo(expediente.getFolderNumber() + " - " + expediente.getTitulo());

		String fecha = UtilDate.convertirFechaEnString(marcarInspeccionableAct.getFechaLimInspeccion());
		marcarInspeccionableAct.setFechaLimInspeccionStr(fecha);

		List<RelExpActSub> relExpActSubLista = new ArrayList<RelExpActSub>();
		relExpActSubLista = this.relExpActSubService.findRelEXpActSubPorExpedienteMET(idExpediente, idConvocatoria);

		String observaciones = "";

		RelExpIns relExpIns = new RelExpIns();
		relExpIns.setIdExpediente(idExpediente);
		relExpIns.setTipoInspeccion(Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO);

		relExpIns = this.relExpInsService.findByIdExpediente(relExpIns);

		if (relExpIns != null) {
			observaciones = marcarInspeccionableService.findDatosProyectoPorId(idExpediente,
					Constantes.TIPO_INSPECCION_ESTUDIO_TECNICO);
		} else {
			if (relExpActSubLista != null) {

				observaciones = appMessageSource.getMessage("fexpediente.motivosMinoracion", null, locale) + "\n";
				List<RelActSubMotMin> relActSubMotMinList = new ArrayList<RelActSubMotMin>();
				List<RelActSubMotMin> relActSubMotMinListAux = new ArrayList<RelActSubMotMin>();
				Integer origenMotivosMinoracion = Constantes.ORIGEN_EST_TECNICO_ACT_SUBV;

				for (RelExpActSub relExpActSub : relExpActSubLista) {
					if (relExpActSub.getIdRelExpActSub() != 0 || relExpActSub.getIdRelExpActSub() != null) {

						Integer idRelActSub = relExpActSub.getIdRelExpActSub();
						relActSubMotMinList = this.relActSubMotMinService.findIdsMotivosMinoraciones(idRelActSub,
								origenMotivosMinoracion);
						if (relActSubMotMinList.size() != 0) {
							for (RelActSubMotMin relActSubMotMin : relActSubMotMinList) {
								relActSubMotMinListAux.add(relActSubMotMin);
							}
						}
					}
				}

				if (relActSubMotMinListAux.size() != 0) {
					for (RelActSubMotMin relActSubMotMin : relActSubMotMinListAux) {

						MotivosMinoracion motivosMinoracion = new MotivosMinoracion();
						List<MotivosMinoracion> listaMotivosMinoracion = new ArrayList<MotivosMinoracion>();

						if (relActSubMotMin != null && relActSubMotMin.getIdMotivoMinoracion() != null) {
							motivosMinoracion.setIdMotivoMinoracion(relActSubMotMin.getIdMotivoMinoracion());
							listaMotivosMinoracion = this.motivosMinoracionService.findAll(motivosMinoracion, null);
						}

						for (MotivosMinoracion motivosMinoracionAux : listaMotivosMinoracion) {
							if (locale.getLanguage() == "es") {
								observaciones += motivosMinoracionAux.getDescripcionCastellano() + "\n";
							} else {
								observaciones += motivosMinoracionAux.getDescripcionEuskera() + "\n";
							}
						}
					}
				}
			}
		}

		if ((appMessageSource.getMessage("fexpediente.motivosMinoracion", null, locale) + "\n").equals(observaciones)) {
			observaciones = "";
		}

		marcarInspeccionableAct.setObservacionInspeccion(observaciones);

		model.addAttribute("inspeccionable", marcarInspeccionableAct);

		return "marcarInspeccionableAct";
	}

	@RequestMapping(value = "/enviarActWS/{tipoInspeccion}", method = RequestMethod.POST)
	public @ResponseBody String enviarActWS(@RequestBody MarcarInspeccionableAct marcarInspeccionable,
			@PathVariable Integer tipoInspeccion, @ModelAttribute(value = "usuario") Usuario usuario) {

		Usuario usuarioAux = new Usuario();
		usuarioAux.setNombreUsuario(usuario.getNombreUsuario());

		marcarInspeccionable.setUsuario(usuarioAux);

		marcarInspeccionable.setOrigenInspeccion(Constantes.ORIGEN_INSPECCION_AYUDAS);

		InspeccionWS objetoEnviarWebService = new InspeccionWS();

		for (int i = 0; i < marcarInspeccionable.getDatosInspeccionEnviarWS().size(); i++) {
			objetoEnviarWebService.getDatosInspeccionWS().add(marcarInspeccionable.getDatosInspeccionEnviarWS().get(i));
		}

		GregorianCalendar conversor = new GregorianCalendar();
		if (marcarInspeccionable != null && marcarInspeccionable.getFechaLimInspeccion() != null) {
			conversor.setTime(marcarInspeccionable.getFechaLimInspeccion());

			try {
				XMLGregorianCalendar FechaXMLGregorian = DatatypeFactory.newInstance()
						.newXMLGregorianCalendar(conversor);
				objetoEnviarWebService.setFechaLimiteInspeccion(FechaXMLGregorian);
			} catch (DatatypeConfigurationException e) {
				e.printStackTrace();
			}
		}

		objetoEnviarWebService.setObservacionesActuacionInspeccion(marcarInspeccionable.getObservacionInspeccion());
		objetoEnviarWebService.setTipoInspeccion(tipoInspeccion);

		PreguntasExpediente filterPreguntasExpediente = new PreguntasExpediente();
		filterPreguntasExpediente.setIdExpediente(marcarInspeccionable.getExpediente().getIdExpediente());
		filterPreguntasExpediente.setTipoInspeccion(tipoInspeccion);
		List<PreguntasExpediente> listaPreguntasExpediente = this.preguntasExpedienteService
				.findAll(filterPreguntasExpediente, null);

		List<PreguntasExpedienteWS> listaPreguntasExpedienteWS = new ArrayList<PreguntasExpedienteWS>();

		for (PreguntasExpediente preguntaExpediente : listaPreguntasExpediente) {
			PreguntasExpedienteWS preguntaExpedienteWS = new PreguntasExpedienteWS();

			preguntaExpedienteWS.setDescripcionCastellano(preguntaExpediente.getDescripcionCastellano());
			preguntaExpedienteWS.setDescripcionEuskera(preguntaExpediente.getDescripcionEuskera());
			preguntaExpedienteWS.setIdTipoPregunta(preguntaExpediente.getTipoPregunta());
			preguntaExpedienteWS.setOpcionesCastellano(preguntaExpediente.getOpcionesCastellano());
			preguntaExpedienteWS.setOpcionesEuskera(preguntaExpediente.getOpcionesEuskera());

			listaPreguntasExpedienteWS.add(preguntaExpedienteWS);
		}

		try {
			String respuesta = ab79WebServiceAdaptadorService.crearInspeccion(
					marcarInspeccionable.getExpediente().getFolderId(), objetoEnviarWebService,
					listaPreguntasExpedienteWS, usuarioAux, marcarInspeccionable.getOrigenInspeccion(), null, null,
					null, null, null);
			if (respuesta != null) {
				// Si va bien, guardar los datos en AB60
				respuesta = this.marcarInspeccionableService.guardarMarcarInspeccionableAct(marcarInspeccionable,
						respuesta);
			}
			return respuesta;
		} catch (Ab79Exception e) {
			e.printStackTrace();
			return "error";
		}

	}
}
