package com.ejie.ab60.control.expedientes;

import com.ejie.ab60.service.RelExpInsService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import com.ejie.ab60.model.RelExpIns;

/**
 * RelExpInsController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/relexpins")

public class RelExpInsController {

	private static final Logger logger = LoggerFactory.getLogger(RelExpInsController.class);

	@Autowired
	private RelExpInsService relExpInsService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelExpIns
	 *            Integer
	 * @return RelExpIns Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelExpIns}", method = RequestMethod.GET)
	public @ResponseBody RelExpIns get(@PathVariable Integer idRelExpIns) {
		RelExpIns relExpIns = new RelExpIns();
		relExpIns.setIdRelExpIns(idRelExpIns);
		relExpIns = this.relExpInsService.find(relExpIns);
		RelExpInsController.logger.info("[GET - findBy_PK] : Obtener RelExpIns por PK");
		return relExpIns;
	}

	@RequestMapping(value = "findByIdentificadorInspeccion/{identificadorInspeccion}", method = RequestMethod.GET)
	public @ResponseBody RelExpIns findByIdentificadorInspeccion(@PathVariable String identificadorInspeccion) {
		RelExpIns relExpIns = new RelExpIns();
		relExpIns.setIdentificadorInspeccion(identificadorInspeccion);
		relExpIns = this.relExpInsService.findByIdentificadorInspeccion(relExpIns);
		RelExpInsController.logger.info("[GET - findBy_PK] : Obtener RelExpIns por identificadorInspeccion");
		return relExpIns;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelExpIns
	 *            RelExpIns Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelExpIns> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelExpIns> getAll(@ModelAttribute RelExpIns filterRelExpIns) {
		RelExpInsController.logger.info("[GET - find_ALL] : Obtener RelExpIns por filtro");
		return this.relExpInsService.findAll(filterRelExpIns, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpIns
	 *            RelExpIns Bean que contiene la informacion a modificar.
	 * @return RelExpIns Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelExpIns edit(@RequestBody RelExpIns relExpIns) {
		RelExpIns relExpInsAux = this.relExpInsService.update(relExpIns);
		RelExpInsController.logger.info("[PUT] : RelExpIns actualizado correctamente");
		return relExpInsAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relExpIns
	 *            RelExpIns Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return RelExpIns Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelExpIns add(@RequestBody RelExpIns relExpIns) {
		RelExpIns relExpInsAux = this.relExpInsService.add(relExpIns);
		RelExpInsController.logger.info("[POST] : RelExpIns insertado correctamente");
		return relExpInsAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelExpIns
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return RelExpIns Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelExpIns}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelExpIns remove(@PathVariable Integer idRelExpIns) {
		RelExpIns relExpIns = new RelExpIns();
		relExpIns.setIdRelExpIns(idRelExpIns);
		this.relExpInsService.remove(relExpIns);
		RelExpInsController.logger.info("[DELETE] : RelExpIns borrado correctamente");
		return relExpIns;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelExpInsController.logger.info("[GET - View] : relexpins");
		return "relexpins";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelExpIns
	 *            RelExpIns Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelExpIns> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelExpIns> filter(
			@RequestJsonBody(param = "filter") RelExpIns filterRelExpIns,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpInsController.logger.info("[POST - filter] : Obtener RelExpInss");
		return this.relExpInsService.filter(filterRelExpIns, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelExpIns
	 *            RelExpIns Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelExpIns
	 *            RelExpIns Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelExpIns> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelExpIns>> search(
			@RequestJsonBody(param = "filter") RelExpIns filterRelExpIns,
			@RequestJsonBody(param = "search") RelExpIns searchRelExpIns,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpInsController.logger.info("[POST - search] : Buscar RelExpInss");
		return this.relExpInsService.search(filterRelExpIns, searchRelExpIns, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelExpIns
	 *            RelExpIns Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelExpIns filterRelExpIns,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpInsController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelExpInss");
		this.relExpInsService.removeMultiple(filterRelExpIns, jqGridRequestDto, false);
		RelExpInsController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelExpIns
	 *            RelExpIns Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpIns>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpIns>> jerarquia(
			@RequestJsonBody(param = "filter") RelExpIns filterRelExpIns,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpInsController.logger.info("[POST - jerarquia] : Obtener RelExpInss jerarquia");
		return this.relExpInsService.jerarquia(filterRelExpIns, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelExpIns
	 *            RelExpIns Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelExpIns>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelExpIns>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelExpIns filterRelExpIns,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelExpInsController.logger.info("[POST - jerarquia] : Obtener RelExpInss jerarquia - Hijos");
		return this.relExpInsService.jerarquiaChildren(filterRelExpIns, jqGridRequestDto);
	}

	@RequestMapping(value = "/obtenerId/{identificadorInspeccion}", method = RequestMethod.GET)
	public @ResponseBody Integer obtenerId(@PathVariable String identificadorInspeccion) {
		RelExpInsController.logger.info("[GET] : Obtener ID: " + identificadorInspeccion);

		return this.relExpInsService.obtenerID(identificadorInspeccion);
	}

}
