package com.ejie.ab60.control.inicio;

import java.util.List;
import java.util.Locale;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.i18n.CookieLocaleResolver;
import org.springframework.web.servlet.support.RequestContextUtils;

import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderList;
import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.SeguridadAplicacion;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.MEC.Participantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.terceros.VistaDatosExpediente;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.BEC.PuntuacionesService;
import com.ejie.ab60.service.MEC.ParticipantesService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.ab60.service.terceros.RelExpTerService;
import com.ejie.ab60.util.UtilDate;

/**
 * Acceso a la aplicacion
 * 
 *  
 */
@Controller()
@SessionAttributes("usuario")
@RequestMapping(value = "/inicio")
public class InitController {

	private static final Logger logger = LoggerFactory.getLogger(InitController.class);

	@Autowired
	private ConvocatoriasService convocatoriasService;

	@Autowired
	private ProcedimientosService procedimientosService;

	@Autowired
	private RelExpTerService relExpTerService;

	@Autowired
	private ParticipantesService participantesService;

	@Autowired
	private ExpedientesService expedientesService;

	@Autowired
	private PuntuacionesService puntuacionesService;

	/**
	 * Method 'initApp' metodo de entrada a la aplicacion
	 * 
	 * @param httpRequest
	 *            HttpServletRequest
	 * @param procedureId
	 *            String
	 * @param folderId
	 *            String
	 * @param folderNumber
	 *            String
	 * @param fechaSolicitud
	 *            String
	 * @param folderDescription
	 *            String
	 * @param dni
	 *            String
	 * @param tipoExpediente
	 *            String
	 * @param tramite
	 *            String
	 * @param tarea
	 *            String
	 * @param idioma
	 *            String
	 * @param model
	 *            Model
	 * 
	 * @return ModelAndView
	 * @throws Exception
	 */
	@RequestMapping(method = RequestMethod.POST)
	public ModelAndView postAccess(HttpServletRequest httpRequest, HttpServletResponse response,
			@RequestParam(value = "procedureId") String procedureId, @RequestParam(value = "folderId") String folderId,
			@RequestParam(value = "folderNumber") String folderNumber,
			@RequestParam(value = "fechaSolicitud") String fechaSolicitud,
			@RequestParam(value = "folderDescription") String folderDescription,
			@RequestParam(value = "dni") String dni, @RequestParam(value = "expConv") String tipoExpediente,
			@RequestParam(value = "tramite") String tramite, @RequestParam(value = "tarea") String tarea,
			@RequestParam(value = "idioma") String idioma, Model model) throws Exception {
		InitController.logger.info("[POST - INICIO] Acceso a la aplicacion por Init Con datos: ");

		// Comprobamos que el usuario tiene acceso a la convocatoria
		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setCodProcedureId(procedureId);
		procedimientos = this.procedimientosService.findProc(procedimientos);

		// Se cambia el idioma para que se entre en la aplicacion con el que
		// llega como parametro
		Locale locale = new Locale(idioma);
		LocaleContextHolder.setLocale(locale);
		// Sobreescribir cookie
		((CookieLocaleResolver) RequestContextUtils.getLocaleResolver(httpRequest)).setLocale(httpRequest, response,
				locale);

		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		InitController.logger.info("autotenticación:getAuthentication" + aut);

		/** Dejamos el usuario logueado en session */
		Usuario usuario = new Usuario();
		String username = "";
		if (null != aut) {

			username = (String) aut.getPrincipal();
		}

		usuario.setNombreUsuario(username);
		model.addAttribute("usuario", usuario);

		InitForm init = this.guardarDatosTramitagune(procedureId, folderId, folderNumber, fechaSolicitud,
				folderDescription, dni, tipoExpediente, tramite, tarea, idioma, procedimientos);

		return this.getAccess(httpRequest, model, init, usuario);

	}

	private InitForm guardarDatosTramitagune(String procedureId, String folderId, String folderNumber,
			String fechaSolicitud, String folderDescription, String dni, String tipoExpediente, String tramite,
			String tarea, String idioma, Procedimientos procedimientos) {
		InitController.logger.info("[procedureId = " + procedureId + ", folderId = " + folderId + ", folderNumber = "
				+ folderNumber + ", fechaSolicitud = " + fechaSolicitud + ", folderDescription = " + folderDescription
				+ ", dni = " + dni + ", tramite = " + tramite + ", tarea = " + tarea + ", tipoExpediente = "
				+ tipoExpediente + ", idioma = " + idioma);

		InitForm datosTramitagune = new InitForm();
		datosTramitagune.setProcedureId(procedureId);
		datosTramitagune.setFolderId(folderId);
		datosTramitagune.setFolderNumber(folderNumber);
		datosTramitagune.setFechaSolicitud(fechaSolicitud);
		datosTramitagune.setFolderDescription(folderDescription);
		datosTramitagune.setDni(dni);
		datosTramitagune.setTramite(tramite);
		datosTramitagune.setTarea(tarea);
		datosTramitagune.setTipoExpediente(tipoExpediente);
		datosTramitagune.setIdioma(idioma);

		Procedimientos procedimiento = new Procedimientos();
		procedimiento.setIdProcedimiento(procedimientos.getIdProcedimiento());
		procedimiento = this.procedimientosService.findInspeccionable(procedimiento);
		if (procedimiento != null && procedimiento.getInspeccionable() != null) {
			datosTramitagune.setInspeccionable(procedimiento.getInspeccionable());
		}

		Integer idExpediente = this.procedimientosService.findIdExpedientePorFolderId(folderId);

		if (idExpediente != null) {
			Integer idActSubPadre = this.procedimientosService.findIdActSubPadre(idExpediente);

			if (idActSubPadre != null) {
				datosTramitagune.setInitIdActSubPadre(idActSubPadre);
			}
		}

		return datosTramitagune;
	}

	private ModelAndView initConvocatoria(Procedimientos procedimientos, Model model, InitForm datosTramitagune) {

		// buscar en la tabla convocatorias si existe la convocatoria

		Convocatorias convocatorias = new Convocatorias();
		convocatorias.setIdProcedimiento(procedimientos.getIdProcedimiento());

		if (convocatorias.getIdProcedimiento() != null) {
			convocatorias = this.convocatoriasService.findProc(convocatorias);
			String fechaResolucion = UtilDate.convertirFechaEnString(convocatorias.getFechaResolucion());
			convocatorias.setFechaResolucionStr(fechaResolucion);
			convocatorias.setDescripcionEs(procedimientos.getDescripcionEs());
			convocatorias.setDescripcionEu(procedimientos.getDescripcionEu());
			convocatorias.setCodProcedureId(datosTramitagune.getProcedureId());
			model.addAttribute("datosConv", convocatorias);

			datosTramitagune.setIdConvocatoria(convocatorias.getIdConvocatoria());
			datosTramitagune.setTipoAyuda(convocatorias.getIdTipoAyuda());

			// Comprobamos que el usuario tiene acceso a la convocatoria
			procedimientos = this.procedimientosService.find(procedimientos);

			// Si no tiene acceso redireccionamos a la pagina de error
			if (!SeguridadAplicacion.validarAccesoProcedimiento(procedimientos))
				return new ModelAndView("accessDenied");

		} else {
			convocatorias.setIdTipoConvocatoria(Long.parseLong("2"));
			convocatorias = this.convocatoriasService.add(convocatorias);
			model.addAttribute("datosConv", convocatorias);
			datosTramitagune.setIdConvocatoria(convocatorias.getIdConvocatoria());
			datosTramitagune.setTipoAyuda(convocatorias.getIdTipoAyuda());
		}

		model.addAttribute("procedimiento", procedimientos);
		return new ModelAndView("convocatorias", "model", model);

	}

	@RequestMapping(method = RequestMethod.GET)
	private ModelAndView getAccess(HttpServletRequest httpRequest, Model model, InitForm datosTramitagune,
			Usuario usuario) throws Exception {

		InitController.logger.info("[INICIO] Acceso a la aplicacion por Init");

		model.addAttribute("initForm", datosTramitagune);
		if ((datosTramitagune.getFolderNumber() == null || "".equals(datosTramitagune.getFolderNumber()))
				&& !datosTramitagune.getTipoExpediente()
						.equalsIgnoreCase(com.ejie.ab60.comun.Constantes.CONVOCATORIA)) {
			InitController.logger.info("[INICIO] No hay un FolderNumber valido.");
			return new ModelAndView("folderError");
		}
		if (datosTramitagune.getTipoExpediente().equalsIgnoreCase(com.ejie.ab60.comun.Constantes.CONVOCATORIA)) {

			Procedimientos procedimientos = new Procedimientos();
			procedimientos.setCodProcedureId(datosTramitagune.getProcedureId());
			procedimientos = this.procedimientosService.findProc(procedimientos);

			return this.initConvocatoria(procedimientos, model, datosTramitagune);

		} else {

			// Guardar IDCONVOCATORIA en la sesion de USUARIO para no perder los
			// datos desde expediente

			Convocatorias convocatorias = new Convocatorias();
			Procedimientos procedimientos = new Procedimientos();
			procedimientos.setCodProcedureId(datosTramitagune.getProcedureId());
			procedimientos = this.procedimientosService.findProc(procedimientos);
			convocatorias.setIdProcedimiento(procedimientos.getIdProcedimiento());
			convocatorias = this.convocatoriasService.findProc(convocatorias);
			datosTramitagune.setIdConvocatoria(convocatorias.getIdConvocatoria());
			datosTramitagune.setTipoAyuda(convocatorias.getIdTipoAyuda());
			datosTramitagune.setIdProcedimientoExpediente(procedimientos.getIdProcedimiento());

			/*********************************************************************/

			Expedientes expedientes = new Expedientes();
			expedientes.setFolderId(datosTramitagune.getFolderId());

			expedientes = this.expedientesService.findByFolderId(expedientes);
			if (expedientes == null) {
				return new ModelAndView("folderNoExiste");
			} else {

				datosTramitagune.setIdExpediente(expedientes.getIdExpediente());
				datosTramitagune.setTituloExpediente(expedientes.getTitulo());

				Expedientes expedienteFilter = new Expedientes();

				expedientes.setFolderNumber(datosTramitagune.getFolderNumber());
				expedientes.setFolderId(datosTramitagune.getFolderId());
				expedienteFilter = this.expedientesService.updateFolder(expedientes);

				expedienteFilter.setIdExpediente(datosTramitagune.getIdExpediente());
				return this.initExpedientes(procedimientos, model, datosTramitagune, usuario);

			}

		}
	}

	/**
	 * 
	 * @param httpRequest
	 *            HttpServletRequest
	 * @param model
	 *            Model
	 * @param datosTramitagune
	 *            InitForm
	 * 
	 * @return ModelAndView
	 * @throws Exception
	 */
	@RequestMapping(value = "/initCambioIdioma", method = RequestMethod.POST)
	public ModelAndView initCambioIdioma(HttpServletRequest httpRequest, Model model, InitForm datosTramitagune,
			Usuario usuario) throws Exception {

		InitController.logger.info("[INICIO initCambioIdioma] Cambio de idioma.");

		return this.getAccess(httpRequest, model, datosTramitagune, usuario);

	}

	private ModelAndView initExpedientes(Procedimientos procedimientos, Model model, InitForm datosTramitagune,
			Usuario usuario) throws Exception {

		String idioma = LocaleContextHolder.getLocale().getLanguage();
		InitController.logger
				.info("[INICIO] Buscando terceros con NumExpediente " + datosTramitagune.getIdExpediente());

		if (null != datosTramitagune.getIdExpediente()) {

			// Comprobamos que el usuario tiene acceso a la expedientes
			procedimientos = this.procedimientosService.find(procedimientos);

			// Si no tiene acceso redireccionamos a la pagina de error
			if (!SeguridadAplicacion.validarAccesoProcedimiento(procedimientos))
				return new ModelAndView("accessDenied");

			Integer idExpediente = datosTramitagune.getIdExpediente();
			TFolderList resultado = expedientesService.obtenerInfoPlatea(datosTramitagune.getFolderId());

			if (null != resultado) {
				try {
					// // Actualizamos el titulo de expediente.
					this.expedientesService.actualizarTituloExpediente(resultado, usuario, datosTramitagune);

					// // Lista de personas de la Participacion
					relExpTerService.actualizarListParticipantesPorParticipacion(resultado, idExpediente, usuario,
							datosTramitagune);
					model.addAttribute("flagSearchFolder", true);
				} catch (Exception e) {

					InitController.logger.error(e.getMessage());
					model.addAttribute("flagSearchFolder", false);
				}
			} else {
				// el flag es false cuando ha fallado el servicio para
				// buscar
				// solicitantes y titulares
				model.addAttribute("flagSearchFolder", false);
			}
			// Primero obtengo la lista de participaciones de mi BBDD, ya
			// actualiza previamente desde el webService
			List<VistaDatosExpediente> listaParticipantesParticipacion = relExpTerService
					.findParticipaciones(idExpediente, true);
			InitController.logger.info("[INICIO] Participantes " + listaParticipantesParticipacion.size()
					+ " para el expediente : " + datosTramitagune.getIdExpediente());

			Integer idTercero = 0;

			// Sacamos el idTercero del solicitante titular
			for (int i = 0; i < listaParticipantesParticipacion.size(); i++) {
				if (i == 0) {
					model.addAttribute("listaSearch", listaParticipantesParticipacion.get(0).getVistaTercerosList());
					/// Sacamos el id tercero del solicitante titular
					for (int k = 0; k < listaParticipantesParticipacion.get(0).getVistaTercerosList().size(); k++) {
						if (null != listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
								.getIdTipoTercero()) {
							if (listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k).getIdTipoTercero()
									.compareTo(Constantes.PARTICIPACION_SOLICITANTE) == 0) {
								for (int h = 0; h < listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
										.getDatosTercerosList().size(); h++) {

									if (listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
											.getDatosTercerosList().get(h).getTipoParticipante()
											.compareTo(Constantes.PARTICIPANTE_TITULAR) == 0) {
										idTercero = listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
												.getDatosTercerosList().get(h).getIdTercero();

									}

								}

							}

						}
					}
				} else if (i == 1) {
					if (listaParticipantesParticipacion.get(1).getVistaTercerosList().size() > 0) {
						for (int h = 0; h < listaParticipantesParticipacion.get(1).getVistaTercerosList().get(0)
								.getListaDirecciones().size(); h++) {
							int resul = listaParticipantesParticipacion.get(1).getVistaTercerosList().get(0)
									.getListaDirecciones().get(h).getTiposDireccion().getIdTipoDireccion()
									.compareTo(Constantes.ID_DIRECCION_SOLICITANTE);
							if (resul == 0) {
								model.addAttribute("listaDomicilio", listaParticipantesParticipacion.get(1)
										.getVistaTercerosList().get(0).getListaDirecciones().get(h));
							} else {
								model.addAttribute("listaUbicacion", listaParticipantesParticipacion.get(1)
										.getVistaTercerosList().get(0).getListaDirecciones().get(h));
							}

						}
					}
				} else if (i == 2)
					if (listaParticipantesParticipacion.get(1).getVistaTercerosList().size() > 0) {
						model.addAttribute("listaBBDD", listaParticipantesParticipacion.get(2).getVistaTercerosList());
					}
			}
			InitController.logger.info("[INICIO] Participantes id tercero para comunidad bienes:" + idTercero);
			// le pasamos el idTercero a la comudidad de bienes
			if (idTercero != null) {
				List<Participantes> listaParticipantes = this.participantesService.find(idTercero);
				InitController.logger.info("[INICIO] Participantes " + listaParticipantes.size()
						+ " para el expediente : " + datosTramitagune.getIdExpediente());
				model.addAttribute("txtComunidadBienes", listaParticipantes);
			}
			if (datosTramitagune.getTipoAyuda() == Constantes.TIPO_AYUDA_BEC) {
				Puntuaciones puntuacion = new Puntuaciones();
				puntuacion.setIdExpediente(datosTramitagune.getIdExpediente());
				Puntuaciones requisitos = this.puntuacionesService.findRequisitos(puntuacion);
				model.addAttribute("txtRequisitos", requisitos);
			}
			model.addAttribute("idTercero", idTercero);
			Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
			model.addAttribute("urlab61", prop.getProperty("URLAB61"));
			model.addAttribute("ab61_folderID", datosTramitagune.getFolderId());

			Integer idConvocatoria = datosTramitagune.getIdConvocatoria();
			String nombreExpediente = datosTramitagune.getFolderNumber();
			String tituloExpediente = datosTramitagune.getTituloExpediente();

			Procedimientos procedimiento = this.procedimientosService
					.find(new Procedimientos(datosTramitagune.getIdProcedimientoExpediente()));
			if (procedimiento != null) {
				model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
			}

			model.addAttribute("idConvocatoria", idConvocatoria);
			model.addAttribute("nombreExpediente", nombreExpediente);
			model.addAttribute("tituloExpediente", tituloExpediente);

			String url = prop.getProperty("urlVerDocumento");
			url = url.replace("[folderID]", datosTramitagune.getFolderId());
			model.addAttribute("urlVerDocumentos", url);
			model.addAttribute("lenguaje", idioma);
			return new ModelAndView("datosExpediente", "model", model);
		} else {
			return new ModelAndView("folderError");
		}

	}

}
