package com.ejie.ab60.control.justificacion;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Properties;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.dao.actuacionesSubvencionables.ActSubvencionableDao;
import com.ejie.ab60.dao.actuacionesSubvencionables.RelExpActSubDao;
import com.ejie.ab60.model.OtrosIngresos;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotDen;
import com.ejie.ab60.model.actuacionesSubvencionables.RelActSubMotMin;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.justificacion.Justificacion;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.OtrosIngresosService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubMotDenService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelActSubMotMinService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.calculoAyuda.CalculoAyudaService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.ab60.service.justificacion.JustificacionService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.ab60.util.UtilDate;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.reports.ReportData;

/**
 * JustificacionController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/justificacion")

public class JustificacionController {

	private static final Logger logger = LoggerFactory.getLogger(JustificacionController.class);

	@Autowired
	private JustificacionService justificacionService;

	@Autowired
	private ConvocatoriasService convocatoriasService;

	@Autowired
	private CalculoAyudaService calculoAyudaService;

	@Autowired
	private ActSubvencionableDao actSubvencionableDao;

	@Autowired
	private RelExpActSubDao relExpActSubDao;

	@Autowired
	private RelActSubMotDenService relActSubMotDenService;

	@Autowired
	private RelActSubMotMinService relActSubMotMinService;

	@Autowired
	private RelExpActSubService relExpActSubService;

	@Autowired
	private OtrosIngresosService otrosIngresosService;

	@Autowired
	private ExpedientesService expedientesService;

	@Autowired
	private ProcedimientosService procedimientosService;

	@Resource
	private ReloadableResourceBundleMessageSource appMessageSource;

	/**
	 * Cargar la vista calculo de ayuda
	 * 
	 * @param model
	 *            Model
	 * @param request
	 *            request
	 * 
	 * @return ModelAndView
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String init(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {

		String idioma = LocaleContextHolder.getLocale().getLanguage();
		Integer idExpediente = initForm.getIdExpediente();
		Integer idConvocatoria = initForm.getIdConvocatoria();
		String expediente = initForm.getFolderNumber();

		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Justificacion justificacionAux = new Justificacion();
		Justificacion justificacion = new Justificacion();
		justificacionAux.setIdExpediente(idExpediente);
		justificacionAux.setIdConvocatoria(idConvocatoria);
		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);
		convocatoria = convocatoriasService.find(convocatoria);
		Long tipoConvocatoria = convocatoria.getIdTipoConvocatoria();
		if (tipoConvocatoria == Constantes.ID_TIPO_NO_CONCURSAL) {
			model.addAttribute("noConcursal", tipoConvocatoria);
		}

		justificacion = this.justificacionService.find(justificacionAux);

		JustificacionController.logger.info("[GET - findBy_PK] : Obtener Justificacion por PK");

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}
		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("lenguaje", idioma);
		model.addAttribute("idExpediente", idExpediente);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);
		model.addAttribute("Expediente", expediente);
		model.addAttribute("origenInspeccion", Constantes.ORIGEN_INSPECCION_JUSTIFICACION_TECNICO);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		if (justificacion == null) {
			model.addAttribute("datosExpediente", new Justificacion());
		} else {

			model.addAttribute("idInspeccion", justificacion.getRelExpIns().getIdInspeccion());
			String fechaInf = UtilDate.convertirFechaEnString(justificacion.getFechaInformeJus());
			justificacion.setFechaInformeStr(fechaInf);
			model.addAttribute("datosExpediente", justificacion);
		}

		if (convocatoria.getIdTipoAyuda() != Constantes.TIPO_AYUDA_OTC) {
			return "justificacion";
		} else {
			return "justificacionOTC";
		}
	}

	@SuppressWarnings("null")
	@RequestMapping(value = "/facturas/{idExpediente}/{idConvocatoria}/{idRelExpActSub}/{idActSub}", method = RequestMethod.GET)
	public String facturasModal(Model model, @PathVariable Integer idExpediente, @PathVariable Integer idConvocatoria,
			@PathVariable Integer idRelExpActSub, @PathVariable Integer idActSub) {

		String idioma = LocaleContextHolder.getLocale().getLanguage();

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);
		convocatoria = convocatoriasService.find(convocatoria);
		Long tipoConvocatoria = convocatoria.getIdTipoConvocatoria();
		if (tipoConvocatoria == Constantes.ID_TIPO_NO_CONCURSAL) {
			model.addAttribute("noConcursal", tipoConvocatoria);
		}

		ActSubvencionable actSubvencionableDao = new ActSubvencionable();

		actSubvencionableDao.setIdActSub(idActSub);
		ActSubvencionable listaRelFacActSubvencionables = this.actSubvencionableDao.find(actSubvencionableDao);

		RelExpActSub relExpActSub = new RelExpActSub();

		relExpActSub.setIdRelExpActSub(idRelExpActSub);
		RelExpActSub listaRelExpActSubvencionables = this.relExpActSubDao.findJustificacion(relExpActSub);

		if (idioma == "es") {
			model.addAttribute("descripcion", listaRelFacActSubvencionables.getDescripcionCastellano());
		} else {
			model.addAttribute("descripcion", listaRelFacActSubvencionables.getDescripcionEuskera());
		}

		RelActSubMotDen relActSubMotDen = new RelActSubMotDen();
		relActSubMotDen.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		List<RelActSubMotDen> listaRelActSubMotDen = this.relActSubMotDenService.findAll(relActSubMotDen, null);

		List<Long> idsDenegacion = new ArrayList<Long>();

		if (listaRelActSubMotDen.size() != 0) {
			for (int x = 0; x < listaRelActSubMotDen.size(); x++) {
				idsDenegacion.add(listaRelActSubMotDen.get(x).getIdMotivoDenegacion());
			}
		}

		RelActSubMotMin relActSubMotMin = new RelActSubMotMin();
		relActSubMotMin.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		relActSubMotMin.setOrigen(Constantes.ORIGEN_DENEGACION_MINORACION_ACTSUBVENCIONABLE_JUS);
		List<RelActSubMotMin> listaRelActSubMotMin = this.relActSubMotMinService.findAll(relActSubMotMin, null);

		List<Long> idsMinoracion = new ArrayList<Long>();

		if (listaRelActSubMotMin.size() != 0) {
			for (int x = 0; x < listaRelActSubMotMin.size(); x++) {
				idsMinoracion.add(listaRelActSubMotMin.get(x).getIdMotivoMinoracion());
			}
		}

		OtrosIngresos otrosIngresos = new OtrosIngresos();
		otrosIngresos.setIdRelExpActSub(relExpActSub.getIdRelExpActSub());
		otrosIngresos.setFase(Constantes.FASE_JUSTIFICACION);
		otrosIngresos = this.otrosIngresosService.findByIdRelExpActSub(otrosIngresos);
		if (otrosIngresos != null) {
			model.addAttribute("otrosIngresos", otrosIngresos.getImporte());
		}

		model.addAttribute("comboDenegacion", idsDenegacion);
		model.addAttribute("comboMinoracion", idsMinoracion);

		model.addAttribute("notas", listaRelExpActSubvencionables.getNotas());
		model.addAttribute("obCastellano", listaRelExpActSubvencionables.getObservacionesCastellano());
		model.addAttribute("obEuskera", listaRelExpActSubvencionables.getObservacionesEuskera());

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("lenguaje", idioma);
		model.addAttribute("idExpediente", idExpediente);
		model.addAttribute("idRelExpActSub", idRelExpActSub);
		model.addAttribute("idActSub", idActSub);
		model.addAttribute("origenInspeccion", Constantes.ORIGEN_INSPECCION_JUSTIFICACION_TECNICO);

		return "facturasModal";
	}

	/**
	 * Metod para hacer un update de justificacion
	 * 
	 * @param tercero
	 * @return Justificacion Bean resultante del proceso de creacion
	 */
	@RequestMapping(value = "/save/{idExpediente}/{idConvocatoria}", method = RequestMethod.POST)
	public @ResponseBody() Justificacion saveJustificacion(@RequestBody() Justificacion justificacion,
			@ModelAttribute(value = "usuario") Usuario usuario, @PathVariable Integer idExpediente,
			@PathVariable Integer idConvocatoria) throws Exception {
		JustificacionController.logger.info("entrar en save");
		return this.justificacionService.saveJustificacion(justificacion, usuario, idExpediente, idConvocatoria);

	}

	/**
	 * Actualiza los importe de expediente una vez que le damos al boton de
	 * calcular ayuda
	 *
	 * 
	 * @param idExpediente
	 *            Integer
	 * @return justificacion Obj justificacion
	 */
	@RequestMapping(value = "/refrescar/{idExpediente}", method = RequestMethod.GET)
	public @ResponseBody Justificacion refrescarImportes(@PathVariable Integer idExpediente) {

		Justificacion justificacion = new Justificacion();
		justificacion.setIdProyectoExpediente(idExpediente);

		justificacion = this.justificacionService.refescarImportes(idExpediente);
		JustificacionController.logger
				.info("[GET - findBy_PK] : Obtener todo los Totales de todo de Justificacion por PK");
		return justificacion;
	}

	/**
	 * Metodo que llama al pl-sql de calcular ayuda
	 *
	 * 
	 * @param idConvocatoria
	 * 
	 * @param idExpediente
	 * @return Msg
	 */
	@RequestMapping(value = "/llamarPLSQL/{idConvocatoria}/{idExpediente}", method = RequestMethod.GET)
	public @ResponseBody() String calcularAyuda(@PathVariable Integer idConvocatoria,
			@PathVariable Integer idExpediente) throws Exception {

		JustificacionController.logger.info("[GET - llamarPLSQL] : Obtener PL DE AYUDA");
		int inFase = 2;
		return calculoAyudaService.calculoAyuda(idConvocatoria, idExpediente, inFase);
	}

	@RequestMapping(value = { "/xlsReport/{idConvocatoria}/{idExpedientes}",
			"/xlsxReport/{idConvocatoria}/{idExpedientes}" }, method = RequestMethod.POST)
	protected ModelAndView getExcelPOI(@ModelAttribute RelExpActSub filterActSub,
			@ModelAttribute JQGridRequestDto jqGridRequestDto, ModelMap modelMap, @PathVariable Integer idConvocatoria,
			@PathVariable Integer idExpedientes, @RequestParam(value = "columns", required = false) String columns,
			HttpServletRequest request) {

		Locale locale = LocaleContextHolder.getLocale();

		filterActSub.setIdExpediente(idExpedientes);
		filterActSub.setIdconvocatoria(idConvocatoria);

		Convocatorias convocatoria = new Convocatorias();
		convocatoria.setIdConvocatoria(idConvocatoria);

		Expedientes expediente = new Expedientes();
		expediente.setIdExpediente(idExpedientes);
		expediente = this.expedientesService.find(expediente);

		convocatoria = convocatoriasService.find(convocatoria);

		List<RelExpActSub> listProgramasAll = null;

		jqGridRequestDto.setPage(null);
		jqGridRequestDto.setRows(null);

		// Hoja 1
		ReportData<Expedientes> usuarioExcelDataAll = new ReportData<Expedientes>();

		if (locale.getLanguage() == "es") {
			columns = "[['descEs','" + appMessageSource.getMessage("excel.concepto", null, locale) + "']"
					+ ",['importePresentado','" + appMessageSource.getMessage("excel.presentado", null, locale) + "']"
					+ ",['importeAdmitido','" + appMessageSource.getMessage("excel.admitido", null, locale) + "']"
					+ ",['importeJustPresentado','"
					+ appMessageSource.getMessage("excel.importeJustPresentado", null, locale) + "']"
					+ ",['importeJustAdmitido','"
					+ appMessageSource.getMessage("excel.importeJustAdmitido", null, locale) + "']"
					+ ",['porcentajeJus','" + appMessageSource.getMessage("excel.porcentajeJus", null, locale) + "']"
					+ ",['importe','" + appMessageSource.getMessage("excel.importe", null, locale) + "']" + "]";
		} else {
			columns = "[['descEus','" + appMessageSource.getMessage("excel.concepto", null, locale) + "']"
					+ ",['importePresentado','" + appMessageSource.getMessage("excel.presentado", null, locale) + "']"
					+ ",['importeAdmitido','" + appMessageSource.getMessage("excel.admitido", null, locale) + "']"
					+ ",['importeJustPresentado','"
					+ appMessageSource.getMessage("excel.importeJustPresentado", null, locale) + "']"
					+ ",['importeJustAdmitido','"
					+ appMessageSource.getMessage("excel.importeJustAdmitido", null, locale) + "']"
					+ ",['porcentajeJus','" + appMessageSource.getMessage("excel.porcentajeJus", null, locale) + "']"
					+ ",['importe','" + appMessageSource.getMessage("excel.importe", null, locale) + "']" + "]";
		}

		listProgramasAll = relExpActSubService.filterJustificacionTer(filterActSub, jqGridRequestDto, false);

		switch (convocatoria.getIdTipoAyuda()) {
		case Constantes.TIPO_AYUDA_CTP:
			// nombre hoja
			usuarioExcelDataAll
					.setSheetName(appMessageSource.getMessage("usuarioExcel.justificacionCTP", null, locale));
			break;
		case Constantes.TIPO_AYUDA_DEC:
			// nombre hoja
			usuarioExcelDataAll
					.setSheetName(appMessageSource.getMessage("usuarioExcel.justificacionDEC", null, locale));
			break;
		case Constantes.TIPO_AYUDA_EMET:
			// nombre hoja
			usuarioExcelDataAll
					.setSheetName(appMessageSource.getMessage("usuarioExcel.justificacionEMET", null, locale));
			break;
		case Constantes.TIPO_AYUDA_PTT:
			// nombre hoja
			usuarioExcelDataAll
					.setSheetName(appMessageSource.getMessage("usuarioExcel.justificacionPTT", null, locale));
			break;
		case Constantes.TIPO_AYUDA_OTC:
			// nombre hoja
			usuarioExcelDataAll
					.setSheetName(appMessageSource.getMessage("usuarioExcel.justificacionOTC", null, locale));
			break;
		default:
			break;
		}

		String nombreFichero = null;
		if (locale.getLanguage() == "es") {
			nombreFichero = "Justificacion_" + expediente.getFolderNumber();
		} else {
			nombreFichero = "Justifikazioa_" + expediente.getFolderNumber();
		}

		// Nombre fichero
		modelMap.put("fileName", nombreFichero);
		// Datos
		List<Object> reportData = new ArrayList<Object>();
		// cabeceras hoja
		usuarioExcelDataAll.setHeaderNames(ReportData.parseColumns(columns));
		// datos hoja
		usuarioExcelDataAll.setModelData(listProgramasAll);
		reportData.add(usuarioExcelDataAll);
		modelMap.put("reportData", reportData);

		// Generación del XLS o XLSX
		if (request.getServletPath().indexOf("xlsReport") != -1) {
			return new ModelAndView("xlsReport", modelMap);
		} else {
			return new ModelAndView("xlsxReport", modelMap);
		}

	}

}