package com.ejie.ab60.control.justificacion;

import com.ejie.ab60.model.justificacion.MotivosIncumplimiento;
import com.ejie.ab60.service.justificacion.MotivosIncumplimientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * MotivosIncumplimientoController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/motivosincumplimiento")

public class MotivosIncumplimientoController {

	private static final Logger logger = LoggerFactory.getLogger(MotivosIncumplimientoController.class);

	@Autowired
	private MotivosIncumplimientoService motivosIncumplimientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idMotivoIncumplimiento
	 *            Long
	 * @return MotivosIncumplimiento Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idMotivoIncumplimiento}", method = RequestMethod.GET)
	public @ResponseBody MotivosIncumplimiento get(@PathVariable Long idMotivoIncumplimiento) {
		MotivosIncumplimiento motivosIncumplimiento = new MotivosIncumplimiento();
		motivosIncumplimiento.setIdMotivoIncumplimiento(idMotivoIncumplimiento);
		motivosIncumplimiento = this.motivosIncumplimientoService.find(motivosIncumplimiento);
		MotivosIncumplimientoController.logger.info("[GET - findBy_PK] : Obtener MotivosIncumplimiento por PK");
		return motivosIncumplimiento;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<MotivosIncumplimiento> Lista de objetos correspondientes a
	 *         la busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<MotivosIncumplimiento> getAll(
			@ModelAttribute MotivosIncumplimiento filterMotivosIncumplimiento) {
		MotivosIncumplimientoController.logger.info("[GET - find_ALL] : Obtener MotivosIncumplimiento por filtro");
		return this.motivosIncumplimientoService.findAll(filterMotivosIncumplimiento, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param motivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene la informacion a
	 *            modificar.
	 * @return MotivosIncumplimiento Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody MotivosIncumplimiento edit(@RequestBody MotivosIncumplimiento motivosIncumplimiento) {
		MotivosIncumplimiento motivosIncumplimientoAux = this.motivosIncumplimientoService
				.update(motivosIncumplimiento);
		MotivosIncumplimientoController.logger.info("[PUT] : MotivosIncumplimiento actualizado correctamente");
		return motivosIncumplimientoAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param motivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return MotivosIncumplimiento Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody MotivosIncumplimiento add(@RequestBody MotivosIncumplimiento motivosIncumplimiento) {
		MotivosIncumplimiento motivosIncumplimientoAux = this.motivosIncumplimientoService.add(motivosIncumplimiento);
		MotivosIncumplimientoController.logger.info("[POST] : MotivosIncumplimiento insertado correctamente");
		return motivosIncumplimientoAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idMotivoIncumplimiento
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return MotivosIncumplimiento Bean eliminado.
	 */
	@RequestMapping(value = "/{idMotivoIncumplimiento}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody MotivosIncumplimiento remove(@PathVariable Long idMotivoIncumplimiento) {
		MotivosIncumplimiento motivosIncumplimiento = new MotivosIncumplimiento();
		motivosIncumplimiento.setIdMotivoIncumplimiento(idMotivoIncumplimiento);
		this.motivosIncumplimientoService.remove(motivosIncumplimiento);
		MotivosIncumplimientoController.logger.info("[DELETE] : MotivosIncumplimiento borrado correctamente");
		return motivosIncumplimiento;
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de motivos
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo", method = RequestMethod.GET)
	public @ResponseBody List<MotivosIncumplimiento> init() {
		MotivosIncumplimientoController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.motivosIncumplimientoService.findMotivo();

	}
	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		MotivosIncumplimientoController.logger.info("[GET - View] : motivosincumplimiento");
		return "motivosincumplimiento";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<MotivosIncumplimiento> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<MotivosIncumplimiento> filter(
			@RequestJsonBody(param = "filter") MotivosIncumplimiento filterMotivosIncumplimiento,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosIncumplimientoController.logger.info("[POST - filter] : Obtener MotivosIncumplimientos");
		return this.motivosIncumplimientoService.filter(filterMotivosIncumplimiento, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchMotivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<MotivosIncumplimiento> Dto que contiene el resultado
	 *         de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<MotivosIncumplimiento>> search(
			@RequestJsonBody(param = "filter") MotivosIncumplimiento filterMotivosIncumplimiento,
			@RequestJsonBody(param = "search") MotivosIncumplimiento searchMotivosIncumplimiento,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosIncumplimientoController.logger.info("[POST - search] : Buscar MotivosIncumplimientos");
		return this.motivosIncumplimientoService.search(filterMotivosIncumplimiento, searchMotivosIncumplimiento,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") MotivosIncumplimiento filterMotivosIncumplimiento,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosIncumplimientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples MotivosIncumplimientos");
		this.motivosIncumplimientoService.removeMultiple(filterMotivosIncumplimiento, jqGridRequestDto, false);
		MotivosIncumplimientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosIncumplimiento>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosIncumplimiento>> jerarquia(
			@RequestJsonBody(param = "filter") MotivosIncumplimiento filterMotivosIncumplimiento,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosIncumplimientoController.logger.info("[POST - jerarquia] : Obtener MotivosIncumplimientos jerarquia");
		return this.motivosIncumplimientoService.jerarquia(filterMotivosIncumplimiento, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterMotivosIncumplimiento
	 *            MotivosIncumplimiento Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<MotivosIncumplimiento>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<MotivosIncumplimiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") MotivosIncumplimiento filterMotivosIncumplimiento,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		MotivosIncumplimientoController.logger
				.info("[POST - jerarquia] : Obtener MotivosIncumplimientos jerarquia - Hijos");
		return this.motivosIncumplimientoService.jerarquiaChildren(filterMotivosIncumplimiento, jqGridRequestDto);
	}

}
