package com.ejie.ab60.control.justificacion;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.justificacion.RelFacActSubvencionables;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.MEC.FacturasService;
import com.ejie.ab60.service.actuacionesSubvencionables.ActSubvencionableService;
import com.ejie.ab60.service.actuacionesSubvencionables.RelExpActSubService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.ab60.service.justificacion.RelFacActSubvencionablesService;
import com.ejie.ab60.util.UtilDate;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import com.ejie.x38.reports.ReportData;

/**
 * RelFacActSubvencionablesController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/relFacActSubvencionables")

public class RelFacActSubvencionablesController {

	private static final Logger logger = LoggerFactory.getLogger(RelFacActSubvencionablesController.class);

	@Autowired
	private RelFacActSubvencionablesService relFacActSubvencionablesService;

	@Autowired
	private RelExpActSubService relExpActSubService;

	@Autowired
	private FacturasService facturasService;

	@Autowired
	private ExpedientesService expedientesService;

	@Autowired
	private ActSubvencionableService actSubvencionableService;

	@Resource
	private ReloadableResourceBundleMessageSource appMessageSource;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 *
	 * @param idRelExpActSub
	 *            Integer
	 * @return RelExpActSub Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idExpediente}/{idRelExpActSub}/{idFactura}", method = RequestMethod.GET)
	public @ResponseBody RelFacActSubvencionables getData(@PathVariable Integer idExpediente,
			@PathVariable Integer idRelExpActSub, @PathVariable Integer idFactura,
			@ModelAttribute(value = "usuario") Usuario usuario) {
		RelFacActSubvencionablesController.logger.info("[GET - findBy_PK] : Obtener Facturas por PK");
		Facturas factura = new Facturas();
		factura.setIdFactura(idFactura);

		factura = this.facturasService.find(factura);

		String fechaFactura = UtilDate.convertirFechaEnString(factura.getFechaFactura());
		String fechaPagado = UtilDate.convertirFechaEnString(factura.getFechaPagado());

		factura.setFechaFacturaStr(fechaFactura);
		factura.setFechaPagadoStr(fechaPagado);

		RelFacActSubvencionables relFacActSubvencionables = new RelFacActSubvencionables();
		relFacActSubvencionables.setIdRelExpActSub(factura.getRelExpActSub().getIdRelExpActSub());
		relFacActSubvencionables.setIdExpediente(idExpediente);
		relFacActSubvencionables.setFactura(factura);
		// relFacActSubvencionables =
		// this.relFacActSubvencionablesService.find(relFacActSubvencionables);

		relFacActSubvencionables.setFactura(factura);

		return relFacActSubvencionables;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelFacActSubvencionables
	 *            RelFacActSubvencionables Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<RelFacActSubvencionables> Lista de objetos correspondientes
	 *         a la busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelFacActSubvencionables> getAll(
			@ModelAttribute RelFacActSubvencionables filterRelFacActSubvencionables) {
		RelFacActSubvencionablesController.logger
				.info("[GET - find_ALL] : Obtener RelFacActSubvencionables por filtro");
		return this.relFacActSubvencionablesService.findAll(filterRelFacActSubvencionables, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene la informacion a
	 *            modificar.
	 * @return RelFacActSubvencionables Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/{idExpediente}/{idRelExpActSub}", method = RequestMethod.PUT)
	public @ResponseBody RelFacActSubvencionables edit(@RequestBody RelFacActSubvencionables relFacActSubvencionables,
			@PathVariable Integer idExpediente, @PathVariable Integer idRelExpActSub,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		Facturas factura = relFacActSubvencionables.getFactura();

		// el combo de motivos de denegacion y de minoracion de las facturas no
		// llega bien si esta dentro del objeto facturas
		// se pone en el objeto RelFacActSubvencionables y se pasa a facturas
		// para que funcione, mientras vemos porque puede pasar
		factura.setComboFacturaDenegacion(relFacActSubvencionables.getComboFacturaDenegacion());
		factura.setComboFacturaMinoracion(relFacActSubvencionables.getComboFacturaMinoracion());

		/*
		 * String fechaFactura =
		 * UtilDate.convertirFechaEnString(factura.getFechaFactura()); String
		 * fechaPagado =
		 * UtilDate.convertirFechaEnString(factura.getFechaPagado());
		 * 
		 * factura.setFechaFacturaStr(fechaFactura);
		 * factura.setFechaPagadoStr(fechaPagado);
		 */

		// relFacActSubvencionables.setIdRelExpActSub(factura.getRelExpActSub().getIdRelExpActSub());
		// relFacActSubvencionables.setIdExpediente(idExpediente);
		// relFacActSubvencionables =
		// this.relFacActSubvencionablesService.find(relFacActSubvencionables);

		// relFacActSubvencionables.setFactura(factura);

		RelFacActSubvencionablesController.logger.info("[PUT] : Factura actualizada correctamente");

		Facturas facturaAux = this.facturasService
				.editFacturaJustificacion(relFacActSubvencionables.getIdRelExpActSub(), idExpediente, factura, usuario);

		relFacActSubvencionables.setFactura(facturaAux);

		return relFacActSubvencionables;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene la informacion con
	 *            la que se va a crear el nuevo registro.
	 * @return RelFacActSubvencionables Bean resultante del proceso de creacion.
	 */
	@RequestMapping(value = "/{idExpediente}/{idRelExpActSub}", method = RequestMethod.POST)
	public @ResponseBody RelFacActSubvencionables add(@PathVariable Integer idExpediente,
			@PathVariable Integer idRelExpActSub, @RequestBody RelFacActSubvencionables relFacActSubvencionables,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		// No serializa en el jsp bien los combos de denegación y minoracion,
		// por eso se recogen y despues se mueven los valores al objeto que se
		// va a tratar posteriormente.
		Facturas miFac = relFacActSubvencionables.getFactura();
		miFac.setComboFacturaDenegacion(relFacActSubvencionables.getComboFacturaDenegacion());
		miFac.setComboFacturaMinoracion(relFacActSubvencionables.getComboFacturaMinoracion());
		relFacActSubvencionables.setFactura(miFac);

		Facturas facturaAux = this.facturasService.addJustificacion(relFacActSubvencionables.getIdRelExpActSub(),
				idExpediente, relFacActSubvencionables.getIdActSub(), relFacActSubvencionables.getFactura(), usuario);

		relFacActSubvencionables.setFactura(facturaAux);

		return relFacActSubvencionables;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idExpediente
	 *            Integer
	 * @param folderNumber
	 *            String
	 * @param idRelExpActSub
	 *            Integer
	 * @param descripcionCastellano
	 *            String
	 * @param descripcionEuskera
	 *            String Identificador del objeto que se desea eliminar.
	 * @return RelFacActSubvencionables Bean eliminado.
	 */
	@RequestMapping(value = "/{idExpediente}/{idRelExpActSub}/{idFactura}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Facturas remove(@PathVariable Integer idExpediente, @PathVariable Integer idRelExpActSub,
			@PathVariable Integer idFactura, @ModelAttribute(value = "usuario") Usuario usuario) {

		// Necesito el idRelacion
		Facturas factura = new Facturas();
		factura.setIdFactura(idFactura);

		factura = facturasService.find(factura);
		RelFacActSubvencionablesController.logger.info("[DELETE] : BORRAR FACTURAS");
		return facturasService.removeFacturasJustificacion(idFactura, factura.getRelExpActSub().getIdRelExpActSub(),
				idExpediente, usuario);

	}

	/**
	 * Operacion que me trae los totales de las facturas de una acion
	 * cubvencionable
	 * 
	 * 
	 * @param idRelacion
	 *            Integer
	 * @param idExpediente
	 *            Integer
	 * @param idCriterio,
	 *            Integer
	 * @return RelExpActSub
	 */

	@RequestMapping(value = "/totales/{idExpediente}/{idRelExpActSub}", method = RequestMethod.GET)
	public @ResponseBody RelExpActSub totales(@PathVariable Integer idExpediente,
			@PathVariable Integer idRelExpActSub) {

		/*
		 * RelExpActSub relExpActSubId = new RelExpActSub();
		 * FacturasController.logger.
		 * info("[POST - filter] : Obtener RelacionSubvencionable con ides"); if
		 * (0 == idRelacion) { relExpActSubId =
		 * relExpActSubService.findUltimoId(idExpediente, idCriterio);
		 * idRelacion = relExpActSubId.getIdRelExpActSub(); RelExpActSub
		 * ultimaRelacionExistente =
		 * relExpActSubService.findLastId(idExpediente, idCriterio); if
		 * (!ultimaRelacionExistente.getIdRelExpActSub().equals(idRelacion)) {
		 * idRelacion = ultimaRelacionExistente.getIdRelExpActSub(); } }
		 */

		return this.relExpActSubService.findTotalesJustificacion(idExpediente, idRelExpActSub);
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelFacActSubvencionablesController.logger.info("[GET - View] : relFacActSubvencionables");
		return "relFacActSubvencionables";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelFacActSubvencionables> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/{idExpediente}/{idRelExpActSub}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelFacActSubvencionables> filter(
			@RequestJsonBody(param = "filter") RelFacActSubvencionables filterRelFacActSubvencionables,
			@PathVariable Integer idExpediente, @PathVariable Integer idRelExpActSub,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacActSubvencionablesController.logger.info("[POST - filter] : Obtener RelFacActSubvencionabless");

		filterRelFacActSubvencionables.setIdExpediente(idExpediente);
		filterRelFacActSubvencionables.setIdRelExpActSub(idRelExpActSub);
		return this.relFacActSubvencionablesService.filter(filterRelFacActSubvencionables, jqGridRequestDto, false);
	}

	/**
	 * Metodo para modicar el importe de admitido, cuando le damos al boton de
	 * admitir todo
	 * 
	 * @param facturas
	 *            Facturas Bean que contiene la informacion a modificar.
	 * @return Facturas Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/admitirTodo", method = RequestMethod.GET)
	public void editImporteJustificacion(@RequestParam(value = "idExpediente", required = true) int idExpediente,
			@RequestParam(value = "idRelExpActSub", required = true) int idRelExpActSub,
			@ModelAttribute(value = "usuario") Usuario usuario) {

		RelFacActSubvencionables relFacActSubvencionable = new RelFacActSubvencionables();
		relFacActSubvencionable.setIdExpediente(idExpediente);
		relFacActSubvencionable.setIdRelExpActSub(idRelExpActSub);

		List<RelFacActSubvencionables> relFacActSubvencionablesList = this.relFacActSubvencionablesService
				.findAll(relFacActSubvencionable, null);

		facturasService.editImporteJustificacion(relFacActSubvencionablesList, usuario);

	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchRelFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelFacActSubvencionables> Dto que contiene el
	 *         resultado de la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelFacActSubvencionables>> search(
			@RequestJsonBody(param = "filter") RelFacActSubvencionables filterRelFacActSubvencionables,
			@RequestJsonBody(param = "search") RelFacActSubvencionables searchRelFacActSubvencionables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacActSubvencionablesController.logger.info("[POST - search] : Buscar RelFacActSubvencionabless");
		return this.relFacActSubvencionablesService.search(filterRelFacActSubvencionables,
				searchRelFacActSubvencionables, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") RelFacActSubvencionables filterRelFacActSubvencionables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacActSubvencionablesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelFacActSubvencionabless");
		this.relFacActSubvencionablesService.removeMultiple(filterRelFacActSubvencionables, jqGridRequestDto, false);
		RelFacActSubvencionablesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelFacActSubvencionables>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelFacActSubvencionables>> jerarquia(
			@RequestJsonBody(param = "filter") RelFacActSubvencionables filterRelFacActSubvencionables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacActSubvencionablesController.logger
				.info("[POST - jerarquia] : Obtener RelFacActSubvencionabless jerarquia");
		return this.relFacActSubvencionablesService.jerarquia(filterRelFacActSubvencionables, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelFacActSubvencionables
	 *            RelFacActSubvencionables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelFacActSubvencionables>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelFacActSubvencionables>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelFacActSubvencionables filterRelFacActSubvencionables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelFacActSubvencionablesController.logger
				.info("[POST - jerarquia] : Obtener RelFacActSubvencionables jerarquia - Hijos");
		return this.relFacActSubvencionablesService.jerarquiaChildren(filterRelFacActSubvencionables, jqGridRequestDto);
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo actuaciones
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idExpediente}", method = RequestMethod.GET)
	public @ResponseBody List<RelFacActSubvencionables> getComboActuaciones(@PathVariable Integer idExpediente) {
		RelFacActSubvencionablesController.logger
				.info("[GET - getValorCombo] : Obtener valores del combo Actuaciones ");

		return this.relFacActSubvencionablesService.findActuaciones(idExpediente);

	}

	/**
	 * Metodo que nos trae la lista para cargar el combo actuaciones
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorComboMEC/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<ActSubvencionable> getComboActuacionesMEC(@PathVariable Integer idConvocatoria) {
		RelFacActSubvencionablesController.logger
				.info("[GET - getValorCombo] : Obtener valores del combo Actuaciones ");

		return this.actSubvencionableService.findActuacionesMEC(idConvocatoria);

	}

	@RequestMapping(value = "/verValorComboEMCO/{idConvocatoria}/{idActSubHijo}", method = RequestMethod.GET)
	public @ResponseBody List<ActSubvencionable> getComboActuacionesEMCO(@PathVariable Integer idConvocatoria,
			@PathVariable Integer idActSubHijo) {
		RelFacActSubvencionablesController.logger
				.info("[GET - getValorCombo] : Obtener valores del combo Actuaciones ");

		return this.actSubvencionableService.findActuacionesEMCO(idConvocatoria, idActSubHijo);

	}

	/**
	 * Permite crear reportes xls o xlsx
	 * 
	 * @param filterDireccion
	 * @param jqGridRequestDto
	 * @param modelMap
	 * @param columns
	 * @param request
	 * @return
	 */

	@RequestMapping(value = { "{idExpediente}/{idRelExpAct}/xlsReport",
			"{idExpediente}/{idRelExpAct}/xlsxReport" }, method = RequestMethod.POST)
	public ModelAndView getExcelPOI(@ModelAttribute ActSubvencionable filterActSubvencionable,
			@ModelAttribute JQGridRequestDto jqGridRequestDto, ModelMap modelMap, @PathVariable Integer idExpediente,
			@PathVariable Integer idRelExpAct, @ModelAttribute(value = "initForm") InitForm initForm,
			@RequestParam(value = "columns", required = false) String columns, HttpServletRequest request) {

		Locale locale = LocaleContextHolder.getLocale();
		RelFacActSubvencionables relFacActSubvencionables = new RelFacActSubvencionables();
		relFacActSubvencionables.setIdExpediente(idExpediente);
		relFacActSubvencionables.setIdRelExpActSub(idRelExpAct);
		columns = "[['descripcionEs','" + appMessageSource.getMessage("excel.descripcion", null, locale) + "']"
				+ ",['factura.numeroFactura','" + appMessageSource.getMessage("excel.numFactura", null, locale) + "']"
				+ ",['factura.descripcion','" + appMessageSource.getMessage("excel.descFactura", null, locale) + "']"
				+ ",['factura.proveedor','" + appMessageSource.getMessage("excel.proveedor", null, locale) + "']"
				+ ",['factura.fechaFactura','" + appMessageSource.getMessage("excel.fechaFactura", null, locale) + "']"
				+ ",['factura.fechaPagado','" + appMessageSource.getMessage("excel.fechaPagado", null, locale) + "']"
				+ ",['factura.importe','" + appMessageSource.getMessage("excel.fechaImporte", null, locale) + "']"
				+ ",['factura.importeAdmitido','" + appMessageSource.getMessage("excel.importeAdmitido", null, locale)
				+ "']]";

		jqGridRequestDto.setPage(null);
		jqGridRequestDto.setRows(null);

		Expedientes expediente = new Expedientes();
		expediente.setIdExpediente(idExpediente);
		expediente = this.expedientesService.find(expediente);

		// Acceso a BD para recuperar datos
		List<RelFacActSubvencionables> listactSubPage = this.relFacActSubvencionablesService
				.findAllLike(relFacActSubvencionables, jqGridRequestDto, null);

		// Nombre fichero

		String nombreFichero = null;
		if (locale.getLanguage() == "es") {
			nombreFichero = "Justificacion_facturas_" + expediente.getFolderNumber();
		} else {
			nombreFichero = "Justifikazio_fakturak_" + expediente.getFolderNumber();
		}
		modelMap.put("fileName", nombreFichero);

		// Datos
		List<Object> reportData = new ArrayList<Object>();
		// Hoja 1
		ReportData<ActSubvencionable> usuarioExcelDataAll = new ReportData<ActSubvencionable>();
		// nombre hoja
		usuarioExcelDataAll.setSheetName(appMessageSource.getMessage("usuarioExcel.justificacion", null, locale));
		// cabeceras hoja
		usuarioExcelDataAll.setHeaderNames(ReportData.parseColumns(columns));
		// datos hoja
		usuarioExcelDataAll.setModelData(listactSubPage);
		reportData.add(usuarioExcelDataAll);

		modelMap.put("reportData", reportData);
		// Generación del XLS o XLSX
		if (request.getServletPath().indexOf("xlsReport") != -1) {
			return new ModelAndView("xlsReport", modelMap);
		} else {
			return new ModelAndView("xlsxReport", modelMap);
		}
	}
}
