package com.ejie.ab60.control.justificacion;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.justificacion.RelTipGasCon;
import com.ejie.ab60.service.justificacion.RelTipGasConService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelTipGasConController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/reltipgascon")

public class RelTipGasConController {

	private static final Logger logger = LoggerFactory.getLogger(RelTipGasConController.class);

	@Autowired
	private RelTipGasConService relTipGasConService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRelTipGasCon
	 *            Long
	 * @return RelTipGasCon Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelTipGasCon}", method = RequestMethod.GET)
	public @ResponseBody RelTipGasCon get(@PathVariable Long idRelTipGasCon) {
		RelTipGasCon relTipGasCon = new RelTipGasCon();
		relTipGasCon.setIdRelTipGasCon(idRelTipGasCon);
		relTipGasCon = this.relTipGasConService.find(relTipGasCon);
		RelTipGasConController.logger.info("[GET - findBy_PK] : Obtener RelTipGasCon por PK");
		return relTipGasCon;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterRelTipGasCon
	 *            RelTipGasCon Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<RelTipGasCon> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<RelTipGasCon> getAll(@ModelAttribute RelTipGasCon filterRelTipGasCon) {
		RelTipGasConController.logger.info("[GET - find_ALL] : Obtener RelTipGasCon por filtro");
		return this.relTipGasConService.findAll(filterRelTipGasCon, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relTipGasCon
	 *            RelTipGasCon Bean que contiene la informacion a modificar.
	 * @return RelTipGasCon Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelTipGasCon edit(@RequestBody RelTipGasCon relTipGasCon) {
		RelTipGasCon relTipGasConAux = this.relTipGasConService.update(relTipGasCon);
		RelTipGasConController.logger.info("[PUT] : RelTipGasCon actualizado correctamente");
		return relTipGasConAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relTipGasCon
	 *            RelTipGasCon Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelTipGasCon Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelTipGasCon add(@RequestBody RelTipGasCon relTipGasCon) {
		RelTipGasCon relTipGasConAux = this.relTipGasConService.add(relTipGasCon);
		RelTipGasConController.logger.info("[POST] : RelTipGasCon insertado correctamente");
		return relTipGasConAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelTipGasCon
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return RelTipGasCon Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelTipGasCon}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody RelTipGasCon remove(@PathVariable Long idRelTipGasCon) {
		RelTipGasCon relTipGasCon = new RelTipGasCon();
		relTipGasCon.setIdRelTipGasCon(idRelTipGasCon);
		this.relTipGasConService.remove(relTipGasCon);
		RelTipGasConController.logger.info("[DELETE] : RelTipGasCon borrado correctamente");
		return relTipGasCon;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RelTipGasConController.logger.info("[GET - View] : reltipgascon");
		return "reltipgascon";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterRelTipGasCon
	 *            RelTipGasCon Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<RelTipGasCon> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<RelTipGasCon> filter(
			@RequestJsonBody(param = "filter") RelTipGasCon filterRelTipGasCon,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelTipGasConController.logger.info("[POST - filter] : Obtener RelTipGasCons");
		return this.relTipGasConService.filter(filterRelTipGasCon, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterRelTipGasCon
	 *            RelTipGasCon Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchRelTipGasCon
	 *            RelTipGasCon Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<RelTipGasCon> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<RelTipGasCon>> search(
			@RequestJsonBody(param = "filter") RelTipGasCon filterRelTipGasCon,
			@RequestJsonBody(param = "search") RelTipGasCon searchRelTipGasCon,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelTipGasConController.logger.info("[POST - search] : Buscar RelTipGasCons");
		return this.relTipGasConService.search(filterRelTipGasCon, searchRelTipGasCon, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterRelTipGasCon
	 *            RelTipGasCon Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") RelTipGasCon filterRelTipGasCon,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelTipGasConController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples RelTipGasCons");
		this.relTipGasConService.removeMultiple(filterRelTipGasCon, jqGridRequestDto, false);
		RelTipGasConController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterRelTipGasCon
	 *            RelTipGasCon Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelTipGasCon>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelTipGasCon>> jerarquia(
			@RequestJsonBody(param = "filter") RelTipGasCon filterRelTipGasCon,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelTipGasConController.logger.info("[POST - jerarquia] : Obtener RelTipGasCons jerarquia");
		return this.relTipGasConService.jerarquia(filterRelTipGasCon, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterRelTipGasCon
	 *            RelTipGasCon Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<RelTipGasCon>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<RelTipGasCon>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") RelTipGasCon filterRelTipGasCon,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RelTipGasConController.logger.info("[POST - jerarquia] : Obtener RelTipGasCons jerarquia - Hijos");
		return this.relTipGasConService.jerarquiaChildren(filterRelTipGasCon, jqGridRequestDto);
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo tipos de gastos
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<RelTipGasCon> getComboTiposGastos(@PathVariable Integer idConvocatoria) {
		RelTipGasConController.logger.info("[GET - getValorCombo] : Obtener valores del combo Tipos de Gastos ");

		return this.relTipGasConService.findTipos(idConvocatoria);

	}

}
