package com.ejie.ab60.control.justificacion;

import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.justificacion.TiposResJus;
import com.ejie.ab60.service.justificacion.TiposResJusService;

/**
 * TiposResJusController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tiposresjus")

public class TiposResJusController {

	private static final Logger logger = LoggerFactory.getLogger(TiposResJusController.class);

	@Autowired
	private TiposResJusService tiposResJusService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idResJustificacion
	 *            Long
	 * @return TiposResJus Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idResJustificacion}", method = RequestMethod.GET)
	public @ResponseBody TiposResJus get(@PathVariable Long idResJustificacion) {
		TiposResJus tiposResJus = new TiposResJus();
		tiposResJus.setIdResJustificacion(idResJustificacion);
		tiposResJus = this.tiposResJusService.find(tiposResJus);
		TiposResJusController.logger.info("[GET - findBy_PK] : Obtener TiposResJus por PK");
		return tiposResJus;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposResJus
	 *            TiposResJus Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<TiposResJus> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposResJus> getAll(@ModelAttribute TiposResJus filterTiposResJus) {
		TiposResJusController.logger.info("[GET - find_ALL] : Obtener TiposResJus por filtro");
		return this.tiposResJusService.findAll(filterTiposResJus, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposResJus
	 *            TiposResJus Bean que contiene la informacion a modificar.
	 * @return TiposResJus Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposResJus edit(@RequestBody TiposResJus tiposResJus) {
		TiposResJus tiposResJusAux = this.tiposResJusService.update(tiposResJus);
		TiposResJusController.logger.info("[PUT] : TiposResJus actualizado correctamente");
		return tiposResJusAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposResJus
	 *            TiposResJus Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return TiposResJus Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposResJus add(@RequestBody TiposResJus tiposResJus) {
		TiposResJus tiposResJusAux = this.tiposResJusService.add(tiposResJus);
		TiposResJusController.logger.info("[POST] : TiposResJus insertado correctamente");
		return tiposResJusAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idResJustificacion
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposResJus Bean eliminado.
	 */
	@RequestMapping(value = "/{idResJustificacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposResJus remove(@PathVariable Long idResJustificacion) {
		TiposResJus tiposResJus = new TiposResJus();
		tiposResJus.setIdResJustificacion(idResJustificacion);
		this.tiposResJusService.remove(tiposResJus);
		TiposResJusController.logger.info("[DELETE] : TiposResJus borrado correctamente");
		return tiposResJus;
	}

	/**
	 * Metodo que nos trae la lista para cargar el combo de resultados
	 * 
	 * 
	 */
	@RequestMapping(value = "/verValorCombo", method = RequestMethod.GET)
	public @ResponseBody List<TiposResJus> init() {
		TiposResJusController.logger.info("[GET - getValorCombo] : Obtener valores del combo ");
		return this.tiposResJusService.findResultado();

	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposResJusController.logger.info("[GET - View] : tiposresjus");
		return "tiposresjus";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposResJus
	 *            TiposResJus Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposResJus> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposResJus> filter(
			@RequestJsonBody(param = "filter") TiposResJus filterTiposResJus,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResJusController.logger.info("[POST - filter] : Obtener TiposResJuss");
		return this.tiposResJusService.filter(filterTiposResJus, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposResJus
	 *            TiposResJus Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchTiposResJus
	 *            TiposResJus Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposResJus> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposResJus>> search(
			@RequestJsonBody(param = "filter") TiposResJus filterTiposResJus,
			@RequestJsonBody(param = "search") TiposResJus searchTiposResJus,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResJusController.logger.info("[POST - search] : Buscar TiposResJuss");
		return this.tiposResJusService.search(filterTiposResJus, searchTiposResJus, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposResJus
	 *            TiposResJus Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") TiposResJus filterTiposResJus,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResJusController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposResJuss");
		this.tiposResJusService.removeMultiple(filterTiposResJus, jqGridRequestDto, false);
		TiposResJusController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposResJus
	 *            TiposResJus Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposResJus>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposResJus>> jerarquia(
			@RequestJsonBody(param = "filter") TiposResJus filterTiposResJus,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResJusController.logger.info("[POST - jerarquia] : Obtener TiposResJuss jerarquia");
		return this.tiposResJusService.jerarquia(filterTiposResJus, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposResJus
	 *            TiposResJus Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposResJus>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposResJus>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposResJus filterTiposResJus,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposResJusController.logger.info("[POST - jerarquia] : Obtener TiposResJuss jerarquia - Hijos");
		return this.tiposResJusService.jerarquiaChildren(filterTiposResJus, jqGridRequestDto);
	}

}
