package com.ejie.ab60.control.moduloContable;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.moduloContable.DocContables;
import com.ejie.ab60.model.moduloContable.DocumentosContables;
import com.ejie.ab60.service.moduloContable.DocContablesDOService;
import com.ejie.ab60.service.moduloContable.DocContablesDService;
import com.ejie.ab60.service.moduloContable.DocContablesOService;
import com.ejie.ab60.service.moduloContable.DocumentosContablesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

/**
 * DocContablesController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/docContables")

public class DocContablesController {

	private static final Logger logger = LoggerFactory.getLogger(DocContablesController.class);

	@Autowired
	private DocContablesDService docContablesDService;

	@Autowired
	private DocContablesOService docContablesOService;

	@Autowired
	private DocContablesDOService docContablesDOService;

	@Autowired
	private DocumentosContablesService documentosContablesService;

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idConvocatoria
	 *            Integer
	 * @return DocContables Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFicheroContable}/{idDocumentoContable}", method = RequestMethod.GET)
	public @ResponseBody DocumentosContables get(@PathVariable("idFicheroContable") String idFicheroContable,
			@PathVariable("idDocumentoContable") String idDocumentoContable) {
		DocumentosContables documentosContables = new DocumentosContables();
		documentosContables.setIdDocumentoContable(idDocumentoContable);
		documentosContables = this.documentosContablesService.find(documentosContables);
		DocContablesController.logger.info("[GET - findBy_PK] : Obtener DocumentosContables por PK");
		return documentosContables;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {
		DocContablesController.logger.info("[GET - View] : docContables");
		model.addAttribute("docContables", new DocContables());
		return "docContables";
	}

	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEditURL(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {
		DocContablesController.logger.info("[GET - View] : docContables");
		model.addAttribute("docContables", new DocContables());
		return "docContables";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterDocContables
	 *            DocContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<DocContables> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/{idFicheroContable}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DocumentosContables> filter(
			@PathVariable("idFicheroContable") Integer idFicheroContable,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocContablesController.logger.info("[POST - filter] : Obtener DocContabless");
		return this.documentosContablesService.filterDocumentos(new DocumentosContables(), jqGridRequestDto, false,
				idFicheroContable);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterDocContables
	 *            DocContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<DocContables> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filtro/{idTipoDoc}/{idPagoConvo}/{idProcedimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DocContables> filterDocs(@PathVariable("idTipoDoc") String idTipoDoc,
			@PathVariable("idProcedimiento") Integer idProcedimiento, @PathVariable("idPagoConvo") Integer numeroPago,
			@RequestJsonBody(param = "filter") DocContables filterDocContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocContablesController.logger.info("[POST - filter] : Obtener DocContabless");
		filterDocContables.setTipoDocumento(idTipoDoc);
		filterDocContables.setIdProcedimiento(idProcedimiento);

		if (Constantes.TIPO_DOCUMENTO_CONTABLE_D.equals(filterDocContables.getTipoDocumento())) {
			return this.docContablesDService.filter(filterDocContables, jqGridRequestDto, false);
		} else if (Constantes.TIPO_DOCUMENTO_CONTABLE_O.equals(filterDocContables.getTipoDocumento())) {
			filterDocContables.setNumeroPago(numeroPago);
			return this.docContablesOService.filter(filterDocContables, jqGridRequestDto, false);
		} else if (Constantes.TIPO_DOCUMENTO_CONTABLE_DO.equals(filterDocContables.getTipoDocumento())) {
			return this.docContablesDOService.filter(filterDocContables, jqGridRequestDto, false);
		} else
			return null;
	}

}
