package com.ejie.ab60.control.moduloContable;

import java.math.BigDecimal;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.model.convocatorias.AplicacionesPresupuestarias;
import com.ejie.ab60.model.moduloContable.DocumentosContables;
import com.ejie.ab60.service.convocatorias.AplicacionesPresupuestariasService;
import com.ejie.ab60.service.moduloContable.DocumentosContablesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * DocumentosContablesController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/documentoscontables")

public class DocumentosContablesController {

	private static final Logger logger = LoggerFactory.getLogger(DocumentosContablesController.class);

	@Autowired
	private DocumentosContablesService documentosContablesService;

	@Autowired
	private AplicacionesPresupuestariasService aplicacionesPresupuestariasService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idDocumentoContable
	 *            String
	 * @return DocumentosContables Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idDocumentoContable}", method = RequestMethod.GET)
	public @ResponseBody DocumentosContables get(@PathVariable String idDocumentoContable) {
		DocumentosContables documentosContables = new DocumentosContables();
		documentosContables.setIdDocumentoContable(idDocumentoContable);
		documentosContables = this.documentosContablesService.find(documentosContables);
		DocumentosContablesController.logger.info("[GET - findBy_PK] : Obtener DocumentosContables por PK");
		return documentosContables;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterDocumentosContables
	 *            DocumentosContables Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<DocumentosContables> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<DocumentosContables> getAll(
			@ModelAttribute DocumentosContables filterDocumentosContables) {
		DocumentosContablesController.logger.info("[GET - find_ALL] : Obtener DocumentosContables por filtro");
		return this.documentosContablesService.findAll(filterDocumentosContables, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param documentosContables
	 *            DocumentosContables Bean que contiene la informacion a
	 *            modificar.
	 * @return DocumentosContables Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody DocumentosContables edit(@RequestBody DocumentosContables documentosContables) {
		DocumentosContables documentosContablesAux = this.documentosContablesService.update(documentosContables);
		DocumentosContablesController.logger.info("[PUT] : DocumentosContables actualizado correctamente");
		return documentosContablesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param documentosContables
	 *            DocumentosContables Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return DocumentosContables Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody DocumentosContables add(@RequestBody DocumentosContables documentosContables) {
		DocumentosContables documentosContablesAux = this.documentosContablesService.add(documentosContables);
		DocumentosContablesController.logger.info("[POST] : DocumentosContables insertado correctamente");
		return documentosContablesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idDocumentoContable
	 *            String Identificador del objeto que se desea eliminar.
	 * @return DocumentosContables Bean eliminado.
	 */
	@RequestMapping(value = "/{idDocumentoContable}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody DocumentosContables remove(@PathVariable String idDocumentoContable) {
		DocumentosContables documentosContables = new DocumentosContables();
		documentosContables.setIdDocumentoContable(idDocumentoContable);
		this.documentosContablesService.remove(documentosContables);
		DocumentosContablesController.logger.info("[DELETE] : DocumentosContables borrado correctamente");
		return documentosContables;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idFicheroContable
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return FicherosContables Bean eliminado.
	 */
	@RequestMapping(value = "/eliminarDocContables/{idFicheroContable}", method = RequestMethod.GET)
	public @ResponseBody void removeDocContables(
			@RequestParam(value = "idSeleccionados", required = true) String idSeleccionados,
			@RequestParam(value = "idsAplicPresu", required = true) String idsAplicPresu,
			@RequestParam(value = "importes", required = true) String importes,
			@PathVariable("idFicheroContable") Integer idFicheroContable) {

		String[] ids = idSeleccionados.split(",");

		String[] idsAplic = idsAplicPresu.split(",");

		String[] listaImportes = importes.split(",");

		if (ids != null) {
			for (int x = 0; x < ids.length; x++) {
				DocumentosContables documentoContable = new DocumentosContables();
				documentoContable.setIdExpediente(Integer.parseInt(ids[x]));
				documentoContable.setIdFicheroContable(idFicheroContable);

				documentosContablesService.removeByFicheroContable(documentoContable);

				// Actualizo el importe disponible de la aplicación
				// presupuestaria
				AplicacionesPresupuestarias aplPresu = new AplicacionesPresupuestarias();
				aplPresu.setIdAplicacionPresupuestaria(Integer.parseInt(idsAplic[x]));

				aplPresu = this.aplicacionesPresupuestariasService.find(aplPresu);

				BigDecimal importeSeleccionado = new BigDecimal(listaImportes[x]);
				aplPresu.setImporteDisponible(importeSeleccionado.add(aplPresu.getImporteDisponible()));

				this.aplicacionesPresupuestariasService.updateImporteDisponible(aplPresu);
			}
		}

		DocumentosContablesController.logger.info("[DELETE] : DocumentosContables borrado correctamente");
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		DocumentosContablesController.logger.info("[GET - View] : documentoscontables");
		return "documentoscontables";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterDocumentosContables
	 *            DocumentosContables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<DocumentosContables> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/{idProcedimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DocumentosContables> filter(@PathVariable Integer idProcedimiento,
			@RequestJsonBody(param = "filter") DocumentosContables filterDocumentosContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocumentosContablesController.logger.info("[POST - filter] : Obtener DocumentosContabless");
		return this.documentosContablesService.filter(filterDocumentosContables, jqGridRequestDto, false,
				idProcedimiento);
	}

	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DocumentosContables> filterInicial(
			@RequestJsonBody(param = "filter") DocumentosContables filterDocumentosContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocumentosContablesController.logger.info("[POST - filter] : Obtener DocumentosContabless");
		return this.documentosContablesService.filter(filterDocumentosContables, jqGridRequestDto, false, 0);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterDocumentosContables
	 *            DocumentosContables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchDocumentosContables
	 *            DocumentosContables Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<DocumentosContables> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<DocumentosContables>> search(
			@RequestJsonBody(param = "filter") DocumentosContables filterDocumentosContables,
			@RequestJsonBody(param = "search") DocumentosContables searchDocumentosContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocumentosContablesController.logger.info("[POST - search] : Buscar DocumentosContabless");
		return this.documentosContablesService.search(filterDocumentosContables, searchDocumentosContables,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterDocumentosContables
	 *            DocumentosContables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") DocumentosContables filterDocumentosContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocumentosContablesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples DocumentosContabless");
		this.documentosContablesService.removeMultiple(filterDocumentosContables, jqGridRequestDto, false);
		DocumentosContablesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterDocumentosContables
	 *            DocumentosContables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<DocumentosContables>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DocumentosContables>> jerarquia(
			@RequestJsonBody(param = "filter") DocumentosContables filterDocumentosContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocumentosContablesController.logger.info("[POST - jerarquia] : Obtener DocumentosContabless jerarquia");
		return this.documentosContablesService.jerarquia(filterDocumentosContables, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterDocumentosContables
	 *            DocumentosContables Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<DocumentosContables>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DocumentosContables>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") DocumentosContables filterDocumentosContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DocumentosContablesController.logger
				.info("[POST - jerarquia] : Obtener DocumentosContabless jerarquia - Hijos");
		return this.documentosContablesService.jerarquiaChildren(filterDocumentosContables, jqGridRequestDto);
	}

}
