package com.ejie.ab60.control.moduloContable;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.multipart.MultipartFile;

import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.convocatorias.InfDatosIkus;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.moduloContable.DocumentosContables;
import com.ejie.ab60.model.moduloContable.ModuloContable;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.moduloContable.DocumentosContablesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

/**
 * DocContablesController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/moduloContable")

public class ModuloContableController {

	private static final Logger logger = LoggerFactory.getLogger(ModuloContableController.class);

	@Autowired
	private DocumentosContablesService documentosContablesService;

	public List<String> listaNumeroExpedientes;

	public String tipoArchivoSeleccionado;

	public boolean estado;

	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditMenu(Model model, @ModelAttribute(value = "initForm") InitForm initForm) {
		ModuloContableController.logger.info("[GET - View] : docContables");

		Integer idConvocatoria = initForm.getIdConvocatoria();

		InfDatosIkus datosIkus = new InfDatosIkus();

		model.addAttribute("infDatosIkus", datosIkus);

		ModuloContable moduloContable = new ModuloContable();
		moduloContable.setIdProcedimiento(idConvocatoria);
		model.addAttribute("moduloContable", moduloContable);
		return "moduloContable";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterDocContables
	 *            DocContables Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<DocContables> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/archivosMAKyREL/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DocumentosContables> filterArchivos(
			@RequestJsonBody(param = "filter") DocumentosContables filterDocContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto, @ModelAttribute(value = "initForm") InitForm initForm) {
		ModuloContableController.logger.info("[POST - filter] : Obtener DocContabless");
		return this.documentosContablesService.filterArchivos(filterDocContables, jqGridRequestDto, false,
				listaNumeroExpedientes, tipoArchivoSeleccionado);
	}

	@RequestMapping(value = "/cargarFicherosIKUS/{tipoArchivo}", method = RequestMethod.POST)
	public @ResponseBody void doPost(Model model, @ModelAttribute DocumentosContables documentoContable,
			@PathVariable("tipoArchivo") String tipoArchivo,
			@RequestParam(value = "file", required = false) MultipartFile file,
			@ModelAttribute(value = "initForm") InitForm initForm) throws IOException {

		estado = false;

		if (file.getSize() > 0) {
			String datos = new String(file.getBytes());
			String[] partes = datos.split("\r\n"); // Lo divido por líneas

			if (tipoArchivo.equals(Constantes.ARCHIVO_MAK)) {
				leerArchivoMAK(partes);
				tipoArchivoSeleccionado = Constantes.ARCHIVO_MAK;
			} else if (tipoArchivo.equals(Constantes.ARCHIVO_REL)) {
				leerArchivoREL(partes);
				tipoArchivoSeleccionado = Constantes.ARCHIVO_REL;
			}

		}

		ModuloContableController.logger.info("[POST] : Obtener Carga de Fichero");

		// return this.getFormEditMenu(model, initForm);
	}

	public void leerArchivoMAK(String[] partes) {
		listaNumeroExpedientes = new ArrayList<String>();
		for (int x = 2; x < partes.length; x++) {
			try {
				DocumentosContables documentoContableAux = new DocumentosContables();

				// documentoContableAux.setEstado(false);

				documentoContableAux.setPuntoTramitacion(partes[x].substring(10, 18).replaceAll("\\s+", ""));
				documentoContableAux.setNumeroMaqueta(partes[x].substring(18, 24).replaceAll("\\s+", ""));
				documentoContableAux.setNumeroExpediente(partes[x].substring(24, 49));
				listaNumeroExpedientes.add(documentoContableAux.getNumeroExpediente().replaceAll("\\s+", ""));
				/*
				 * initForm.setListaNumeroExpedientes(new ArrayList<String>());
				 * initForm.getListaNumeroExpedientes().add(
				 * documentoContableAux.getNumeroExpediente());
				 */

				String fechaOriginal = partes[x].substring(49, 63);

				Date formatter = new SimpleDateFormat("yyyyMMddhhmmss").parse(fechaOriginal);
				// String krwtrDate = new SimpleDateFormat("yyyy-MM-dd",
				// Locale.ENGLISH).format(formatter);
				// Date date = formatter.parse(fechaOriginal);
				documentoContableAux.setFechaActualizacion(formatter);

				fechaOriginal = partes[x].substring(63, 71);
				formatter = new SimpleDateFormat("yyyyMMdd").parse(fechaOriginal);
				documentoContableAux.setFechaContabilizacion(formatter);

				if ("0".equals(partes[x].substring(71, 72))) {
					documentoContableAux.setIndicadorError(partes[x].substring(71, 72));
				}

				documentoContableAux.setFechaUltModificacion(new Date());

				Authentication aut = SecurityContextHolder.getContext().getAuthentication();
				Usuario usuario = new Usuario();
				String username = "";
				if (null != aut) {
					username = (String) aut.getPrincipal();
				}
				usuario.setNombreUsuario(username);

				documentoContableAux.setUsuarioUltModificacion(usuario.getNombreUsuario());

				// Solo si es de Tipo D
				if ("D".equals(partes[x - 1].substring(1, 5).replaceAll("\\s+", ""))) {
					documentosContablesService.updateRegistrosDocContableMAK(documentoContableAux);
					// documentoContableAux.setEstado(true);
				}
				x = x + 1;

			} catch (ParseException pe) {
				ModuloContableController.logger.error("[ERROR] : Error al parsear");
				x = x + 1;
			} catch (Exception e) {
				ModuloContableController.logger.error("[ERROR] : Error al leer el archivo");
				x = x + 1;
			}

		}
	}

	public void leerArchivoREL(String[] partes) {
		listaNumeroExpedientes = new ArrayList<String>();
		for (int x = 0; x < partes.length; x++) {
			try {
				DocumentosContables documentoContableAux = new DocumentosContables();

				// documentoContableAux.setEstado(false);

				documentoContableAux.setNumeroApunte(partes[x].substring(22, 28).replaceAll("\\s+", ""));
				documentoContableAux.setRefIntD(partes[x].substring(42, 46).replaceAll("\\s+", ""));
				documentoContableAux.setRefIntO(partes[x].substring(46, 50).replaceAll("\\s+", ""));
				documentoContableAux.setNumeroOrden(partes[x].substring(50, 54).replaceAll("\\s+", ""));
				documentoContableAux.setNumeroOrdenMV(partes[x].substring(54, 58).replaceAll("\\s+", ""));
				documentoContableAux.setNumeroExpediente(partes[x].substring(58, 83));

				listaNumeroExpedientes.add(documentoContableAux.getNumeroExpediente().replaceAll("\\s+", ""));

				String fechaOriginal = partes[x].substring(83, 91);
				Date formatter = new SimpleDateFormat("yyyyMMdd").parse(fechaOriginal);

				documentoContableAux.setFechaContabilizacion(formatter);
				documentoContableAux.setReferencial(partes[x].substring(91, 98).replaceAll("\\s+", ""));
				documentoContableAux.setNumeroApunteEP(partes[x].substring(98, 104).replaceAll("\\s+", ""));

				documentoContableAux.setFechaUltModificacion(new Date());

				Authentication aut = SecurityContextHolder.getContext().getAuthentication();
				Usuario usuario = new Usuario();
				String username = "";
				if (null != aut) {
					username = (String) aut.getPrincipal();
				}
				usuario.setNombreUsuario(username);

				documentoContableAux.setUsuarioUltModificacion(usuario.getNombreUsuario());

				documentosContablesService.updateRegistrosDocContableREL(documentoContableAux);
				// documentoContableAux.setEstado(true);

			} catch (Exception e) {
				ModuloContableController.logger.error("[ERROR] : Error al leer el archivo");
			}

		}
	}

}
