package com.ejie.ab60.control.moduloContable;

import com.ejie.ab60.model.moduloContable.TiposDocContables;
import com.ejie.ab60.service.moduloContable.TiposDocContablesService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

/**
 * TiposDocContablesController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/tiposdoccontables")

public class TiposDocContablesController {

	private static final Logger logger = LoggerFactory.getLogger(TiposDocContablesController.class);

	@Autowired
	private TiposDocContablesService tiposDocContablesService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoDocCon
	 *            Long
	 * @return TiposDocContables Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idTipoDocCon}", method = RequestMethod.GET)
	public @ResponseBody TiposDocContables get(@PathVariable Long idTipoDocCon) {
		TiposDocContables tiposDocContables = new TiposDocContables();
		tiposDocContables.setIdTipoDocCon(idTipoDocCon);
		tiposDocContables = this.tiposDocContablesService.find(tiposDocContables);
		TiposDocContablesController.logger.info("[GET - findBy_PK] : Obtener TiposDocContables por PK");
		return tiposDocContables;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterTiposDocContables
	 *            TiposDocContables Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<TiposDocContables> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TiposDocContables> getAll(@ModelAttribute TiposDocContables filterTiposDocContables) {
		TiposDocContablesController.logger.info("[GET - find_ALL] : Obtener TiposDocContables por filtro");
		return this.tiposDocContablesService.findAll(filterTiposDocContables, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tiposDocContables
	 *            TiposDocContables Bean que contiene la informacion a
	 *            modificar.
	 * @return TiposDocContables Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TiposDocContables edit(@RequestBody TiposDocContables tiposDocContables) {
		TiposDocContables tiposDocContablesAux = this.tiposDocContablesService.update(tiposDocContables);
		TiposDocContablesController.logger.info("[PUT] : TiposDocContables actualizado correctamente");
		return tiposDocContablesAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tiposDocContables
	 *            TiposDocContables Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return TiposDocContables Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TiposDocContables add(@RequestBody TiposDocContables tiposDocContables) {
		TiposDocContables tiposDocContablesAux = this.tiposDocContablesService.add(tiposDocContables);
		TiposDocContablesController.logger.info("[POST] : TiposDocContables insertado correctamente");
		return tiposDocContablesAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoDocCon
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return TiposDocContables Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoDocCon}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TiposDocContables remove(@PathVariable Long idTipoDocCon) {
		TiposDocContables tiposDocContables = new TiposDocContables();
		tiposDocContables.setIdTipoDocCon(idTipoDocCon);
		this.tiposDocContablesService.remove(tiposDocContables);
		TiposDocContablesController.logger.info("[DELETE] : TiposDocContables borrado correctamente");
		return tiposDocContables;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TiposDocContablesController.logger.info("[GET - View] : tiposdoccontables");
		return "tiposdoccontables";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterTiposDocContables
	 *            TiposDocContables Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<TiposDocContables> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TiposDocContables> filter(
			@RequestJsonBody(param = "filter") TiposDocContables filterTiposDocContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposDocContablesController.logger.info("[POST - filter] : Obtener TiposDocContabless");
		return this.tiposDocContablesService.filter(filterTiposDocContables, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterTiposDocContables
	 *            TiposDocContables Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchTiposDocContables
	 *            TiposDocContables Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<TiposDocContables> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TiposDocContables>> search(
			@RequestJsonBody(param = "filter") TiposDocContables filterTiposDocContables,
			@RequestJsonBody(param = "search") TiposDocContables searchTiposDocContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposDocContablesController.logger.info("[POST - search] : Buscar TiposDocContabless");
		return this.tiposDocContablesService.search(filterTiposDocContables, searchTiposDocContables, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterTiposDocContables
	 *            TiposDocContables Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TiposDocContables filterTiposDocContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposDocContablesController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples TiposDocContabless");
		this.tiposDocContablesService.removeMultiple(filterTiposDocContables, jqGridRequestDto, false);
		TiposDocContablesController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterTiposDocContables
	 *            TiposDocContables Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposDocContables>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposDocContables>> jerarquia(
			@RequestJsonBody(param = "filter") TiposDocContables filterTiposDocContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposDocContablesController.logger.info("[POST - jerarquia] : Obtener TiposDocContabless jerarquia");
		return this.tiposDocContablesService.jerarquia(filterTiposDocContables, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterTiposDocContables
	 *            TiposDocContables Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<TiposDocContables>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TiposDocContables>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TiposDocContables filterTiposDocContables,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TiposDocContablesController.logger.info("[POST - jerarquia] : Obtener TiposDocContabless jerarquia - Hijos");
		return this.tiposDocContablesService.jerarquiaChildren(filterTiposDocContables, jqGridRequestDto);
	}

}
