package com.ejie.ab60.control.pagos;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.pagos.PagosConvocatoria;
import com.ejie.ab60.service.pagos.PagosConvocatoriaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PagosConvocatoriaController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/pagosconvocatoria")

public class PagosConvocatoriaController {

	private static final Logger logger = LoggerFactory.getLogger(PagosConvocatoriaController.class);

	@Autowired
	private PagosConvocatoriaService pagosConvocatoriaService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idPagoConvocatoria
	 *            Integer
	 * @return PagosConvocatoria Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idPagoConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody PagosConvocatoria get(@PathVariable Integer idPagoConvocatoria) {
		PagosConvocatoria pagosConvocatoria = new PagosConvocatoria();
		pagosConvocatoria.setIdPagoConvocatoria(idPagoConvocatoria);
		pagosConvocatoria = this.pagosConvocatoriaService.find(pagosConvocatoria);
		PagosConvocatoriaController.logger.info("[GET - findBy_PK] : Obtener PagosConvocatoria por PK");
		return pagosConvocatoria;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<PagosConvocatoria> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(value = "/comboNumPagos/{idConvocatoria}", method = RequestMethod.GET)
	public @ResponseBody List<PagosConvocatoria> getAll(@ModelAttribute PagosConvocatoria filterPagosConvocatoria,
			@PathVariable("idConvocatoria") Integer idConvocatoria) {
		PagosConvocatoriaController.logger.info("[GET - find_ALL] : Obtener PagosConvocatoria por filtro");
		filterPagosConvocatoria.setConvocatorias(new Convocatorias(idConvocatoria));

		return this.pagosConvocatoriaService.findAllPagos(filterPagosConvocatoria, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria Bean que contiene la informacion a
	 *            modificar.
	 * @return PagosConvocatoria Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody PagosConvocatoria edit(@RequestBody PagosConvocatoria pagosConvocatoria) {
		PagosConvocatoria pagosConvocatoriaAux = this.pagosConvocatoriaService.update(pagosConvocatoria);
		PagosConvocatoriaController.logger.info("[PUT] : PagosConvocatoria actualizado correctamente");
		return pagosConvocatoriaAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param pagosConvocatoria
	 *            PagosConvocatoria Bean que contiene la informacion con la que
	 *            se va a crear el nuevo registro.
	 * @return PagosConvocatoria Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody PagosConvocatoria add(@RequestBody PagosConvocatoria pagosConvocatoria) {
		PagosConvocatoria pagosConvocatoriaAux = this.pagosConvocatoriaService.add(pagosConvocatoria);
		PagosConvocatoriaController.logger.info("[POST] : PagosConvocatoria insertado correctamente");
		return pagosConvocatoriaAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idPagoConvocatoria
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return PagosConvocatoria Bean eliminado.
	 */
	@RequestMapping(value = "/{idPagoConvocatoria}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody PagosConvocatoria remove(@PathVariable Integer idPagoConvocatoria) {
		PagosConvocatoria pagosConvocatoria = new PagosConvocatoria();
		pagosConvocatoria.setIdPagoConvocatoria(idPagoConvocatoria);
		this.pagosConvocatoriaService.remove(pagosConvocatoria);
		PagosConvocatoriaController.logger.info("[DELETE] : PagosConvocatoria borrado correctamente");
		return pagosConvocatoria;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		PagosConvocatoriaController.logger.info("[GET - View] : pagosconvocatoria");
		return "pagosconvocatoria";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<PagosConvocatoria> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<PagosConvocatoria> filter(
			@RequestJsonBody(param = "filter") PagosConvocatoria filterPagosConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PagosConvocatoriaController.logger.info("[POST - filter] : Obtener PagosConvocatorias");
		return this.pagosConvocatoriaService.filter(filterPagosConvocatoria, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param searchPagosConvocatoria
	 *            PagosConvocatoria Bean que contiene los parametros de busqueda
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<PagosConvocatoria> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<PagosConvocatoria>> search(
			@RequestJsonBody(param = "filter") PagosConvocatoria filterPagosConvocatoria,
			@RequestJsonBody(param = "search") PagosConvocatoria searchPagosConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PagosConvocatoriaController.logger.info("[POST - search] : Buscar PagosConvocatorias");
		return this.pagosConvocatoriaService.search(filterPagosConvocatoria, searchPagosConvocatoria, jqGridRequestDto,
				false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") PagosConvocatoria filterPagosConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PagosConvocatoriaController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples PagosConvocatorias");
		this.pagosConvocatoriaService.removeMultiple(filterPagosConvocatoria, jqGridRequestDto, false);
		PagosConvocatoriaController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PagosConvocatoria>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PagosConvocatoria>> jerarquia(
			@RequestJsonBody(param = "filter") PagosConvocatoria filterPagosConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PagosConvocatoriaController.logger.info("[POST - jerarquia] : Obtener PagosConvocatorias jerarquia");
		return this.pagosConvocatoriaService.jerarquia(filterPagosConvocatoria, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterPagosConvocatoria
	 *            PagosConvocatoria Bean que contiene los parametros de filtrado
	 *            a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PagosConvocatoria>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PagosConvocatoria>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") PagosConvocatoria filterPagosConvocatoria,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PagosConvocatoriaController.logger.info("[POST - jerarquia] : Obtener PagosConvocatorias jerarquia - Hijos");
		return this.pagosConvocatoriaService.jerarquiaChildren(filterPagosConvocatoria, jqGridRequestDto);
	}

}
