package com.ejie.ab60.control.plantillas;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.adaptadores.ab61WebServiceAdaptadorService;
import com.ejie.ab60.clientesWS.ab61WebService.Ab61Exception;
import com.ejie.ab60.clientesWS.ab61WebService.Origen;
import com.ejie.ab60.comun.CargarPropiedades;
import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.model.expedientes.RelExpPla;
import com.ejie.ab60.model.plantillas.Documentos;
import com.ejie.ab60.model.plantillas.ParametrosConfig;
import com.ejie.ab60.model.plantillas.Plantillas;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.terceros.DatosTerceros;
import com.ejie.ab60.model.terceros.RelExpTer;
import com.ejie.ab60.model.terceros.TiposTercero;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.plantillas.ParametrosConfigService;
import com.ejie.ab60.service.plantillas.PlantillasService;
import com.ejie.ab60.service.terceros.RelExpTerService;
import com.ejie.ab60.tramita.adapter.PifAdapterService;
import com.ejie.ab60.util.PermisosXLNETS;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

/**
 * PlantillasController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/plantillas")

public class PlantillasController {

	private static final Logger logger = LoggerFactory.getLogger(PlantillasController.class);

	@Autowired
	private PlantillasService plantillasService;

	@Autowired
	private PifAdapterService pifAdapterService;
	@Autowired
	private ab61WebServiceAdaptadorService ab61WebServiceAdaptadorService;

	@Resource
	ReloadableResourceBundleMessageSource appMessageSource;

	@Autowired
	private ParametrosConfigService parametrosConfigService;

	public static final String TEMP_PATH = CargarPropiedades.getConfigAplicacion("TEMP.DIR");

	@Autowired
	private RelExpTerService relExpTerService;

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint/{idProcedimiento}/{idExpediente}", method = RequestMethod.GET)
	public String getFormEditPlantilla(@PathVariable Integer idProcedimiento, @PathVariable String idExpediente,
			Model model) {
		PlantillasController.logger.info("[GET - View] : plantillas");

		/*
		 * Sacamos el valor ( 0 , 1 , 2 ) segun descripcion del parametro de
		 * configuracion
		 */
		model.addAttribute("idProcedimiento", idProcedimiento);
		model.addAttribute("idExpediente", idExpediente);

		ParametrosConfig parametrosConfig = new ParametrosConfig();
		parametrosConfig.setDescripcion(Constantes.CONFIGURACION_DOCUMENTOS);
		parametrosConfig = this.parametrosConfigService.find(parametrosConfig);

		model.addAttribute("parametroConfig", parametrosConfig.getValor());
		// Al mostrar la modal con las plantillas, si tenemos idExpediente
		// estamos a nivel Expediente y ni no lo tenemos estamos a nivel
		// Convocatoria

		model.addAttribute("plantilla", new Plantillas());

		Integer idiomaSolicitante = Constantes.IDIOMA_TODOS;
		String lenguaje = LocaleContextHolder.getLocale().getLanguage();
		model.addAttribute("lenguaje", lenguaje);

		if (!"null".equalsIgnoreCase(idExpediente)) {

			model.addAttribute("origen", Constantes.ORIGEN_EXPEDIENTE);
			List<RelExpTer> listRelExpTer = this.relExpTerService.findParticipantes(Integer.parseInt(idExpediente),
					false);

			String idParticipacion = "";
			List<TiposTercero> listTiposTercero = new ArrayList<TiposTercero>();
			List<DatosTerceros> listDatosTercero = new ArrayList<DatosTerceros>();
			TiposTercero tiposTercero = null;
			DatosTerceros datosTerceros = null;
			for (int i = 0; i < listRelExpTer.size(); i++) {

				// cambio de partcipacion
				if (!idParticipacion.equalsIgnoreCase(listRelExpTer.get(i).getParticipantId())) {
					// para saber que no es el primero
					if (StringUtils.isNotBlank(idParticipacion)) {
						tiposTercero.setTerceroses(listDatosTercero);
						listDatosTercero = new ArrayList<DatosTerceros>();
						listTiposTercero.add(tiposTercero);

					}
					tiposTercero = new TiposTercero();
					tiposTercero.setIdTipoTercero(listRelExpTer.get(i).getTiposTercero().getIdTipoTercero());
					tiposTercero.setDescripcionCastellano(
							listRelExpTer.get(i).getTiposTercero().getDescripcionCastellano());
					tiposTercero.setDescripcionEuskera(listRelExpTer.get(i).getTiposTercero().getDescripcionEuskera());

					datosTerceros = new DatosTerceros();
					datosTerceros.setIdTercero(listRelExpTer.get(i).getDatosTerceros().getIdTercero());
					datosTerceros.setDocumento(listRelExpTer.get(i).getDatosTerceros().getDocumento());
					datosTerceros.setNombre(listRelExpTer.get(i).getDatosTerceros().getNombre());
					datosTerceros.setApellido1(listRelExpTer.get(i).getDatosTerceros().getApellido1());
					datosTerceros.setApellido2(listRelExpTer.get(i).getDatosTerceros().getApellido2());
					datosTerceros.setIdioma(listRelExpTer.get(i).getDatosTerceros().getIdioma());
					datosTerceros.setTipoParticipante(listRelExpTer.get(i).getDatosTerceros().getTipoParticipante());
					listDatosTercero.add(datosTerceros);

					idParticipacion = listRelExpTer.get(i).getParticipantId();

				} else {

					datosTerceros = new DatosTerceros();
					datosTerceros.setIdTercero(listRelExpTer.get(i).getDatosTerceros().getIdTercero());
					datosTerceros.setDocumento(listRelExpTer.get(i).getDatosTerceros().getDocumento());
					datosTerceros.setNombre(listRelExpTer.get(i).getDatosTerceros().getNombre());
					datosTerceros.setApellido1(listRelExpTer.get(i).getDatosTerceros().getApellido1());
					datosTerceros.setApellido2(listRelExpTer.get(i).getDatosTerceros().getApellido2());
					datosTerceros.setIdioma(listRelExpTer.get(i).getDatosTerceros().getIdioma());
					datosTerceros.setTipoParticipante(listRelExpTer.get(i).getDatosTerceros().getTipoParticipante());
					listDatosTercero.add(datosTerceros);

				}

				if (listRelExpTer.get(i).getTiposTercero()
						.getIdTipoTercero() == Constantes.ID_TIPO_TERCERO_SOLICITANTE) {
					idiomaSolicitante = listRelExpTer.get(i).getDatosTerceros().getIdioma();
				}

			}
			tiposTercero.setTerceroses(listDatosTercero);
			listTiposTercero.add(tiposTercero);

			model.addAttribute("listaParticipantes", listTiposTercero);
		} else {
			model.addAttribute("origen", Constantes.ORIGEN_CONVOCATORIA);
		}

		model.addAttribute("idiomaSolicitante", idiomaSolicitante);

		return "plantillas";
	}

	/**
	 * Metodo para llamar al webservice de la AB61 y que me genere el documento
	 * rtf
	 * 
	 * @param model
	 *            Model
	 * @return String
	 * @throws AB61Exception
	 */
	@RequestMapping(value = "/llamarWebService/descargarDocumento/{procedureId}/{folderId}/{idPlantilla}", method = RequestMethod.GET)
	public @ResponseBody String descargarDocumento(@PathVariable String procedureId, @PathVariable String folderId,
			@PathVariable Integer idPlantilla) throws Ab61Exception {
		PlantillasController.logger.info("[GET - descargarDocumento] : descargarDocumento");
		String aplicacion = Constantes.CODIGO_APLICACION;
		String identificador;
		Origen origen;

		if ("0".equals(folderId)) {
			identificador = procedureId;
			origen = Origen.PROCEDIMIENTO;
		} else {
			identificador = folderId;
			origen = Origen.EXPEDIENTE;
		}
		return ab61WebServiceAdaptadorService.descargarDocumentoNegocio(idPlantilla, identificador, origen, aplicacion);

	}

	@RequestMapping(value = "/descargar", method = RequestMethod.POST)
	public @ResponseBody String descargar(HttpServletResponse httpResponse, @ModelAttribute Plantillas plantilla)
			throws Exception {

		String rutaDocumento = plantilla.getRutaDocumento();
		BufferedInputStream contenidoXml = this.pifAdapterService
				.getFile("/" + Constantes.CODIGO_APLICACION + "/" + rutaDocumento);
		int numRead;
		final int bufferSize = 1024;
		byte[] buffer = new byte[bufferSize];
		ByteArrayOutputStream outString = new ByteArrayOutputStream();
		try {
			while ((numRead = contenidoXml.read(buffer)) != -1) {
				outString.write(buffer, 0, numRead);
			}
		} finally {
			contenidoXml.close();
		}
		byte[] strbase64Doc1 = outString.toByteArray();

		// String nombreDocumento =
		// rutaDocumento.substring(rutaDocumento.indexOf("/"));
		String nombreDocumento = rutaDocumento;
		httpResponse.setHeader("Content-Disposition", "attachment; filename=\"" + nombreDocumento + "\"");
		Cookie cookie = new Cookie("fileDownload", "true");
		cookie.setMaxAge(2);
		cookie.setPath("/");
		httpResponse.addCookie(cookie);
		httpResponse.setContentType("application/doc");

		httpResponse.setContentLength(strbase64Doc1.length);
		httpResponse.getOutputStream().write(strbase64Doc1);

		httpResponse.getOutputStream().flush();
		httpResponse.getOutputStream().close();
		return null;
	}

	/**
	 * Metodo para llamar al webservice de la AB61 y que me genere el documento
	 * rtf
	 * 
	 * @param model
	 *            Model
	 * @return String
	 * @throws AB61Exception
	 */
	@RequestMapping(value = "/llamarWebService/{procedureId}/{folderId}/{idPlantilla}", method = RequestMethod.GET)
	public @ResponseBody String generarDocumento(@PathVariable String procedureId, @PathVariable String folderId,
			@PathVariable Integer idPlantilla, @ModelAttribute(value = "usuario") Usuario usuario)
			throws Ab61Exception {
		PlantillasController.logger.info("[GET - generarDocumento] : generarDocumento");

		String identificador;
		Origen origen;

		if ("0".equals(folderId)) {
			identificador = procedureId;
			origen = Origen.PROCEDIMIENTO;
		} else {
			identificador = folderId;
			origen = Origen.EXPEDIENTE;
		}

		return ab61WebServiceAdaptadorService.generarDocumentoNegocio(idPlantilla, identificador, origen,
				usuario.getNombreUsuario().toLowerCase());

	}

	/**
	 * llama al webService que realiza la tarea indicada
	 * 
	 * @param idPlantilla
	 *            Integer
	 * @param procedureId
	 *            String
	 * @param folderId
	 *            String
	 * 
	 */

	@RequestMapping(value = "/llamarWebService/eliminarDocumento/{idPlantilla}/{procedureId}/{folderId}", method = RequestMethod.GET)
	public @ResponseBody String eliminarDocumento(HttpServletRequest httpRequest, @PathVariable Integer idPlantilla,
			@PathVariable String procedureId, @PathVariable String folderId,
			@ModelAttribute(value = "usuario") Usuario usuario) throws Ab61Exception {

		PlantillasController.logger.info("Entrada a eliminarDocumento");

		String identificador;

		if ("0".equals(folderId)) {
			identificador = procedureId;
		} else {
			identificador = folderId;
		}

		return ab61WebServiceAdaptadorService.eliminarDocumentoNegocio(idPlantilla, identificador);

	}

	/**
	 * Metodo para llamar al webservice de la AB61 y que me modifique el
	 * documento rtf
	 * 
	 * @param model
	 *            Model
	 * @return String
	 * @throws AB61Exception
	 */
	@RequestMapping(value = "/llamarWebService/modificarDocumento/{idPlantilla}/{procedureId}/{folderId}", method = RequestMethod.GET)
	public @ResponseBody String modificarDocumento(@PathVariable String procedureId, @PathVariable String folderId,
			@PathVariable Integer idPlantilla, @ModelAttribute(value = "usuario") Usuario usuario)
			throws Ab61Exception {
		PlantillasController.logger.info("[GET - modificarDocumento] : modificarDocumento");
		String nombre = usuario.getNombreUsuario();
		String identificador;

		if ("0".equals(folderId)) {
			identificador = procedureId;
		} else {
			identificador = folderId;
		}

		return ab61WebServiceAdaptadorService.modificarDocumentoNegocio(idPlantilla, identificador, nombre);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPlantillas
	 *            Plantillas Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Plantillas> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/tabla/{idProcedimiento}/{origen}/{procedureId}/{folderId}/{idiomaBusq}/{cambiarIdioma}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Plantillas> filter(
			@RequestJsonBody(param = "filter") Plantillas filterPlantillas, @PathVariable Integer idProcedimiento,
			@PathVariable String procedureId, @PathVariable Integer origen, @PathVariable String folderId,
			@PathVariable Integer idiomaBusq, @PathVariable boolean cambiarIdioma,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {

		PlantillasController.logger.info("[POST - filter] : Obtener Plantillass");

		String identificador;

		if ("0".equals(folderId)) {
			identificador = procedureId;
		} else {
			identificador = folderId;
		}
		filterPlantillas.setProcedimientos(new Procedimientos(idProcedimiento));
		filterPlantillas.setOrigen(origen);
		RelExpPla relExpPla = new RelExpPla();
		relExpPla.setIdentificador(identificador);
		filterPlantillas.setRelExpPla(relExpPla);
		Documentos documentoAux = new Documentos();
		documentoAux.setIdioma(idiomaBusq);
		filterPlantillas.setDocumento(documentoAux);
		filterPlantillas.setCambiarIdioma(cambiarIdioma);

		return this.plantillasService.filter(filterPlantillas, jqGridRequestDto, false);

	}

	/**
	 * llama al webService que realiza la tarea indicada
	 * 
	 * @param idPlantilla
	 *            Integer
	 * @param procedureId
	 *            String
	 * @param folderId
	 *            String
	 * @param n38Login
	 *            String
	 * @return String
	 * @throws Ab61Exception
	 */
	@RequestMapping(value = "/aportarDocumento/{idPlantilla}/{procedureId}/{folderId}", method = RequestMethod.GET)
	public @ResponseBody String aportarDocumento(HttpServletRequest httpRequest, @PathVariable Integer idPlantilla,
			@PathVariable String procedureId, @PathVariable String folderId,
			@ModelAttribute(value = "usuario") Usuario usuario) throws Ab61Exception {

		PlantillasController.logger.info("Entrada a aportarDocumento");

		return this.ab61WebServiceAdaptadorService.aportarDocumentoNegocio(idPlantilla, procedureId, folderId,
				PermisosXLNETS.fncLogin(httpRequest), usuario.getNombreUsuario());
	}

	/**
	 * Captura las excepciones AB61Exception.
	 *
	 */
	@ExceptionHandler(value = { Ab61Exception.class })
	public void handleSQLException(HttpServletRequest request, HttpServletResponse response, Exception ex)
			throws Exception {

		String mensajeError = "";

		if (LocaleContextHolder.getLocale().getLanguage().equalsIgnoreCase(Constantes.CASTELLANO))
			mensajeError = ((Ab61Exception) ex).getFaultInfo().getMensajeCastellano();
		else
			mensajeError = ((Ab61Exception) ex).getFaultInfo().getMensajeEuskera();

		// stated Content-Length
		response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
		response.setContentType("text/html;charset=UTF-8");
		response.getWriter().write(mensajeError);
		response.flushBuffer();
	}
}
