package com.ejie.ab60.control.preguntasExpediente;

import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab60.model.preguntasExpediente.PreguntasExpediente;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.preguntasExpediente.PreguntasExpedienteService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PreguntasExpedienteController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/preguntasexpediente")

public class PreguntasExpedienteController {

	private static final Logger logger = LoggerFactory.getLogger(PreguntasExpedienteController.class);

	@Autowired
	private PreguntasExpedienteService preguntasExpedienteService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idPreguntaExpediente
	 *            Integer
	 * @return PreguntasExpediente Objeto correspondiente al identificador
	 *         indicado.
	 */
	@RequestMapping(value = "/{idPreguntaExpediente}", method = RequestMethod.GET)
	public @ResponseBody PreguntasExpediente get(@PathVariable Integer idPreguntaExpediente) {
		PreguntasExpediente preguntasExpediente = new PreguntasExpediente();
		preguntasExpediente.setIdPreguntaExpediente(idPreguntaExpediente);
		preguntasExpediente = this.preguntasExpedienteService.find(preguntasExpediente);
		PreguntasExpedienteController.logger.info("[GET - findBy_PK] : Obtener PreguntasExpediente por PK");
		return preguntasExpediente;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente Objeto que contiene los parametros de
	 *            filtrado utilizados en la busqueda.
	 * @return List<PreguntasExpediente> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<PreguntasExpediente> getAll(
			@ModelAttribute PreguntasExpediente filterPreguntasExpediente) {
		PreguntasExpedienteController.logger.info("[GET - find_ALL] : Obtener PreguntasExpediente por filtro");
		return this.preguntasExpedienteService.findAll(filterPreguntasExpediente, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param preguntasExpediente
	 *            PreguntasExpediente Bean que contiene la informacion a
	 *            modificar.
	 * @return PreguntasExpediente Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody PreguntasExpediente edit(@RequestBody PreguntasExpediente preguntasExpediente) {
		PreguntasExpediente preguntasExpedienteAux = this.preguntasExpedienteService.update(preguntasExpediente);
		PreguntasExpedienteController.logger.info("[PUT] : PreguntasExpediente actualizado correctamente");
		return preguntasExpedienteAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param preguntasExpediente
	 *            PreguntasExpediente Bean que contiene la informacion con la
	 *            que se va a crear el nuevo registro.
	 * @return PreguntasExpediente Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody PreguntasExpediente add(@RequestBody PreguntasExpediente preguntasExpediente,
			@ModelAttribute("usuario") Usuario usuario, Model model) {

		Date fechaHoy = new Date();
		preguntasExpediente.setFechaRegistro(fechaHoy);
		preguntasExpediente.setUsuarioRegistro(usuario.getNombreUsuario());

		String opcionesCastellano = "";
		String opcionesEuskera = "";

		if (preguntasExpediente.getOpcionesCastellano() != null) {
			opcionesCastellano = preguntasExpediente.getOpcionesCastellano().trim();
		}
		if (preguntasExpediente.getOpcionesEuskera() != null) {
			opcionesEuskera = preguntasExpediente.getOpcionesEuskera().trim();
		}

		preguntasExpediente.setOpcionesCastellano(opcionesCastellano);
		preguntasExpediente.setOpcionesEuskera(opcionesEuskera);

		PreguntasExpediente preguntasExpedienteAux = this.preguntasExpedienteService.add(preguntasExpediente);
		PreguntasExpedienteController.logger.info("[POST] : PreguntasExpediente insertado correctamente");

		return preguntasExpedienteAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idPreguntaExpediente
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return PreguntasExpediente Bean eliminado.
	 */
	@RequestMapping(value = "/{idPreguntaExpediente}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody PreguntasExpediente remove(@PathVariable Integer idPreguntaExpediente) {
		PreguntasExpediente preguntasExpediente = new PreguntasExpediente();
		preguntasExpediente.setIdPreguntaExpediente(idPreguntaExpediente);
		this.preguntasExpedienteService.remove(preguntasExpediente);
		PreguntasExpedienteController.logger.info("[DELETE] : PreguntasExpediente borrado correctamente");
		return preguntasExpediente;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint/{tipoInspecion}", method = RequestMethod.GET)
	public String getFormEdit(Model model, @PathVariable("tipoInspecion") Integer tipoInspeccion) {
		PreguntasExpedienteController.logger.info("[GET - View] : preguntasexpediente");
		model.addAttribute("tipoInspeccion", tipoInspeccion);
		return "preguntasexpediente";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<PreguntasExpediente> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<PreguntasExpediente> filter(
			@RequestJsonBody(param = "filter") PreguntasExpediente filterPreguntasExpediente,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PreguntasExpedienteController.logger.info("[POST - filter] : Obtener PreguntasExpedientes");
		return this.preguntasExpedienteService.filter(filterPreguntasExpediente, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param searchPreguntasExpediente
	 *            PreguntasExpediente Bean que contiene los parametros de
	 *            busqueda a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<PreguntasExpediente> Dto que contiene el resultado de
	 *         la busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<PreguntasExpediente>> search(
			@RequestJsonBody(param = "filter") PreguntasExpediente filterPreguntasExpediente,
			@RequestJsonBody(param = "search") PreguntasExpediente searchPreguntasExpediente,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PreguntasExpedienteController.logger.info("[POST - search] : Buscar PreguntasExpedientes");
		return this.preguntasExpedienteService.search(filterPreguntasExpediente, searchPreguntasExpediente,
				jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") PreguntasExpediente filterPreguntasExpediente,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PreguntasExpedienteController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples PreguntasExpedientes");
		this.preguntasExpedienteService.removeMultiple(filterPreguntasExpediente, jqGridRequestDto, false);
		PreguntasExpedienteController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PreguntasExpediente>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PreguntasExpediente>> jerarquia(
			@RequestJsonBody(param = "filter") PreguntasExpediente filterPreguntasExpediente,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PreguntasExpedienteController.logger.info("[POST - jerarquia] : Obtener PreguntasExpedientes jerarquia");
		return this.preguntasExpedienteService.jerarquia(filterPreguntasExpediente, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterPreguntasExpediente
	 *            PreguntasExpediente Bean que contiene los parametros de
	 *            filtrado a emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<PreguntasExpediente>> Dto que
	 *         contiene el resultado del filtrado realizado por el componente
	 *         RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<PreguntasExpediente>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") PreguntasExpediente filterPreguntasExpediente,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		PreguntasExpedienteController.logger
				.info("[POST - jerarquia] : Obtener PreguntasExpedientes jerarquia - Hijos");
		return this.preguntasExpedienteService.jerarquiaChildren(filterPreguntasExpediente, jqGridRequestDto);
	}

}
