package com.ejie.ab60.control.terceros;

import java.util.List;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderList;
import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.MEC.Participantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.terceros.RelExpTer;
import com.ejie.ab60.model.terceros.VistaDatosExpediente;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.BEC.PuntuacionesService;
import com.ejie.ab60.service.MEC.ParticipantesService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.ab60.service.terceros.RelExpTerService;

/**
 * RelExpTerController  
 * 
 *  
 */

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/relexpter")
public class RelExpTerController {

	private static final Logger logger = LoggerFactory.getLogger(RelExpTerController.class);

	@Autowired
	private RelExpTerService relExpTerService;
	@Autowired
	private ExpedientesService expedientesService;
	@Autowired
	private PuntuacionesService puntuacionesService;
	@Autowired
	private ParticipantesService participantesService;

	@Autowired
	private ConvocatoriasService convocatoriasService;

	@Autowired
	private ProcedimientosService procedimientosService;

	/**
	 * Guardar ubicacion y direccion del solicitante y si es bec tambien la
	 * puntacuion
	 *
	 * @param relExpTerEmp
	 *            RelExpTerEmp Bean que contiene la informacion con la que se va
	 *            a crear el nuevo registro.
	 * @return RelExpTerEmp Bean resultante del proceso de creacion.
	 * @throws Exception
	 */
	@RequestMapping(value = "/guardarInteresadoUbicacion/{idTercero}", method = RequestMethod.POST)
	public ModelAndView addDomicilioUbicacionSolicitante(HttpServletRequest request, Model model, Usuario usuario,
			@PathVariable("idTercero") Integer idTercero, @ModelAttribute(value = "initForm") InitForm initForm)
			throws Exception {

		if (idTercero != 0) {
			this.relExpTerService.addDomicilioUbicacionSolicitante(request, model, usuario, idTercero);
		}
		Expedientes expediente = new Expedientes();
		expediente.setIdExpediente(initForm.getIdExpediente());
		expediente = expedientesService.find(expediente);
		initForm.setIdExpediente(expediente.getIdExpediente());
		initForm.setFolderId(expediente.getFolderId());
		initForm.setFolderNumber(expediente.getFolderNumber());
		initForm.setTituloExpediente(expediente.getTitulo());
		if (null != expediente.getProcedimientos() && null != expediente.getProcedimientos().getIdProcedimiento()) {
			Convocatorias convocatoria = convocatoriasService
					.findWithProcedimiento(expediente.getProcedimientos().getIdProcedimiento());
			initForm.setIdConvocatoria(convocatoria.getIdConvocatoria());
			initForm.setTipoAyuda(convocatoria.getIdTipoAyuda());

		}

		if (null != expediente.getProcedimientos() && null != expediente.getProcedimientos().getCodProcedureId()
				&& !"".equalsIgnoreCase(expediente.getProcedimientos().getCodProcedureId())) {
			initForm.setProcedureId(expediente.getProcedimientos().getCodProcedureId());
			initForm.setIdProcedimientoExpediente(expediente.getProcedimientos().getIdProcedimiento());

		}

		Procedimientos procedimiento = new Procedimientos();
		procedimiento.setIdProcedimiento(expediente.getProcedimientos().getIdProcedimiento());
		procedimiento = this.procedimientosService.findInspeccionable(procedimiento);
		if (procedimiento != null && procedimiento.getInspeccionable() != null) {
			initForm.setInspeccionable(procedimiento.getInspeccionable());
		}

		Integer idActSubPadre = this.procedimientosService.findIdActSubPadre(expediente.getIdExpediente());

		if (idActSubPadre != null) {
			initForm.setInitIdActSubPadre(idActSubPadre);
		}

		model.addAttribute("initForm", initForm);

		return mostrar(model, initForm, usuario);

	}

	// private ModelAndView mostrar(Model model, Convocatorias convocatorias,

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param relExpTer
	 *            RelExpTer Bean que contiene la informacion a modificar.
	 * @return RelExpTer Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody RelExpTer edit(@RequestBody RelExpTer relExpTer) {
		RelExpTer relExpTerAux = this.relExpTerService.update(relExpTer);
		RelExpTerController.logger.info("[PUT] : RelExpTer actualizado correctamente");
		return relExpTerAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param relExpTer
	 *            RelExpTer Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return RelExpTer Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody RelExpTer add(@RequestBody RelExpTer relExpTer) {
		RelExpTer relExpTerAux = this.relExpTerService.add(relExpTer);
		RelExpTerController.logger.info("[POST] : RelExpTer insertado correctamente");
		return relExpTerAux;
	}

	@RequestMapping(value = "/maint/{idExpediente}", method = RequestMethod.POST)
	public ModelAndView mostrarExp(Model model, Procedimientos procedimientos, RelExpTer relExpTer,
			@PathVariable Integer idExpediente, @ModelAttribute(value = "initForm") InitForm initForm, Usuario usuario)
			throws Exception {

		initForm.setIdExpediente(idExpediente);
		Expedientes expediente = new Expedientes();
		expediente.setIdExpediente(idExpediente);
		expediente = expedientesService.find(expediente);
		initForm.setFolderId(expediente.getFolderId());
		if (null != expediente.getProcedimientos() && null != expediente.getProcedimientos().getCodProcedureId()
				&& !"".equalsIgnoreCase(expediente.getProcedimientos().getCodProcedureId())) {
			initForm.setProcedureId(expediente.getProcedimientos().getCodProcedureId());
			initForm.setIdProcedimientoExpediente(expediente.getProcedimientos().getIdProcedimiento());

		}
		initForm.setFolderNumber(expediente.getFolderNumber());
		initForm.setTituloExpediente(expediente.getTitulo());
		if (null != expediente.getProcedimientos() && null != expediente.getProcedimientos().getIdProcedimiento()) {
			Convocatorias convocatoria = convocatoriasService
					.findWithProcedimiento(expediente.getProcedimientos().getIdProcedimiento());
			initForm.setIdConvocatoria(convocatoria.getIdConvocatoria());

			initForm.setTipoAyuda(convocatoria.getIdTipoAyuda());

			Procedimientos procedimiento = new Procedimientos();
			procedimiento.setIdProcedimiento(expediente.getProcedimientos().getIdProcedimiento());
			procedimiento = this.procedimientosService.findInspeccionable(procedimiento);
			if (procedimiento != null && procedimiento.getInspeccionable() != null) {
				initForm.setInspeccionable(procedimiento.getInspeccionable());
			}

		}

		Integer idActSubPadre = this.procedimientosService.findIdActSubPadre(idExpediente);

		if (idActSubPadre != null) {
			initForm.setInitIdActSubPadre(idActSubPadre);
		}

		model.addAttribute("initForm", initForm);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		if (null != initForm.getFolderId()) {
			url = url.replace("[folderID]", initForm.getFolderId());

			model.addAttribute("urlVerDocumentos", url);
		}

		return mostrar(model, initForm, usuario);
	}

	/**
	 * @param model
	 *            Model
	 * @param initForm
	 *            initForm
	 * 
	 * @return ModelAndView
	 * @throws Exception
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public ModelAndView mostrarInit(Model model, @ModelAttribute(value = "initForm") InitForm initForm, Usuario usuario)
			throws Exception {

		Integer idConvocatoria = initForm.getIdConvocatoria();
		String nombreExpediente = initForm.getFolderNumber();
		String tituloExpediente = initForm.getTituloExpediente();

		Procedimientos procedimiento = this.procedimientosService
				.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
		if (procedimiento != null) {
			model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
		}

		model.addAttribute("idConvocatoria", idConvocatoria);
		model.addAttribute("nombreExpediente", nombreExpediente);
		model.addAttribute("tituloExpediente", tituloExpediente);

		Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
		String url = prop.getProperty("urlVerDocumento");
		url = url.replace("[folderID]", initForm.getFolderId());
		model.addAttribute("urlVerDocumentos", url);

		return mostrar(model, initForm, usuario);

	}

	private ModelAndView mostrar(Model model, InitForm initForm, Usuario usuario) throws Exception {

		String idioma = LocaleContextHolder.getLocale().getLanguage();
		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		RelExpTerController.logger.info("autotenticación:getAuthentication" + aut);

		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}

		usuario.setNombreUsuario(username);
		model.addAttribute("usuario", usuario);

		if (null != initForm.getIdExpediente()) {

			Integer idExpediente = initForm.getIdExpediente();
			TFolderList resultado = expedientesService.obtenerInfoPlatea(initForm.getFolderId());

			if (null != resultado) {

				try {
					// Actualizamos el titulo de expediente.
					this.expedientesService.actualizarTituloExpediente(resultado, usuario, initForm);

					// Lista de personas de la Participacion
					relExpTerService.actualizarListParticipantesPorParticipacion(resultado, idExpediente, usuario,
							initForm);
					model.addAttribute("flagSearchFolder", true);
				} catch (Exception e) {

					RelExpTerController.logger.error(e.getMessage());
					model.addAttribute("flagSearchFolder", false);
				}

			} else {
				model.addAttribute("flagSearchFolder", false);
			}
			// Primero obtengo la lista de participaciones de mi BBDD, ya
			// actualiza previamente desde el webService
			List<VistaDatosExpediente> listaParticipantesParticipacion = relExpTerService
					.findParticipaciones(idExpediente, true);
			RelExpTerController.logger.info("[INICIO] Participantes " + listaParticipantesParticipacion.size()
					+ " para el expediente : " + initForm.getIdExpediente());

			Integer idTercero = 0;

			// Sacamos el idTercero del solicitante titular
			for (int i = 0; i < listaParticipantesParticipacion.size(); i++) {
				if (i == 0) {
					model.addAttribute("listaSearch", listaParticipantesParticipacion.get(0).getVistaTercerosList());
					/// Sacamos el id tercero del solicitante titular
					for (int k = 0; k < listaParticipantesParticipacion.get(0).getVistaTercerosList().size(); k++) {
						if (null != listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
								.getIdTipoTercero()) {
							if (listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k).getIdTipoTercero()
									.compareTo(Constantes.PARTICIPACION_SOLICITANTE) == 0) {
								for (int h = 0; h < listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
										.getDatosTercerosList().size(); h++) {

									if (listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
											.getDatosTercerosList().get(h).getTipoParticipante()
											.compareTo(Constantes.PARTICIPANTE_TITULAR) == 0) {
										idTercero = listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
												.getDatosTercerosList().get(h).getIdTercero();

									}

								}

							}

						}
					}
				} else if (i == 1) {
					if (listaParticipantesParticipacion.get(1).getVistaTercerosList().size() > 0) {
						for (int h = 0; h < listaParticipantesParticipacion.get(1).getVistaTercerosList().get(0)
								.getListaDirecciones().size(); h++) {
							int resul = listaParticipantesParticipacion.get(1).getVistaTercerosList().get(0)
									.getListaDirecciones().get(h).getTiposDireccion().getIdTipoDireccion()
									.compareTo(Constantes.ID_DIRECCION_SOLICITANTE);
							if (resul == 0) {
								model.addAttribute("listaDomicilio", listaParticipantesParticipacion.get(1)
										.getVistaTercerosList().get(0).getListaDirecciones().get(h));
							} else {
								model.addAttribute("listaUbicacion", listaParticipantesParticipacion.get(1)
										.getVistaTercerosList().get(0).getListaDirecciones().get(h));
							}

						}
					}
				} else if (i == 2)
					if (listaParticipantesParticipacion.get(1).getVistaTercerosList().size() > 0) {
						model.addAttribute("listaBBDD", listaParticipantesParticipacion.get(2).getVistaTercerosList());
					}
			}
			RelExpTerController.logger.info("[INICIO] Participantes id tercero para comunidad bienes:" + idTercero);
			// le pasamos el idTercero a la comudidad de bienes
			if (idTercero != null) {
				List<Participantes> listaParticipantes = this.participantesService.find(idTercero);
				RelExpTerController.logger.info("[INICIO] Participantes " + listaParticipantes.size()
						+ " para el expediente : " + initForm.getIdExpediente());
				model.addAttribute("txtComunidadBienes", listaParticipantes);
			}
			if (initForm.getTipoAyuda() == Constantes.TIPO_AYUDA_BEC) {
				Puntuaciones puntuacion = new Puntuaciones();
				puntuacion.setIdExpediente(initForm.getIdExpediente());
				Puntuaciones requisitos = this.puntuacionesService.findRequisitos(puntuacion);
				model.addAttribute("txtRequisitos", requisitos);
			}
			model.addAttribute("idTercero", idTercero);
			Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
			model.addAttribute("urlab61", prop.getProperty("URLAB61"));
			model.addAttribute("ab61_folderID", initForm.getFolderId());

			Integer idConvocatoria = initForm.getIdConvocatoria();
			String nombreExpediente = initForm.getFolderNumber();
			String tituloExpediente = initForm.getTituloExpediente();

			Procedimientos procedimiento = this.procedimientosService
					.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
			if (procedimiento != null) {
				model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
			}

			model.addAttribute("idConvocatoria", idConvocatoria);
			model.addAttribute("nombreExpediente", nombreExpediente);
			model.addAttribute("tituloExpediente", tituloExpediente);

			String url = prop.getProperty("urlVerDocumento");
			url = url.replace("[folderID]", initForm.getFolderId());
			model.addAttribute("urlVerDocumentos", url);
			model.addAttribute("lenguaje", idioma);
			return new ModelAndView("datosExpediente", "model", model);
		} else {
			return new ModelAndView("folderError");
		}

	}
}
