package com.ejie.ab60.control.verExpediente;

import java.util.List;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.SessionAttributes;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab60.clientesWS.X43ExpedienteElectronico.TFolderList;
import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.config.Config;
import com.ejie.ab60.model.BEC.Puntuaciones;
import com.ejie.ab60.model.MEC.Participantes;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.expedientes.Expedientes;
import com.ejie.ab60.model.inicio.InitForm;
import com.ejie.ab60.model.procedimientos.Procedimientos;
import com.ejie.ab60.model.terceros.VistaDatosExpediente;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.ab60.service.BEC.PuntuacionesService;
import com.ejie.ab60.service.MEC.ParticipantesService;
import com.ejie.ab60.service.convocatorias.ConvocatoriasService;
import com.ejie.ab60.service.expedientes.ExpedientesService;
import com.ejie.ab60.service.procedimientos.ProcedimientosService;
import com.ejie.ab60.service.terceros.RelExpTerService;

@Controller
@SessionAttributes("usuario")
@RequestMapping(value = "/verexpediente")

public class VerExpedienteController {

	private static final Logger logger = LoggerFactory.getLogger(VerExpedienteController.class);

	@Autowired
	private RelExpTerService relExpTerService;
	@Autowired
	private ExpedientesService expedientesService;
	@Autowired
	private PuntuacionesService puntuacionesService;
	@Autowired
	private ParticipantesService participantesService;
	@Autowired
	private ConvocatoriasService convocatoriasService;
	@Autowired
	private ProcedimientosService procedimientosService;

	@RequestMapping(value = "/{folderId}", method = RequestMethod.GET)
	public ModelAndView mostrarExp(Model model, @PathVariable String folderId,
			@ModelAttribute(value = "initForm") InitForm initForm, Usuario usuario) throws Exception {

		Expedientes expedienteByFolderId = new Expedientes();
		expedienteByFolderId.setFolderId(folderId);
		expedienteByFolderId = expedientesService.findByFolderId(expedienteByFolderId);

		if (expedienteByFolderId != null && expedienteByFolderId.getIdExpediente() != null) {

			initForm.setIdExpediente(expedienteByFolderId.getIdExpediente());
			Expedientes expediente = new Expedientes();
			expediente.setIdExpediente(expedienteByFolderId.getIdExpediente());
			expediente = expedientesService.find(expediente);
			initForm.setFolderId(expediente.getFolderId());
			if (null != expediente.getProcedimientos() && null != expediente.getProcedimientos().getCodProcedureId()
					&& !"".equalsIgnoreCase(expediente.getProcedimientos().getCodProcedureId())) {
				initForm.setProcedureId(expediente.getProcedimientos().getCodProcedureId());
				initForm.setIdProcedimientoExpediente(expediente.getProcedimientos().getIdProcedimiento());

			}
			initForm.setFolderNumber(expediente.getFolderNumber());
			initForm.setTituloExpediente(expediente.getTitulo());
			if (null != expediente.getProcedimientos() && null != expediente.getProcedimientos().getIdProcedimiento()) {
				Convocatorias convocatoria = convocatoriasService
						.findWithProcedimiento(expediente.getProcedimientos().getIdProcedimiento());
				initForm.setIdConvocatoria(convocatoria.getIdConvocatoria());

				initForm.setTipoAyuda(convocatoria.getIdTipoAyuda());

				Procedimientos procedimiento = new Procedimientos();
				procedimiento.setIdProcedimiento(expediente.getProcedimientos().getIdProcedimiento());
				procedimiento = this.procedimientosService.findInspeccionable(procedimiento);
				if (procedimiento != null && procedimiento.getInspeccionable() != null) {
					initForm.setInspeccionable(procedimiento.getInspeccionable());
				}
			}

			Integer idActSubPadre = this.procedimientosService
					.findIdActSubPadre(expedienteByFolderId.getIdExpediente());

			if (idActSubPadre != null) {
				initForm.setInitIdActSubPadre(idActSubPadre);
			}

			model.addAttribute("initForm", initForm);

			Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
			String url = prop.getProperty("urlVerDocumento");
			if (null != initForm.getFolderId()) {
				url = url.replace("[folderID]", initForm.getFolderId());

				model.addAttribute("urlVerDocumentos", url);
			}

			return mostrar(model, initForm, usuario);
		} else {
			return mostrarError();
		}
	}

	private ModelAndView mostrar(Model model, InitForm initForm, Usuario usuario) throws Exception {

		String idioma = LocaleContextHolder.getLocale().getLanguage();
		Authentication aut = SecurityContextHolder.getContext().getAuthentication();
		VerExpedienteController.logger.info("autotenticación:getAuthentication" + aut);

		/** Dejamos el usuario logueado en session */
		String username = "";
		if (null != aut) {
			username = (String) aut.getPrincipal();
		}

		usuario.setNombreUsuario(username);
		model.addAttribute("usuario", usuario);

		if (null != initForm.getIdExpediente()) {

			Integer idExpediente = initForm.getIdExpediente();
			TFolderList resultado = expedientesService.obtenerInfoPlatea(initForm.getFolderId());

			if (null != resultado) {
				try {
					// // Actualizamos el titulo de expediente.
					this.expedientesService.actualizarTituloExpediente(resultado, usuario, initForm);

					// // Lista de personas de la Participacion
					relExpTerService.actualizarListParticipantesPorParticipacion(resultado, idExpediente, usuario,
							initForm);
					model.addAttribute("flagSearchFolder", true);
				} catch (Exception e) {

					VerExpedienteController.logger.error(e.getMessage());
					model.addAttribute("flagSearchFolder", false);
				}
			} else {
				model.addAttribute("flagSearchFolder", false);
			}
			// Primero obtengo la lista de participaciones de mi BBDD, ya
			// actualiza previamente desde el webService
			List<VistaDatosExpediente> listaParticipantesParticipacion = relExpTerService
					.findParticipaciones(idExpediente, true);
			VerExpedienteController.logger.info("[INICIO] Participantes " + listaParticipantesParticipacion.size()
					+ " para el expediente : " + initForm.getIdExpediente());

			Integer idTercero = 0;

			// Sacamos el idTercero del solicitante titular
			for (int i = 0; i < listaParticipantesParticipacion.size(); i++) {
				if (i == 0) {
					model.addAttribute("listaSearch", listaParticipantesParticipacion.get(0).getVistaTercerosList());
					/// Sacamos el id tercero del solicitante titular
					for (int k = 0; k < listaParticipantesParticipacion.get(0).getVistaTercerosList().size(); k++) {
						if (null != listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
								.getIdTipoTercero()) {
							if (listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k).getIdTipoTercero()
									.compareTo(Constantes.PARTICIPACION_SOLICITANTE) == 0) {
								for (int h = 0; h < listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
										.getDatosTercerosList().size(); h++) {

									if (listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
											.getDatosTercerosList().get(h).getTipoParticipante()
											.compareTo(Constantes.PARTICIPANTE_TITULAR) == 0) {
										idTercero = listaParticipantesParticipacion.get(0).getVistaTercerosList().get(k)
												.getDatosTercerosList().get(h).getIdTercero();

									}

								}

							}

						}
					}
				} else if (i == 1) {
					if (listaParticipantesParticipacion.get(1).getVistaTercerosList().size() > 0) {
						for (int h = 0; h < listaParticipantesParticipacion.get(1).getVistaTercerosList().get(0)
								.getListaDirecciones().size(); h++) {
							int resul = listaParticipantesParticipacion.get(1).getVistaTercerosList().get(0)
									.getListaDirecciones().get(h).getTiposDireccion().getIdTipoDireccion()
									.compareTo(Constantes.ID_DIRECCION_SOLICITANTE);
							if (resul == 0) {
								model.addAttribute("listaDomicilio", listaParticipantesParticipacion.get(1)
										.getVistaTercerosList().get(0).getListaDirecciones().get(h));
							} else {
								model.addAttribute("listaUbicacion", listaParticipantesParticipacion.get(1)
										.getVistaTercerosList().get(0).getListaDirecciones().get(h));
							}

						}
					}
				} else if (i == 2)
					if (listaParticipantesParticipacion.get(1).getVistaTercerosList().size() > 0) {
						model.addAttribute("listaBBDD", listaParticipantesParticipacion.get(2).getVistaTercerosList());
					}
			}
			VerExpedienteController.logger.info("[INICIO] Participantes id tercero para comunidad bienes:" + idTercero);
			// le pasamos el idTercero a la comudidad de bienes
			if (idTercero != null) {
				List<Participantes> listaParticipantes = this.participantesService.find(idTercero);
				VerExpedienteController.logger.info("[INICIO] Participantes " + listaParticipantes.size()
						+ " para el expediente : " + initForm.getIdExpediente());
				model.addAttribute("txtComunidadBienes", listaParticipantes);
			}
			if (initForm.getTipoAyuda() == Constantes.TIPO_AYUDA_BEC) {
				Puntuaciones puntuacion = new Puntuaciones();
				puntuacion.setIdExpediente(initForm.getIdExpediente());
				Puntuaciones requisitos = this.puntuacionesService.findRequisitos(puntuacion);
				model.addAttribute("txtRequisitos", requisitos);
			}
			model.addAttribute("idTercero", idTercero);
			Properties prop = Config.loadProperties(Constantes.COD_APPL_CONFIG);
			model.addAttribute("urlab61", prop.getProperty("URLAB61"));
			model.addAttribute("ab61_folderID", initForm.getFolderId());

			Integer idConvocatoria = initForm.getIdConvocatoria();
			String nombreExpediente = initForm.getFolderNumber();
			String tituloExpediente = initForm.getTituloExpediente();

			Procedimientos procedimiento = this.procedimientosService
					.find(new Procedimientos(initForm.getIdProcedimientoExpediente()));
			if (procedimiento != null) {
				model.addAttribute("procedimientoExpediente", procedimiento.getDescripcionConCodProcedure());
			}

			model.addAttribute("idConvocatoria", idConvocatoria);
			model.addAttribute("nombreExpediente", nombreExpediente);
			model.addAttribute("tituloExpediente", tituloExpediente);

			String url = prop.getProperty("urlVerDocumento");
			url = url.replace("[folderID]", initForm.getFolderId());
			model.addAttribute("urlVerDocumentos", url);
			model.addAttribute("lenguaje", idioma);
			return new ModelAndView("datosExpediente", "model", model);
		} else {
			return new ModelAndView("folderError");
		}

	}

	private ModelAndView mostrarError() throws Exception {
		return new ModelAndView("folderError");
	}
}
