package com.ejie.ab60.dao.actuacionesSubvencionables;

import java.math.BigDecimal;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab60.comun.CargarPropiedades;
import com.ejie.ab60.comun.Constantes;
import com.ejie.ab60.comun.utilidades.SecuenciasSQL;
import com.ejie.ab60.dao.convocatorias.ConvocatoriasDao;
import com.ejie.ab60.model.DEC.ActAsociacion;
import com.ejie.ab60.model.DEC.ActAyuntamiento;
import com.ejie.ab60.model.MEC.Facturas;
import com.ejie.ab60.model.PTT.ContratacionesPersonal;
import com.ejie.ab60.model.PTT.GastosTuristicos;
import com.ejie.ab60.model.PTT.PersonasContratadas;
import com.ejie.ab60.model.PTT.PertenenciasRedes;
import com.ejie.ab60.model.PTT.ProductosTuristicos;
import com.ejie.ab60.model.actuacionesSubvencionables.ActSubvencionable;
import com.ejie.ab60.model.actuacionesSubvencionables.RelExpActSub;
import com.ejie.ab60.model.convocatorias.Convocatorias;
import com.ejie.ab60.model.estudioTecnico.Conceptos;
import com.ejie.ab60.model.estudioTecnico.EstudioTecnico;
import com.ejie.ab60.model.estudioTecnico.TiposResultado;
import com.ejie.ab60.model.expedientes.MarcarInspeccionableAct;
import com.ejie.ab60.model.terceros.DatosTerceros;
import com.ejie.ab60.model.usuario.Usuario;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpActSubDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelExpActSubDaoImpl implements RelExpActSubDao {
	private static final Logger logger = LoggerFactory.getLogger(CargarPropiedades.class);

	@Autowired
	private ConvocatoriasDao convocatoriasDao;

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELEXPACTSUB", "IDEXPEDIENTE", "FECHAREGISTRO",
			"USUARIOREGISTRO", "IDACTSUB", "NOTAS", "OBSERVACIONESEUSKERA", "OBSERVACIONESCASTELLANO",
			"IMPORTEADMITIDO", "IMPORTEPRESENTADO", "IMPORTEJUSTPRESENTADO", "IMPORTEJUSTADMITIDO",
			"USUARIOULTMODIFICACION", "FECHAULTMODIFICACION", "ACTSUBVENCIONABLEIDACTSUB", "IDACTSUBPADRE",
			"ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO", "ACTSUBVENCIONABLEDESCRIPCIONEUSKERA",
			"ACTSUBVENCIONABLEPORCENTAJEACTUACION", "ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION",
			"ACTSUBVENCIONABLERUTAXMLCARGA", "ACTSUBVENCIONABLERUTAXMLHIJOCARGA", "ACTSUBVENCIONABLEFECHAREGISTRO",
			"ACTSUBVENCIONABLEUSUARIOREGISTRO", "ACTSUBVENCIONABLEFECHAULTMODIFICACION",
			"ACTSUBVENCIONABLEUSUARIOULTMODIFICACION", "ACTSUBVENCIONABLEIDCONVOCATORIA", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "DESCRIPCASTELLANO", "DESCRIPNEUSKERA", "DESCASTELLANO", "DESEUSKERA", "PUNTOS",
			"FOLDERNUMBER", "DESCRIPCIONES", "DESCRIPCIONEU", "PORCENTAJEJUS", "IMPORTE", "NOTAS", "OBCASTELLANO",
			"OBEUSKERA", "EXENTOIVA", "IMPORTESINIVA", "DESCRIPCION", "SUMAIMPORTES", "IMPORTECONCEDIDO",
			"SUBCALCULADA", "PORCENTAJE", "SUBCALCULADA", "IMPORTECONCEDIDO", "DESCRIPCIONCASTELLANOPT",
			"DESCRIPCIONEUSKERAPT", "DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "IMPORTEADMITIDOACT",
			"IMPORTEPRESENTADOACT", "TITULOACTAYUNTAMIENTO" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelExpActSub> rwMap = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new ActSubvencionable(resultSet.getInt("ActSubvencionableIDACTSUB"),
							resultSet.getString("ActSubvencionableDESCRIPCIONCASTELLANO"),
							resultSet.getString("ActSubvencionableDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("ActSubvencionablePORCENTAJEACTUACION"),
							resultSet.getBigDecimal("ActSubvencionableIMPORTEMINIMOINVERSION"),
							resultSet.getDate("ActSubvencionableFECHAREGISTRO"),
							resultSet.getString("ActSubvencionableUSUARIOREGISTRO"),
							resultSet.getDate("ActSubvencionableFECHAULTMODIFICACION"),
							resultSet.getString("ActSubvencionableUSUARIOULTMODIFICACION"),
							new Convocatorias(resultSet.getInt("ActSubvencionableIDCONVOCATORIA"))),
					resultSet.getInt("ActSubvencionableIDACTSUB"));

		}
	};

	private RowMapper<RelExpActSub> rwMap2 = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new ActSubvencionable(resultSet.getInt("ACTSUBVENCIONABLEIDACTSUB"),
							resultSet.getString("ACTSUBVENCIONABLECAS"), resultSet.getString("ACTSUBVENCIONABLEEUS"),
							resultSet.getBigDecimal("ACTSUBPORCENTAJEACTUACION"),
							resultSet.getBigDecimal("ACTSUBPORCENTAJEACTUACION"),
							resultSet.getDate("ACTSUBFECHAREGISTRO"), resultSet.getString("ACTSUBUSUARIOREGISTRO"),
							resultSet.getDate("ACTSUBFECHAULTMODIFICACION"),
							resultSet.getString("ACTSUBUSUARIOULTMODIFICACION"),
							new Convocatorias(resultSet.getInt("ACTSUBIDCONVOCATORIA"))),
					resultSet.getInt("ACTSUBVENCIONABLEIDACTSUB"));

		}
	};

	private RowMapper<RelExpActSub> rwMapJustificacion = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();

			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdActSub(resultSet.getInt("IDACTSUB"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImporteJustPresentado(resultSet.getBigDecimal("IMPORTEJUSPRESENTADO"));
			relExpActSub.setImporteJustAdmitido(resultSet.getBigDecimal("IMPORTEJUSADMITIDO"));
			relExpActSub.setPorcentajeJus(resultSet.getBigDecimal("PORCENTAJEJUS"));
			relExpActSub.setImporte(resultSet.getBigDecimal("IMPORTE"));
			relExpActSub.setFolderNumber(resultSet.getString("FOLDERNUMBER"));
			relExpActSub.setDescEs(resultSet.getString("DESCRIPCIONES"));
			relExpActSub.setDescEus(resultSet.getString("DESCRIPCIONEU"));

			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapNotasObservaciones = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();

			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setNotas(resultSet.getString("NOTAS"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBSERVACIONESES"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEU"));

			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapExento = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();

			relExpActSub.setExento(resultSet.getInt("EXENTOIVA"));

			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapJustificacionOb = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();

			relExpActSub.setNotas(resultSet.getString("NOTAS"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBCASTELLANO"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBEUSKERA"));

			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapRelExpActPTT14 = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("IDACTSUB"),
					resultSet.getString("NOTAS"), resultSet.getString("OBSERVACIONESEUSKERA"),
					resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					new ActSubvencionable(resultSet.getInt("IDACTSUBPADRE"), null), new PertenenciasRedes(
							resultSet.getInt("IDPERTENENCIAREDES"), resultSet.getString("DENOMINACIONREDES")));
		}

	};

	private RowMapper<RelExpActSub> rwMapRelExpAct = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("IDACTSUB"),
					resultSet.getString("NOTAS"), resultSet.getString("OBSERVACIONESEUSKERA"),
					resultSet.getString("OBSERVACIONESCASTELLANO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					new ActSubvencionable(resultSet.getInt("ORDEN"), null, resultSet.getInt("IDACTSUBPADRE"), null,
							null, resultSet.getString("DESCASTELLANO"), resultSet.getString("DESEUSKERA")));
		}

	};

	private RowMapper<RelExpActSub> rwMapRelExpActEntidadBancaria = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();

			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setIdActSub(resultSet.getInt("IDACTSUB"));
			relExpActSub.setNotas(resultSet.getString("NOTAS"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBSERVACIONESCASTELLANO"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEUSKERA"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));

			ActSubvencionable actSubvencionable = new ActSubvencionable();

			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("IDACTSUBPADRE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESEUSKERA"));
			actSubvencionable.setEntidadBancaria(resultSet.getString("ENTIDADBANCARIA"));

			relExpActSub.setActSubvencionable(actSubvencionable);

			return relExpActSub;

		}

	};

	private RowMapper<RelExpActSub> rwMapfindRelEXpActSubPorExpediente = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdActSub(resultSet.getInt("IDACTSUB"));
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpediente = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("ActSubvencionableIDACTSUBPADRE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			actSubvencionable.setConvocatorias(convocatorias);
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setEstudioTecnico(new EstudioTecnico());
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpedienteMEC = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("ActSubvencionableIDACTSUBPADRE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			actSubvencionable.setConvocatorias(convocatorias);
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setEstudioTecnico(new EstudioTecnico());
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			Facturas factura = new Facturas();
			factura.setDescripcion(resultSet.getString("DESFACTURA"));
			relExpActSub.setFactura(factura);
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpedienteOMIC = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("ActSubvencionableIDACTSUBPADRE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			actSubvencionable.setConvocatorias(convocatorias);
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setEstudioTecnico(new EstudioTecnico());
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setPuntos(resultSet.getInt("PUNTOS"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpedienteEMET = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("ActSubvencionableIDACTSUBPADRE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			actSubvencionable.setConvocatorias(convocatorias);
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setEstudioTecnico(new EstudioTecnico());
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setAyudaConcedida(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpedienteCOVIDT = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("ActSubvencionableIDACTSUBPADRE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			actSubvencionable.setEntidadBancaria(resultSet.getString("ENTIDADBANCARIA"));
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			actSubvencionable.setConvocatorias(convocatorias);
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setEstudioTecnico(new EstudioTecnico());
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setAyudaConcedida(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpedienteCTP = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("ActSubvencionableIDACTSUBPADRE"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			Convocatorias convocatorias = new Convocatorias();
			convocatorias.setIdConvocatoria(resultSet.getInt("IDCONVOCATORIA"));
			actSubvencionable.setConvocatorias(convocatorias);
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setEstudioTecnico(new EstudioTecnico());
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setAyudaConcedida(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpedientePTT = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setInspeccionable(resultSet.getInt("INSPECCIONABLE"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBSERVACIONESCASTELLANO"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEUSKERA"));
			relExpActSub.setNotas(resultSet.getString("NOTAS"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("IDACTSUBPADRE"));
			// actSubvencionable.setIdActSubComboHijo(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			actSubvencionable.setIdActSubAgrupacion(resultSet.getInt("IDACTSUBAGRUPACION"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			ContratacionesPersonal contratacionesPersonal = new ContratacionesPersonal();
			contratacionesPersonal.setIdContratacionPersonal(resultSet.getInt("IDCONTRATACIONPERSONAL"));
			contratacionesPersonal.setNombre(resultSet.getString("NOMBRECP"));
			contratacionesPersonal.setApellido1(resultSet.getString("APELLIDO1CP"));
			contratacionesPersonal.setApellido2(resultSet.getString("APELLIDO2CP"));
			contratacionesPersonal.setIdSexo(resultSet.getLong("IDSEXOCP"));
			contratacionesPersonal.setPeriodoContratacion(resultSet.getString("PERIODO_CONTRATACIONCP"));
			contratacionesPersonal.setIdModalidadContrato(resultSet.getLong("IDMODALIDADCONTRATOCP"));
			contratacionesPersonal.setEmpresaContratada(resultSet.getString("EMPRESACONTRATADACP"));
			relExpActSub.setContratacionesPersonal(contratacionesPersonal);
			GastosTuristicos gastosTuristicos = new GastosTuristicos();
			gastosTuristicos.setIdGastosTuristicos(resultSet.getInt("IDGASTOSTURISTICOS"));
			gastosTuristicos.setDenominacion(resultSet.getString("DENOMINACION"));
			ProductosTuristicos productosTuristicos = new ProductosTuristicos();
			productosTuristicos.setIdProductoTuristico(resultSet.getLong("IDPRODUCTOTURISTICO"));
			productosTuristicos.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANOPT"));
			productosTuristicos.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERAPT"));
			gastosTuristicos.setProductosTuristicos(productosTuristicos);
			// productosTuristicosGastos.setIdProductoTuristico(idProductoTuristico);
			relExpActSub.setGastosTuristicos(gastosTuristicos);
			PertenenciasRedes pertenenciasRedes = new PertenenciasRedes();
			pertenenciasRedes.setIdPertenenciaRedes(resultSet.getInt("IDPERTENENCIAREDES"));
			pertenenciasRedes.setDenominacion(resultSet.getString("DENOMINACIONREDES"));
			relExpActSub.setPertenenciasRedes(pertenenciasRedes);
			relExpActSub.setProductosTuristicos(productosTuristicos);
			PersonasContratadas personasContratadas = new PersonasContratadas();
			personasContratadas.setIdPersonaContratada(resultSet.getInt("IDPERSONACONTRATADA"));
			personasContratadas.setNombrePC(resultSet.getString("NOMBREPC"));
			personasContratadas.setApellido1PC(resultSet.getString("APELLIDO1PC"));
			personasContratadas.setApellido2PC(resultSet.getString("APELLIDO2PC"));
			relExpActSub.setPersonasContratadas(personasContratadas);
			relExpActSub.setAyudaConcedida(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorExpedientePTT2 = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setInspeccionable(resultSet.getInt("INSPECCIONABLE"));
			relExpActSub.setObservacionesCastellano(resultSet.getString("OBSERVACIONESCASTELLANO"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBSERVACIONESEUSKERA"));
			relExpActSub.setNotas(resultSet.getString("NOTAS"));
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setIdActSubPadre(resultSet.getInt("IDACTSUBPADRE"));
			// actSubvencionable.setIdActSubComboHijo(resultSet.getInt("ActSubvencionableIDACTSUB"));
			actSubvencionable.setDescripcionCastellano(resultSet.getString("ActDESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("ActDESCRIPCIONEUSKERA"));
			actSubvencionable.setIdActSubAgrupacion(resultSet.getInt("IDACTSUBAGRUPACION"));
			relExpActSub.setActSubvencionable(actSubvencionable);
			ContratacionesPersonal contratacionesPersonal = new ContratacionesPersonal();
			contratacionesPersonal.setIdContratacionPersonal(resultSet.getInt("IDCONTRATACIONPERSONAL"));
			contratacionesPersonal.setNombre(resultSet.getString("NOMBRECP"));
			contratacionesPersonal.setApellido1(resultSet.getString("APELLIDO1CP"));
			contratacionesPersonal.setApellido2(resultSet.getString("APELLIDO2CP"));
			contratacionesPersonal.setIdSexo(resultSet.getLong("IDSEXOCP"));
			contratacionesPersonal.setPeriodoContratacion(resultSet.getString("PERIODO_CONTRATACIONCP"));
			contratacionesPersonal.setIdModalidadContrato(resultSet.getLong("IDMODALIDADCONTRATOCP"));
			contratacionesPersonal.setEmpresaContratada(resultSet.getString("EMPRESACONTRATADACP"));
			relExpActSub.setContratacionesPersonal(contratacionesPersonal);
			GastosTuristicos gastosTuristicos = new GastosTuristicos();
			gastosTuristicos.setIdGastosTuristicos(resultSet.getInt("IDGASTOSTURISTICOS"));
			gastosTuristicos.setDenominacion(resultSet.getString("DENOMINACION"));
			ProductosTuristicos productosTuristicos = new ProductosTuristicos();
			productosTuristicos.setIdProductoTuristico(resultSet.getLong("IDPRODUCTOTURISTICO"));
			productosTuristicos.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANOPT"));
			productosTuristicos.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERAPT"));
			gastosTuristicos.setProductosTuristicos(productosTuristicos);
			// productosTuristicosGastos.setIdProductoTuristico(idProductoTuristico);
			relExpActSub.setGastosTuristicos(gastosTuristicos);
			PertenenciasRedes pertenenciasRedes = new PertenenciasRedes();
			pertenenciasRedes.setIdPertenenciaRedes(resultSet.getInt("IDPERTENENCIAREDES"));
			pertenenciasRedes.setDenominacion(resultSet.getString("DENOMINACIONREDES"));
			relExpActSub.setPertenenciasRedes(pertenenciasRedes);
			relExpActSub.setProductosTuristicos(productosTuristicos);
			PersonasContratadas personasContratadas = new PersonasContratadas();
			personasContratadas.setIdPersonaContratada(resultSet.getInt("IDPERSONACONTRATADA"));
			personasContratadas.setNombrePC(resultSet.getString("NOMBREPC"));
			personasContratadas.setApellido1PC(resultSet.getString("APELLIDO1PC"));
			personasContratadas.setApellido2PC(resultSet.getString("APELLIDO2PC"));
			relExpActSub.setPersonasContratadas(personasContratadas);
			relExpActSub.setAyudaConcedida(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorDEC = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getBigDecimal("SUBVENCIONCALCULADA"), resultSet.getBigDecimal("PORCENTAJE"),
					new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"), resultSet.getString("TITULO")),
					new ActAsociacion(resultSet.getInt("IDACTASOCIACION"), resultSet.getString("TITULO"), null, null,
							null, null, null, null),
					resultSet.getBigDecimal("IMPORTETOTAL"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					new ActSubvencionable(resultSet.getInt("ORDEN"), resultSet.getInt("IDACTSUB"),
							resultSet.getInt("IDACTSUBPADRE"), resultSet.getInt("ACTSUBPADREAGRUPACION"),
							new Convocatorias(resultSet.getInt("IDCONVOCATORIA")),
							resultSet.getString("TIPOCASTELLANO"), resultSet.getString("TIPOEUSKERA")));

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorEMCO = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getBigDecimal("SUBVENCIONCALCULADA"), resultSet.getBigDecimal("PORCENTAJE"),
					new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"), resultSet.getString("TITULO")),
					new Facturas(resultSet.getInt("IDACTASOCIACION"), resultSet.getString("TITULO")),
					resultSet.getBigDecimal("IMPORTETOTAL"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					new ActSubvencionable(resultSet.getInt("ORDEN"), resultSet.getInt("IDACTSUB"),
							resultSet.getInt("IDACTSUBPADRE"), resultSet.getInt("ACTSUBPADREAGRUPACION"),
							new Convocatorias(resultSet.getInt("IDCONVOCATORIA")),
							resultSet.getString("TIPOCASTELLANO"), resultSet.getString("TIPOEUSKERA")));

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorEMCOExcel = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			Conceptos conceptos = new Conceptos();

			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			conceptos.setConcepto(resultSet.getString("TITULOACTAYUNTAMIENTO"));

			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOACT"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOACT"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));

			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setConceptos(conceptos);

			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapRelActSubPorEMCOEmpreExcel = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();
			ActSubvencionable actSubvencionable = new ActSubvencionable();
			Facturas factura = new Facturas();

			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			factura.setDescripcion(resultSet.getString("DESCRIPCION"));

			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTE"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTE_ADMITIDO"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBVENCIONCALCULADA"));

			relExpActSub.setActSubvencionable(actSubvencionable);
			relExpActSub.setFactura(factura);

			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapTotales = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));

			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapTotalesEMCO = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapTotalesAct = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setImporteJustPresentado(resultSet.getBigDecimal("IMPORTE"));
			relExpActSub.setImporteJustAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));

			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapTotalesJus = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			return new RelExpActSub(resultSet.getBigDecimal("IMPORTEPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEADMITIDO"), resultSet.getBigDecimal("IMPORTEJUSPRESENTADO"),
					resultSet.getBigDecimal("IMPORTEJUSADMITIDO"), resultSet.getBigDecimal("PORCENTAJEJUS"),
					resultSet.getBigDecimal("IMPORTE"));
		}
	};

	private RowMapper<RelExpActSub> rwMapTotalesJus2 = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setImporteJustPresentado(resultSet.getBigDecimal("IMPORTEJUSPRESENTADO"));
			relExpActSub.setImporteJustAdmitido(resultSet.getBigDecimal("IMPORTEJUSADMITIDO"));

			return relExpActSub;
		}
	};

	private RowMapper<RelExpActSub> rwMapPK = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
		}
	};

	private RowMapper<RelExpActSub> rwMapPKIdActSub = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(new ActSubvencionable(resultSet.getInt("IDACTSUB")));
		}
	};

	private RowMapper<RelExpActSub> rwMapDEC = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("INSPECCIONABLE"),
					resultSet.getString("OBSERVACIONESINSCAS"), resultSet.getString("OBSERVACIONESINSEUS"),
					resultSet.getBigDecimal("IMPORTEPRESENTADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getString("NOTAS"), resultSet.getString("OBSERVACIONESCASTELLANO"),
					resultSet.getString("OBSERVACIONESEUSKERA"),
					new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"),
							new RelExpActSub(resultSet.getInt("IDRELEXPACTSUBAYUNTAMIENTO")),
							resultSet.getString("TITULOAYUNTAMIENTO"),
							resultSet.getBigDecimal("PRESUPUESTOMATERIALAYUN"),
							resultSet.getBigDecimal("IMPORTEIVAAYUNTAMIENTO"),
							resultSet.getDate("FECHAADJUDICACIONAYUNTAMIENTO"),
							resultSet.getDate("FECHAINICIOAYUNTAMIENTO"), resultSet.getDate("FECHAFINAYUNTAMIENTO")),
					new ActAsociacion(resultSet.getInt("IDACTASOCIACION"),
							new RelExpActSub(resultSet.getInt("IDRELEXPACTSUBASOCIACION")),
							resultSet.getString("TITULOASOCIACION"), resultSet.getDate("FECHAINICIOASOCIACION"),
							resultSet.getDate("FECHAFINASOCIACION"), resultSet.getString("DESCRIPCIONASOCIACION")),
					new ActSubvencionable(null, resultSet.getInt("IDACTSUB"), resultSet.getInt("IDACTSUBPADRE"), null,
							null, resultSet.getString("DESCRIPCIONCASTELLANO"),
							resultSet.getString("DESCRIPCIONEUSKERA")));
		}
	};

	private RowMapper<RelExpActSub> rwMapEMCO = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"), resultSet.getInt("INSPECCIONABLE"),
					resultSet.getString("OBSERVACIONESINSCAS"), resultSet.getString("OBSERVACIONESINSEUS"),
					resultSet.getBigDecimal("IMPORTEPRESENTADO"), resultSet.getBigDecimal("IMPORTEADMITIDO"),
					resultSet.getString("NOTAS"), resultSet.getString("OBSERVACIONESCASTELLANO"),
					resultSet.getString("OBSERVACIONESEUSKERA"),
					new ActAyuntamiento(resultSet.getInt("IDACTAYUNTAMIENTO"),
							new RelExpActSub(resultSet.getInt("IDRELEXPACTSUBAYUNTAMIENTO")),
							resultSet.getString("TITULOAYUNTAMIENTO"), resultSet.getString("DESCRIPCION"), null, null,
							null, resultSet.getDate("FECHAINICIOAYUNTAMIENTO"),
							resultSet.getDate("FECHAFINAYUNTAMIENTO")),
					new ActAsociacion(resultSet.getInt("IDACTASOCIACION"),
							new RelExpActSub(resultSet.getInt("IDRELEXPACTSUBASOCIACION")),
							resultSet.getString("TITULOASOCIACION"), resultSet.getDate("FECHAINICIOASOCIACION"),
							resultSet.getDate("FECHAFINASOCIACION"), resultSet.getString("DESCRIPCIONASOCIACION")),
					new ActSubvencionable(null, resultSet.getInt("IDACTSUB"), resultSet.getInt("IDACTSUBPADRE"), null,
							null, resultSet.getString("DESCRIPCIONCASTELLANO"),
							resultSet.getString("DESCRIPCIONEUSKERA")));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<RelExpActSub> rwSumaImportesFacturasEMCO = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relexpactsub = new RelExpActSub();

			relexpactsub.setImportePresentado(resultSet.getBigDecimal("SUMAIMPORTES"));
			relexpactsub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));

			return relexpactsub;
		}
	};

	private RowMapper<JerarquiaDto<RelExpActSub>> rwMapJerarquia = new RowMapper<JerarquiaDto<RelExpActSub>>() {
		public JerarquiaDto<RelExpActSub> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relexpactsub = new RelExpActSub(resultSet.getInt("IDRELEXPACTSUB"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new ActSubvencionable(resultSet.getInt("ActSubvencionableIDACTSUB"),
							resultSet.getString("ActSubvencionableDESCRIPCIONCASTELLANO"),
							resultSet.getString("ActSubvencionableDESCRIPCIONEUSKERA"),
							resultSet.getBigDecimal("ActSubvencionablePORCENTAJEACTUACION"),
							resultSet.getBigDecimal("ActSubvencionableIMPORTEMINIMOINVERSION"),
							resultSet.getDate("ActSubvencionableFECHAREGISTRO"),
							resultSet.getString("ActSubvencionableUSUARIOREGISTRO"),
							resultSet.getDate("ActSubvencionableFECHAULTMODIFICACION"),
							resultSet.getString("ActSubvencionableUSUARIOULTMODIFICACION"),
							new Convocatorias(resultSet.getInt("ActSubvencionableIDCONVOCATORIA"))),
					resultSet.getInt("ActSubvencionableIDACTSUB"));

			JerarquiaDto<RelExpActSub> jerarquia = new JerarquiaDto<RelExpActSub>();
			jerarquia.setModel(relexpactsub);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	private RowMapper<RelExpActSub> rwMapEmpTer = new RowMapper<RelExpActSub>() {
		SimpleDateFormat formatoDeFecha = new SimpleDateFormat("dd/MM/yyyy hh:mm:ss");

		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			String folderNumber = "";
			String titulo = "";
			Date fechaEntrada = null;
			Date fechaDoc = null;
			Date fechaUltaPor = null;
			BigDecimal importePresentado = null;
			BigDecimal importeAdmitido = null;
			BigDecimal subvencionCalculada = null;
			BigDecimal subvencionResuelta = null;
			String descripcionCastellano = "";
			String descripcionEuskera = "";
			String documento = "";
			String nombre = "";
			String apellido1 = "";
			String apellido2 = "";
			Integer idTipoAyuda = resultSet.getInt("IDTIPOAYUDA");

			try {
				if (null != resultSet.getString("FOLDERNUMBER")) {
					folderNumber = resultSet.getString("FOLDERNUMBER");
				}
				if (null != resultSet.getString("TITULO")) {
					titulo = resultSet.getString("TITULO");
				}
				if (null != resultSet.getString("FECHAENTRADA")) {
					fechaEntrada = formatoDeFecha.parse(resultSet.getString("FECHAENTRADA"));
				}
				if (null != resultSet.getString("FECHADOCFORMAL")) {
					fechaDoc = formatoDeFecha.parse(resultSet.getString("FECHADOCFORMAL"));
				}
				if (null != resultSet.getString("FECHAULTAPOR")) {
					fechaUltaPor = formatoDeFecha.parse(resultSet.getString("FECHAULTAPOR"));
				}
				if (null != resultSet.getBigDecimal("IMPORTEPRESENTADO")) {
					importePresentado = resultSet.getBigDecimal("IMPORTEPRESENTADO");
				}
				if (null != resultSet.getBigDecimal("IMPORTEADMITIDO")) {
					importeAdmitido = resultSet.getBigDecimal("IMPORTEADMITIDO");
				}
				if (null != resultSet.getBigDecimal("SUBVENCIONCALCULADA")) {
					subvencionCalculada = resultSet.getBigDecimal("SUBVENCIONCALCULADA");
				}
				if (null != resultSet.getBigDecimal("SUBVENCIONRESUELTA")) {
					subvencionResuelta = resultSet.getBigDecimal("SUBVENCIONRESUELTA");
				}
				if (null != resultSet.getString("DESCRIPCIONCASTELLANO")) {
					descripcionCastellano = resultSet.getString("DESCRIPCIONCASTELLANO");
				}
				if (null != resultSet.getString("DESCRIPCIONEUSKERA")) {
					descripcionEuskera = resultSet.getString("DESCRIPCIONEUSKERA");
				}

				if (null != resultSet.getString("NOMBRE")) {
					nombre = resultSet.getString("NOMBRE");
				}
				if (null != resultSet.getString("DOCUMENTO")) {
					documento = resultSet.getString("DOCUMENTO");
				}

				if (null != resultSet.getString("APELLIDO1")) {
					apellido1 = resultSet.getString("APELLIDO1");
				}
				if (null != resultSet.getString("APELLIDO2")) {
					apellido2 = resultSet.getString("APELLIDO2");
				}
			} catch (ParseException e) {
				logger.error(
						"Excepcion recogida en el mapRow al parsear las fechas de la busqueda de expedientes =  " + e);
			}
			logger.info("fechaEntrada = " + fechaEntrada);
			logger.info("fechaDoc = " + fechaDoc);
			logger.info("fechaUltaPor = " + fechaUltaPor);

			RelExpActSub expedientes = new RelExpActSub();
			expedientes.setIdExpediente(resultSet.getInt("IDEXPEDIENTE"));
			expedientes.setFolderNumber(folderNumber);
			EstudioTecnico estudioTecnico = new EstudioTecnico();
			TiposResultado tipoResultado = new TiposResultado();

			DatosTerceros datosTerceros = new DatosTerceros();

			if (idTipoAyuda != Constantes.TIPO_AYUDA_BEC) {
				estudioTecnico.setImportePresentado(importePresentado);
				estudioTecnico.setImporteAdmitido(importeAdmitido);
				estudioTecnico.setSubvencionCalculada(subvencionCalculada);
				estudioTecnico.setSubvencionResuelta(subvencionResuelta);
				expedientes.setEstudioTecnico(estudioTecnico);
				tipoResultado.setDescripcionCastellano(descripcionCastellano);
				tipoResultado.setDescripcionEuskera(descripcionEuskera);

				datosTerceros.setDocumento(documento);
				datosTerceros.setNombre(nombre);
				datosTerceros.setApellido1(apellido1);
				datosTerceros.setApellido2(apellido2);
			} else {
				datosTerceros.setDocumento(documento);
				datosTerceros.setNombre(nombre);
				datosTerceros.setApellido1(apellido1);
				datosTerceros.setApellido2(apellido2);
				expedientes.setEstudioTecnico(estudioTecnico);
			}

			return expedientes;
		}
	};

	private RowMapper<RelExpActSub> rwMapImportesPorExentoSi = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();

			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			relExpActSub.setIdActSub(resultSet.getInt("IDACTSUB"));

			return relExpActSub;

		}
	};

	private RowMapper<RelExpActSub> rwMapImportesPorExentoNo = new RowMapper<RelExpActSub>() {
		public RelExpActSub mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpActSub relExpActSub = new RelExpActSub();

			relExpActSub.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTESINIVA"));
			relExpActSub.setIdActSub(resultSet.getInt("IDACTSUB"));

			return relExpActSub;

		}
	};

	private RowMapper<MarcarInspeccionableAct> rwMapMarcarInspeccionable = new RowMapper<MarcarInspeccionableAct>() {
		public MarcarInspeccionableAct mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MarcarInspeccionableAct marcarInspeccionableAct = new MarcarInspeccionableAct();

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));

			actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			actSubvencionable.setEntidadBancaria(resultSet.getString("ENTIDADBANCARIA"));

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPACT") != null ? resultSet.getInt("ENVIADOINSPACT") : null);
			relExpActSub.setInspeccionable(
					resultSet.getObject("INSPECCIONABLEACT") != null ? resultSet.getInt("INSPECCIONABLEACT") : null);
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOACT"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOACT"));

			relExpActSub.setAyudaConcedida(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));

			relExpActSub.setObservacionesCastellano(resultSet.getString("OBCASTELLANOACT"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBEUSKERAACT"));

			Conceptos conceptos = new Conceptos();
			conceptos.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPCON") != null ? resultSet.getInt("ENVIADOINSPCON") : null);
			conceptos.setInspeccionable(
					resultSet.getObject("INSPECCIONABLECON") != null ? resultSet.getInt("INSPECCIONABLECON") : null);

			if (resultSet.getString("CONCEPTOS") != null) {
				conceptos.setConcepto(resultSet.getString("CONCEPTOS"));
			} else if (resultSet.getString("TITULO") != null) {
				conceptos.setConcepto(resultSet.getString("TITULO"));
			} else if (resultSet.getString("NOMBRE") != null || resultSet.getString("APELLIDO1") != null) {
				String apellido2 = resultSet.getString("APELLIDO2") != null ? resultSet.getString("APELLIDO2") : "";
				conceptos.setConcepto(
						resultSet.getString("NOMBRE") + " " + resultSet.getString("APELLIDO1") + " " + apellido2);
			} else if (resultSet.getString("NOMBREPC") != null || resultSet.getString("APELLIDO1PC") != null) {
				String apellido2PC = resultSet.getString("APELLIDO2PC") != null ? resultSet.getString("APELLIDO2PC")
						: "";
				conceptos.setConcepto(
						resultSet.getString("NOMBREPC") + " " + resultSet.getString("APELLIDO1PC") + " " + apellido2PC);
			}

			conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOCON"));
			conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOCON"));
			conceptos.setObservacionesCastellano(resultSet.getString("OBCASTELLANOCON"));
			conceptos.setObservacionesEuskera(resultSet.getString("OBEUSKERACON"));
			conceptos.setIdConcepto(resultSet.getInt("IDCONCEPTO"));
			conceptos.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));

			marcarInspeccionableAct.setActSubs(actSubvencionable);
			marcarInspeccionableAct.setRelExpActSub(relExpActSub);
			marcarInspeccionableAct.setConceptos(conceptos);

			return marcarInspeccionableAct;

		}
	};

	private RowMapper<MarcarInspeccionableAct> rwMapMarcarInspeccionablePTT = new RowMapper<MarcarInspeccionableAct>() {
		public MarcarInspeccionableAct mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			MarcarInspeccionableAct marcarInspeccionableAct = new MarcarInspeccionableAct();

			ActSubvencionable actSubvencionable = new ActSubvencionable();
			actSubvencionable.setOrden(resultSet.getInt("ORDEN"));
			actSubvencionable.setIdActSub(resultSet.getInt("IDACTSUB"));

			if (resultSet.getString("CONCEPTOS") != null) {

				if (resultSet.getString("DESCRIPCIONCASTELLANOPT") != null
						&& resultSet.getString("DESCRIPCIONEUSKERAPT") != null) {
					actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO") + "("
							+ resultSet.getString("DESCRIPCIONCASTELLANOPT") + ")");
					actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA") + "("
							+ resultSet.getString("DESCRIPCIONEUSKERAPT") + ")");
				} else {
					actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
					actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
				}
			} else if (resultSet.getString("NOMBREPC") != null && resultSet.getString("APELLIDO1PC") != null) {
				String apellido2PC = resultSet.getString("APELLIDO2PC") != null ? resultSet.getString("APELLIDO2PC")
						: "";

				actSubvencionable.setDescripcionCastellano(
						resultSet.getString("DESCRIPCIONCASTELLANO") + "(" + resultSet.getString("NOMBREPC") + " "
								+ resultSet.getString("APELLIDO1PC") + " " + apellido2PC + ")");
				actSubvencionable.setDescripcionEuskera(
						resultSet.getString("DESCRIPCIONEUSKERA") + "(" + resultSet.getString("NOMBREPC") + " "
								+ resultSet.getString("APELLIDO1PC") + " " + apellido2PC + ")");
			} else if (resultSet.getString("NOMBRE") != null && resultSet.getString("APELLIDO1") != null) {
				String apellido2PC = resultSet.getString("APELLIDO2") != null ? resultSet.getString("APELLIDO2") : "";

				actSubvencionable.setDescripcionCastellano(
						resultSet.getString("DESCRIPCIONCASTELLANO") + "(" + resultSet.getString("NOMBRE") + " "
								+ resultSet.getString("APELLIDO1") + " " + apellido2PC + ")");
				actSubvencionable.setDescripcionEuskera(
						resultSet.getString("DESCRIPCIONEUSKERA") + "(" + resultSet.getString("NOMBRE") + " "
								+ resultSet.getString("APELLIDO1") + " " + apellido2PC + ")");
			} else {
				actSubvencionable.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
				actSubvencionable.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));
			}

			RelExpActSub relExpActSub = new RelExpActSub();
			relExpActSub.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPACT") != null ? resultSet.getInt("ENVIADOINSPACT") : null);
			relExpActSub.setInspeccionable(
					resultSet.getObject("INSPECCIONABLEACT") != null ? resultSet.getInt("INSPECCIONABLEACT") : null);
			relExpActSub.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOACT"));
			relExpActSub.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOACT"));

			relExpActSub.setAyudaConcedida(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			relExpActSub.setSubvencionCalculada(resultSet.getBigDecimal("SUBCALCULADA"));
			relExpActSub.setPorcentaje(resultSet.getBigDecimal("PORCENTAJE"));

			relExpActSub.setObservacionesCastellano(resultSet.getString("OBCASTELLANOACT"));
			relExpActSub.setObservacionesEuskera(resultSet.getString("OBEUSKERAACT"));

			Conceptos conceptos = new Conceptos();
			conceptos.setEnviadoInspeccionar(
					resultSet.getObject("ENVIADOINSPCON") != null ? resultSet.getInt("ENVIADOINSPCON") : null);
			conceptos.setInspeccionable(
					resultSet.getObject("INSPECCIONABLECON") != null ? resultSet.getInt("INSPECCIONABLECON") : null);

			if (resultSet.getString("CONCEPTOS") != null) {
				conceptos.setConcepto(resultSet.getString("CONCEPTOS"));
			}

			conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOCON"));
			conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOCON"));

			if (resultSet.getBigDecimal("IMPORTEADMITIDOCON") == null) {
				conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDOACT"));
			}

			if (resultSet.getBigDecimal("IMPORTEPRESENTADOCON") == null) {
				conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADOACT"));
			}

			conceptos.setObservacionesCastellano(resultSet.getString("OBCASTELLANOCON"));
			conceptos.setObservacionesEuskera(resultSet.getString("OBEUSKERACON"));
			conceptos.setIdConcepto(resultSet.getInt("IDCONCEPTO"));
			conceptos.setIdRelExpActSub(resultSet.getInt("IDRELEXPACTSUB"));

			marcarInspeccionableAct.setActSubs(actSubvencionable);
			marcarInspeccionableAct.setRelExpActSub(relExpActSub);
			marcarInspeccionableAct.setConceptos(conceptos);

			return marcarInspeccionableAct;

		}
	};

	private RowMapper<Conceptos> rwMapSumConceptosPorRelExpActSub = new RowMapper<Conceptos>() {
		public Conceptos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			Conceptos conceptos = new Conceptos();

			conceptos.setImportePresentado(resultSet.getBigDecimal("IMPORTEPRESENTADO"));
			conceptos.setImporteAdmitido(resultSet.getBigDecimal("IMPORTEADMITIDO"));
			conceptos.setAyudaSubvencionada(resultSet.getBigDecimal("SUBCALCULADA"));
			conceptos.setImporteConcedido(resultSet.getBigDecimal("IMPORTECONCEDIDO"));
			return conceptos;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Finds el ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findLastId(Integer idExpediente, Integer idActSub) {
		String query = "SELECT MAX (ID_REL_EXP_ACT_SUB) IDRELEXPACTSUB FROM REL_EXP_ACT_SUB WHERE ID_EXPEDIENTE = ? AND ID_ACT_SUB = ?";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapPK, idExpediente, idActSub);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);

	}

	/**
	 * Finds el siguiente al ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findUltimoId() {
		String query = "SELECT S_AB6023T00.NEXTVAL IDRELEXPACTSUB FROM dual";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapPK);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);

	}

	/**
	 * Finds el siguiente al ultimo id de la tabla in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findRelExpActSub(Integer idActSub, Integer idExpediente) {
		String query = "SELECT ID_REL_EXP_ACT_SUB IDRELEXPACTSUB FROM REL_EXP_ACT_SUB WHERE ID_ACT_SUB = ? AND ID_EXPEDIENTE = ?";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapPK, idActSub, idExpediente);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);

	}

	/**
	 * Sumo todos los importes de las Relaciones hijos de un expediente sin su
	 * padre.
	 *
	 * @param idExpediente
	 *            Integer
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findRelExpActHijosPorExpediente(Integer idExpediente) {
		String query = "SELECT SUM(t1.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(t1.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB t1, ACT_SUBVENCIONABLE t2 WHERE t1.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_ACT_SUB_PADRE IS NOT NULL";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapTotales, idExpediente);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);

	}

	/**
	 * Find DEC
	 *
	 * @param idExpediente
	 *            Integer
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findDEC(RelExpActSub relExpActSub) {
		String query = "SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, T1.INSPECCIONABLE INSPECCIONABLE, T1.OBSERVACIONES_INS_CAS OBSERVACIONESINSCAS, T1.OBSERVACIONES_INS_EUS OBSERVACIONESINSEUS, T5.IMPORTE_TOTAL IMPORTEPRESENTADO, T1.IMPORTE_ADMITIDO IMPORTEADMITIDO,T1.NOTAS NOTAS, T1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, T1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t2.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO, T2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUBAYUNTAMIENTO, T2.TITULO TITULOAYUNTAMIENTO, T5.PRESUPUESTO_MATERIAL PRESUPUESTOMATERIALAYUN, T2.IMPORTE_IVA IMPORTEIVAAYUNTAMIENTO, T2.FECHA_ADJUDICACION FECHAADJUDICACIONAYUNTAMIENTO, T2.FECHA_INICIO FECHAINICIOAYUNTAMIENTO, T2.FECHA_FIN FECHAFINAYUNTAMIENTO, T3.ID_ACT_ASOCIACION IDACTASOCIACION, T3.ID_REL_EXP_ACT_SUB IDRELEXPACTSUBASOCIACION, T3.TITULO TITULOASOCIACION, T3.FECHA_INICIO FECHAINICIOASOCIACION, T3.FECHA_FIN FECHAFINASOCIACION, T3.DESCRIPCION DESCRIPCIONASOCIACION, T4.ID_ACT_SUB IDACTSUB, T4.ID_ACT_SUB_PADRE IDACTSUBPADRE, T4.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T4.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM REL_EXP_ACT_SUB T1 LEFT OUTER JOIN AB6022T00 T2 ON T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB LEFT OUTER JOIN AB6024T00 T3 ON T1.ID_REL_EXP_ACT_SUB = T3.ID_REL_EXP_ACT_SUB JOIN AB6006T00 T4 ON T1.ID_ACT_SUB = T4.ID_ACT_SUB LEFT OUTER JOIN ACT_AYUNTAMIENTO T5 ON T1.ID_REL_EXP_ACT_SUB = T5.ID_REL_EXP_ACT_SUB WHERE T1.ID_REL_EXP_ACT_SUB = ?";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapDEC,
				relExpActSub.getIdRelExpActSub());
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);

	}

	@Transactional(readOnly = true)
	public RelExpActSub findEMCO(RelExpActSub relExpActSub) {
		String query = "SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, T1.INSPECCIONABLE INSPECCIONABLE, T1.OBSERVACIONES_INS_CAS OBSERVACIONESINSCAS, T1.OBSERVACIONES_INS_EUS OBSERVACIONESINSEUS, T1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, T1.IMPORTE_ADMITIDO IMPORTEADMITIDO,T1.NOTAS NOTAS, T1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, T1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t2.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO, T2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUBAYUNTAMIENTO, T2.TITULO TITULOAYUNTAMIENTO, T2.DESCRIPCION DESCRIPCION, T2.FECHA_INICIO FECHAINICIOAYUNTAMIENTO, T2.FECHA_FIN FECHAFINAYUNTAMIENTO, T3.ID_ACT_ASOCIACION IDACTASOCIACION, T3.ID_REL_EXP_ACT_SUB IDRELEXPACTSUBASOCIACION, T3.TITULO TITULOASOCIACION, T3.FECHA_INICIO FECHAINICIOASOCIACION, T3.FECHA_FIN FECHAFINASOCIACION, T3.DESCRIPCION DESCRIPCIONASOCIACION, T4.ID_ACT_SUB IDACTSUB, T4.ID_ACT_SUB_PADRE IDACTSUBPADRE, T4.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T4.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA FROM REL_EXP_ACT_SUB T1 LEFT OUTER JOIN AB601ET00 T2 ON T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB LEFT OUTER JOIN AB6024T00 T3 ON T1.ID_REL_EXP_ACT_SUB = T3.ID_REL_EXP_ACT_SUB JOIN AB6006T00 T4 ON T1.ID_ACT_SUB = T4.ID_ACT_SUB WHERE T1.ID_REL_EXP_ACT_SUB = ?";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapEMCO,
				relExpActSub.getIdRelExpActSub());
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);

	}

	/**
	 * Inserts a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub add(RelExpActSub relexpactsub) {
		String query = "INSERT INTO REL_EXP_ACT_SUB (ID_REL_EXP_ACT_SUB, ID_ACT_SUB, ID_EXPEDIENTE,IMPORTE_PRESENTADO,IMPORTE_ADMITIDO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, relexpactsub.getIdRelExpActSub(), relexpactsub.getIdActSub(),
				relexpactsub.getIdExpediente(), relexpactsub.getImportePresentado(), relexpactsub.getImporteAdmitido(),
				relexpactsub.getFechaRegistro(), relexpactsub.getUsuarioRegistro());

		return relexpactsub;
	}

	/**
	 * Inserts a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub anyadirRelacion(RelExpActSub relexpactsub) {
		int idRelExpActSub = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6023T00"));
		relexpactsub.setIdRelExpActSub(idRelExpActSub);
		String query = "INSERT INTO REL_EXP_ACT_SUB (ID_REL_EXP_ACT_SUB, ID_ACT_SUB, ID_EXPEDIENTE, IMPORTE_ADMITIDO, IMPORTE_PRESENTADO, FECHA_REGISTRO, USUARIO_REGISTRO, NOTAS, OBSERVACIONES_CASTELLANO, OBSERVACIONES_EUSKERA, INSPECCIONABLE) VALUES (?,?,?,?,?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, relexpactsub.getIdRelExpActSub(),
				relexpactsub.getActSubvencionable().getIdActSub(), relexpactsub.getIdExpediente(),
				relexpactsub.getImporteAdmitido(), relexpactsub.getImportePresentado(), new Date(),
				relexpactsub.getUsuarioRegistro(), relexpactsub.getNotas(), relexpactsub.getObservacionesCastellano(),
				relexpactsub.getObservacionesEuskera(), relexpactsub.getInspeccionable());

		return relexpactsub;
	}

	public RelExpActSub anyadirRelacionDEC(RelExpActSub relexpactsub) {
		int idRelExpActSub = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6023T00"));
		relexpactsub.setIdRelExpActSub(idRelExpActSub);
		String query = "INSERT INTO REL_EXP_ACT_SUB (ID_REL_EXP_ACT_SUB, ID_ACT_SUB, ID_EXPEDIENTE, IMPORTE_ADMITIDO, IMPORTE_PRESENTADO, FECHA_REGISTRO, USUARIO_REGISTRO, NOTAS, OBSERVACIONES_CASTELLANO, OBSERVACIONES_EUSKERA, INSPECCIONABLE, OBSERVACIONES_INS_CAS, OBSERVACIONES_INS_EUS) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, relexpactsub.getIdRelExpActSub(),
				relexpactsub.getActSubvencionable().getIdActSub(), relexpactsub.getIdExpediente(),
				relexpactsub.getImporteAdmitido(), relexpactsub.getActAyuntamiento().getPresupuestoMaterial(),
				new Date(), relexpactsub.getUsuarioRegistro(), relexpactsub.getNotas(),
				relexpactsub.getObservacionesCastellano(), relexpactsub.getObservacionesEuskera(),
				relexpactsub.getInspeccionable(), relexpactsub.getObservacionesInspCastellano(),
				relexpactsub.getObservacionesInspEuskera());

		return relexpactsub;
	}

	public RelExpActSub anyadirRelacionEMCO(RelExpActSub relexpactsub) {
		int idRelExpActSub = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6023T00"));
		relexpactsub.setIdRelExpActSub(idRelExpActSub);
		String query = "INSERT INTO REL_EXP_ACT_SUB (ID_REL_EXP_ACT_SUB, ID_ACT_SUB, ID_EXPEDIENTE, IMPORTE_ADMITIDO, IMPORTE_PRESENTADO, FECHA_REGISTRO, USUARIO_REGISTRO, NOTAS, OBSERVACIONES_CASTELLANO, OBSERVACIONES_EUSKERA, INSPECCIONABLE, OBSERVACIONES_INS_CAS, OBSERVACIONES_INS_EUS) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, relexpactsub.getIdRelExpActSub(),
				relexpactsub.getActSubvencionable().getIdActSub(), relexpactsub.getIdExpediente(),
				relexpactsub.getImporteAdmitido(), relexpactsub.getImportePresentado(), new Date(),
				relexpactsub.getUsuarioRegistro(), relexpactsub.getNotas(), relexpactsub.getObservacionesCastellano(),
				relexpactsub.getObservacionesEuskera(), relexpactsub.getInspeccionable(),
				relexpactsub.getObservacionesInspCastellano(), relexpactsub.getObservacionesInspEuskera());

		return relexpactsub;
	}

	/**
	 * Inserts a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub anyadirRelacionPadre(RelExpActSub relexpactsub) {
		int idRelExpActSub = this.jdbcTemplate.queryForInt(SecuenciasSQL.getSelectNext("AB60.S_AB6023T00"));
		relexpactsub.setIdRelExpActSub(idRelExpActSub);
		String query = "INSERT INTO REL_EXP_ACT_SUB (ID_REL_EXP_ACT_SUB, ID_ACT_SUB, ID_EXPEDIENTE, IMPORTE_ADMITIDO, IMPORTE_PRESENTADO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, relexpactsub.getIdRelExpActSub(),
				relexpactsub.getActSubvencionable().getIdActSubPadre(), relexpactsub.getIdExpediente(),
				relexpactsub.getImporteAdmitido(), relexpactsub.getImportePresentado(), new Date(),
				relexpactsub.getUsuarioRegistro());

		return relexpactsub;
	}

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub update(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET NOTAS = ?, OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getNotas(), relexpactsub.getObservacionesCastellano(),
				relexpactsub.getObservacionesEuskera(), relexpactsub.getFechaUltmodificacion(),
				relexpactsub.getUsuarioUltmodificacion(), relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	@Override
	public RelExpActSub updateEntidadBancaria(RelExpActSub relExpActSub) {
		String query = "UPDATE ENTIDADES_BANCARIAS SET ENTIDAD_BANCARIA = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relExpActSub.getActSubvencionable().getEntidadBancaria(),
				relExpActSub.getIdRelExpActSub());
		return relExpActSub;
	}

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateDEC(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET SUBVENCION_CALCULADA = ?, PORCENTAJE = ?, INSPECCIONABLE = ?, OBSERVACIONES_INS_CAS=?, OBSERVACIONES_INS_EUS=?, IMPORTE_PRESENTADO = ?, IMPORTE_ADMITIDO = ?, NOTAS = ?, OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getSubvencionCalculada(), relexpactsub.getPorcentaje(),
				relexpactsub.getInspeccionable(), relexpactsub.getObservacionesInspCastellano(),
				relexpactsub.getObservacionesInspEuskera(), relexpactsub.getActAyuntamiento().getPresupuestoMaterial(),
				relexpactsub.getImporteAdmitido(), relexpactsub.getNotas(), relexpactsub.getObservacionesCastellano(),
				relexpactsub.getObservacionesEuskera(), new Date(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	public RelExpActSub updateEMCORelActSub(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET SUBVENCION_CALCULADA = ?, PORCENTAJE = ?, INSPECCIONABLE = ?, OBSERVACIONES_INS_CAS=?, OBSERVACIONES_INS_EUS=?, IMPORTE_PRESENTADO = ?, IMPORTE_ADMITIDO = ?, NOTAS = ?, OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getSubvencionCalculada(), relexpactsub.getPorcentaje(),
				relexpactsub.getInspeccionable(), relexpactsub.getObservacionesInspCastellano(),
				relexpactsub.getObservacionesInspEuskera(), relexpactsub.getActAyuntamiento().getImporteTotal(),
				relexpactsub.getImporteAdmitido(), relexpactsub.getNotas(), relexpactsub.getObservacionesCastellano(),
				relexpactsub.getObservacionesEuskera(), new Date(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateDECsinImportes(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET SUBVENCION_CALCULADA = ?, PORCENTAJE = ?, INSPECCIONABLE = ?, NOTAS = ?, OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getSubvencionCalculada(), relexpactsub.getPorcentaje(),
				relexpactsub.getInspeccionable(), relexpactsub.getNotas(), relexpactsub.getObservacionesCastellano(),
				relexpactsub.getObservacionesEuskera(), new Date(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateSubvencionPorcentaje(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET SUBVENCION_CALCULADA = ?, PORCENTAJE = ? WHERE ID_EXPEDIENTE = ?";

		this.jdbcTemplate.update(query, relexpactsub.getSubvencionCalculada(), relexpactsub.getPorcentaje(),
				relexpactsub.getIdExpediente());
		return relexpactsub;
	}

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Override
	public RelExpActSub updatePTT(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET NOTAS = ? , IMPORTE_PRESENTADO = ?, IMPORTE_ADMITIDO = ?, INSPECCIONABLE = ?, OBSERVACIONES_CASTELLANO = ?, OBSERVACIONES_EUSKERA = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getNotas(), relexpactsub.getImportePresentado(),
				relexpactsub.getImporteAdmitido(), relexpactsub.getInspeccionable(),
				relexpactsub.getObservacionesCastellano(), relexpactsub.getObservacionesEuskera(),
				relexpactsub.getFechaUltmodificacion(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateOTC(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET  IMPORTE_ADMITIDO = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getImporteAdmitido(), new Date(),
				relexpactsub.getUsuarioUltmodificacion(), relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	public void updateJustOTC(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET  IMPORTE_JUS_ADMITIDO = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getImporteJustAdmitido(), new Date(),
				relexpactsub.getUsuarioUltmodificacion(), relexpactsub.getIdRelExpActSub());
	}

	/**
	 * Updates a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateOMIC(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET  IMPORTE_ADMITIDO = ?, FECHA_ULTMODIFICACION = ?, USUARIO_ULTMODIFICACION = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getImporteAdmitido(), new Date(),
				relexpactsub.getUsuarioUltmodificacion(), relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	/**
	 * sumOMIC
	 * 
	 * @param idExpediente
	 * @return
	 */
	@Override
	@Transactional(readOnly = true)
	public RelExpActSub sumOMIC(Integer idExpediente) {
		String query = "SELECT SUM(T2.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(T2.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM ACT_SUBVENCIONABLE T1, REL_EXP_ACT_SUB T2 where T2.ID_ACT_SUB = T1.ID_ACT_SUB  and T1.ID_ACT_SUB_PADRE is null AND T2.ID_EXPEDIENTE   = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotales, idExpediente);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Updates de Importe Admitido y importe presentado in the RelExpActSub
	 * table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateImportePresentadoAdmtido(RelExpActSub relexpactsub) {

		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ? , IMPORTE_ADMITIDO = ? , SUBVENCION_CALCULADA = ? , PORCENTAJE=?,  FECHA_ULTMODIFICACION = ? , USUARIO_ULTMODIFICACION = ? WHERE ID_EXPEDIENTE = ? AND ID_REL_EXP_ACT_SUB = ?";
		this.jdbcTemplate.update(query, relexpactsub.getImportePresentado(), relexpactsub.getImporteAdmitido(),
				relexpactsub.getSubvencionCalculada(), relexpactsub.getPorcentaje(),
				relexpactsub.getFechaUltmodificacion(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdExpediente(), relexpactsub.getIdRelExpActSub());

		return relexpactsub;
	}

	/**
	 * Updates de Importe Admitido y importe presentado in the RelExpActSub
	 * table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateImporteJusPresentadoAdmtido(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_JUS_PRESENTADO = ? , IMPORTE_JUS_ADMITIDO = ? , IMPORTE_JUS_CALCULADO = ?, PORCENTAJE_JUS=?,  FECHA_ULTMODIFICACION = ? , USUARIO_ULTMODIFICACION = ? WHERE ID_EXPEDIENTE = ? AND ID_REL_EXP_ACT_SUB = ?";
		this.jdbcTemplate.update(query, relexpactsub.getImporteJustPresentado(), relexpactsub.getImporteJustAdmitido(),
				relexpactsub.getImporteJustCalculado(), relexpactsub.getPorcentajeJus(),
				relexpactsub.getFechaUltmodificacion(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdExpediente(), relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	/**
	 * Updates de Importe Admitido y importe presentado de la Relacion
	 * Expediente act subven Padre
	 * 
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Override
	public RelExpActSub updateImportePresentadoAdmtidoPadre(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ? , IMPORTE_ADMITIDO = ? , SUBVENCION_CALCULADA = ? , PORCENTAJE=?,  FECHA_ULTMODIFICACION = ? , USUARIO_ULTMODIFICACION = ? WHERE ID_EXPEDIENTE = ? AND ID_ACT_SUB = ?";
		this.jdbcTemplate.update(query, relexpactsub.getImportePresentado(), relexpactsub.getImporteAdmitido(),
				relexpactsub.getSubvencionCalculada(), relexpactsub.getPorcentaje(),
				relexpactsub.getFechaUltmodificacion(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdExpediente(), relexpactsub.getIdActSub());
		return relexpactsub;
	}

	/**
	 * Updates de SUBVENCION_CALCULADA y PORCENTAJE in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateImporteSubvencionCalculada(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET SUBVENCION_CALCULADA = ? ,PORCENTAJE=?, FECHA_ULTMODIFICACION = ? , USUARIO_ULTMODIFICACION = ? WHERE ID_EXPEDIENTE = ?";
		this.jdbcTemplate.update(query, relexpactsub.getSubvencionCalculada(), relexpactsub.getPorcentaje(),
				relexpactsub.getFechaUltmodificacion(), relexpactsub.getUsuarioUltmodificacion(),
				relexpactsub.getIdExpediente());
		return relexpactsub;
	}

	/**
	 * Updates de Importe Admitido y importe presentado in the RelExpActSub
	 * table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateImportePorIdActSub(RelExpActSub relexpactsub, Integer idActSub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ? , IMPORTE_ADMITIDO = ? , FECHA_ULTMODIFICACION = ? , USUARIO_ULTMODIFICACION = ? WHERE ID_ACT_SUB = ? AND ID_EXPEDIENTE = ?";
		this.jdbcTemplate.update(query, relexpactsub.getImportePresentado(), relexpactsub.getImporteAdmitido(),
				new Date(), relexpactsub.getUsuarioUltmodificacion(), idActSub, relexpactsub.getIdExpediente());
		return relexpactsub;
	}

	/**
	 * Updates de Importe Admitido in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateImporte(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_ADMITIDO = ? , SUBVENCION_CALCULADA = ? ,PORCENTAJE=?,  FECHA_ULTMODIFICACION = ? , USUARIO_ULTMODIFICACION = ? WHERE ID_EXPEDIENTE = ? AND ID_REL_EXP_ACT_SUB = ?";
		this.jdbcTemplate.update(query, relexpactsub.getImporteAdmitido(), relexpactsub.getSubvencionCalculada(),
				relexpactsub.getPorcentaje(), relexpactsub.getFechaUltmodificacion(),
				relexpactsub.getUsuarioUltmodificacion(), relexpactsub.getIdExpediente(),
				relexpactsub.getIdRelExpActSub());
		return relexpactsub;
	}

	/**
	 * Updates de Importe Admitido y importe presentado in the RelExpActSub
	 * table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	public RelExpActSub updateImporteAyuntamiento(RelExpActSub relexpactsub, Integer idActSub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ? , IMPORTE_ADMITIDO = ? , FECHA_ULTMODIFICACION = ? , USUARIO_ULTMODIFICACION = ? WHERE ID_ACT_SUB = (SELECT ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = ?) AND ID_EXPEDIENTE = ?";
		this.jdbcTemplate.update(query, relexpactsub.getImportePresentado(), relexpactsub.getImporteAdmitido(),
				new Date(), relexpactsub.getUsuarioUltmodificacion(), idActSub, relexpactsub.getIdExpediente());
		return relexpactsub;
	}

	/**
	 * Sacamos la tabla de relaciones de act subencionables por expediente
	 *
	 * @param Integer
	 *            idExpediente
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpediente(Integer idExpediente) {
		String query = "SELECT t1.ID_ACT_SUB IDACTSUB, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t1.PORCENTAJE PORCENTAJE   FROM REL_EXP_ACT_SUB t1 WHERE t1.ID_EXPEDIENTE=?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapfindRelEXpActSubPorExpediente,
				idExpediente);

		return relExpActSubList;
	}

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpedienteMEC(Integer idExpediente, Integer idConvocatoria) {

		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t1.PORCENTAJE PORCENTAJE, t3.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA, t3.ID_ACT_SUB  ActSubvencionableIDACTSUB,  t3.ID_ACT_SUB_PADRE ActSubvencionableIDACTSUBPADRE, t3.ID_CONVOCATORIA IDCONVOCATORIA ,  t3.ORDEN ORDEN FROM REL_EXP_ACT_SUB t1  RIGHT OUTER JOIN  ACT_SUBVENCIONABLE t3   ON t1.ID_ACT_SUB = t3.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? WHERE t3.ID_CONVOCATORIA =? ORDER BY t3.ORDEN";

		List<RelExpActSub> facturasList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpediente, idExpediente,
				idConvocatoria);

		return facturasList;
	}

	@Override
	public List<RelExpActSub> findRelEXpActSubPorExpedienteCOVIDT(Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t1.PORCENTAJE PORCENTAJE, t2.DESCRIPCION_CASTELLANO ACTDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA ACTDESCRIPCIONEUSKERA, t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB, t2.ID_ACT_SUB_PADRE ACTSUBVENCIONABLEIDACTSUBPADRE, t2.ID_CONVOCATORIA IDCONVOCATORIA, t2.ORDEN ORDEN, t3.ENTIDAD_BANCARIA ENTIDADBANCARIA, ( SELECT t4.IMPORTE FROM OTROS_INGRESOS t4 WHERE t1.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB (+) AND t4.FASE = ? ) IMPORTECONCEDIDO FROM REL_EXP_ACT_SUB t1 RIGHT OUTER JOIN ACT_SUBVENCIONABLE t2 ON t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? LEFT OUTER JOIN ENTIDADES_BANCARIAS t3 ON t1.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB WHERE t2.ID_CONVOCATORIA = ? ORDER BY t2.ORDEN";

		List<RelExpActSub> facturasList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedienteCOVIDT,
				Constantes.FASE_SOLICITUD, idExpediente, idConvocatoria);

		return facturasList;
	}

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales para
	 * la ayuda CPT
	 *
	 * @param Integer
	 *            idExpediente
	 * 
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpedienteCTP(Integer idExpediente, Integer idConvocatoria) {

		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t1.PORCENTAJE PORCENTAJE, t3.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA, t3.ID_ACT_SUB ActSubvencionableIDACTSUB, t3.ID_ACT_SUB_PADRE ActSubvencionableIDACTSUBPADRE, t3.ID_CONVOCATORIA IDCONVOCATORIA, t3.ORDEN ORDEN, (SELECT t4.IMPORTE FROM OTROS_INGRESOS t4 WHERE t1.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t4.FASE = 1) IMPORTECONCEDIDO FROM REL_EXP_ACT_SUB t1, ACT_SUBVENCIONABLE t3 WHERE t1.ID_EXPEDIENTE = ? AND t3.ID_CONVOCATORIA = ? AND t3.ID_ACT_SUB = t1.ID_ACT_SUB ORDER BY t3.ORDEN";

		List<RelExpActSub> facturasList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedienteCTP,
				idExpediente, idConvocatoria);

		return facturasList;
	}

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpedienteEMET(Integer idExpediente, Integer idConvocatoria) {

		String query = "SELECT REL_EXP_ACT_SUB.ID_EXPEDIENTE IDEXPEDIENTE, REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB idrelexpactsub, REL_EXP_ACT_SUB.IMPORTE_PRESENTADO importepresentado, REL_EXP_ACT_SUB.IMPORTE_ADMITIDO importeadmitido, REL_EXP_ACT_SUB.SUBVENCION_CALCULADA subvencioncalculada, REL_EXP_ACT_SUB.PORCENTAJE porcentaje,  ACT_SUBVENCIONABLE.DESCRIPCION_CASTELLANO actdescripcioncastellano, ACT_SUBVENCIONABLE.DESCRIPCION_EUSKERA actdescripcioneuskera, ACT_SUBVENCIONABLE.ID_ACT_SUB actsubvencionableidactsub , ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE actsubvencionableidactsubpadre, ACT_SUBVENCIONABLE.ID_CONVOCATORIA IDCONVOCATORIA , ACT_SUBVENCIONABLE.ORDEN ORDEN, (SELECT IMPORTE FROM OTROS_INGRESOS WHERE REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB = OTROS_INGRESOS.ID_REL_EXP_ACT_SUB AND OTROS_INGRESOS.FASE = 1) IMPORTECONCEDIDO FROM ACT_SUBVENCIONABLE LEFT JOIN REL_EXP_ACT_SUB ON REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ID_EXPEDIENTE =? WHERE (ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE = (SELECT ACT_SUBVENCIONABLE.ID_ACT_SUB FROM REL_EXP_ACT_SUB, ACT_SUBVENCIONABLE WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ID_EXPEDIENTE =?)) OR (ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ACT_SUBVENCIONABLE.ID_ACT_SUB = (SELECT ACT_SUBVENCIONABLE.ID_ACT_SUB FROM REL_EXP_ACT_SUB, ACT_SUBVENCIONABLE WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ID_EXPEDIENTE =?) AND (select count(*) from ACT_SUBVENCIONABLE where ID_ACT_SUB_PADRE = (SELECT ACT_SUBVENCIONABLE.ID_ACT_SUB FROM REL_EXP_ACT_SUB, ACT_SUBVENCIONABLE WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ID_EXPEDIENTE =?)) = 0)    ORDER BY ACT_SUBVENCIONABLE.ORDEN ";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedienteEMET,
				idExpediente, idExpediente, idExpediente, idExpediente);

		return relExpActSubList;
	}

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpedientePTT(Integer idExpediente, Integer idConvocatoria) {

		String query = "SELECT t2.ID_EXPEDIENTE IDEXPEDIENTE,t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO, t2.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,"
				+ " t2.PORCENTAJE PORCENTAJE, t1.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA, t1.ID_ACT_SUB ActSubvencionableIDACTSUB, t1.ID_AGRUPACION IDACTSUBAGRUPACION, "
				+ " t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t2.INSPECCIONABLE INSPECCIONABLE, "
				+ " t2.NOTAS NOTAS, "
				+ " t1.ORDEN ORDEN ,t1.ID_ACT_SUB_PADRE IDACTSUBPADRE, t3.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL, t3.NOMBRE NOMBRECP, t3.APELLIDO1 APELLIDO1CP, t3.APELLIDO2 APELLIDO2CP,"
				+ " t3.ID_SEXO IDSEXOCP, t3.PERIODO_CONTRATACION PERIODO_CONTRATACIONCP, t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATOCP, t3.EMPRESA_CONTRATADA EMPRESACONTRATADACP, "
				+ " t4.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS, t4.DENOMIMACION DENOMINACION, t5.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO, t5.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANOPT, "
				+ " t5.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERAPT,  t6.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA, t6.NOMBRE NOMBREPC, t6.APELLIDO1 APELLIDO1PC, t6.APELLIDO2 APELLIDO2PC "
				+ " ,t7.ID_PERTENENCIA_REDES IDPERTENENCIAREDES, t7.DENOMINACION DENOMINACIONREDES, (SELECT t8.IMPORTE FROM OTROS_INGRESOS t8 WHERE t2.ID_REL_EXP_ACT_SUB = t8.ID_REL_EXP_ACT_SUB(+)AND t8.FASE = 1) IMPORTECONCEDIDO "
				+ " FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONTRATACIONES_PERSONAL t3, GASTOS_TURISTICOS t4, PRODUCTOS_TURISTICOS t5, PERSONAS_CONTRATADAS t6, PERTENENCIAS_REDES t7  WHERE t1.ID_CONVOCATORIA = ? "
				+ "AND t1.ID_ACT_SUB = t2.ID_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND "
				+ "t5.ID_PRODUCTO_TURISTICO(+) = t4.ID_PRODUCTO_TURISTICO AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t7.ID_REL_EXP_ACT_SUB(+) AND (t1.ID_ACT_SUB_PADRE IS NOT NULL OR (t1.ID_ACT_SUB_PADRE IS NULL "
				+ "AND t1.ID_ACT_SUB NOT IN (SELECT DISTINCT t1.ID_ACT_SUB_PADRE  FROM ACT_SUBVENCIONABLE t1  WHERE t1.ID_CONVOCATORIA = ?  AND t1.ID_ACT_SUB_PADRE IS NOT NULL))) ";

		if (LocaleContextHolder.getLocale().getLanguage().equalsIgnoreCase(Constantes.CASTELLANO)) {
			query = query
					+ " ORDER BY t1.ORDEN,NOMBRECP, APELLIDO1CP,APELLIDO2CP,NOMBREPC,APELLIDO1PC,APELLIDO2PC, DESCRIPCIONCASTELLANOPT, DENOMINACION ";
		} else {
			query = query
					+ " ORDER BY t1.ORDEN,NOMBRECP, APELLIDO1CP,APELLIDO2CP,NOMBREPC,APELLIDO1PC,APELLIDO2PC, DESCRIPCIONEUSKERAPT, DENOMINACION ";
		}

		logger.info("LocaleContextHolder.getLocale().toString(): " + LocaleContextHolder.getLocale().toString());

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedientePTT,
				idConvocatoria, idExpediente, idConvocatoria);

		return relExpActSubList;
	}

	/**
	 * Sacamos el detalle de act subencionables
	 * 
	 * @param idExpediente
	 *            idExpediente
	 * @param idConvocatoria
	 *            idConvocatoria
	 * @param idRelExpActSub
	 *            idRelExpActSub
	 * @return
	 */
	@Override
	@Transactional(readOnly = true)
	public RelExpActSub findDetallePTT(Integer idExpediente, Integer idConvocatoria, Integer idRelExpActSub) {

		String query = "SELECT t2.ID_EXPEDIENTE IDEXPEDIENTE,t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO, t2.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, "
				+ " t2.PORCENTAJE PORCENTAJE, t1.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA, t1.ID_ACT_SUB ActSubvencionableIDACTSUB, t1.ID_AGRUPACION IDACTSUBAGRUPACION, "
				+ " t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t2.INSPECCIONABLE INSPECCIONABLE, "
				+ " t2.NOTAS NOTAS, "
				+ " t1.ORDEN ORDEN ,  t1.ID_ACT_SUB_PADRE IDACTSUBPADRE,  t3.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL, t3.NOMBRE NOMBRECP, t3.APELLIDO1 APELLIDO1CP, t3.APELLIDO2 APELLIDO2CP, "
				+ " t3.ID_SEXO IDSEXOCP, t3.PERIODO_CONTRATACION PERIODO_CONTRATACIONCP, t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATOCP, t3.EMPRESA_CONTRATADA EMPRESACONTRATADACP, "
				+ " t4.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS, t4.DENOMIMACION DENOMINACION, t5.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO, t5.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANOPT, "
				+ " t5.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERAPT,  t6.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA, t6.NOMBRE NOMBREPC, t6.APELLIDO1 APELLIDO1PC, t6.APELLIDO2 APELLIDO2PC "
				+ " ,t7.ID_PERTENENCIA_REDES IDPERTENENCIAREDES, t7.DENOMINACION DENOMINACIONREDES, (SELECT t8.IMPORTE FROM OTROS_INGRESOS t8 WHERE t2.ID_REL_EXP_ACT_SUB = t8.ID_REL_EXP_ACT_SUB AND t8.FASE= 1) IMPORTECONCEDIDO "
				+ " FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONTRATACIONES_PERSONAL t3, GASTOS_TURISTICOS t4, PRODUCTOS_TURISTICOS t5, PERSONAS_CONTRATADAS t6, PERTENENCIAS_REDES t7 "
				+ " WHERE t1.ID_CONVOCATORIA = ? AND t1.ID_ACT_SUB = t2.ID_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) "
				+ " AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t5.ID_PRODUCTO_TURISTICO(+) = t4.ID_PRODUCTO_TURISTICO AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t7.ID_REL_EXP_ACT_SUB(+)  "
				+ " AND (t1.ID_ACT_SUB_PADRE IS NOT NULL OR (t1.ID_ACT_SUB_PADRE IS NULL AND t1.ID_ACT_SUB NOT IN (SELECT DISTINCT t1.ID_ACT_SUB_PADRE  FROM ACT_SUBVENCIONABLE t1  "
				+ " WHERE t1.ID_CONVOCATORIA = ?  AND t1.ID_ACT_SUB_PADRE IS NOT NULL))) AND t2.ID_REL_EXP_ACT_SUB  = ? ORDER BY ORDEN";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedientePTT2,
				idConvocatoria, idExpediente, idConvocatoria, idRelExpActSub);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpedienteDEC(Integer idExpediente) {

		String query = "SELECT * FROM ( " + "SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, "
				+ "T1.ID_EXPEDIENTE IDEXPEDIENTE, " + "T1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, "
				+ "T1.PORCENTAJE PORCENTAJE, " + "T2.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO, "
				+ "NULL AS IDACTASOCIACION, " + "T2.TITULO TITULO, " + "T1.IMPORTE_PRESENTADO IMPORTETOTAL, "
				+ "T1.IMPORTE_ADMITIDO IMPORTEADMITIDO, " + "T4.ID_ACT_SUB IDACTSUB, "
				+ "T4.ID_ACT_SUB_PADRE IDACTSUBPADRE, " + "T4.ID_CONVOCATORIA IDCONVOCATORIA, " + "T4.ORDEN ORDEN, "
				+ "(SELECT T3.DESCRIPCION_CASTELLANO FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOCASTELLANO, "
				+ "(SELECT T3.DESCRIPCION_EUSKERA FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOEUSKERA, "
				+ "(SELECT ID_AGRUPACION FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = T4.ID_ACT_SUB_PADRE) AS ACTSUBPADREAGRUPACION "
				+ " FROM REL_EXP_ACT_SUB T1, ACT_AYUNTAMIENTO T2, ACT_SUBVENCIONABLE T4 "
				+ " WHERE ID_EXPEDIENTE =? AND T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T1.ID_ACT_SUB = T4.ID_ACT_SUB "
				+ " UNION " + "SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, "
				+ "T1.ID_EXPEDIENTE IDEXPEDIENTE, T1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, "
				+ "T1.PORCENTAJE PORCENTAJE, NULL AS IDACTAYUNTAMIENTO, "
				+ "T3.ID_ACT_ASOCIACION IDACTASOCIACION, T3.TITULO TITULO, "
				+ "T1.IMPORTE_PRESENTADO IMPORTETOTAL, T1.IMPORTE_ADMITIDO IMPORTEADMITIDO, "
				+ "T4.ID_ACT_SUB IDACTSUB, T4.ID_ACT_SUB_PADRE IDACTSUBPADRE, "
				+ "T4.ID_CONVOCATORIA IDCONVOCATORIA, T4.ORDEN ORDEN, "
				+ "(SELECT T3.DESCRIPCION_CASTELLANO FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOCASTELLANO, "
				+ "(SELECT T3.DESCRIPCION_EUSKERA FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOEUSKERA, "
				+ "(SELECT ID_AGRUPACION FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = T4.ID_ACT_SUB_PADRE) AS ACTSUBPADREAGRUPACION "
				+ "FROM REL_EXP_ACT_SUB T1, ACT_ASOCIACION T3, ACT_SUBVENCIONABLE T4 "
				+ "WHERE ID_EXPEDIENTE = ? AND T1.ID_REL_EXP_ACT_SUB = T3.ID_REL_EXP_ACT_SUB AND   T1.ID_ACT_SUB = T4.ID_ACT_SUB"
				+ ") ORDER BY ORDEN, TITULO";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorDEC, idExpediente,
				idExpediente);

		return relExpActSubList;
	}

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpedienteOMIC(Integer idExpediente) {

		String query = "SELECT REL_EXP_ACT_SUB.ID_EXPEDIENTE IDEXPEDIENTE,"
				+ " REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB idrelexpactsub,"
				+ " REL_EXP_ACT_SUB.IMPORTE_PRESENTADO importepresentado,"
				+ " REL_EXP_ACT_SUB.IMPORTE_ADMITIDO importeadmitido,"
				+ " REL_EXP_ACT_SUB.SUBVENCION_CALCULADA subvencioncalculada,"
				+ " REL_EXP_ACT_SUB.PORCENTAJE porcentaje," + " T1.DESCRIPCION_CASTELLANO actdescripcioncastellano,"
				+ " T1.DESCRIPCION_EUSKERA actdescripcioneuskera," + " T1.ID_ACT_SUB actsubvencionableidactsub,"
				+ " T1.ID_ACT_SUB_PADRE actsubvencionableidactsubpadre," + " T1.ID_CONVOCATORIA IDCONVOCATORIA,"
				+ " T1.ORDEN ORDEN, T2.PUNTOS PUNTOS"
				+ " FROM ACT_SUBVENCIONABLE T1, REL_EXP_ACT_SUB, PUNTOS_OBTENIDOS T2"
				+ " WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = T1.ID_ACT_SUB" + " AND ID_EXPEDIENTE = ?"
				+ " AND( (T1.ID_ACT_SUB_PADRE IS NULL AND (SELECT COUNT(1) FROM ACT_SUBVENCIONABLE T2 WHERE T2.ID_ACT_SUB_PADRE = T1.ID_ACT_SUB) = 0)"
				+ " OR (T1.ID_ACT_SUB_PADRE IS NOT NULL) ) AND REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB(+)"
				+ " ORDER BY T1.ORDEN";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedienteOMIC,
				idExpediente);

		return relExpActSubList;
	}

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub find(RelExpActSub relexpactsub) {
		String query = "SELECT t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB, t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEDESCRIPCIONEUSKERA, t2.PORCENTAJE_ACTUACION ACTSUBVENCIONABLEPORCENTAJEACTUACION, t2.IMPORTE_MINIMO_INVERSION ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION, t2.RUTA_XML_CARGA ACTSUBVENCIONABLERUTAXMLCARGA, t2.RUTA_XML_HIJO_CARGA ACTSUBVENCIONABLERUTAXMLHIJOCARGA, t2.FECHA_REGISTRO ACTSUBVENCIONABLEFECHAREGISTRO, t2.USUARIO_REGISTRO ACTSUBVENCIONABLEUSUARIOREGISTRO, t2.FECHA_ULTMODIFICACION ACTSUBVENCIONABLEFECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION ACTSUBVENCIONABLEUSUARIOULTMODIFICACION, t2.ID_CONVOCATORIA ACTSUBVENCIONABLEIDCONVOCATORIA FROM REL_EXP_ACT_SUB t1 , ACT_SUBVENCIONABLE t2  WHERE t1.ID_REL_EXP_ACT_SUB = ?   AND t1.ID_ACT_SUB= t2.ID_ACT_SUB(+)";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMap,
				relexpactsub.getIdRelExpActSub());
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	@Override
	public RelExpActSub findNotasObservaciones(RelExpActSub relExpActSub) {
		String query = "SELECT t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.NOTAS NOTAS, t1.OBSERVACIONES_CASTELLANO OBSERVACIONESES, t1.OBSERVACIONES_EUSKERA OBSERVACIONESEU FROM REL_EXP_ACT_SUB t1 WHERE t1.ID_REL_EXP_ACT_SUB = ?";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapNotasObservaciones,
				relExpActSub.getIdRelExpActSub());
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	@Transactional(readOnly = true)
	public RelExpActSub findPorIdActSubPadre(Integer idActSubPadre, Integer idExpediente) {
		String query = "SELECT t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB, t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLECAS, t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEEUS, t2.PORCENTAJE_ACTUACION ACTSUBPORCENTAJEACTUACION, t2.FECHA_REGISTRO ACTSUBFECHAREGISTRO, t2.USUARIO_REGISTRO ACTSUBUSUARIOREGISTRO, t2.FECHA_ULTMODIFICACION ACTSUBFECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION ACTSUBUSUARIOULTMODIFICACION, t2.ID_CONVOCATORIA ACTSUBIDCONVOCATORIA FROM REL_EXP_ACT_SUB t1, ACT_SUBVENCIONABLE t2 WHERE t1.ID_ACT_SUB = ? AND t1.ID_ACT_SUB = t2.ID_ACT_SUB(+) AND t1.ID_EXPEDIENTE = ?";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMap2, idActSubPadre, idExpediente);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	@Override
	public RelExpActSub findJustificacion(RelExpActSub relExpActSub) {
		String query = "SELECT t1.NOTAS NOTAS, t1.OBSERVACIONES_JUS_CASTELLANO OBCASTELLANO, t1.OBSERVACIONES_JUS_EUSKERA OBEUSKERA FROM REL_EXP_ACT_SUB t1 WHERE t1.ID_REL_EXP_ACT_SUB = ?";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapJustificacionOb,
				relExpActSub.getIdRelExpActSub());
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findIdActSub(Integer idRelexpactsub) {
		String query = "SELECT ID_ACT_SUB IDACTSUB FROM REL_EXP_ACT_SUB WHERE ID_REL_EXP_ACT_SUB = ?";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapPKIdActSub, idRelexpactsub);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findIdActSubPorExpedienteNotNull(Integer idExpediente, Integer idActSubPadre) {
		String query = "SELECT T1.ID_ACT_SUB IDACTSUB FROM ACT_SUBVENCIONABLE T1 JOIN AB6023T00 T2 ON T2.ID_ACT_SUB = T1.ID_ACT_SUB AND T2.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB_PADRE IS NOT NULL WHERE T1.ID_ACT_SUB = ?";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapPKIdActSub, idExpediente,
				idActSubPadre);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	@Transactional(readOnly = true)
	public RelExpActSub findIdActSubPorExpedienteNotNullEMCO(Integer idExpediente, Integer idActSubPadre) {
		String query = "SELECT T1.ID_ACT_SUB IDACTSUB FROM ACT_SUBVENCIONABLE T1 JOIN AB6023T00 T2 ON T2.ID_ACT_SUB = T1.ID_ACT_SUB AND T2.ID_EXPEDIENTE = ? WHERE T1.ID_ACT_SUB = ?";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapPKIdActSub, idExpediente,
				idActSubPadre);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public Integer findIdActSubAgrupacionPorExpediente(Integer idExpediente) {
		String query = "SELECT T1.ID_AGRUPACION FROM ACT_SUBVENCIONABLE T1 JOIN AB6023T00 T2 ON T2.ID_ACT_SUB = T1.ID_ACT_SUB AND T2.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB_PADRE IS NULL";

		Integer relexpactsubList = this.jdbcTemplate.queryForInt(query, idExpediente);
		return relexpactsubList;
	}

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param idExpedientes,
	 *            IdCreiterio Integer, Integer
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findRelPorExpedientePorCriterio(Integer idExpedientes, Integer IdCriterio) {
		String query = "SELECT  t4.ORDEN ORDEN , t4.ID_ACT_SUB_PADRE IDACTSUBPADRE , t4.DESCRIPCION_CASTELLANO DESCASTELLANO, t4.DESCRIPCION_EUSKERA DESEUSKERA, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.ID_ACT_SUB IDACTSUB, t1.NOTAS NOTAS, t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA FROM  REL_EXP_ACT_SUB t1, ACT_SUBVENCIONABLE t4 WHERE t1.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB   = ? AND t4.ID_ACT_SUB  = t1.ID_ACT_SUB ORDER BY t4.ORDEN";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapRelExpAct, idExpedientes,
				IdCriterio);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	@Override
	public RelExpActSub findRelPorExpedientePorCriterioEntidadBancaria(Integer idExpedientes, Integer idActSub,
			String entidadBancaria) {
		String query = "SELECT  t4.ORDEN ORDEN , t4.ID_ACT_SUB_PADRE IDACTSUBPADRE , t4.DESCRIPCION_CASTELLANO DESCASTELLANO, t4.DESCRIPCION_EUSKERA DESEUSKERA, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.ID_ACT_SUB IDACTSUB, t1.NOTAS NOTAS, t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t3.ENTIDAD_BANCARIA ENTIDADBANCARIA FROM  REL_EXP_ACT_SUB t1 LEFT OUTER JOIN ENTIDADES_BANCARIAS t3 ON t1.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB, ACT_SUBVENCIONABLE t4 WHERE t1.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB   = ? AND t4.ID_ACT_SUB  = t1.ID_ACT_SUB AND t3.ENTIDAD_BANCARIA = ? ORDER BY t4.ORDEN";
		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapRelExpActEntidadBancaria,
				idExpedientes, idActSub, entidadBancaria);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	/**
	 * Finds a single row in the RelExpActSub table.
	 *
	 * @param idExpedientes,
	 *            IdCreiterio Integer, Integer
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findRelPorExpedientePorCriterioPTT(Integer idExpedientes, Integer IdCriterio) {
		StringBuilder query = new StringBuilder();
		query.append(
				"SELECT t5.ID_ACT_SUB_PADRE IDACTSUBPADRE,t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.ID_ACT_SUB IDACTSUB, t1.NOTAS NOTAS, t1.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t1.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO");
		if (IdCriterio.equals(14)) {
			query.append(", t4.ID_PERTENENCIA_REDES IDPERTENENCIAREDES, t4.DENOMINACION DENOMINACIONREDES ");

		}
		query.append("FROM REL_EXP_ACT_SUB t1, ACT_SUBVENCIONABLE t5 ");
		if (IdCriterio.equals(14)) {
			query.append(", PERTENENCIAS_REDES t4 ");
		}
		query.append("WHERE t1.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB  = ? AND t5.ID_ACT_SUB  = t1.ID_ACT_SUB ");
		if (IdCriterio.equals(14)) {
			query.append("AND t4.ID_REL_EXP_ACT_SUB(+) = t1.ID_REL_EXP_ACT_SUB");
		}
		List<RelExpActSub> relexpactsubList;
		if (IdCriterio.equals(14)) {
			relexpactsubList = this.jdbcTemplate.query(query.toString(), this.rwMapRelExpActPTT14, idExpedientes,
					IdCriterio);
		} else {
			relexpactsubList = this.jdbcTemplate.query(query.toString(), this.rwMapRelExpAct, idExpedientes,
					IdCriterio);
		}

		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

	/**
	 * Devuelve los totales de un expediente
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findTotales(Integer idRelacion) {
		String query = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO FROM REL_EXP_ACT_SUB t1 WHERE t1.ID_REL_EXP_ACT_SUB = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotales, idRelacion);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Devuelve los totales de un expediente
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub findTotalesJustificacion(Integer idExpediente, Integer idRelExpActSub) {
		String query = "SELECT SUM(T3.IMPORTE) IMPORTE, SUM(T3.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM AB61.V_T_ACT_SUBVENCIONABLES T1 INNER JOIN REL_EXP_ACT_SUB T2 ON T2.ID_EXPEDIENTE       = T1.ID_EXPEDIENTE AND T2.ID_REL_EXP_ACT_SUB = T1.VALOR INNER JOIN FACTURAS T3 ON T3.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB INNER JOIN TIPOS_GASTO_FAC T4 ON T4.ID_TIPO_GASTO_FAC = T3.ID_TIPO_GASTO_FAC WHERE 1=1 AND t1.ID_EXPEDIENTE = ? AND t1.VALOR = ? AND t2.ID_REL_EXP_ACT_SUB = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotalesAct, idExpediente,
				idRelExpActSub, idRelExpActSub);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub sumTotales(Integer idExpediente) {
		String query = "SELECT SUM(t1.IMPORTE_PRESENTADO) IMPORTEPRESENTADO,SUM(t1.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB t1 WHERE t1.ID_EXPEDIENTE = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotales, idExpediente);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub sumTotalesJus(Integer idExpediente) {
		String query = "SELECT SUM(t2.IMPORTE_JUS_PRESENTADO) IMPORTEJUSPRESENTADO,SUM(t2.IMPORTE_JUS_ADMITIDO) IMPORTEJUSADMITIDO from AB61.V_T_ACT_SUBVENCIONABLES t1 inner join rel_exp_act_sub t2 on t2.ID_REL_EXP_ACT_SUB = t1.VALOR WHERE t1.ID_EXPEDIENTE = ? ";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotalesJus2, idExpediente);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub sumEstudioActuacion(Integer idExpediente, Integer idActuacion) {
		String query = "SELECT SUM(T1.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(T1.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB T1, ACT_SUBVENCIONABLE T2 WHERE T1.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB = T2.ID_ACT_SUB AND T2.ID_ACT_SUB_PADRE = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotales, idExpediente,
				idActuacion);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Devuelve los totales de un relacion de expedientes por actividad
	 * subcionable
	 *
	 * @param Integer
	 *            IdExpediente
	 *
	 * @return RelExpActSub
	 */
	@Transactional(readOnly = true)
	public RelExpActSub sumAyuntamiento(Integer idActSub, Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT SUM(T2.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(T2.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM ACT_SUBVENCIONABLE T1 INNER JOIN REL_EXP_ACT_SUB T2 ON T2.ID_ACT_SUB = T1.ID_ACT_SUB WHERE T1.ID_ACT_SUB_PADRE = (SELECT T1.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE T1 WHERE T1.ID_ACT_SUB = ?) AND T1.ID_CONVOCATORIA = ? AND   T2.ID_EXPEDIENTE = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotales, idActSub,
				idConvocatoria, idExpediente);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	public RelExpActSub sumAyuntamientoEMCO(Integer idActSub, Integer idExpediente, Integer idConvocatoria) {
		String query = "SELECT SUM(T1.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(T1.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB T1 WHERE T1.ID_ACT_SUB = ? AND ID_EXPEDIENTE = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotalesEMCO, idActSub,
				idExpediente);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * sumPTT
	 * 
	 * @param idConvocatoria
	 * @param idExpediente
	 * @return
	 */
	@Override
	@Transactional(readOnly = true)
	public RelExpActSub sumPTT(Integer idConvocatoria, Integer idExpediente) {
		String query = "SELECT SUM(T2.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(T2.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM ACT_SUBVENCIONABLE T1, REL_EXP_ACT_SUB T2 where T2.ID_ACT_SUB = T1.ID_ACT_SUB  and T1.ID_ACT_SUB_PADRE is not null AND T1.ID_CONVOCATORIA = ? AND T2.ID_EXPEDIENTE   = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotales, idConvocatoria,
				idExpediente);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * sumOTC
	 * 
	 * @param idExpediente
	 * @param idActSub
	 * @return
	 */
	@Override
	@Transactional(readOnly = true)
	public RelExpActSub sumOTC(Integer idRelExpActSub) {
		String query = "SELECT SUM(T1.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(T1.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB T1,  ACT_SUBVENCIONABLE T2 WHERE T1.ID_REL_EXP_ACT_SUB  = ? AND T1.ID_ACT_SUB = T2.ID_ACT_SUB";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotales, idRelExpActSub);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * sumOTC
	 * 
	 * @param idExpediente
	 * @param idActSub
	 * @return
	 */
	@Override
	@Transactional(readOnly = true)
	public RelExpActSub sumJusOTC(Integer idExpediente) {
		String query = "SELECT SUM(t1.IMPORTE_JUS_PRESENTADO) IMPORTEJUSPRESENTADO,SUM(t1.IMPORTE_JUS_ADMITIDO) IMPORTEJUSADMITIDO FROM REL_EXP_ACT_SUB t1 WHERE t1.ID_EXPEDIENTE = ?";
		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapTotalesJus2, idExpediente);

		return (RelExpActSub) DataAccessUtils.uniqueResult(relExpActSubList);

	}

	/**
	 * Removes a single row in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return
	 */
	public void remove(RelExpActSub relexpactsub) {
		String query = "DELETE FROM REL_EXP_ACT_SUB WHERE ID_REL_EXP_ACT_SUB=?";
		this.jdbcTemplate.update(query, relexpactsub.getIdRelExpActSub());
	}

	/**
	 * Finds a list of rows in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findAll(RelExpActSub relexpactsub, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB,t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEDESCRIPCIONEUSKERA,t2.PORCENTAJE_ACTUACION ACTSUBVENCIONABLEPORCENTAJEACTUACION,t2.IMPORTE_MINIMO_INVERSION ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION,t2.RUTA_XML_CARGA ACTSUBVENCIONABLERUTAXMLCARGA,t2.RUTA_XML_HIJO_CARGA ACTSUBVENCIONABLERUTAXMLHIJOCARGA,t2.FECHA_REGISTRO ACTSUBVENCIONABLEFECHAREGISTRO,t2.USUARIO_REGISTRO ACTSUBVENCIONABLEUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION ACTSUBVENCIONABLEFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION ACTSUBVENCIONABLEUSUARIOULTMODIFICACION,t2.ID_CONVOCATORIA ACTSUBVENCIONABLEIDCONVOCATORIA ");
		query.append("FROM REL_EXP_ACT_SUB t1 ,ACT_SUBVENCIONABLE t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpactsub);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ACT_SUB= t2.ID_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpActSubDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpActSub>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the RelExpActSub table using like.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findAllLike(RelExpActSub relexpactsub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB,t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEDESCRIPCIONEUSKERA,t2.PORCENTAJE_ACTUACION ACTSUBVENCIONABLEPORCENTAJEACTUACION,t2.IMPORTE_MINIMO_INVERSION ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION,t2.RUTA_XML_CARGA ACTSUBVENCIONABLERUTAXMLCARGA,t2.RUTA_XML_HIJO_CARGA ACTSUBVENCIONABLERUTAXMLHIJOCARGA,t2.FECHA_REGISTRO ACTSUBVENCIONABLEFECHAREGISTRO,t2.USUARIO_REGISTRO ACTSUBVENCIONABLEUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION ACTSUBVENCIONABLEFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION ACTSUBVENCIONABLEUSUARIOULTMODIFICACION,t2.ID_CONVOCATORIA ACTSUBVENCIONABLEIDCONVOCATORIA ");
		query.append("FROM REL_EXP_ACT_SUB t1 ,ACT_SUBVENCIONABLE t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpactsub, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ACT_SUB= t2.ID_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpActSubDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpActSub>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelExpActSub table.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelExpActSub relexpactsub) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_ACT_SUB t1 , ACT_SUBVENCIONABLE t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpactsub);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ACT_SUB= t2.ID_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the RelExpActSub table using like.
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelExpActSub relexpactsub, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_ACT_SUB t1 ,ACT_SUBVENCIONABLE t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpactsub, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ACT_SUB= t2.ID_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of RelExpActSub selected for rup_table
	 *
	 * @param relexpactsub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpActSub>>
	 */
	@Override
	public List<TableRowDto<RelExpActSub>> reorderSelection(RelExpActSub relexpactsub,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB,t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEDESCRIPCIONEUSKERA,t2.PORCENTAJE_ACTUACION ACTSUBVENCIONABLEPORCENTAJEACTUACION,t2.IMPORTE_MINIMO_INVERSION ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION,t2.RUTA_XML_CARGA ACTSUBVENCIONABLERUTAXMLCARGA,t2.RUTA_XML_HIJO_CARGA ACTSUBVENCIONABLERUTAXMLHIJOCARGA,t2.FECHA_REGISTRO ACTSUBVENCIONABLEFECHAREGISTRO,t2.USUARIO_REGISTRO ACTSUBVENCIONABLEUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION ACTSUBVENCIONABLEFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION ACTSUBVENCIONABLEUSUARIOULTMODIFICACION,t2.ID_CONVOCATORIA ACTSUBVENCIONABLEIDCONVOCATORIA ");
		// FROM
		query.append("FROM REL_EXP_ACT_SUB t1 ,ACT_SUBVENCIONABLE t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpactsub, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ACT_SUB= t2.ID_ACT_SUB(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelExpActSub.class,
				filterParamList, "ID_REL_EXP_ACT_SUB");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpActSub>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelExpActSub
	 * @param searchParams
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpActSub>>
	 */
	@Override
	public List<TableRowDto<RelExpActSub>> search(RelExpActSub filterParams, RelExpActSub searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB,t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEDESCRIPCIONEUSKERA,t2.PORCENTAJE_ACTUACION ACTSUBVENCIONABLEPORCENTAJEACTUACION,t2.IMPORTE_MINIMO_INVERSION ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION,t2.RUTA_XML_CARGA ACTSUBVENCIONABLERUTAXMLCARGA,t2.RUTA_XML_HIJO_CARGA ACTSUBVENCIONABLERUTAXMLHIJOCARGA,t2.FECHA_REGISTRO ACTSUBVENCIONABLEFECHAREGISTRO,t2.USUARIO_REGISTRO ACTSUBVENCIONABLEUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION ACTSUBVENCIONABLEFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION ACTSUBVENCIONABLEUSUARIOULTMODIFICACION,t2.ID_CONVOCATORIA ACTSUBVENCIONABLEIDCONVOCATORIA ");
		// FROM
		query.append("FROM REL_EXP_ACT_SUB t1 ,ACT_SUBVENCIONABLE t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ACT_SUB= t2.ID_ACT_SUB(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelExpActSub.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_EXP_ACT_SUB");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpActSub>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelexpactsub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelExpActSub filterrelexpactsub, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB,t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEDESCRIPCIONEUSKERA,t2.PORCENTAJE_ACTUACION ACTSUBVENCIONABLEPORCENTAJEACTUACION,t2.IMPORTE_MINIMO_INVERSION ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION,t2.RUTA_XML_CARGA ACTSUBVENCIONABLERUTAXMLCARGA,t2.RUTA_XML_HIJO_CARGA ACTSUBVENCIONABLERUTAXMLHIJOCARGA,t2.FECHA_REGISTRO ACTSUBVENCIONABLEFECHAREGISTRO,t2.USUARIO_REGISTRO ACTSUBVENCIONABLEUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION ACTSUBVENCIONABLEFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION ACTSUBVENCIONABLEUSUARIOULTMODIFICACION,t2.ID_CONVOCATORIA ACTSUBVENCIONABLEIDCONVOCATORIA ");
		// FROM
		query.append("FROM REL_EXP_ACT_SUB t1 ,ACT_SUBVENCIONABLE t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelexpactsub, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelExpActSub.class,
				query, params, "ID_REL_EXP_ACT_SUB");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical RelExpActSub table.
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelExpActSub>>
	 */
	@Override
	public List<JerarquiaDto<RelExpActSub>> findAllLikeJerarquia(RelExpActSub filterRelExpActSub,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_ACT_SUB ACTSUBVENCIONABLEIDACTSUB,t2.DESCRIPCION_CASTELLANO ACTSUBVENCIONABLEDESCRIPCIONCASTELLANO,t2.DESCRIPCION_EUSKERA ACTSUBVENCIONABLEDESCRIPCIONEUSKERA,t2.PORCENTAJE_ACTUACION ACTSUBVENCIONABLEPORCENTAJEACTUACION,t2.IMPORTE_MINIMO_INVERSION ACTSUBVENCIONABLEIMPORTEMINIMOINVERSION,t2.RUTA_XML_CARGA ACTSUBVENCIONABLERUTAXMLCARGA,t2.RUTA_XML_HIJO_CARGA ACTSUBVENCIONABLERUTAXMLHIJOCARGA,t2.FECHA_REGISTRO ACTSUBVENCIONABLEFECHAREGISTRO,t2.USUARIO_REGISTRO ACTSUBVENCIONABLEUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION ACTSUBVENCIONABLEFECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION ACTSUBVENCIONABLEUSUARIOULTMODIFICACION,t2.ID_CONVOCATORIA ACTSUBVENCIONABLEIDCONVOCATORIA ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ACT_SUB t1
		// ,ACT_SUBVENCIONABLE t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ACT_SUB");
		from.add("ACT_SUBVENCIONABLE");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpActSub, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_REL_EXP_ACT_SUB", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RelExpActSubDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(RelExpActSub filterRelExpActSub, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_ACT_SUB t1
		// ,ACT_SUBVENCIONABLE t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ACT_SUB");
		from.add("ACT_SUBVENCIONABLE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpActSub, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_REL_EXP_ACT_SUB",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpActSub
	 *            RelExpActSub
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpActSub>>
	 */
	@Override
	public List<TableRowDto<RelExpActSub>> findAllChild(RelExpActSub filterRelExpActSub,
			JQGridRequestDto jqGridRequestDto) {

		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_ACT_SUB");
		from.add("ACT_SUBVENCIONABLE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpActSub, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_EXP_ACT_SUB",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelExpActSub>(this.rwMapPK, "ID_REL_EXP_ACT_SUB"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpActSub entity
	 *
	 * @param relexpactsub
	 *            RelExpActSub Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelExpActSub relexpactsub) {

		StringBuilder where = new StringBuilder(RelExpActSubDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpactsub != null && relexpactsub.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relexpactsub.getIdRelExpActSub());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(relexpactsub.getActSubvencionable().getIdActSub());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getConvocatorias() != null
				&& relexpactsub.getActSubvencionable().getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(relexpactsub.getActSubvencionable().getConvocatorias().getIdConvocatoria());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(relexpactsub.getActSubvencionable().getDescripcionCastellano());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(relexpactsub.getActSubvencionable().getDescripcionEuskera());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getPorcentajeActuacion() != null) {
			where.append(" AND t2.PORCENTAJE_ACTUACION = ?");
			params.add(relexpactsub.getActSubvencionable().getPorcentajeActuacion());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getImporteMinimoInversion() != null) {
			where.append(" AND t2.IMPORTE_MINIMO_INVERSION = ?");
			params.add(relexpactsub.getActSubvencionable().getImporteMinimoInversion());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getRutaXmlCarga() != null) {
			where.append(" AND t2.RUTA_XML_CARGA = ?");
			params.add(relexpactsub.getActSubvencionable().getRutaXmlCarga());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getRutaXmlHijoCarga() != null) {
			where.append(" AND t2.RUTA_XML_HIJO_CARGA = ?");
			params.add(relexpactsub.getActSubvencionable().getRutaXmlHijoCarga());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpactsub.getActSubvencionable().getFechaRegistro());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(relexpactsub.getActSubvencionable().getUsuarioRegistro());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(relexpactsub.getActSubvencionable().getFechaUltmodificacion());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(relexpactsub.getActSubvencionable().getUsuarioUltmodificacion());
		}
		if (relexpactsub != null && relexpactsub.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpactsub.getIdExpediente());
		}
		if (relexpactsub != null && relexpactsub.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpactsub.getFechaRegistro());
		}
		if (relexpactsub != null && relexpactsub.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relexpactsub.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpActSub entity
	 *
	 * @param relexpactsub
	 *            RelExpActSub Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelExpActSub relexpactsub, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelExpActSubDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpactsub != null && relexpactsub.getIdRelExpActSub() != null) {
			where.append(" AND t1.ID_REL_EXP_ACT_SUB = ?");
			params.add(relexpactsub.getIdRelExpActSub());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getIdActSub() != null) {
			where.append(" AND t2.ID_ACT_SUB = ?");
			params.add(relexpactsub.getActSubvencionable().getIdActSub());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getConvocatorias() != null
				&& relexpactsub.getActSubvencionable().getConvocatorias().getIdConvocatoria() != null) {
			where.append(" AND t2.ID_CONVOCATORIA = ?");
			params.add(relexpactsub.getActSubvencionable().getConvocatorias().getIdConvocatoria());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpactsub.getActSubvencionable().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + relexpactsub.getActSubvencionable().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpactsub.getActSubvencionable().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + relexpactsub.getActSubvencionable().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getPorcentajeActuacion() != null) {
			where.append(" AND t2.PORCENTAJE_ACTUACION = ?");
			params.add(relexpactsub.getActSubvencionable().getPorcentajeActuacion());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getImporteMinimoInversion() != null) {
			where.append(" AND t2.IMPORTE_MINIMO_INVERSION = ?");
			params.add(relexpactsub.getActSubvencionable().getImporteMinimoInversion());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getRutaXmlCarga() != null) {
			where.append(" AND UPPER(t2.RUTA_XML_CARGA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpactsub.getActSubvencionable().getRutaXmlCarga().toUpperCase() + "%");
			} else {
				params.add("%" + relexpactsub.getActSubvencionable().getRutaXmlCarga().toUpperCase() + "%");
			}
			where.append(" AND t2.RUTA_XML_CARGA IS NOT NULL");
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getRutaXmlHijoCarga() != null) {
			where.append(" AND UPPER(t2.RUTA_XML_HIJO_CARGA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpactsub.getActSubvencionable().getRutaXmlHijoCarga().toUpperCase() + "%");
			} else {
				params.add("%" + relexpactsub.getActSubvencionable().getRutaXmlHijoCarga().toUpperCase() + "%");
			}
			where.append(" AND t2.RUTA_XML_HIJO_CARGA IS NOT NULL");
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpactsub.getActSubvencionable().getFechaRegistro());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpactsub.getActSubvencionable().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpactsub.getActSubvencionable().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(relexpactsub.getActSubvencionable().getFechaUltmodificacion());
		}
		if (relexpactsub != null && relexpactsub.getActSubvencionable() != null
				&& relexpactsub.getActSubvencionable().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpactsub.getActSubvencionable().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relexpactsub.getActSubvencionable().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (relexpactsub != null && relexpactsub.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpactsub.getIdExpediente());
		}
		if (relexpactsub != null && relexpactsub.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpactsub.getFechaRegistro());
		}
		if (relexpactsub != null && relexpactsub.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpactsub.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpactsub.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public List<RelExpActSub> findAllLikeJustificacion(RelExpActSub filterRelFacActSubvencionables,
			JQGridRequestDto jqGridRequestDto, boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT T1.ID_EXPEDIENTE IDEXPEDIENTE, T1.PARAMETRO FOLDERNUMBER, T2.ID_ACT_SUB IDACTSUB,  T1.VALOR IDRELEXPACTSUB, REPLACE(T1.DESCRIPCION_CASTELLANO, '[salto]', '') DESCRIPCIONES, REPLACE(T1.DESCRIPCION_EUSKERA, '[salto]', '') DESCRIPCIONEU,  T2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, T2.IMPORTE_ADMITIDO IMPORTEADMITIDO, T2.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO, T2.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO, T2.PORCENTAJE_JUS PORCENTAJEJUS, (SELECT SUM(IMPORTE) FROM OTROS_INGRESOS T3 WHERE T3.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T3.FASE = 2) IMPORTE FROM AB61.V_T_ACT_SUBVENCIONABLES T1 INNER JOIN REL_EXP_ACT_SUB T2 ON T2.ID_EXPEDIENTE = T1.ID_EXPEDIENTE AND T2.ID_REL_EXP_ACT_SUB = T1.VALOR WHERE 1=1 AND t1.ID_EXPEDIENTE = ? ORDER BY ID_ACT_SUB");

		return (List<RelExpActSub>) this.jdbcTemplate.query(query.toString(), this.rwMapJustificacion,
				filterRelFacActSubvencionables.getIdExpediente());
	}

	@Override
	public Long findAllLikeCountJustificacion(RelExpActSub relExpActSub, boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM AB61.V_T_ACT_SUBVENCIONABLES T1 INNER JOIN REL_EXP_ACT_SUB T2 ON T2.ID_EXPEDIENTE = T1.ID_EXPEDIENTE AND T2.ID_REL_EXP_ACT_SUB = T1.VALOR LEFT JOIN OTROS_INGRESOS T3 ON T3.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB WHERE 1=1 AND t1.ID_EXPEDIENTE = ? ");
		return this.jdbcTemplate.queryForLong(query.toString(), relExpActSub.getIdExpediente());
	}

	@Override
	public RelExpActSub saveDatosJustificacion(Integer idExpediente, RelExpActSub relExpActSub, Usuario usuario) {
		String query = "UPDATE REL_EXP_ACT_SUB SET NOTAS = ? , OBSERVACIONES_JUS_CASTELLANO = ? , OBSERVACIONES_JUS_EUSKERA = ? WHERE ID_REL_EXP_ACT_SUB = ?";
		this.jdbcTemplate.update(query, relExpActSub.getNotas(), relExpActSub.getObservacionesCastellano(),
				relExpActSub.getObservacionesEuskera(), relExpActSub.getIdRelExpActSub());
		return relExpActSub;
	}

	@Override
	public List<RelExpActSub> findExentoPorExpediente(Integer idExpediente) {
		StringBuilder query = new StringBuilder(
				"SELECT T1.EXENTOIVA EXENTOIVA FROM REL_MUN_ASO_COM T1 WHERE T1.ID_EXPEDIENTE = ?");

		return (List<RelExpActSub>) this.jdbcTemplate.query(query.toString(), this.rwMapExento, idExpediente);
	}

	@Override
	public List<RelExpActSub> filterDECTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		String query = "SELECT * FROM ( " + "SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, "
				+ "T1.ID_EXPEDIENTE IDEXPEDIENTE, " + "T1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, "
				+ "T1.PORCENTAJE PORCENTAJE, " + "T2.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO, "
				+ "NULL AS IDACTASOCIACION, " + "T2.TITULO TITULO, " + "T1.IMPORTE_PRESENTADO IMPORTETOTAL, "
				+ "T1.IMPORTE_ADMITIDO IMPORTEADMITIDO, " + "T4.ID_ACT_SUB IDACTSUB, "
				+ "T4.ID_ACT_SUB_PADRE IDACTSUBPADRE, " + "T4.ID_CONVOCATORIA IDCONVOCATORIA, " + "T4.ORDEN ORDEN, "
				+ "(SELECT T3.DESCRIPCION_CASTELLANO FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOCASTELLANO, "
				+ "(SELECT T3.DESCRIPCION_EUSKERA FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOEUSKERA, "
				+ "(SELECT ID_AGRUPACION FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = T4.ID_ACT_SUB_PADRE) AS ACTSUBPADREAGRUPACION "
				+ " FROM REL_EXP_ACT_SUB T1, ACT_AYUNTAMIENTO T2, ACT_SUBVENCIONABLE T4 "
				+ " WHERE ID_EXPEDIENTE =? AND T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T1.ID_ACT_SUB = T4.ID_ACT_SUB "
				+ " UNION " + "SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, "
				+ "T1.ID_EXPEDIENTE IDEXPEDIENTE, T1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, "
				+ "T1.PORCENTAJE PORCENTAJE, NULL AS IDACTAYUNTAMIENTO, "
				+ "T3.ID_ACT_ASOCIACION IDACTASOCIACION, T3.TITULO TITULO, "
				+ "T1.IMPORTE_PRESENTADO IMPORTETOTAL, T1.IMPORTE_ADMITIDO IMPORTEADMITIDO, "
				+ "T4.ID_ACT_SUB IDACTSUB, T4.ID_ACT_SUB_PADRE IDACTSUBPADRE, "
				+ "T4.ID_CONVOCATORIA IDCONVOCATORIA, T4.ORDEN ORDEN, "
				+ "(SELECT T3.DESCRIPCION_CASTELLANO FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOCASTELLANO, "
				+ "(SELECT T3.DESCRIPCION_EUSKERA FROM ACT_SUBVENCIONABLE T3 WHERE T3.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOEUSKERA, "
				+ "(SELECT ID_AGRUPACION FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = T4.ID_ACT_SUB_PADRE) AS ACTSUBPADREAGRUPACION "
				+ "FROM REL_EXP_ACT_SUB T1, ACT_ASOCIACION T3, ACT_SUBVENCIONABLE T4 "
				+ "WHERE ID_EXPEDIENTE = ? AND T1.ID_REL_EXP_ACT_SUB = T3.ID_REL_EXP_ACT_SUB AND   T1.ID_ACT_SUB = T4.ID_ACT_SUB"
				+ ") ORDER BY ORDEN, TITULO";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorDEC,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		RelExpActSub espacio = new RelExpActSub();
		RelExpActSub totales = new RelExpActSub();
		ActSubvencionable actuacionTotalEspacio = new ActSubvencionable();
		actuacionTotalEspacio.setDescripcionCastellano("");
		actuacionTotalEspacio.setDescripcionEuskera("");
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				totales.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				totales.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				totales.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				totales.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		espacio.setActSubvencionable(actuacionTotalEspacio);
		totales.setActSubvencionable(actuacionTotal);
		relExpActSubList.add(espacio);
		relExpActSubList.add(totales);

		return relExpActSubList;
	}

	@Override
	public List<RelExpActSub> filterOMICTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		String query = "SELECT REL_EXP_ACT_SUB.ID_EXPEDIENTE IDEXPEDIENTE,"
				+ " REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB idrelexpactsub,"
				+ " REL_EXP_ACT_SUB.IMPORTE_PRESENTADO importepresentado,"
				+ " REL_EXP_ACT_SUB.IMPORTE_ADMITIDO importeadmitido,"
				+ " REL_EXP_ACT_SUB.SUBVENCION_CALCULADA subvencioncalculada,"
				+ " REL_EXP_ACT_SUB.PORCENTAJE porcentaje," + " T1.DESCRIPCION_CASTELLANO actdescripcioncastellano,"
				+ " T1.DESCRIPCION_EUSKERA actdescripcioneuskera," + " T1.ID_ACT_SUB actsubvencionableidactsub,"
				+ " T1.ID_ACT_SUB_PADRE actsubvencionableidactsubpadre," + " T1.ID_CONVOCATORIA IDCONVOCATORIA,"
				+ " T1.ORDEN ORDEN, T2.PUNTOS PUNTOS"
				+ " FROM ACT_SUBVENCIONABLE T1, REL_EXP_ACT_SUB, PUNTOS_OBTENIDOS T2"
				+ " WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = T1.ID_ACT_SUB" + " AND ID_EXPEDIENTE = ?"
				+ " AND( (T1.ID_ACT_SUB_PADRE IS NULL AND (SELECT COUNT(1) FROM ACT_SUBVENCIONABLE T2 WHERE T2.ID_ACT_SUB_PADRE = T1.ID_ACT_SUB) = 0)"
				+ " OR (T1.ID_ACT_SUB_PADRE IS NOT NULL) ) AND REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB(+)"
				+ " ORDER BY T1.ORDEN";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedienteOMIC,
				filterActSub.getIdExpediente());

		RelExpActSub espacio = new RelExpActSub();
		RelExpActSub totales = new RelExpActSub();
		ActSubvencionable actuacionTotalEspacio = new ActSubvencionable();
		actuacionTotalEspacio.setDescripcionCastellano("");
		actuacionTotalEspacio.setDescripcionEuskera("");
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				totales.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				totales.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				totales.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				totales.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		espacio.setActSubvencionable(actuacionTotalEspacio);
		totales.setActSubvencionable(actuacionTotal);
		relExpActSubList.add(espacio);
		relExpActSubList.add(totales);

		return relExpActSubList;
	}

	@Override
	public List<MarcarInspeccionableAct> filterConConceptosTer(RelExpActSub filterActSub,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {

		String query = "SELECT t1.ORDEN ORDEN, t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ENVIADO_INSPECCIONAR ENVIADOINSPACT, t2.INSPECCIONABLE INSPECCIONABLEACT, t2.IMPORTE_ADMITIDO IMPORTEADMITIDOACT, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADOACT, (SELECT t10.IMPORTE FROM OTROS_INGRESOS t10 WHERE t2.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1) IMPORTECONCEDIDO, t2.SUBVENCION_CALCULADA SUBCALCULADA, t2.PORCENTAJE PORCENTAJE, t2. OBSERVACIONES_CASTELLANO OBCASTELLANOACT, t2. OBSERVACIONES_EUSKERA OBEUSKERAACT, t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,  t3.ID_CONCEPTO IDCONCEPTO, t3.ENVIADO_INSPECCIONAR ENVIADOINSPCON, t3.INSPECCIONABLE INSPECCIONABLECON, t3.CONCEPTO CONCEPTOS, t3.IMPORTE_ADMITIDO IMPORTEADMITIDOCON, t3.IMPORTE_PRESENTADO IMPORTEPRESENTADOCON, t3.OBSERVACIONES_CASTELLANO OBCASTELLANOCON, t3.OBSERVACIONES_EUSKERA OBEUSKERACON, t4.TITULO TITULO, t5.NOMBRE NOMBRE,  t5.APELLIDO1 APELLIDO1,  t5.APELLIDO2 APELLIDO2,  t6.NOMBRE NOMBREPC,  t6.APELLIDO1 APELLIDO1PC,  t6.APELLIDO2 APELLIDO2PC, t9.ENTIDAD_BANCARIA ENTIDADBANCARIA FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, ACT_AYUNTAMIENTO t4, CONTRATACIONES_PERSONAL t5, PERSONAS_CONTRATADAS t6, ENTIDADES_BANCARIAS t9 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN (SELECT t6.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE t6, EXPEDIENTES t7, CONVOCATORIAS t8 WHERE t6.ID_ACT_SUB_PADRE = t1.ID_ACT_SUB AND t2.ID_EXPEDIENTE = t7.ID_EXPEDIENTE AND t7.ID_PROCEDIMIENTO = t8.ID_PROCEDIMIENTO AND NOT t8.ID_TIPO_AYUDA = "
				+ Constantes.TIPO_AYUDA_CTP
				+ ") AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t5.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+)  AND t2.ID_REL_EXP_ACT_SUB  = t9.ID_REL_EXP_ACT_SUB(+) ORDER BY t1.ORDEN ";
		List<MarcarInspeccionableAct> actSubvencionableList = this.jdbcTemplate.query(query,
				this.rwMapMarcarInspeccionable, filterActSub.getIdExpediente());

		MarcarInspeccionableAct espacio = new MarcarInspeccionableAct();
		MarcarInspeccionableAct totales = new MarcarInspeccionableAct();
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		Conceptos conceptosTotal = new Conceptos();
		RelExpActSub relExpActSub = new RelExpActSub();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				conceptosTotal.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				conceptosTotal.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				relExpActSub.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				relExpActSub.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		totales.setConceptos(conceptosTotal);
		totales.setRelExpActSub(relExpActSub);

		totales.setActSubs(actuacionTotal);

		actSubvencionableList.add(espacio);
		actSubvencionableList.add(totales);

		return actSubvencionableList;
	}

	@Override
	public List<RelExpActSub> filterEMETTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		String query = "SELECT REL_EXP_ACT_SUB.ID_EXPEDIENTE IDEXPEDIENTE, REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB idrelexpactsub, REL_EXP_ACT_SUB.IMPORTE_PRESENTADO importepresentado, REL_EXP_ACT_SUB.IMPORTE_ADMITIDO importeadmitido, REL_EXP_ACT_SUB.SUBVENCION_CALCULADA subvencioncalculada, REL_EXP_ACT_SUB.PORCENTAJE porcentaje,  ACT_SUBVENCIONABLE.DESCRIPCION_CASTELLANO actdescripcioncastellano, ACT_SUBVENCIONABLE.DESCRIPCION_EUSKERA actdescripcioneuskera, ACT_SUBVENCIONABLE.ID_ACT_SUB actsubvencionableidactsub , ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE actsubvencionableidactsubpadre, ACT_SUBVENCIONABLE.ID_CONVOCATORIA IDCONVOCATORIA , ACT_SUBVENCIONABLE.ORDEN ORDEN, (SELECT IMPORTE FROM OTROS_INGRESOS WHERE REL_EXP_ACT_SUB.ID_REL_EXP_ACT_SUB = OTROS_INGRESOS.ID_REL_EXP_ACT_SUB AND OTROS_INGRESOS.FASE = 1) IMPORTECONCEDIDO FROM ACT_SUBVENCIONABLE LEFT JOIN REL_EXP_ACT_SUB ON REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ID_EXPEDIENTE =? WHERE (ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE = (SELECT ACT_SUBVENCIONABLE.ID_ACT_SUB FROM REL_EXP_ACT_SUB, ACT_SUBVENCIONABLE WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ID_EXPEDIENTE =?)) OR (ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ACT_SUBVENCIONABLE.ID_ACT_SUB = (SELECT ACT_SUBVENCIONABLE.ID_ACT_SUB FROM REL_EXP_ACT_SUB, ACT_SUBVENCIONABLE WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ID_EXPEDIENTE =?) AND (select count(*) from ACT_SUBVENCIONABLE where ID_ACT_SUB_PADRE = (SELECT ACT_SUBVENCIONABLE.ID_ACT_SUB FROM REL_EXP_ACT_SUB, ACT_SUBVENCIONABLE WHERE REL_EXP_ACT_SUB.ID_ACT_SUB = ACT_SUBVENCIONABLE.ID_ACT_SUB AND ACT_SUBVENCIONABLE.ID_ACT_SUB_PADRE IS NULL AND ID_EXPEDIENTE =?)) = 0)    ORDER BY ACT_SUBVENCIONABLE.ORDEN ";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedienteEMET,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente(), filterActSub.getIdExpediente(),
				filterActSub.getIdExpediente());

		return relExpActSubList;
	}

	@Override
	public List<RelExpActSub> filterPTTTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		String query = "SELECT t2.ID_EXPEDIENTE IDEXPEDIENTE,t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO, t2.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,"
				+ " t2.PORCENTAJE PORCENTAJE, t1.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA, t1.ID_ACT_SUB ActSubvencionableIDACTSUB, t1.ID_AGRUPACION IDACTSUBAGRUPACION, "
				+ " t2.OBSERVACIONES_CASTELLANO OBSERVACIONESCASTELLANO, t2.OBSERVACIONES_EUSKERA OBSERVACIONESEUSKERA, t2.INSPECCIONABLE INSPECCIONABLE, "
				+ " t2.NOTAS NOTAS, "
				+ " t1.ORDEN ORDEN ,t1.ID_ACT_SUB_PADRE IDACTSUBPADRE, t3.ID_CONTRATACION_PERSONAL IDCONTRATACIONPERSONAL, t3.NOMBRE NOMBRECP, t3.APELLIDO1 APELLIDO1CP, t3.APELLIDO2 APELLIDO2CP,"
				+ " t3.ID_SEXO IDSEXOCP, t3.PERIODO_CONTRATACION PERIODO_CONTRATACIONCP, t3.ID_MODALIDAD_CONTRATO IDMODALIDADCONTRATOCP, t3.EMPRESA_CONTRATADA EMPRESACONTRATADACP, "
				+ " t4.ID_GASTOS_TURISTICOS IDGASTOSTURISTICOS, t4.DENOMIMACION DENOMINACION, t5.ID_PRODUCTO_TURISTICO IDPRODUCTOTURISTICO, t5.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANOPT, "
				+ " t5.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERAPT,  t6.ID_PERSONA_CONTRATADA IDPERSONACONTRATADA, t6.NOMBRE NOMBREPC, t6.APELLIDO1 APELLIDO1PC, t6.APELLIDO2 APELLIDO2PC "
				+ " ,t7.ID_PERTENENCIA_REDES IDPERTENENCIAREDES, t7.DENOMINACION DENOMINACIONREDES, (SELECT t8.IMPORTE FROM OTROS_INGRESOS t8 WHERE t2.ID_REL_EXP_ACT_SUB = t8.ID_REL_EXP_ACT_SUB(+)AND t8.FASE = 1) IMPORTECONCEDIDO "
				+ " FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONTRATACIONES_PERSONAL t3, GASTOS_TURISTICOS t4, PRODUCTOS_TURISTICOS t5, PERSONAS_CONTRATADAS t6, PERTENENCIAS_REDES t7  WHERE t1.ID_CONVOCATORIA = ? "
				+ "AND t1.ID_ACT_SUB = t2.ID_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND "
				+ "t5.ID_PRODUCTO_TURISTICO(+) = t4.ID_PRODUCTO_TURISTICO AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t7.ID_REL_EXP_ACT_SUB(+) AND (t1.ID_ACT_SUB_PADRE IS NOT NULL OR (t1.ID_ACT_SUB_PADRE IS NULL "
				+ "AND t1.ID_ACT_SUB NOT IN (SELECT DISTINCT t1.ID_ACT_SUB_PADRE  FROM ACT_SUBVENCIONABLE t1  WHERE t1.ID_CONVOCATORIA = ?  AND t1.ID_ACT_SUB_PADRE IS NOT NULL))) ";

		if (LocaleContextHolder.getLocale().getLanguage().equalsIgnoreCase(Constantes.CASTELLANO)) {
			query = query
					+ " ORDER BY t1.ORDEN,NOMBRECP, APELLIDO1CP,APELLIDO2CP,NOMBREPC,APELLIDO1PC,APELLIDO2PC, DESCRIPCIONCASTELLANOPT, DENOMINACION ";
		} else {
			query = query
					+ " ORDER BY t1.ORDEN,NOMBRECP, APELLIDO1CP,APELLIDO2CP,NOMBREPC,APELLIDO1PC,APELLIDO2PC, DESCRIPCIONEUSKERAPT, DENOMINACION ";
		}

		logger.info("LocaleContextHolder.getLocale().toString(): " + LocaleContextHolder.getLocale().toString());

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedientePTT,
				filterActSub.getIdconvocatoria(), filterActSub.getIdExpediente(), filterActSub.getIdconvocatoria());

		RelExpActSub espacio = new RelExpActSub();
		RelExpActSub totales = new RelExpActSub();
		ActSubvencionable actuacionTotalEspacio = new ActSubvencionable();
		actuacionTotalEspacio.setDescripcionCastellano("");
		actuacionTotalEspacio.setDescripcionEuskera("");
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				totales.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				totales.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				totales.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				totales.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		espacio.setActSubvencionable(actuacionTotalEspacio);
		totales.setActSubvencionable(actuacionTotal);
		relExpActSubList.add(espacio);
		relExpActSubList.add(totales);

		return relExpActSubList;
	}

	@Override
	public List<RelExpActSub> filterOTCTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t1.PORCENTAJE PORCENTAJE, t3.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA, t3.ID_ACT_SUB  ActSubvencionableIDACTSUB,  t3.ID_ACT_SUB_PADRE ActSubvencionableIDACTSUBPADRE, t3.ID_CONVOCATORIA IDCONVOCATORIA ,  t3.ORDEN ORDEN FROM REL_EXP_ACT_SUB t1  RIGHT OUTER JOIN  ACT_SUBVENCIONABLE t3   ON t1.ID_ACT_SUB = t3.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? WHERE t3.ID_CONVOCATORIA =? ORDER BY t3.ORDEN";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpediente,
				filterActSub.getIdExpediente(), filterActSub.getIdconvocatoria());

		RelExpActSub espacio = new RelExpActSub();
		RelExpActSub totales = new RelExpActSub();
		ActSubvencionable actuacionTotalEspacio = new ActSubvencionable();
		actuacionTotalEspacio.setDescripcionCastellano("");
		actuacionTotalEspacio.setDescripcionEuskera("");
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				totales.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				totales.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				totales.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				totales.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		espacio.setActSubvencionable(actuacionTotalEspacio);
		totales.setActSubvencionable(actuacionTotal);
		relExpActSubList.add(espacio);
		relExpActSubList.add(totales);

		return relExpActSubList;
	}

	@Override
	public List<RelExpActSub> filterMECTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		String query = "SELECT t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, t2.DESCRIPCION DESFACTURA, t2.IMPORTE IMPORTEPRESENTADO, t2.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t1.PORCENTAJE PORCENTAJE, t3.DESCRIPCION_CASTELLANO ActDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA ActDESCRIPCIONEUSKERA, t3.ID_ACT_SUB ActSubvencionableIDACTSUB, t3.ID_ACT_SUB_PADRE ActSubvencionableIDACTSUBPADRE, t3.ID_CONVOCATORIA IDCONVOCATORIA, t3.ORDEN ORDEN FROM REL_EXP_ACT_SUB t1,FACTURAS t2,ACT_SUBVENCIONABLE t3 WHERE t3.ID_CONVOCATORIA = ? AND t1.ID_REL_EXP_ACT_SUB = t2.ID_REL_EXP_ACT_SUB AND t1.ID_ACT_SUB = t3.ID_ACT_SUB(+) AND t1.ID_EXPEDIENTE = ? ORDER BY t3.ORDEN";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorExpedienteMEC,
				filterActSub.getIdconvocatoria(), filterActSub.getIdExpediente());

		RelExpActSub espacio = new RelExpActSub();
		RelExpActSub totales = new RelExpActSub();
		ActSubvencionable actuacionTotalEspacio = new ActSubvencionable();
		actuacionTotalEspacio.setDescripcionCastellano("");
		actuacionTotalEspacio.setDescripcionEuskera("");
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");
		Facturas facturas = new Facturas();

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				totales.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				totales.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				totales.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				totales.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		espacio.setActSubvencionable(actuacionTotalEspacio);
		espacio.setFactura(facturas);
		totales.setActSubvencionable(actuacionTotal);
		totales.setFactura(facturas);
		relExpActSubList.add(espacio);
		relExpActSubList.add(totales);

		return relExpActSubList;

	}

	@Override
	public List<RelExpActSub> filterJustificacionTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		StringBuilder query = new StringBuilder(
				"SELECT T1.ID_EXPEDIENTE IDEXPEDIENTE, T1.PARAMETRO FOLDERNUMBER, T2.ID_ACT_SUB IDACTSUB,  T1.VALOR IDRELEXPACTSUB, REPLACE(T1.DESCRIPCION_CASTELLANO, '[salto]', '') DESCRIPCIONES, REPLACE(T1.DESCRIPCION_EUSKERA, '[salto]', '') DESCRIPCIONEU,  T2.IMPORTE_PRESENTADO IMPORTEPRESENTADO, T2.IMPORTE_ADMITIDO IMPORTEADMITIDO, T2.IMPORTE_JUS_PRESENTADO IMPORTEJUSPRESENTADO, T2.IMPORTE_JUS_ADMITIDO IMPORTEJUSADMITIDO, T2.PORCENTAJE_JUS PORCENTAJEJUS, (SELECT SUM(IMPORTE) FROM OTROS_INGRESOS T3 WHERE T3.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T3.FASE = 2) IMPORTE FROM AB61.V_T_ACT_SUBVENCIONABLES T1 INNER JOIN REL_EXP_ACT_SUB T2 ON T2.ID_EXPEDIENTE = T1.ID_EXPEDIENTE AND T2.ID_REL_EXP_ACT_SUB = T1.VALOR WHERE 1=1 AND t1.ID_EXPEDIENTE = ? ORDER BY ID_ACT_SUB");

		return (List<RelExpActSub>) this.jdbcTemplate.query(query.toString(), this.rwMapJustificacion,
				filterActSub.getIdExpediente());
	}

	/**
	 * Sacamos la tabla de act subencionables por expediente y sus totales
	 *
	 * @param Integer
	 *            idExpediente
	 * @param Integer
	 *            idConvocatoria
	 * @return List<RelExpActSub>
	 */
	@Transactional(readOnly = true)
	public List<RelExpActSub> findRelEXpActSubPorExpedienteEMCO(Integer idExpediente) {

		String query = "SELECT * FROM (SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,T1.ID_EXPEDIENTE IDEXPEDIENTE,T1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,T1.PORCENTAJE PORCENTAJE,T2.ID_ACT_AYUNTAMIENTO IDACTAYUNTAMIENTO,NULL AS IDACTASOCIACION,T2.TITULO TITULO,T1.IMPORTE_PRESENTADO IMPORTETOTAL,T1.IMPORTE_ADMITIDO IMPORTEADMITIDO,T3.ID_ACT_SUB IDACTSUB,T3.ID_ACT_SUB_PADRE IDACTSUBPADRE,T3.ID_CONVOCATORIA IDCONVOCATORIA,T3.ORDEN ORDEN,(SELECT T4.DESCRIPCION_CASTELLANO FROM ACT_SUBVENCIONABLE T4 WHERE T4.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOCASTELLANO,(SELECT T5.DESCRIPCION_EUSKERA FROM ACT_SUBVENCIONABLE T5 WHERE T5.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOEUSKERA,(SELECT ID_AGRUPACION FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = T3.ID_ACT_SUB_PADRE) AS ACTSUBPADREAGRUPACION FROM REL_EXP_ACT_SUB T1, REL_ACT_AYUNTAMIENTO T2, ACT_SUBVENCIONABLE T3 WHERE ID_EXPEDIENTE = ? AND T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T1.ID_ACT_SUB = T3.ID_ACT_SUB UNION SELECT T1.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,T1.ID_EXPEDIENTE IDEXPEDIENTE,T1.SUBVENCION_CALCULADA SUBVENCIONCALCULADA,T1.PORCENTAJE PORCENTAJE,NULL AS IDACTAYUNTAMIENTO,NULL AS IDACTASOCIACION,NULL AS TITULO,T1.IMPORTE_PRESENTADO IMPORTETOTAL,T1.IMPORTE_ADMITIDO IMPORTEADMITIDO,T3.ID_ACT_SUB IDACTSUB,T3.ID_ACT_SUB_PADRE IDACTSUBPADRE,T3.ID_CONVOCATORIA IDCONVOCATORIA,T3.ORDEN ORDEN,(SELECT T4.DESCRIPCION_CASTELLANO FROM ACT_SUBVENCIONABLE T4 WHERE T4.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOCASTELLANO,(SELECT T5.DESCRIPCION_EUSKERA FROM ACT_SUBVENCIONABLE T5 WHERE T5.ID_ACT_SUB = T1.ID_ACT_SUB) AS TIPOEUSKERA,(SELECT ID_AGRUPACION FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB = T3.ID_ACT_SUB_PADRE) AS ACTSUBPADREAGRUPACION FROM REL_EXP_ACT_SUB T1, ACT_SUBVENCIONABLE T3 WHERE ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB = T3.ID_ACT_SUB AND (SELECT COUNT(1) FROM REL_ACT_AYUNTAMIENTO T6 WHERE T6.ID_REL_EXP_ACT_SUB = T1.ID_REL_EXP_ACT_SUB) = 0 AND T3.ID_ACT_SUB_PADRE IS NOT NULL AND (SELECT COUNT(1) FROM ACT_SUBVENCIONABLE T7 WHERE T7.ID_ACT_SUB_PADRE = T1.ID_ACT_SUB) = 0) ORDER BY ORDEN,TITULO";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorEMCO, idExpediente,
				idExpediente);

		return relExpActSubList;
	}

	@Override
	public List<RelExpActSub> importesPorExento(Integer idExpediente, Integer exento) {

		String query = null;

		if (exento == 1) {
			query = "SELECT T2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, SUM(T2.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, T1.ID_ACT_SUB IDACTSUB FROM REL_EXP_ACT_SUB T1, CONCEPTOS T2 WHERE T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T1.ID_EXPEDIENTE = ? GROUP BY T2.ID_REL_EXP_ACT_SUB, T1.ID_ACT_SUB";
			return (List<RelExpActSub>) this.jdbcTemplate.query(query, this.rwMapImportesPorExentoSi, idExpediente);
		} else {
			query = "SELECT T2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB, SUM(T2.IMPORTE_SIN_IVA) IMPORTESINIVA, T1.ID_ACT_SUB IDACTSUB FROM REL_EXP_ACT_SUB T1, CONCEPTOS T2 WHERE T1.ID_REL_EXP_ACT_SUB = T2.ID_REL_EXP_ACT_SUB AND T1.ID_EXPEDIENTE = ? GROUP BY T2.ID_REL_EXP_ACT_SUB, T1.ID_ACT_SUB";
			return (List<RelExpActSub>) this.jdbcTemplate.query(query, this.rwMapImportesPorExentoNo, idExpediente);
		}
	}

	@Override
	public void updateImportesPorExento(RelExpActSub relexpactsub) {
		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ? WHERE ID_REL_EXP_ACT_SUB = ?";

		this.jdbcTemplate.update(query, relexpactsub.getImportePresentado(), relexpactsub.getIdRelExpActSub());
	}

	@Override
	public void updateImportesPadre(RelExpActSub relExpActSubPadre, BigDecimal presentadoTotal) {

		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ? WHERE ID_REL_EXP_ACT_SUB = ?";
		this.jdbcTemplate.update(query, presentadoTotal, relExpActSubPadre.getIdRelExpActSub());
	}

	@Override
	public void updateImportesProyecto(BigDecimal presentadoTotal, Integer idExpediente) {
		String query = "UPDATE DATOS_PROYECTO SET IMPORTE_PRESENTADO = ? WHERE ID_EXPEDIENTE= ?";
		this.jdbcTemplate.update(query, presentadoTotal, idExpediente);
	}

	@Override
	public void updateRelExpActSubEmpreEMCO(Integer idRelacion, Integer idActSubPadre, RelExpActSub relExpActSub,
			Integer idExpediente) {

		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ?, IMPORTE_ADMITIDO=? WHERE ID_REL_EXP_ACT_SUB = ?";
		this.jdbcTemplate.update(query, relExpActSub.getImportePresentado(), relExpActSub.getImporteAdmitido(),
				idRelacion);
	}

	@Override
	public RelExpActSub sumaImportesFacturasEMCO(Integer idExpediente, Integer idActSubPadre) {
		String query = "SELECT SUM(T1.IMPORTE_PRESENTADO) AS SUMAIMPORTES, SUM(T1.IMPORTE_ADMITIDO) AS IMPORTEADMITIDO FROM REL_EXP_ACT_SUB T1, ACT_SUBVENCIONABLE T2 WHERE T1.ID_ACT_SUB = T2.ID_ACT_SUB AND T1.ID_EXPEDIENTE = ? AND T1.ID_ACT_SUB <> ? AND T2.ID_ACT_SUB_PADRE <> ?";

		List<RelExpActSub> listaSuma = this.jdbcTemplate.query(query, this.rwSumaImportesFacturasEMCO, idExpediente,
				idActSubPadre, idActSubPadre);

		return (RelExpActSub) DataAccessUtils.uniqueResult(listaSuma);

	}

	@Override
	public void updateRelExpActSubEmprePadreEMCO(Integer idActSubPadre, BigDecimal sumaImporteEMCO,
			Integer idExpediente) {
		String query = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ? WHERE ID_EXPEDIENTE= ? AND ID_ACT_SUB = ?";
		this.jdbcTemplate.update(query, sumaImporteEMCO, idExpediente, idActSubPadre);
	}

	@Override
	public Integer findRelExpActSubEmprePadreEMCO(Integer idActSubHijo) {
		String query = "SELECT ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB= ?";

		return this.jdbcTemplate.queryForInt(query, idActSubHijo);
	}

	@Override
	public void updateDatosProyectoEMCO(Integer idExpediente, BigDecimal sumaImporteEMCO) {
		String query = "UPDATE DATOS_PROYECTO SET IMPORTE_PRESENTADO = ? WHERE ID_EXPEDIENTE= ?";
		this.jdbcTemplate.update(query, sumaImporteEMCO, idExpediente);
	}

	@Override
	public void updateRelExpActSubPadreEMCO(Integer idRelacion, Integer idActSubHijo, Integer idExpediente,
			RelExpActSub relExpActSub) {
		String query2 = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ?, IMPORTE_ADMITIDO=? WHERE ID_EXPEDIENTE= ? AND ID_ACT_SUB = ?";
		this.jdbcTemplate.update(query2, relExpActSub.getImportePresentado(), relExpActSub.getImporteAdmitido(),
				idExpediente, idActSubHijo);
	}

	@Override
	public Integer findNuevoIdActSubHijo(Integer idRelacion) {
		String query = "SELECT ID_ACT_SUB_PADRE FROM REL_EXP_ACT_SUB t1, ACT_SUBVENCIONABLE t2 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND T1.ID_REL_EXP_ACT_SUB = ?";
		return this.jdbcTemplate.queryForInt(query, idRelacion);
	}

	@Override
	public void updateRelExpActSubAbueloEMCO(EstudioTecnico estudioTecnico, Integer idActSubPadre) {
		String query2 = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_PRESENTADO = ?, IMPORTE_ADMITIDO=? WHERE ID_EXPEDIENTE= ? AND ID_ACT_SUB = ?";
		this.jdbcTemplate.update(query2, estudioTecnico.getImportePresentado(), estudioTecnico.getImporteAdmitido(),
				estudioTecnico.getIdExpediente(), idActSubPadre);

	}

	@Override
	public Boolean existeRelacionPadre(RelExpActSub relExpActSubHijoNew) {

		String query = "SELECT COUNT(T1.ID_REL_EXP_ACT_SUB) IDRELEXPACTSUB FROM REL_EXP_ACT_SUB T1 WHERE T1.ID_ACT_SUB = (SELECT T2.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE T2 WHERE  T2.ID_ACT_SUB =?) AND ID_EXPEDIENTE = ?";

		int contador = this.jdbcTemplate.queryForInt(query, relExpActSubHijoNew.getActSubvencionable().getIdActSub(),
				relExpActSubHijoNew.getIdExpediente());

		if (contador != 0) {
			return true;
		} else {
			return false;
		}

	}

	@Override
	public Integer findRelExpActSubEmpreHijoEMCO(Integer idActSub) {
		String query = "SELECT ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB= ?";

		return this.jdbcTemplate.queryForInt(query, idActSub);
	}

	@Override
	public Integer findIdCriterio(Integer idRelacion, Integer idExpediente) {
		String query = "SELECT ID_ACT_SUB FROM REL_EXP_ACT_SUB WHERE ID_EXPEDIENTE = ? AND ID_REL_EXP_ACT_SUB = ?";

		return this.jdbcTemplate.queryForInt(query, idExpediente, idRelacion);
	}

	@Override
	public void updateRelExpActSubAdmitidoPadreEMCO(Integer idRelacion, Integer idActSubHijo, Integer idExpediente,
			RelExpActSub relExpActSub) {
		String query2 = "UPDATE REL_EXP_ACT_SUB SET IMPORTE_ADMITIDO=? WHERE ID_EXPEDIENTE= ? AND ID_ACT_SUB = ?";
		this.jdbcTemplate.update(query2, relExpActSub.getImporteAdmitido(), idExpediente, idActSubHijo);
	}

	@Override
	public Integer existenMasFacturas(Integer idActSubHijo, Integer idExpediente) {
		String query = "SELECT COUNT (t1.ID_REL_EXP_ACT_SUB) FROM REL_EXP_ACT_SUB t1, ACT_SUBVENCIONABLE t2 WHERE T1.ID_ACT_SUB = T2.ID_ACT_SUB AND t1.ID_EXPEDIENTE = ? AND t2.ID_ACT_SUB_PADRE = ?";
		return this.jdbcTemplate.queryForInt(query, idExpediente, idActSubHijo);
	}

	@Override
	public void removeRelExpActSubPadreEMCO(Integer idActSubHijo, Integer idExpediente) {
		String query = "DELETE REL_EXP_ACT_SUB WHERE ID_ACT_SUB= ? AND ID_EXPEDIENTE = ? AND (SELECT COUNT(1) FROM REL_EXP_ACT_SUB WHERE ID_ACT_SUB IN (SELECT ID_ACT_SUB FROM ACT_SUBVENCIONABLE WHERE ID_ACT_SUB_PADRE = ?) AND ID_EXPEDIENTE = ?) = 0";
		this.jdbcTemplate.update(query, idActSubHijo, idExpediente, idActSubHijo, idExpediente);
	}

	@Override
	public List<RelExpActSub> filterEMCOTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto, boolean b,
			Integer idExpediente) {
		String query = "SELECT t1.ORDEN ORDEN, t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.IMPORTE_ADMITIDO IMPORTEADMITIDOACT, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADOACT, t2.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t2.PORCENTAJE PORCENTAJE, t4.TITULO TITULOACTAYUNTAMIENTO FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, REL_ACT_AYUNTAMIENTO t4 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN (SELECT t6.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE t6, EXPEDIENTES t7, CONVOCATORIAS t8 WHERE t6.ID_ACT_SUB_PADRE = t1.ID_ACT_SUB AND t2.ID_EXPEDIENTE = t7.ID_EXPEDIENTE AND t7.ID_PROCEDIMIENTO = t8.ID_PROCEDIMIENTO AND NOT t8.ID_TIPO_AYUDA = 8) AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+)";

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorEMCOExcel,
				idExpediente);

		RelExpActSub espacio = new RelExpActSub();
		RelExpActSub totales = new RelExpActSub();
		ActSubvencionable actuacionTotalEspacio = new ActSubvencionable();
		actuacionTotalEspacio.setDescripcionCastellano("");
		actuacionTotalEspacio.setDescripcionEuskera("");
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");
		Conceptos conceptos = new Conceptos();

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				totales.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				totales.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				totales.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				totales.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		espacio.setActSubvencionable(actuacionTotalEspacio);
		espacio.setConceptos(conceptos);
		totales.setActSubvencionable(actuacionTotal);
		totales.setConceptos(conceptos);
		relExpActSubList.add(espacio);
		relExpActSubList.add(totales);

		return relExpActSubList;
	}

	@Override
	public List<MarcarInspeccionableAct> filterConConceptosPTTTer(RelExpActSub filterActSub,
			JQGridRequestDto jqGridRequestDto, boolean b) {
		String query = "SELECT t1.ORDEN ORDEN, t1.ID_ACT_SUB IDACTSUB, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t2.ENVIADO_INSPECCIONAR ENVIADOINSPACT, t2.INSPECCIONABLE INSPECCIONABLEACT, t2.IMPORTE_ADMITIDO IMPORTEADMITIDOACT, t2.IMPORTE_PRESENTADO IMPORTEPRESENTADOACT, (SELECT t10.IMPORTE FROM OTROS_INGRESOS t10 WHERE t2.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1) IMPORTECONCEDIDO, t2.SUBVENCION_CALCULADA SUBCALCULADA, t2.PORCENTAJE PORCENTAJE, t2. OBSERVACIONES_CASTELLANO OBCASTELLANOACT, t2. OBSERVACIONES_EUSKERA OBEUSKERAACT, t2.ID_REL_EXP_ACT_SUB IDRELEXPACTSUB,  t3.ID_CONCEPTO IDCONCEPTO, t3.ENVIADO_INSPECCIONAR ENVIADOINSPCON, t3.INSPECCIONABLE INSPECCIONABLECON, t3.CONCEPTO CONCEPTOS, t3.IMPORTE_ADMITIDO IMPORTEADMITIDOCON, t3.IMPORTE_PRESENTADO IMPORTEPRESENTADOCON, t3.OBSERVACIONES_CASTELLANO OBCASTELLANOCON, t3.OBSERVACIONES_EUSKERA OBEUSKERACON, t9.TITULO TITULO, t5.NOMBRE NOMBRE,  t5.APELLIDO1 APELLIDO1,  t5.APELLIDO2 APELLIDO2,  t6.NOMBRE NOMBREPC,  t6.APELLIDO1 APELLIDO1PC,  t6.APELLIDO2 APELLIDO2PC, t8.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANOPT, t8.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERAPT FROM ACT_SUBVENCIONABLE t1, REL_EXP_ACT_SUB t2, CONCEPTOS t3, ACT_AYUNTAMIENTO t4, CONTRATACIONES_PERSONAL t5, PERSONAS_CONTRATADAS t6, GASTOS_TURISTICOS t7, PRODUCTOS_TURISTICOS t8, ACT_ASOCIACION t9 WHERE t1.ID_ACT_SUB = t2.ID_ACT_SUB AND t2.ID_REL_EXP_ACT_SUB = t3.ID_REL_EXP_ACT_SUB(+) AND t2.ID_EXPEDIENTE = ? AND t1.ID_ACT_SUB NOT IN (SELECT t6.ID_ACT_SUB_PADRE FROM ACT_SUBVENCIONABLE t6, EXPEDIENTES t7, CONVOCATORIAS t8 WHERE t6.ID_ACT_SUB_PADRE = t1.ID_ACT_SUB AND t2.ID_EXPEDIENTE = t7.ID_EXPEDIENTE AND t7.ID_PROCEDIMIENTO = t8.ID_PROCEDIMIENTO AND NOT t8.ID_TIPO_AYUDA = "
				+ Constantes.TIPO_AYUDA_CTP
				+ ") AND t2.ID_REL_EXP_ACT_SUB = t4.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t5.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t6.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t9.ID_REL_EXP_ACT_SUB(+) AND t2.ID_REL_EXP_ACT_SUB = t7.ID_REL_EXP_ACT_SUB(+) AND t8.ID_PRODUCTO_TURISTICO(+) = t7.ID_PRODUCTO_TURISTICO ORDER BY t1.ORDEN ";
		List<MarcarInspeccionableAct> actSubvencionableList = this.jdbcTemplate.query(query,
				this.rwMapMarcarInspeccionablePTT, filterActSub.getIdExpediente());

		MarcarInspeccionableAct espacio = new MarcarInspeccionableAct();
		MarcarInspeccionableAct totales = new MarcarInspeccionableAct();
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		Conceptos conceptosTotal = new Conceptos();
		RelExpActSub relExpActSub = new RelExpActSub();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				conceptosTotal.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				conceptosTotal.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				relExpActSub.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				relExpActSub.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		totales.setConceptos(conceptosTotal);
		totales.setRelExpActSub(relExpActSub);

		totales.setActSubs(actuacionTotal);

		actSubvencionableList.add(espacio);
		actSubvencionableList.add(totales);

		return actSubvencionableList;
	}

	@Override
	public List<RelExpActSub> filterEMCOEmpreTer(RelExpActSub filterActSub, JQGridRequestDto jqGridRequestDto,
			boolean b, Integer idExpediente) {
		String query = "SELECT t2.ORDEN ORDEN, t2.ID_ACT_SUB IDACTSUB, t2.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t2.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.ID_FACTURA, t1.FECHA_FACTURA, t1.NUMERO_FACTURA, t1.DESCRIPCION, t1.PROVEEDOR, t1.IMPORTE, t1.IMPORTE_ADMITIDO, t1.INSPECCIONABLE, t1.OBSERVACIONES_CASTELLANO, t1.OBSERVACIONES_EUSKERA, t1.ENVIADO_INSPECCIONAR, t3.SUBVENCION_CALCULADA SUBVENCIONCALCULADA, t3.PORCENTAJE PORCENTAJE FROM FACTURAS t1, ACT_SUBVENCIONABLE t2, REL_EXP_ACT_SUB t3 WHERE t2.ID_ACT_SUB = t3.ID_ACT_SUB AND t3.ID_REL_EXP_ACT_SUB = t1.ID_REL_EXP_ACT_SUB(+) AND t3.ID_EXPEDIENTE =  ? AND t2.ID_ACT_SUB_PADRE IS NOT NULL AND t2.ID_ACT_SUB_PADRE <> "
				+ Constantes.ID_AGRUPACION_EMCO_Emprendimiento;

		List<RelExpActSub> relExpActSubList = this.jdbcTemplate.query(query, this.rwMapRelActSubPorEMCOEmpreExcel,
				idExpediente);

		RelExpActSub espacio = new RelExpActSub();
		RelExpActSub totales = new RelExpActSub();
		ActSubvencionable actuacionTotalEspacio = new ActSubvencionable();
		actuacionTotalEspacio.setDescripcionCastellano("");
		actuacionTotalEspacio.setDescripcionEuskera("");
		ActSubvencionable actuacionTotal = new ActSubvencionable();
		actuacionTotal.setDescripcionCastellano("Total");
		actuacionTotal.setDescripcionEuskera("Guztira");
		Facturas factura = new Facturas();

		String importesTotales = "SELECT t1.IMPORTE_PRESENTADO IMPORTEPRESENTADO, t1.IMPORTE_ADMITIDO IMPORTEADMITIDO, t1.SUBVENCION_CALCULADA SUBCALCULADA, (SELECT SUM(t10.IMPORTE) FROM OTROS_INGRESOS t10, REL_EXP_ACT_SUB t9 WHERE t9.ID_REL_EXP_ACT_SUB = t10.ID_REL_EXP_ACT_SUB(+) AND t10.FASE = 1 AND t9.ID_EXPEDIENTE   = ?) IMPORTECONCEDIDO FROM DATOS_PROYECTO t1 WHERE t1.ID_EXPEDIENTE   = ?";

		List<Conceptos> conceptosList = this.jdbcTemplate.query(importesTotales, this.rwMapSumConceptosPorRelExpActSub,
				filterActSub.getIdExpediente(), filterActSub.getIdExpediente());

		if (conceptosList != null && conceptosList.get(0) != null) {
			if (conceptosList.get(0).getImportePresentado() != null) {
				totales.setImportePresentado(conceptosList.get(0).getImportePresentado());
			}
			if (conceptosList.get(0).getImporteAdmitido() != null) {
				totales.setImporteAdmitido(conceptosList.get(0).getImporteAdmitido());
			}
			if (conceptosList.get(0).getAyudaSubvencionada() != null) {
				totales.setSubvencionCalculada(conceptosList.get(0).getAyudaSubvencionada());
			}
			if (conceptosList.get(0).getImporteConcedido() != null) {
				totales.setAyudaConcedida(conceptosList.get(0).getImporteConcedido());
			}
		}

		espacio.setActSubvencionable(actuacionTotalEspacio);
		espacio.setFactura(factura);
		totales.setActSubvencionable(actuacionTotal);
		totales.setFactura(factura);
		relExpActSubList.add(espacio);
		relExpActSubList.add(totales);

		return relExpActSubList;
	}

	@Override
	public void eliminarImporteCalculado(Integer idExpediente) {
		String query = "UPDATE DATOS_PROYECTO SET IMPORTE_JUS_CALCULADO = ? WHERE ID_EXPEDIENTE = ?";
		this.jdbcTemplate.update(query, null, idExpediente);
	}

	@Override
	public RelExpActSub sumImportesConceptos(Integer idExpediente) {
		String query = "SELECT SUM(t1.IMPORTE_PRESENTADO) IMPORTEPRESENTADO, SUM(t1.IMPORTE_ADMITIDO) IMPORTEADMITIDO FROM REL_EXP_ACT_SUB t1 WHERE t1.ID_EXPEDIENTE = ?";

		List<RelExpActSub> relexpactsubList = this.jdbcTemplate.query(query, this.rwMapTotalesEMCO, idExpediente);
		return (RelExpActSub) DataAccessUtils.uniqueResult(relexpactsubList);
	}

}
